(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   4049707,      83740]
NotebookOptionsPosition[   4040953,      83456]
NotebookOutlinePosition[   4042089,      83502]
CellTagsIndexPosition[   4041846,      83491]
WindowFrame->Normal
ContainsDynamic->True *)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Fast edge colouring of graphs with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"]
}], "Title",
 CellChangeTimes->{{3.400134975640625*^9, 3.400135001828125*^9}, {
  3.400135090171875*^9, 3.40013510665625*^9}}],

Cell["Programming codes", "Subtitle",
 CellChangeTimes->{{3.400135095265625*^9, 3.400135109234375*^9}, {
  3.400137945828125*^9, 3.400137954109375*^9}}],

Cell[TextData[StyleBox["\[CapitalAAcute]gnes T\[OAcute]th\nBudapest \
University of Technology and Economics, mathematician student,\n\
tothagi@math.bme.hu  ",
 FontSize->24]], "Text",
 CellChangeTimes->{{3.400135114140625*^9, 3.40013515334375*^9}},
 FontFamily->"Times New Roman",
 FontSize->18,
 FontSlant->"Italic"],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{3.400135265671875*^9}],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Combinatorica`\>\"", "]"}]], "Input"],

Cell[CellGroupData[{

Cell["Colouring the vertices of the linegraph", "Section",
 CellChangeTimes->{{3.400137980859375*^9, 3.4001379890625*^9}, 
   3.400138053328125*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"r", "=", 
   RowBox[{"RandomGraph", "[", 
    RowBox[{"20", ",", ".4"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.400138017390625*^9, 3.400138031015625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EdgeColoring", "[", "r", "]"}]], "Input",
 CellChangeTimes->{{3.4001379925*^9, 3.4001380359375*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "5", ",", "4", ",", "7", ",", "2", ",", "4", ",", "5", ",", "7", 
   ",", "2", ",", "3", ",", "6", ",", "9", ",", "3", ",", "6", ",", "5", ",", 
   "2", ",", "6", ",", "3", ",", "4", ",", "8", ",", "1", ",", "13", ",", "7",
    ",", "4", ",", "2", ",", "3", ",", "9", ",", "1", ",", "5", ",", "1", ",",
    "7", ",", "3", ",", "9", ",", "10", ",", "6", ",", "2", ",", "2", ",", 
   "1", ",", "7", ",", "9", ",", "10", ",", "4", ",", "1", ",", "11", ",", 
   "3", ",", "5", ",", "9", ",", "10", ",", "11", ",", "2", ",", "4", ",", 
   "12", ",", "1", ",", "6", ",", "8", ",", "13", ",", "6", ",", "1", ",", 
   "3", ",", "10", ",", "8", ",", "5", ",", "7", ",", "7", ",", "2", ",", "1",
    ",", "4", ",", "5", ",", "3", ",", "8", ",", "3", ",", "11", ",", "7", 
   ",", "5", ",", "2"}], "}"}]], "Output",
 CellChangeTimes->{3.400684752046875*^9, 3.400829854484375*^9, 
  3.400847342265625*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Algorithm of Misra and Gries", "Section",
 CellChangeTimes->{{3.399829582078125*^9, 3.399829608890625*^9}},
 CellTags->"vizing"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Vizing", "::", "usage"}], "=", 
   "\"\<Vizing[G_]: Uses Vizing's algorithm to colour the edges of the graph \
G.\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Vizing", "[", "G_Graph", "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "VG", ",", "MG", ",", "edgesG", ",", "delta", ",", "colourlist", ",", 
      "h", ",", "i", ",", "v", ",", "ulist", ",", "utemp", ",", "elist", ",", 
      "etemp", ",", "hlist", ",", "htemp", ",", "count", ",", 
      "\[IndentingNewLine]", "hend", ",", "forward", ",", "sszm", ",", "c1", 
      ",", "c2", ",", "G2", ",", "ua", ",", "ub", ",", "cc", ",", "uc", ",", 
      "vertices2", ",", "edges2"}], "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"VG", "=", 
      RowBox[{"V", "[", "G", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"MG", "=", 
      RowBox[{"M", "[", "G", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"edgesG", "=", 
      RowBox[{"Edges", "[", "G", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"delta", "=", 
      RowBox[{"Max", "[", 
       RowBox[{"Degrees", "[", "G", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"colourlist", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "MG"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"h", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"delta", "+", "1"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "VG"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "\[LessEqual]", "MG"}], ",", 
       RowBox[{"i", "++"}], ",", 
       StyleBox["\[IndentingNewLine]",
        FontColor->GrayLevel[0.500008]], 
       RowBox[{
        RowBox[{"v", "=", 
         RowBox[{"edgesG", "\[LeftDoubleBracket]", 
          RowBox[{"i", ",", "1"}], "\[RightDoubleBracket]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"ulist", "=", 
         RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"utemp", "=", 
         RowBox[{"edgesG", "\[LeftDoubleBracket]", 
          RowBox[{"i", ",", "2"}], "\[RightDoubleBracket]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"elist", "=", 
         RowBox[{"{", "i", "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"etemp", "=", "0"}], ";", "\[IndentingNewLine]", 
        RowBox[{"hlist", "=", 
         RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"htemp", "=", "0"}], ";", "\[IndentingNewLine]", 
        RowBox[{"count", "=", "1"}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"While", "[", " ", 
         RowBox[{"(*", 
          RowBox[{"building", " ", "the", " ", "fan"}], "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Intersection", "[", 
              RowBox[{
               RowBox[{
               "h", "\[LeftDoubleBracket]", "v", "\[RightDoubleBracket]"}], 
               ",", 
               RowBox[{
               "h", "\[LeftDoubleBracket]", "utemp", 
                "\[RightDoubleBracket]"}]}], "]"}], "\[Equal]", 
             RowBox[{"{", "}"}]}], ")"}], "&&", 
           RowBox[{"(", 
            RowBox[{"!", 
             RowBox[{"MemberQ", "[", 
              RowBox[{"ulist", ",", "utemp"}], "]"}]}], ")"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"AppendTo", "[", 
            RowBox[{"ulist", ",", "utemp"}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"htemp", "=", 
            RowBox[{"h", "\[LeftDoubleBracket]", 
             RowBox[{"utemp", ",", "1"}], "\[RightDoubleBracket]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"hlist", ",", "htemp"}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"etemp", "=", 
            RowBox[{
             RowBox[{"Select", "[", 
              RowBox[{
               RowBox[{"Range", "[", 
                RowBox[{"i", "-", "1"}], "]"}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                  "colourlist", "\[LeftDoubleBracket]", "#", 
                   "\[RightDoubleBracket]"}], "\[Equal]", "htemp"}], "&&", 
                 RowBox[{"MemberQ", "[", 
                  RowBox[{
                   RowBox[{
                   "edgesG", "\[LeftDoubleBracket]", "#", 
                    "\[RightDoubleBracket]"}], ",", "v"}], "]"}]}], "&"}]}], 
              "]"}], "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}],
            ";", "\[IndentingNewLine]", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"elist", ",", "etemp"}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"utemp", "=", 
            RowBox[{
             RowBox[{"Select", "[", 
              RowBox[{
               RowBox[{
               "edgesG", "\[LeftDoubleBracket]", "etemp", 
                "\[RightDoubleBracket]"}], ",", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"#", "\[NotEqual]", "v"}], ")"}], "&"}]}], "]"}], 
             "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"count", "++"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
        ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"If", "[", "\[IndentingNewLine]", 
         StyleBox[
          RowBox[{"(*", 
           RowBox[{"rotating", " ", "the", " ", "fan"}], "*)"}],
          FontColor->GrayLevel[0.500008]], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"Intersection", "[", 
            RowBox[{
             RowBox[{
             "h", "\[LeftDoubleBracket]", "v", "\[RightDoubleBracket]"}], ",",
              
             RowBox[{
             "h", "\[LeftDoubleBracket]", "utemp", 
              "\[RightDoubleBracket]"}]}], "]"}], "\[NotEqual]", 
           RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          StyleBox[
           RowBox[{"(*", 
            RowBox[{
            "recolor", " ", "the", " ", "edge", " ", "and", " ", "update", 
             " ", "the", " ", "lists", " ", "of", " ", "missing", " ", 
             "colours"}], "*)"}],
           FontColor->GrayLevel[0.500008]], "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"AppendTo", "[", 
            RowBox[{"ulist", ",", "utemp"}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"hend", "=", 
            RowBox[{
             RowBox[{"Intersection", "[", 
              RowBox[{
               RowBox[{
               "h", "\[LeftDoubleBracket]", "v", "\[RightDoubleBracket]"}], 
               ",", 
               RowBox[{
               "h", "\[LeftDoubleBracket]", "utemp", 
                "\[RightDoubleBracket]"}]}], "]"}], "\[LeftDoubleBracket]", 
             "1", "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"hlist", ",", "hend"}], "]"}], ";", "\[IndentingNewLine]",
            
           RowBox[{"forward", "=", 
            RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
           "\[IndentingNewLine]", 
           RowBox[{"Map", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"colourlist", "\[LeftDoubleBracket]", 
                  RowBox[{
                  "elist", "\[LeftDoubleBracket]", "#", 
                   "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}], "=", 
                 
                 RowBox[{
                 "hlist", "\[LeftDoubleBracket]", "#", 
                  "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"h", "\[LeftDoubleBracket]", 
                  RowBox[{
                  "ulist", "\[LeftDoubleBracket]", "#", 
                   "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}], "=", 
                 
                 RowBox[{"Union", "[", 
                  RowBox[{
                   RowBox[{"DeleteCases", "[", 
                    RowBox[{
                    RowBox[{"h", "\[LeftDoubleBracket]", 
                    RowBox[{
                    "ulist", "\[LeftDoubleBracket]", "#", 
                    "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}], ",",
                     
                    RowBox[{
                    "hlist", "\[LeftDoubleBracket]", "#", 
                    "\[RightDoubleBracket]"}]}], "]"}], ",", "forward"}], 
                  "]"}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"forward", "=", 
                 RowBox[{"{", 
                  RowBox[{
                  "hlist", "\[LeftDoubleBracket]", "#", 
                   "\[RightDoubleBracket]"}], "}"}]}]}], ")"}], "&"}], ",", 
             RowBox[{"Range", "[", "count", "]"}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
            "h", "\[LeftDoubleBracket]", "v", "\[RightDoubleBracket]"}], "=", 
            
            RowBox[{"DeleteCases", "[", 
             RowBox[{
              RowBox[{
              "h", "\[LeftDoubleBracket]", "v", "\[RightDoubleBracket]"}], 
              ",", "hend"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
          "\[IndentingNewLine]", ",", 
          StyleBox[
           RowBox[{"(*", 
            RowBox[{"the", " ", "prolematic", " ", "case"}], "*)"}],
           FontColor->GrayLevel[0.500008]], "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"sszm", "=", 
            RowBox[{"Select", "[", 
             RowBox[{
              RowBox[{"Range", "[", "MG", "]"}], ",", 
              RowBox[{
               RowBox[{"MemberQ", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"c1", "=", 
                    RowBox[{"h", "\[LeftDoubleBracket]", 
                    RowBox[{"v", ",", "1"}], "\[RightDoubleBracket]"}]}], ",",
                    " ", 
                   RowBox[{"c2", "=", 
                    RowBox[{"h", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"ulist", "\[LeftDoubleBracket]", 
                    RowBox[{"-", "1"}], "\[RightDoubleBracket]"}], ",", "1"}],
                     "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
                 RowBox[{
                 "colourlist", "\[LeftDoubleBracket]", "#", 
                  "\[RightDoubleBracket]"}]}], "]"}], "&"}]}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"G2", "=", 
            RowBox[{"ChangeEdges", "[", 
             RowBox[{"G", ",", 
              RowBox[{"Extract", "[", 
               RowBox[{"edgesG", ",", 
                RowBox[{"Partition", "[", 
                 RowBox[{"sszm", ",", "1"}], "]"}]}], "]"}]}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"ua", "=", 
            RowBox[{"ulist", "\[LeftDoubleBracket]", 
             RowBox[{"-", "1"}], "\[RightDoubleBracket]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"ub", "=", 
            RowBox[{"ulist", "\[LeftDoubleBracket]", 
             RowBox[{
              RowBox[{
               RowBox[{"Position", "[", 
                RowBox[{"ulist", ",", "utemp"}], "]"}], 
               "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "-", "1"}],
              "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"cc", "=", 
            RowBox[{"ConnectedComponents", "[", "G2", "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"uc", "=", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"MemberQ", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{"cc", ",", 
                   RowBox[{
                    RowBox[{"MemberQ", "[", 
                    RowBox[{"#", ",", "v"}], "]"}], "&"}]}], "]"}], 
                 "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
                "ua"}], "]"}], ",", "ub", ",", "ua"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"(*", 
            RowBox[{
             RowBox[{"ua", " ", "or", " ", "ub"}], ",", " ", 
             RowBox[{
             "which", " ", "is", " ", "not", " ", "lies", " ", "in", " ", 
              "the", " ", "same", " ", "connected", " ", "component", " ", 
              "with", " ", "v"}]}], "*)"}], "\[IndentingNewLine]", 
           RowBox[{"edges2", "=", 
            RowBox[{"Select", "[", 
             RowBox[{"sszm", ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Intersection", "[", "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{
                   "edgesG", "\[LeftDoubleBracket]", "#", 
                    "\[RightDoubleBracket]"}], ",", "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"Select", "[", 
                    RowBox[{"cc", ",", 
                    RowBox[{
                    RowBox[{"MemberQ", "[", 
                    RowBox[{"#", ",", "uc"}], "]"}], "&"}]}], "]"}], 
                    "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
                  "\[IndentingNewLine]", "]"}], "\[NotEqual]", 
                 RowBox[{"{", "}"}]}], ")"}], "&"}]}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"colourlist", "=", 
                RowBox[{"ReplacePart", "[", 
                 RowBox[{"colourlist", ",", 
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    "colourlist", "\[LeftDoubleBracket]", "#", 
                    "\[RightDoubleBracket]"}], "\[Equal]", "c1"}], ",", "c2", 
                    ",", "c1"}], "]"}], ",", "#"}], "]"}]}], ")"}], "&"}], 
             ",", "edges2"}], "]"}], ";", "\[IndentingNewLine]", 
           RowBox[{"vertices2", "=", 
            RowBox[{
             RowBox[{"Select", "[", 
              RowBox[{"cc", ",", 
               RowBox[{
                RowBox[{"MemberQ", "[", 
                 RowBox[{"#", ",", "uc"}], "]"}], "&"}]}], "]"}], 
             "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                "h", "\[LeftDoubleBracket]", "#", "\[RightDoubleBracket]"}], 
                "=", 
                RowBox[{"Replace", "[", 
                 RowBox[{
                  RowBox[{
                  "h", "\[LeftDoubleBracket]", "#", "\[RightDoubleBracket]"}],
                   ",", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"c1", "\[Rule]", "c2"}], ",", 
                    RowBox[{"c2", "\[Rule]", "c1"}]}], "}"}], ",", "1"}], 
                 "]"}]}], ")"}], "&"}], ",", "vertices2"}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"i", "--"}]}]}], "\[IndentingNewLine]", "]"}], ";"}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", "colourlist"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.40013483734375*^9, 3.4001349111875*^9}, {
   3.400138162921875*^9, 3.4001381633125*^9}, {3.4006734396875*^9, 
   3.4006735640625*^9}, {3.400673609609375*^9, 3.400673680875*^9}, {
   3.400673742890625*^9, 3.4006737771875*^9}, {3.40067391971875*^9, 
   3.400673973203125*^9}, {3.400674027140625*^9, 3.400674076046875*^9}, {
   3.4006741719375*^9, 3.4006742311875*^9}, {3.40067431396875*^9, 
   3.40067435840625*^9}, {3.4006744113125*^9, 3.400674489625*^9}, {
   3.400674663140625*^9, 3.400674717390625*^9}, 3.40067563896875*^9, {
   3.400675669515625*^9, 3.400675739359375*^9}, {3.400675770484375*^9, 
   3.400675770953125*^9}, {3.40067902890625*^9, 3.40067903371875*^9}, {
   3.40067950278125*^9, 3.40067954559375*^9}, {3.40068001884375*^9, 
   3.400680039109375*^9}, {3.400680089125*^9, 3.400680129375*^9}, {
   3.400680208078125*^9, 3.4006802706875*^9}, {3.40068033878125*^9, 
   3.400680395234375*^9}, {3.4006835646875*^9, 3.400683564875*^9}, {
   3.400683769109375*^9, 3.4006837995625*^9}, 3.400683888109375*^9, {
   3.400684086*^9, 3.40068408615625*^9}, {3.400752262046875*^9, 
   3.400752262796875*^9}, {3.40082990240625*^9, 3.400829934640625*^9}, {
   3.4008473565*^9, 3.40084739478125*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Vizing", "[", "r", "]"}]], "Input",
 CellChangeTimes->{{3.400138167390625*^9, 3.400138167953125*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "1", ",", "2", ",", "2", ",", "1", ",", "3", ",", "4", ",", "2", 
   ",", "2", ",", "4", ",", "3", ",", "1", ",", "3", ",", "4", ",", "1", ",", 
   "5", ",", "3", ",", "4", ",", "6", ",", "7", ",", "8", ",", "2", ",", "9", 
   ",", "4", ",", "3", ",", "5", ",", "1", ",", "6", ",", "10", ",", "6", ",",
    "5", ",", "3", ",", "4", ",", "2", ",", "7", ",", "8", ",", "3", ",", "5",
    ",", "6", ",", "1", ",", "2", ",", "9", ",", "4", ",", "7", ",", "8", ",",
    "5", ",", "7", ",", "6", ",", "8", ",", "9", ",", "10", ",", "3", ",", 
   "2", ",", "11", ",", "1", ",", "4", ",", "6", ",", "7", ",", "8", ",", 
   "11", ",", "9", ",", "10", ",", "12", ",", "7", ",", "6", ",", "5", ",", 
   "10", ",", "1", ",", "13", ",", "8", ",", "7", ",", "12", ",", "13", ",", 
   "10", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{
  3.400683629984375*^9, {3.400683686984375*^9, 3.4006836904375*^9}, {
   3.4006837583125*^9, 3.40068375990625*^9}, 3.400684804890625*^9, 
   3.4008299734375*^9, 3.4008474074375*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Test results", "Section",
 CellChangeTimes->{{3.400656531796875*^9, 3.400656532375*^9}, {
  3.40065736728125*^9, 3.40065736975*^9}},
 CellTags->"tests"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Colournumber", "[", "l_List", "]"}], ":=", 
   RowBox[{"Length", "[", 
    RowBox[{"Union", "[", "l", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.400657831078125*^9, 3.400657832921875*^9}, 
   3.400829888859375*^9}],

Cell[CellGroupData[{

Cell["Colournumber: GeneralizedPetersenGraph, 1 parameter", "Subsection",
 CellChangeTimes->{{3.400141061234375*^9, 3.400141067171875*^9}, {
  3.400143790203125*^9, 3.400143790296875*^9}, {3.400657379265625*^9, 
  3.400657386265625*^9}, {3.4008474465625*^9, 3.400847479015625*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"min", "=", "300"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"max", "=", "600"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"step", "=", "30"}], ";"}], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"par", "=", "5"}], ";"}],
  FontColor->RGBColor[1, 0.5, 0]]}], "Input",
 CellChangeTimes->{{3.399722338015625*^9, 3.399722338859375*^9}, {
  3.399731030953125*^9, 3.3997310323125*^9}, {3.39973114990625*^9, 
  3.399731175078125*^9}, {3.39973136615625*^9, 3.399731366734375*^9}, {
  3.39973145396875*^9, 3.399731454796875*^9}, {3.399732404703125*^9, 
  3.399732435515625*^9}, {3.40014093365625*^9, 3.400140936125*^9}, {
  3.400142142734375*^9, 3.400142148890625*^9}, {3.400142257546875*^9, 
  3.400142303453125*^9}, {3.4001423598125*^9, 3.40014236146875*^9}, {
  3.400142405578125*^9, 3.40014241403125*^9}, {3.400144570171875*^9, 
  3.400144570859375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphs", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"i", ",", 
       StyleBox[
        RowBox[{"GeneralizedPetersenGraph", "[", 
         RowBox[{"i", ",", "par"}], "]"}],
        FontColor->RGBColor[1, 0.5, 0]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "min", ",", "max", ",", "step"}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{3.402241793210125*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dataEC", "=", 
  RowBox[{
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ",", 
        RowBox[{"Colournumber", "[", 
         RowBox[{"EdgeColoring", "[", 
          RowBox[{"#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
           "]"}], "]"}]}], "}"}], "&"}], ",", "graphs"}], "]"}]}]}]], "Input",\

 CellChangeTimes->{{3.402234408257*^9, 3.40223451072575*^9}, {
  3.40223455510075*^9, 3.402234555303875*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"300", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"330", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"360", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"390", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"420", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"450", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"480", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"510", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"540", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"570", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"600", ",", "4"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.40224184110075*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dataV", "=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
       ",", 
       RowBox[{"Colournumber", "[", 
        RowBox[{"Vizing", "[", 
         RowBox[{"#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         "]"}], "]"}]}], "}"}], "&"}], ",", "graphs"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4022345601945*^9, 3.402234575335125*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"300", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"330", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"360", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"390", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"420", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"450", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"480", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"510", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"540", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"570", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"600", ",", "3"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.402241842960125*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"maxplot", "=", 
   RowBox[{"Max", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Max", "[", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         "&"}], ",", "dataEC"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Max", "[", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         "&"}], ",", "dataV"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.399731584109375*^9, 3.399731614328125*^9}, {
   3.39973174615625*^9, 3.399731748296875*^9}, {3.399732118578125*^9, 
   3.399732160890625*^9}, {3.399732228265625*^9, 3.399732238953125*^9}, 
   3.40013821925*^9, {3.40014001153125*^9, 3.40014001371875*^9}, {
   3.400146641578125*^9, 3.400146642328125*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"plotEC", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"dataEC", ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.02", "]"}], ",", "Blue"}], "}"}]}], ",", 
     
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"min", "-", "1"}], ",", 
          RowBox[{"max", "+", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"1.2", " ", "maxplot"}]}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plotV", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"dataV", ",", "\[IndentingNewLine]", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.02", "]"}], ",", "Red"}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"min", "-", "1"}], ",", 
          RowBox[{"max", "+", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"1.2", " ", "maxplot"}]}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.399731762515625*^9, 3.3997318274375*^9}, {
  3.399731879609375*^9, 3.399731925703125*^9}, {3.399732258765625*^9, 
  3.399732300203125*^9}, {3.399732370046875*^9, 3.399732374359375*^9}, {
  3.39973407359375*^9, 3.3997341183125*^9}, {3.39973426796875*^9, 
  3.3997343069375*^9}, {3.399734351203125*^9, 3.3997343548125*^9}, {
  3.39973443225*^9, 3.399734432484375*^9}, {3.399736510453125*^9, 
  3.399736510703125*^9}, {3.3998266130625*^9, 3.3998266133125*^9}, {
  3.40014002884375*^9, 3.400140042234375*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p5Ba", "=", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"plotEC", ",", "plotV"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<EdgeColoring\>\"", ",", "Blue", ",", "20"}], "]"}], 
        "]"}], ",", 
       RowBox[{"Text", "[", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<Vizing\>\"", ",", "Red", ",", "20"}], "]"}], "]"}]}], 
      "\[IndentingNewLine]", "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<Number of vertices\>\"", ",", "Italic", ",", "16"}], 
         "]"}], "]"}], ",", 
       RowBox[{"Text", "[", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<Number of used colours\>\"", ",", "Italic", ",", "16"}],
          "]"}], "]"}]}], "\[IndentingNewLine]", "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.399732304515625*^9, 3.399732305875*^9}, {
  3.399732359421875*^9, 3.39973237709375*^9}, {3.3997324489375*^9, 
  3.39973245290625*^9}, {3.399826029515625*^9, 3.3998260299375*^9}, {
  3.400138305671875*^9, 3.40013830621875*^9}, {3.4001398620625*^9, 
  3.400139869265625*^9}, {3.40014013853125*^9, 3.400140142890625*^9}, {
  3.40014095609375*^9, 3.400140958671875*^9}, {3.400143793609375*^9, 
  3.40014379371875*^9}, {3.4001466503125*^9, 3.40014665928125*^9}, {
  3.400147064765625*^9, 3.400147064984375*^9}, {3.400657398890625*^9, 
  3.400657401171875*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, 
    {RGBColor[0, 0, 1], PointSize[0.02], 
     PointBox[{{300., 4.}, {330., 4.}, {360., 4.}, {390., 4.}, {420., 4.}, {
      450., 4.}, {480., 4.}, {510., 4.}, {540., 4.}, {570., 4.}, {600., 
      4.}}]}, {}}, {{}, 
    {RGBColor[1, 0, 0], PointSize[0.02], 
     PointBox[{{300., 3.}, {330., 3.}, {360., 3.}, {390., 3.}, {420., 3.}, {
      450., 3.}, {480., 3.}, {510., 3.}, {540., 3.}, {570., 3.}, {600., 
      3.}}]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
     InterpretationBox[
      Cell[
       BoxData[
        FormBox[
         StyleBox[
         "\"Number of vertices\"", Italic, 16, StripOnInput -> False], 
         TraditionalForm]], "Text", "TR"], 
      Text[
       Style["Number of vertices", Italic, 16]]], TraditionalForm], 
    FormBox[
     InterpretationBox[
      Cell[
       BoxData[
        FormBox[
         StyleBox[
         "\"Number of used colours\"", Italic, 16, StripOnInput -> False], 
         TraditionalForm]], "Text", "TR"], 
      Text[
       Style["Number of used colours", Italic, 16]]], TraditionalForm]},
  AxesOrigin->{300., 0},
  ImageSize->500,
  PlotLabel->FormBox[
    RowBox[{"{", 
      RowBox[{
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"EdgeColoring\"", 
             RGBColor[0, 0, 1], 20, StripOnInput -> False], TraditionalForm]],
           "Text", "TR"], 
         Text[
          Style["EdgeColoring", 
           RGBColor[0, 0, 1], 20]]], ",", 
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"Vizing\"", 
             RGBColor[1, 0, 0], 20, StripOnInput -> False], TraditionalForm]],
           "Text", "TR"], 
         Text[
          Style["Vizing", 
           RGBColor[1, 0, 0], 20]]]}], "}"}], TraditionalForm],
  PlotRange->{{299, 601}, {0, 4.8}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.402241849022625*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Colournumber: GeneralizedPetersenGraph, 2 parameter", "Subsection",
 CellChangeTimes->{{3.400141084890625*^9, 3.40014108996875*^9}, {
  3.400143804765625*^9, 3.400143805140625*^9}, {3.40065785040625*^9, 
  3.400657856453125*^9}, {3.400847487390625*^9, 3.400847489328125*^9}}],

Cell[BoxData[{
 StyleBox[
  RowBox[{
   RowBox[{"mini", "=", "200"}], ";"}],
  FontColor->RGBColor[1, 0.5, 0]], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"maxi", "=", "600"}], ";"}],
  FontColor->RGBColor[1, 0.5, 0]], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"stepi", "=", "30"}], ";"}],
  FontColor->RGBColor[1, 0.5, 0]], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"minj", "=", "20"}], ";"}],
  FontColor->RGBColor[1, 0.5, 0]], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"maxj", "=", "60"}], ";"}],
  FontColor->RGBColor[1, 0.5, 0]], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"stepj", "=", "3"}], ";"}],
  FontColor->RGBColor[1, 0.5, 0]]}], "Input",
 CellChangeTimes->{{3.399736537828125*^9, 3.399736543515625*^9}, {
   3.3997365784375*^9, 3.399736590125*^9}, {3.399736736046875*^9, 
   3.39973676965625*^9}, {3.39973682825*^9, 3.3997368286875*^9}, {
   3.39973695203125*^9, 3.39973695609375*^9}, {3.3997370938125*^9, 
   3.399737100265625*^9}, {3.39973750321875*^9, 3.39973755965625*^9}, {
   3.399737988125*^9, 3.399737991609375*^9}, {3.399738022296875*^9, 
   3.399738044234375*^9}, {3.399738515515625*^9, 3.399738526125*^9}, {
   3.400138948328125*^9, 3.40013895584375*^9}, 3.4001390534375*^9, {
   3.400139085328125*^9, 3.40013912934375*^9}, {3.400139181046875*^9, 
   3.40013918534375*^9}, {3.4001392518125*^9, 3.400139262828125*^9}, 
   3.40013963215625*^9, {3.400143933953125*^9, 3.400143937984375*^9}, {
   3.40014404396875*^9, 3.400144064140625*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphs", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"i", ",", "j", ",", 
         StyleBox[
          RowBox[{"GeneralizedPetersenGraph", "[", 
           RowBox[{"i", ",", "j"}], "]"}],
          FontColor->RGBColor[1, 0.5, 0]]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "mini", ",", "maxi", ",", "stepi"}], "}"}]}], "]"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "minj", ",", "maxj", ",", "stepj"}], "}"}]}], "]"}]}],
   ";"}]], "Input",
 CellChangeTimes->{{3.402234719178875*^9, 3.402234786132*^9}, 
   3.402235486632*^9, 3.402237980585125*^9, 3.402241888553875*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dataEC", "=", 
  RowBox[{"Map", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"Function", "[", 
      RowBox[{"x", ",", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
            "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
            
            RowBox[{
            "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",", 
            
            RowBox[{"Colournumber", "[", 
             RowBox[{"EdgeColoring", "[", 
              RowBox[{
              "#", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
              "]"}], "]"}]}], "}"}], "&"}], ",", "x"}], "]"}]}], "]"}], ")"}],
     ",", "graphs"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.40223489653825*^9, {3.402235357272625*^9, 3.4022354193195*^9}, {
   3.40223550160075*^9, 3.402235542507*^9}, {3.402235578460125*^9, 
   3.402235608007*^9}, {3.4022356384445*^9, 3.402235646647625*^9}, {
   3.4022357249445*^9, 3.402235752678875*^9}, {3.402235787210125*^9, 
   3.40223582928825*^9}, {3.402235886210125*^9, 3.402235891007*^9}, 
   3.4022359453195*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "20", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "20", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "20", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "20", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "20", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "20", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "20", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "20", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "20", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "20", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "20", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "20", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "20", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "20", ",", "4"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "23", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "23", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "23", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "23", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "23", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "23", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "23", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "23", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "23", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "23", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "23", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "23", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "23", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "23", ",", "4"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "26", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "26", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "26", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "26", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "26", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "26", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "26", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "26", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "26", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "26", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "26", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "26", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "26", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "26", ",", "4"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "29", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "29", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "29", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "29", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "29", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "29", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "29", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "29", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "29", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "29", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "29", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "29", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "29", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "29", ",", "4"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "32", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "32", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "32", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "32", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "32", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "32", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "32", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "32", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "32", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "32", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "32", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "32", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "32", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "32", ",", "4"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "35", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "35", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "35", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "35", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "35", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "35", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "35", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "35", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "35", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "35", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "35", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "35", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "35", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "35", ",", "4"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "38", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "38", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "38", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "38", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "38", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "38", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "38", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "38", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "38", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "38", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "38", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "38", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "38", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "38", ",", "4"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "41", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "41", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "41", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "41", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "41", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "41", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "41", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "41", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "41", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "41", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "41", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "41", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "41", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "41", ",", "4"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "44", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "44", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "44", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "44", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "44", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "44", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "44", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "44", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "44", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "44", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "44", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "44", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "44", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "44", ",", "4"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "47", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "47", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "47", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "47", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "47", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "47", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "47", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "47", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "47", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "47", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "47", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "47", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "47", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "47", ",", "4"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "50", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "50", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "50", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "50", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "50", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "50", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "50", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "50", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "50", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "50", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "50", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "50", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "50", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "50", ",", "4"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "53", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "53", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "53", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "53", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "53", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "53", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "53", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "53", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "53", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "53", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "53", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "53", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "53", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "53", ",", "4"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "56", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "56", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "56", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "56", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "56", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "56", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "56", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "56", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "56", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "56", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "56", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "56", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "56", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "56", ",", "4"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "59", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "59", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "59", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "59", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "59", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "59", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "59", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "59", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "59", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "59", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "59", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "59", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "59", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "59", ",", "4"}], "}"}]}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{3.40224205128825*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dataV", "=", 
  RowBox[{"Map", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"Function", "[", 
      RowBox[{"x", ",", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
            "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
            
            RowBox[{
            "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",", 
            
            RowBox[{"Colournumber", "[", 
             RowBox[{"Vizing", "[", 
              RowBox[{
              "#", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
              "]"}], "]"}]}], "}"}], "&"}], ",", "x"}], "]"}]}], "]"}], ")"}],
     ",", "graphs"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.402236314710125*^9, 3.402236333022625*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "20", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "20", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "20", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "20", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "20", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "20", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "20", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "20", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "20", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "20", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "20", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "20", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "20", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "20", ",", "4"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "23", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "23", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "23", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "23", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "23", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "23", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "23", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "23", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "23", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "23", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "23", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "23", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "23", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "23", ",", "4"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "26", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "26", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "26", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "26", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "26", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "26", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "26", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "26", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "26", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "26", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "26", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "26", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "26", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "26", ",", "4"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "29", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "29", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "29", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "29", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "29", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "29", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "29", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "29", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "29", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "29", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "29", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "29", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "29", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "29", ",", "4"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "32", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "32", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "32", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "32", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "32", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "32", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "32", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "32", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "32", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "32", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "32", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "32", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "32", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "32", ",", "4"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "35", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "35", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "35", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "35", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "35", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "35", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "35", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "35", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "35", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "35", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "35", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "35", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "35", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "35", ",", "4"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "38", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "38", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "38", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "38", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "38", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "38", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "38", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "38", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "38", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "38", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "38", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "38", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "38", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "38", ",", "4"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "41", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "41", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "41", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "41", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "41", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "41", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "41", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "41", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "41", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "41", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "41", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "41", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "41", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "41", ",", "4"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "44", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "44", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "44", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "44", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "44", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "44", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "44", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "44", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "44", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "44", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "44", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "44", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "44", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "44", ",", "4"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "47", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "47", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "47", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "47", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "47", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "47", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "47", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "47", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "47", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "47", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "47", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "47", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "47", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "47", ",", "4"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "50", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "50", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "50", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "50", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "50", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "50", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "50", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "50", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "50", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "50", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "50", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "50", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "50", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "50", ",", "4"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "53", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "53", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "53", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "53", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "53", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "53", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "53", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "53", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "53", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "53", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "53", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "53", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "53", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "53", ",", "4"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "56", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "56", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "56", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "56", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "56", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "56", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "56", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "56", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "56", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "56", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "56", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "56", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "56", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "56", ",", "4"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "59", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"230", ",", "59", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "59", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"290", ",", "59", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"320", ",", "59", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "59", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "59", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"410", ",", "59", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"440", ",", "59", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"470", ",", "59", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"500", ",", "59", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"530", ",", "59", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "59", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"590", ",", "59", ",", "3"}], "}"}]}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{3.40224208022575*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p5Bb", "=", 
  RowBox[{"ListPlot3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"dataEC", ",", "dataV"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
    RowBox[{"BoxRatios", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"DataRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.39973796165625*^9, 3.39973796434375*^9}, {
  3.4001393685625*^9, 3.400139369453125*^9}, {3.400139444640625*^9, 
  3.4001394459375*^9}, {3.400139550859375*^9, 3.40013959584375*^9}, {
  3.40014082390625*^9, 3.400140826890625*^9}, {3.400143807875*^9, 
  3.40014380796875*^9}, {3.400147049671875*^9, 3.400147110875*^9}, {
  3.4001471473125*^9, 3.400147163703125*^9}, {3.4006578621875*^9, 
  3.40065786378125*^9}}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJztnXGIXNtdx0MVneTNS/btezwXKcOzaDcMpQSZ7CaTTDI7Ozu7MzuV8HxI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   "], {{
     {RGBColor[0, 0, 1], EdgeForm[None], 
      GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwt2Qf8TfUfx/Hz/Trnd75W9iYUDSojpESEkEgI7dLee+8d0d577y2FsglF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         "]], Polygon3DBox[CompressedData["
1:eJwtmnXgVkUWhu+d77u/CxiEhI0I2ILdgYWCIoio2IidqOjqqru6q66Bgd3d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         "]], Polygon3DBox[CompressedData["
1:eJwt1wncVdMax/HTeTvto9FwpUFXdWUoNNxKoYEiSSLj/VzzkFCRyDxmrijK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         "]]}]}, 
     {RGBColor[1, 0, 0], EdgeForm[None], 
      GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxFmXf8jtUbx5+vw3Ofo63SNhMhslKohLIJGdkrKSspoxAi7WVERiIlUdp7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         "]], Polygon3DBox[CompressedData["
1:eJwtmXnAllP6x5+n+7yn97Hv22DKkoRUkqJVRbskUWnPFpIk+14YESrLGDNm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         "]], Polygon3DBox[CompressedData["
1:eJwt13n8lsMax/EnPf2e+8exk7IXheIoKVQqoRKKyNoeKqWylaR9IZQ22qSS
XSuR1KFjLSHaiyKJkmxHdjrv6zW/P76vua/PXNfMfc89c81MhQ49WnTfJ5fL
vU9laGFRLncYHUqHF+dyR+VzubsKuVx5z1eXzuWuosrYK1FP+5TK5S7Fjsae
Z/+lkW+0UxMrwl7HTqaT6Hht1MTe8HwW1aKqWCPsLc91w097g8RejC1ml6dy
VJbfcdgcz2UoTwdhB2AveN6PftPv+WIPxZ5j/+ld/qD9+JXBFkU7VFofzfgd
gy1hH0lF2OXY8dib7LOpItYXa4y9yj4i+sWaY8dig43Lidruwe5OdbEX+fyL
fvcuF2CHYS+zD6a9WFOsPPZSvD/9gzXBymF3a+8o7bVmt6Iq2AI+B9Lf/C7C
jsD6F9JYdmLfRGdiA7AKWBd2Z6qF9cbKYdeyr6ETsae19aMx2aq907C/6Sls
B/Y1leL/GzZQbEXPXT3fTGeL7YMdiV3Pvo5OxgZhJ2C3sLtRbWwq1gCrT/Wi
DuuLHeO5PZ929G+sH3YcdiP7BjoDe827HE2Zcb4Cq4j9h30UFbAWWAVsKfu0
mB/Y7Vg9bD57XyqmQ7R7CDY3/i397Hvr8zsQmxdt0R6sAXYQ9l/2GVQ95qvY
htiTnrcYk830d6YNvvd452PVd/Tcgarx+4nfTBruXXZj87Fn2b+K+0of1bF9
sGewX7A9lGmjFPY2dm70KXYgv0uwafpYq7/n2M/TbdgsPjn6XlEH2xd7gl8T
7bzEXkD9sJlYY+xF9gvUF7sPqxxrWh93Yxdij2ON+M1nz6M+2Ho+t9NtdJm6
e7F3PTekU8UO43cZtpJ9OdXGxmGtsQ8jhprH2hbbChsa85R9AL87+TXAJmF1
1E9lP0qdsIlYbWwa+zG6Edsubiz1ErsZexwbEvMF2x+7A6uPfcRuQXWw8Vgb
bFishVg3WC/sPGw1+2qqj02Mf4d9xR5HvbEt2EzsXrGVYv5gfbALsBPYi7M0
J4bHumDfEHMjS2M0C+vInqPsFGMg9i2x96vrzt7Kb3TkKfW3sGcrb1I24/cm
vxExd7FuWEvsPeyhmKdYV+xKbDk2KuYz1jnGGnsbewBbxb6K6mETsPaRc/j1
wlpjq7AJ2JfsMTSa2hrvGfF+/H42H7ebV/X47Z9PPr945zmxHgvJf6Gyt7KN
9lbzmxj5HuuAXYwtxYZH/sN6YtdgH2Bj82lObdPe+Mh7hTS/FihvVV7L70N+
49RNxurGe7GnUxfs4xiTGIPIyeraYTP4Xeh5Lp851Dv6wPb6ju98R2OsbD7N
x9VZyj+PFtLcjPU3OUv7Ro9CWouxn8zM0l53RyHtLZELlmLNsYcKKS+sK0r/
M/7hJfofom60uprsCr7jPv22wNayu8QawRZhA7Db+P2jr93erxF2eD7tT1Oz
lKduLaS96jxxy7K0fh6OPBrrINaHspL2How9WF1P7Hf+O7XXEDsYGxdri19l
fiOxq7FG7BVZGrdHYtwi/9PjNIzft7H+1U1Q1xQ7E5sS+Tj2eKwv1hHbEOs1
n/Lr01nai+8spFz7gLJq7I/8+vO7SN1I7PTI5dgQ7FJsObsxVcNGYFdiK2L+
UE3sodinsClizzW+M2PdU1fs/RhzqsVvFHYt9gH70sg32OjYk7BlRemb4ztr
aOMKrJf2DmD/Zaxa8jsBm46dX5zya+TZ27H3+DSJPUB792Mtsfv5VcHKYv2w
JtiD2KlYOWwA1rQkZzfU3rPsZ+jWfDr3LMnS+WZEIZ2B1sTaoAZiJ/HrqO4x
deeJfTr2YuqBjcKq8TuG31CsGfYFe2TkZ2xj5EpsG3tU5G1sEzYt3o/9U+wf
sXdq5wF2Z+UX5ssmY1CDX2l1XbAvsU+wM7E89i3fR2mg9r6O/Qf7hj2J+mPb
sWextmK3if1AbGXs18i92NYy6SxZif1L6ZTbV2Yp10fOv0lsa+wzfiv4nYjt
KZ3OH49k6Zx2cyGdRXbpcwpNpvbF6Xtiz/uE38tiFlL/kj1vU5b2wNgL78G6
Yt9qY4s+zsIKJeeSyAcxxjHW3UtyzsdZmmcx324u2aM+ylIOilzUuWROrsKe
YD8ZZx3sFuwHfXyuj3Ow4jgzYNfH/DNWr8Y5CtvI7kPtsHewkdgW9r2RS7C1
2CTsM/Z9kWOwNdhk7JMY99hvsBXYGOwH9gwaiu3C5mKfsgfToMipxSnXvlOU
8knkkOrFKZdt9jwk5oPYlWIfxj5nj6Ae2DpsCnad71jv25b5tgrYT7SJTz+6
J/ab4rSnPcWvVaw5sYv5DIq5wd6cpfz4jPo28U5xptHeu9o7nt+P8Q+w1pET
xC5hD47v4DOm5KzVKv41+3rlRuVysRXx/9EGcXfFPib2XfaDYmezS9EP/Gpj
+5WcczZm6SwUZ6K7sd18psZYid2Bzcqns/wifj1j7dK52I3YBv2u097p2N6Y
+1g7sReJfY09lN8N2Pf8VvGriv0V5wtsF/YRdgr7D/qKPTZL5+t26rezOyp3
Kz/mVwX/s3Q6U7+SpTtF3C3q6OM7fT4W/1i/O7HZ+fS/d2VpH19cSP9+a1Fa
/7HmW8c5S93Xnh+hvmK3RY7BnuPfHmuKvY4Nw3ayJ8Y/xr6MPJZP/3tHltpZ
VEj//lXlQGUnfp/GXq1uCTYc64ZtjTVSsk9vyNL5Ms6Zd+XTvWJhlu4KcWc4
B1vAfilLd8O427zoeYe2JsRc094XMVfy6Sw+Pkvn5k6FdC6P8/j8LN0f4h5R
XV037Dt1nxnTs7Esn+6bb2RpPxhTSHfPyLtrspSvI2/3LNkX1mGzYozpjny6
W72cpXtQ3IfOyqe7ywtZun/FPaxGPt1x5mXpXhD3g9Pz6e48K0v3pbg3nZRP
97Lns3SXjjt1Jex77zOdplGH4nT2as9vp+9Y6TtO5vd75M/Iddh6rBo7l0/3
xjnaa8NuS1Xz6a42O0v3yLhPnoKNx+prv6oxHRvvg/0fAxYQDw==
         "]]}]}, {}, {}, {}}, {
     Line3DBox[{1203, 1, 394, 15, 408, 29, 422, 43, 436, 57, 451, 452, 71, 
      478, 85, 492, 99, 506, 113, 521, 522, 127, 548, 141, 562, 155, 576, 169,
       590, 183, 1398, 184, 1399, 185, 1400, 186, 1401, 187, 1402, 1403, 188, 
      1404, 189, 1405, 190, 1406, 191, 1407, 1408, 192, 1409, 193, 1410, 194, 
      1411, 195, 1412, 196, 602, 182, 588, 168, 574, 154, 560, 140, 546, 545, 
      126, 518, 112, 504, 98, 490, 84, 476, 475, 70, 448, 56, 434, 42, 420, 
      28, 406, 14, 1231, 13, 1229, 12, 1227, 11, 1225, 10, 1222, 1221, 9, 
      1219, 8, 1217, 7, 1215, 6, 1212, 1211, 5, 1209, 4, 1207, 3, 1205, 2, 
      1203}], Line3DBox[{1491, 197, 799, 211, 813, 225, 827, 239, 841, 253, 
      856, 857, 267, 883, 281, 897, 295, 911, 309, 926, 927, 323, 953, 337, 
      967, 351, 981, 365, 995, 379, 1686, 380, 1687, 381, 1688, 382, 1689, 
      383, 1690, 1691, 384, 1692, 385, 1693, 386, 1694, 387, 1695, 1696, 388, 
      1697, 389, 1698, 390, 1699, 391, 1700, 392, 1007, 378, 993, 364, 979, 
      350, 965, 336, 951, 950, 322, 923, 308, 909, 294, 895, 280, 881, 880, 
      266, 853, 252, 839, 238, 825, 224, 811, 210, 1519, 209, 1517, 208, 1515,
       207, 1513, 206, 1510, 1509, 205, 1507, 204, 1505, 203, 1503, 202, 1500,
       1499, 201, 1497, 200, 1495, 199, 1493, 198, 1491}], {
      Line3DBox[{1203, 603, 1204, 1985, 1415, 1233, 1990, 1420, 1248, 1998, 
       1428, 1263, 2009, 1809, 2118, 1278, 2024, 1440, 1293, 2028, 1444, 1308,
        2035, 1451, 1323, 2045, 1842, 2152, 1338, 2058, 1461, 1353, 2061, 
       1464, 1368, 2067, 1470, 1383, 2076, 1479, 1398}], 
      Line3DBox[{1205, 1779, 2088, 1206, 617, 1234, 1991, 1421, 1249, 1999, 
       1429, 1264, 2010, 1810, 2119, 1279, 1821, 2131, 1294, 2029, 1445, 1309,
        2036, 1452, 1324, 2046, 1843, 2153, 1339, 1855, 2167, 1354, 2062, 
       1465, 1369, 2068, 1471, 1384, 2077, 1480, 1399}], 
      Line3DBox[{1207, 1780, 2089, 1208, 1791, 2100, 1235, 631, 1250, 2000, 
       1430, 1265, 2011, 1811, 2120, 1280, 1822, 2132, 1295, 1831, 2141, 1310,
        2037, 1453, 1325, 2047, 1844, 2154, 1340, 1856, 2168, 1355, 1866, 
       2178, 1370, 2069, 1472, 1385, 2078, 1481, 1400}], 
      Line3DBox[{1209, 1781, 2090, 1210, 1792, 2101, 1236, 1800, 2109, 1251, 
       645, 1266, 2012, 1812, 2121, 1281, 1823, 2133, 1296, 1832, 2142, 1311, 
       1838, 2148, 1326, 2048, 1845, 2155, 1341, 1857, 2169, 1356, 1867, 2179,
        1371, 1874, 2186, 1386, 2079, 1482, 1401}], 
      Line3DBox[{1211, 1782, 2091, 1213, 1793, 2102, 1237, 1801, 2110, 1252, 
       1806, 2115, 1267, 663, 2122, 1282, 1824, 2134, 1297, 1833, 2143, 1312, 
       1839, 2149, 1327, 1846, 2156, 2157, 1342, 1858, 2170, 1357, 1868, 2180,
        1372, 1875, 2187, 1387, 1879, 2191, 1402}], 
      Line3DBox[{1215, 1783, 2092, 1216, 1987, 1417, 1239, 1993, 1423, 1254, 
       2002, 1432, 1269, 2014, 1813, 2123, 1284, 686, 1299, 2031, 1447, 1314, 
       2039, 1455, 1329, 2050, 1848, 2159, 1344, 1859, 2171, 1359, 2064, 1467,
        1374, 2071, 1474, 1389, 2081, 1484, 1404}], 
      Line3DBox[{1217, 1784, 2093, 1218, 1794, 2103, 1240, 1994, 1424, 1255, 
       2003, 1433, 1270, 2015, 1814, 2124, 1285, 1825, 2135, 1300, 700, 1315, 
       2040, 1456, 1330, 2051, 1849, 2160, 1345, 1860, 2172, 1360, 1869, 2181,
        1375, 2072, 1475, 1390, 2082, 1485, 1405}], 
      Line3DBox[{1219, 1785, 2094, 1220, 1795, 2104, 1241, 1802, 2111, 1256, 
       2004, 1434, 1271, 2016, 1815, 2125, 1286, 1826, 2136, 1301, 1834, 2144,
        1316, 714, 1331, 2052, 1850, 2161, 1346, 1861, 2173, 1361, 1870, 2182,
        1376, 1876, 2188, 1391, 2083, 1486, 1406}], 
      Line3DBox[{1221, 1786, 2095, 1223, 1796, 2105, 1242, 1803, 2112, 1257, 
       1807, 2116, 1272, 2017, 1816, 2126, 1287, 1827, 2137, 1302, 1835, 2145,
        1317, 1840, 2150, 1332, 736, 2162, 1347, 1862, 2174, 1362, 1871, 2183,
        1377, 1877, 2189, 1392, 1880, 2192, 1407}], 
      Line3DBox[{1225, 1787, 2096, 1226, 1989, 1419, 1244, 1996, 1426, 1259, 
       2006, 1436, 1274, 2020, 1817, 2127, 1289, 2027, 1443, 1304, 2033, 1449,
        1319, 2042, 1458, 1334, 2054, 1851, 2163, 1349, 755, 1364, 2066, 1469,
        1379, 2074, 1477, 1394, 2085, 1488, 1409}], 
      Line3DBox[{1227, 1788, 2097, 1228, 1797, 2106, 1245, 1997, 1427, 1260, 
       2007, 1437, 1275, 2021, 1818, 2128, 1290, 1828, 2138, 1305, 2034, 1450,
        1320, 2043, 1459, 1335, 2055, 1852, 2164, 1350, 1863, 2175, 1365, 769,
        1380, 2075, 1478, 1395, 2086, 1489, 1410}], 
      Line3DBox[{1229, 1789, 2098, 1230, 1798, 2107, 1246, 1804, 2113, 1261, 
       2008, 1438, 1276, 2022, 1819, 2129, 1291, 1829, 2139, 1306, 1836, 2146,
        1321, 2044, 1460, 1336, 2056, 1853, 2165, 1351, 1864, 2176, 1366, 
       1872, 2184, 1381, 783, 1396, 2087, 1490, 1411}], 
      Line3DBox[{1231, 1790, 2099, 1232, 1799, 2108, 1247, 1805, 2114, 1262, 
       1808, 2117, 1277, 2023, 1820, 2130, 1292, 1830, 2140, 1307, 1837, 2147,
        1322, 1841, 2151, 1337, 2057, 1854, 2166, 1352, 1865, 2177, 1367, 
       1873, 2185, 1382, 1878, 2190, 1397, 797, 1412}], 
      Line3DBox[{1403, 1483, 2080, 1388, 1473, 2070, 1373, 1466, 2063, 1358, 
       1462, 2059, 1343, 2158, 1847, 2049, 1328, 1454, 2038, 1313, 1446, 2030,
        1298, 1441, 2025, 1283, 664, 2013, 1268, 1431, 2001, 1253, 1422, 1992,
        1238, 1416, 1986, 1214, 1413, 1983, 1212}], 
      Line3DBox[{1408, 1487, 2084, 1393, 1476, 2073, 1378, 1468, 2065, 1363, 
       1463, 2060, 1348, 737, 2053, 1333, 1457, 2041, 1318, 1448, 2032, 1303, 
       1442, 2026, 1288, 1439, 2019, 2018, 1273, 1435, 2005, 1258, 1425, 1995,
        1243, 1418, 1988, 1224, 1414, 1984, 1222}], 
      Line3DBox[{1491, 1008, 1492, 2195, 1703, 1521, 2200, 1708, 1536, 2208, 
       1716, 1551, 2219, 1911, 2328, 1566, 2234, 1728, 1581, 2238, 1732, 1596,
        2245, 1739, 1611, 2255, 1944, 2362, 1626, 2268, 1749, 1641, 2271, 
       1752, 1656, 2277, 1758, 1671, 2286, 1767, 1686}], 
      Line3DBox[{1493, 1881, 2298, 1494, 1022, 1522, 2201, 1709, 1537, 2209, 
       1717, 1552, 2220, 1912, 2329, 1567, 1923, 2341, 1582, 2239, 1733, 1597,
        2246, 1740, 1612, 2256, 1945, 2363, 1627, 1957, 2377, 1642, 2272, 
       1753, 1657, 2278, 1759, 1672, 2287, 1768, 1687}], 
      Line3DBox[{1495, 1882, 2299, 1496, 1893, 2310, 1523, 1036, 1538, 2210, 
       1718, 1553, 2221, 1913, 2330, 1568, 1924, 2342, 1583, 1933, 2351, 1598,
        2247, 1741, 1613, 2257, 1946, 2364, 1628, 1958, 2378, 1643, 1968, 
       2388, 1658, 2279, 1760, 1673, 2288, 1769, 1688}], 
      Line3DBox[{1497, 1883, 2300, 1498, 1894, 2311, 1524, 1902, 2319, 1539, 
       1050, 1554, 2222, 1914, 2331, 1569, 1925, 2343, 1584, 1934, 2352, 1599,
        1940, 2358, 1614, 2258, 1947, 2365, 1629, 1959, 2379, 1644, 1969, 
       2389, 1659, 1976, 2396, 1674, 2289, 1770, 1689}], 
      Line3DBox[{1499, 1884, 2301, 1501, 1895, 2312, 1525, 1903, 2320, 1540, 
       1908, 2325, 1555, 1068, 2332, 1570, 1926, 2344, 1585, 1935, 2353, 1600,
        1941, 2359, 1615, 1948, 2366, 2367, 1630, 1960, 2380, 1645, 1970, 
       2390, 1660, 1977, 2397, 1675, 1981, 2401, 1690}], 
      Line3DBox[{1503, 1885, 2302, 1504, 2197, 1705, 1527, 2203, 1711, 1542, 
       2212, 1720, 1557, 2224, 1915, 2333, 1572, 1091, 1587, 2241, 1735, 1602,
        2249, 1743, 1617, 2260, 1950, 2369, 1632, 1961, 2381, 1647, 2274, 
       1755, 1662, 2281, 1762, 1677, 2291, 1772, 1692}], 
      Line3DBox[{1505, 1886, 2303, 1506, 1896, 2313, 1528, 2204, 1712, 1543, 
       2213, 1721, 1558, 2225, 1916, 2334, 1573, 1927, 2345, 1588, 1105, 1603,
        2250, 1744, 1618, 2261, 1951, 2370, 1633, 1962, 2382, 1648, 1971, 
       2391, 1663, 2282, 1763, 1678, 2292, 1773, 1693}], 
      Line3DBox[{1507, 1887, 2304, 1508, 1897, 2314, 1529, 1904, 2321, 1544, 
       2214, 1722, 1559, 2226, 1917, 2335, 1574, 1928, 2346, 1589, 1936, 2354,
        1604, 1119, 1619, 2262, 1952, 2371, 1634, 1963, 2383, 1649, 1972, 
       2392, 1664, 1978, 2398, 1679, 2293, 1774, 1694}], 
      Line3DBox[{1509, 1888, 2305, 1511, 1898, 2315, 1530, 1905, 2322, 1545, 
       1909, 2326, 1560, 2227, 1918, 2336, 1575, 1929, 2347, 1590, 1937, 2355,
        1605, 1942, 2360, 1620, 1141, 2372, 1635, 1964, 2384, 1650, 1973, 
       2393, 1665, 1979, 2399, 1680, 1982, 2402, 1695}], 
      Line3DBox[{1513, 1889, 2306, 1514, 2199, 1707, 1532, 2206, 1714, 1547, 
       2216, 1724, 1562, 2230, 1919, 2337, 1577, 2237, 1731, 1592, 2243, 1737,
        1607, 2252, 1746, 1622, 2264, 1953, 2373, 1637, 1160, 1652, 2276, 
       1757, 1667, 2284, 1765, 1682, 2295, 1776, 1697}], 
      Line3DBox[{1515, 1890, 2307, 1516, 1899, 2316, 1533, 2207, 1715, 1548, 
       2217, 1725, 1563, 2231, 1920, 2338, 1578, 1930, 2348, 1593, 2244, 1738,
        1608, 2253, 1747, 1623, 2265, 1954, 2374, 1638, 1965, 2385, 1653, 
       1174, 1668, 2285, 1766, 1683, 2296, 1777, 1698}], 
      Line3DBox[{1517, 1891, 2308, 1518, 1900, 2317, 1534, 1906, 2323, 1549, 
       2218, 1726, 1564, 2232, 1921, 2339, 1579, 1931, 2349, 1594, 1938, 2356,
        1609, 2254, 1748, 1624, 2266, 1955, 2375, 1639, 1966, 2386, 1654, 
       1974, 2394, 1669, 1188, 1684, 2297, 1778, 1699}], 
      Line3DBox[{1519, 1892, 2309, 1520, 1901, 2318, 1535, 1907, 2324, 1550, 
       1910, 2327, 1565, 2233, 1922, 2340, 1580, 1932, 2350, 1595, 1939, 2357,
        1610, 1943, 2361, 1625, 2267, 1956, 2376, 1640, 1967, 2387, 1655, 
       1975, 2395, 1670, 1980, 2400, 1685, 1202, 1700}], 
      Line3DBox[{1691, 1771, 2290, 1676, 1761, 2280, 1661, 1754, 2273, 1646, 
       1750, 2269, 1631, 2368, 1949, 2259, 1616, 1742, 2248, 1601, 1734, 2240,
        1586, 1729, 2235, 1571, 1069, 2223, 1556, 1719, 2211, 1541, 1710, 
       2202, 1526, 1704, 2196, 1502, 1701, 2193, 1500}], 
      Line3DBox[{1696, 1775, 2294, 1681, 1764, 2283, 1666, 1756, 2275, 1651, 
       1751, 2270, 1636, 1142, 2263, 1621, 1745, 2251, 1606, 1736, 2242, 1591,
        1730, 2236, 1576, 1727, 2229, 2228, 1561, 1723, 2215, 1546, 1713, 
       2205, 1531, 1706, 2198, 1512, 1702, 2194, 1510}]}, {
      Line3DBox[{394, 603, 393, 2088, 604, 395, 2089, 605, 396, 2090, 606, 
       397, 2091, 607, 1983, 398, 2092, 608, 399, 2093, 609, 400, 2094, 610, 
       401, 2095, 611, 1984, 402, 2096, 612, 403, 2097, 613, 404, 2098, 614, 
       405, 2099, 615, 406}], 
      Line3DBox[{408, 616, 1985, 407, 617, 409, 2100, 618, 410, 2101, 619, 
       411, 2102, 620, 1986, 412, 621, 1987, 413, 2103, 622, 414, 2104, 623, 
       415, 2105, 624, 1988, 416, 625, 1989, 417, 2106, 626, 418, 2107, 627, 
       419, 2108, 628, 420}], 
      Line3DBox[{422, 629, 1990, 421, 630, 1991, 423, 631, 424, 2109, 632, 
       425, 2110, 633, 1992, 426, 634, 1993, 427, 635, 1994, 428, 2111, 636, 
       429, 2112, 637, 1995, 430, 638, 1996, 431, 639, 1997, 432, 2113, 640, 
       433, 2114, 641, 434}], 
      Line3DBox[{436, 642, 1998, 435, 643, 1999, 437, 644, 2000, 438, 645, 
       439, 2115, 646, 2001, 440, 647, 2002, 441, 648, 2003, 442, 649, 2004, 
       443, 2116, 650, 2005, 444, 651, 2006, 445, 652, 2007, 446, 653, 2008, 
       447, 2117, 654, 448}], 
      Line3DBox[{452, 2118, 656, 450, 2119, 658, 454, 2120, 660, 456, 2121, 
       662, 458, 2122, 664, 460, 2123, 666, 462, 2124, 668, 464, 2125, 670, 
       466, 2126, 672, 2019, 468, 2127, 674, 470, 2128, 676, 472, 2129, 678, 
       474, 2130, 680, 476}], 
      Line3DBox[{475, 2023, 679, 473, 2022, 677, 471, 2021, 675, 469, 2020, 
       673, 467, 2018, 2017, 671, 465, 2016, 669, 463, 2015, 667, 461, 2014, 
       665, 459, 2013, 663, 457, 2012, 661, 455, 2011, 659, 453, 2010, 657, 
       449, 2009, 655, 451}], 
      Line3DBox[{478, 681, 2024, 477, 2131, 682, 479, 2132, 683, 480, 2133, 
       684, 481, 2134, 685, 2025, 482, 686, 483, 2135, 687, 484, 2136, 688, 
       485, 2137, 689, 2026, 486, 690, 2027, 487, 2138, 691, 488, 2139, 692, 
       489, 2140, 693, 490}], 
      Line3DBox[{492, 694, 2028, 491, 695, 2029, 493, 2141, 696, 494, 2142, 
       697, 495, 2143, 698, 2030, 496, 699, 2031, 497, 700, 498, 2144, 701, 
       499, 2145, 702, 2032, 500, 703, 2033, 501, 704, 2034, 502, 2146, 705, 
       503, 2147, 706, 504}], 
      Line3DBox[{506, 707, 2035, 505, 708, 2036, 507, 709, 2037, 508, 2148, 
       710, 509, 2149, 711, 2038, 510, 712, 2039, 511, 713, 2040, 512, 714, 
       513, 2150, 715, 2041, 514, 716, 2042, 515, 717, 2043, 516, 718, 2044, 
       517, 2151, 719, 518}], 
      Line3DBox[{522, 2152, 721, 520, 2153, 723, 524, 2154, 725, 526, 2155, 
       727, 528, 2157, 2158, 729, 530, 2159, 731, 532, 2160, 733, 534, 2161, 
       735, 536, 2162, 737, 538, 2163, 739, 540, 2164, 741, 542, 2165, 743, 
       544, 2166, 745, 546}], 
      Line3DBox[{545, 2057, 744, 543, 2056, 742, 541, 2055, 740, 539, 2054, 
       738, 537, 2053, 736, 535, 2052, 734, 533, 2051, 732, 531, 2050, 730, 
       529, 2049, 728, 2156, 527, 2048, 726, 525, 2047, 724, 523, 2046, 722, 
       519, 2045, 720, 521}], 
      Line3DBox[{548, 746, 2058, 547, 2167, 747, 549, 2168, 748, 550, 2169, 
       749, 551, 2170, 750, 2059, 552, 2171, 751, 553, 2172, 752, 554, 2173, 
       753, 555, 2174, 754, 2060, 556, 755, 557, 2175, 756, 558, 2176, 757, 
       559, 2177, 758, 560}], 
      Line3DBox[{562, 759, 2061, 561, 760, 2062, 563, 2178, 761, 564, 2179, 
       762, 565, 2180, 763, 2063, 566, 764, 2064, 567, 2181, 765, 568, 2182, 
       766, 569, 2183, 767, 2065, 570, 768, 2066, 571, 769, 572, 2184, 770, 
       573, 2185, 771, 574}], 
      Line3DBox[{576, 772, 2067, 575, 773, 2068, 577, 774, 2069, 578, 2186, 
       775, 579, 2187, 776, 2070, 580, 777, 2071, 581, 778, 2072, 582, 2188, 
       779, 583, 2189, 780, 2073, 584, 781, 2074, 585, 782, 2075, 586, 783, 
       587, 2190, 784, 588}], 
      Line3DBox[{590, 785, 2076, 589, 786, 2077, 591, 787, 2078, 592, 788, 
       2079, 593, 2191, 789, 2080, 594, 790, 2081, 595, 791, 2082, 596, 792, 
       2083, 597, 2192, 793, 2084, 598, 794, 2085, 599, 795, 2086, 600, 796, 
       2087, 601, 797, 602}], 
      Line3DBox[{799, 1008, 798, 2298, 1009, 800, 2299, 1010, 801, 2300, 1011,
        802, 2301, 1012, 2193, 803, 2302, 1013, 804, 2303, 1014, 805, 2304, 
       1015, 806, 2305, 1016, 2194, 807, 2306, 1017, 808, 2307, 1018, 809, 
       2308, 1019, 810, 2309, 1020, 811}], 
      Line3DBox[{813, 1021, 2195, 812, 1022, 814, 2310, 1023, 815, 2311, 1024,
        816, 2312, 1025, 2196, 817, 1026, 2197, 818, 2313, 1027, 819, 2314, 
       1028, 820, 2315, 1029, 2198, 821, 1030, 2199, 822, 2316, 1031, 823, 
       2317, 1032, 824, 2318, 1033, 825}], 
      Line3DBox[{827, 1034, 2200, 826, 1035, 2201, 828, 1036, 829, 2319, 1037,
        830, 2320, 1038, 2202, 831, 1039, 2203, 832, 1040, 2204, 833, 2321, 
       1041, 834, 2322, 1042, 2205, 835, 1043, 2206, 836, 1044, 2207, 837, 
       2323, 1045, 838, 2324, 1046, 839}], 
      Line3DBox[{841, 1047, 2208, 840, 1048, 2209, 842, 1049, 2210, 843, 1050,
        844, 2325, 1051, 2211, 845, 1052, 2212, 846, 1053, 2213, 847, 1054, 
       2214, 848, 2326, 1055, 2215, 849, 1056, 2216, 850, 1057, 2217, 851, 
       1058, 2218, 852, 2327, 1059, 853}], 
      Line3DBox[{857, 2328, 1061, 855, 2329, 1063, 859, 2330, 1065, 861, 2331,
        1067, 863, 2332, 1069, 865, 2333, 1071, 867, 2334, 1073, 869, 2335, 
       1075, 871, 2336, 1077, 2229, 873, 2337, 1079, 875, 2338, 1081, 877, 
       2339, 1083, 879, 2340, 1085, 881}], 
      Line3DBox[{880, 2233, 1084, 878, 2232, 1082, 876, 2231, 1080, 874, 2230,
        1078, 872, 2228, 2227, 1076, 870, 2226, 1074, 868, 2225, 1072, 866, 
       2224, 1070, 864, 2223, 1068, 862, 2222, 1066, 860, 2221, 1064, 858, 
       2220, 1062, 854, 2219, 1060, 856}], 
      Line3DBox[{883, 1086, 2234, 882, 2341, 1087, 884, 2342, 1088, 885, 2343,
        1089, 886, 2344, 1090, 2235, 887, 1091, 888, 2345, 1092, 889, 2346, 
       1093, 890, 2347, 1094, 2236, 891, 1095, 2237, 892, 2348, 1096, 893, 
       2349, 1097, 894, 2350, 1098, 895}], 
      Line3DBox[{897, 1099, 2238, 896, 1100, 2239, 898, 2351, 1101, 899, 2352,
        1102, 900, 2353, 1103, 2240, 901, 1104, 2241, 902, 1105, 903, 2354, 
       1106, 904, 2355, 1107, 2242, 905, 1108, 2243, 906, 1109, 2244, 907, 
       2356, 1110, 908, 2357, 1111, 909}], 
      Line3DBox[{911, 1112, 2245, 910, 1113, 2246, 912, 1114, 2247, 913, 2358,
        1115, 914, 2359, 1116, 2248, 915, 1117, 2249, 916, 1118, 2250, 917, 
       1119, 918, 2360, 1120, 2251, 919, 1121, 2252, 920, 1122, 2253, 921, 
       1123, 2254, 922, 2361, 1124, 923}], 
      Line3DBox[{927, 2362, 1126, 925, 2363, 1128, 929, 2364, 1130, 931, 2365,
        1132, 933, 2367, 2368, 1134, 935, 2369, 1136, 937, 2370, 1138, 939, 
       2371, 1140, 941, 2372, 1142, 943, 2373, 1144, 945, 2374, 1146, 947, 
       2375, 1148, 949, 2376, 1150, 951}], 
      Line3DBox[{950, 2267, 1149, 948, 2266, 1147, 946, 2265, 1145, 944, 2264,
        1143, 942, 2263, 1141, 940, 2262, 1139, 938, 2261, 1137, 936, 2260, 
       1135, 934, 2259, 1133, 2366, 932, 2258, 1131, 930, 2257, 1129, 928, 
       2256, 1127, 924, 2255, 1125, 926}], 
      Line3DBox[{953, 1151, 2268, 952, 2377, 1152, 954, 2378, 1153, 955, 2379,
        1154, 956, 2380, 1155, 2269, 957, 2381, 1156, 958, 2382, 1157, 959, 
       2383, 1158, 960, 2384, 1159, 2270, 961, 1160, 962, 2385, 1161, 963, 
       2386, 1162, 964, 2387, 1163, 965}], 
      Line3DBox[{967, 1164, 2271, 966, 1165, 2272, 968, 2388, 1166, 969, 2389,
        1167, 970, 2390, 1168, 2273, 971, 1169, 2274, 972, 2391, 1170, 973, 
       2392, 1171, 974, 2393, 1172, 2275, 975, 1173, 2276, 976, 1174, 977, 
       2394, 1175, 978, 2395, 1176, 979}], 
      Line3DBox[{981, 1177, 2277, 980, 1178, 2278, 982, 1179, 2279, 983, 2396,
        1180, 984, 2397, 1181, 2280, 985, 1182, 2281, 986, 1183, 2282, 987, 
       2398, 1184, 988, 2399, 1185, 2283, 989, 1186, 2284, 990, 1187, 2285, 
       991, 1188, 992, 2400, 1189, 993}], 
      Line3DBox[{995, 1190, 2286, 994, 1191, 2287, 996, 1192, 2288, 997, 1193,
        2289, 998, 2401, 1194, 2290, 999, 1195, 2291, 1000, 1196, 2292, 1001, 
       1197, 2293, 1002, 2402, 1198, 2294, 1003, 1199, 2295, 1004, 1200, 2296,
        1005, 1201, 2297, 1006, 1202, 1007}]}, {}, {}, {}, {}, {}}},
   VertexNormals->CompressedData["
1:eJztfXk8ldv3v6mQFFEJTa40zzKWVVJpppIGJWSIKElIwxFCEm5UZCgpGihD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    "]],
  Axes->True,
  BoxRatios->{1, 1},
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{{200., 590.}, {20., 59.}, {3., 5.}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.402242128632*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztvW1spNl1JnZZ71sf/Orv5jfZ05qWhjPiaNgzbImSODIt0RJtUxJtURJl
UzK1om3a27Hbdq/TtsemJNsbG2ktFt7sBkGAIEh+BFhkskh2N0gQJEgCJEGC
/A7ya5MgQBAgCAIE+T95z3POuffc96PqLbKKxe6WhDtdrKq36q17z/Ocz3vu
V7//9PTX/6XvP/2tH3z/ta/8/vefnP7WD/7gtS//7u9nTyVjzo2dZuMPb7js
8Qcu+V/dvY/OPvqts4+cc//f2Ud/8i9+Ol7+0cgW+/cePh/9jQx3uLE/+RfO
/b9nH2W/t5H9mTz68OHz7N/fhbT/P6O/wZ+OIS5+kq1xqn83Hj6nZR/1TQ31
B0Pa/29Ie5ul/eyjRx+KtP9fo7/Bn44hLDpR+R8XX2FyJ7Yb9R0Oa0Da/8+z
jxLhdufOMkPGtbKRkuTTr/8diP7/Mfqb/ekY1CB5PwtP0KrHb1Cz5uU1b5jo
/3eI/g0leqICekyQz/79bUj+/zb6m/3puOBik8D/Rb13B5F/WYkfkv+/QPLv
GMlPzGN2Zf+j0d/ryz/Iwk74IcQ04RfwePn8HwvL/a/ksat7XRD5l5P5Ifr/
XC0dZ6weF1tAc/AAFo0ySMzjU7z/fx7973lVBq8QPSZZZnkuWi29BkHqJ+e/
iVgfvHwAcbXRcRvK455BRGqUx2/i/f909D/oVRjQEyt4dE580Af8TT8XVI28
vfSy2U+ARybWrskw6AqRa8GzkGduGrg0zePfwLX/bPS/79UYJO5teuCcCjww
dL37ZXjP7Xpfgvf+uM47ixB5udQKIPM/gmPu4r+3jOC3zeMTgOC/H/0d/3TE
w6XZusz0c8UFhP/l0hkQ/v8OE5LGxlMOCB1jPP0AQPhvRn/3Px00Hj4Hmf/b
5/0E545dHbuqSu5fFjwAC/81k0OS3oeoLzK7nGCKrHU0bh7/LeDhvxz9L3i1
B63b/Yt+CJnI2Vr/+CKAeFksJADiPw+ZN8HEMjkH6X3CxLFL77MDIVCYMGri
+4DFfzb63/EqDqiET0TPXMh1zigxg8WPeodpu2mDl0FTcATqP4Wa6BiTaYmd
bkaFcxEqpgwqfg2o+I9H/0NenUFphv9g8B9LdhMbBr3e213uX3xlAUj8M7Gc
JBK+St6zTtGJwYTgYMrg43vAxH84+h/ysg9k3N7Rv+vn3Gp/frbSLs3W+oe9
tU13sX/RVQUg8U8AifUYCUd5JEybx98FEj4c/f2/rAN20acv5ZtkvTN3gr7z
z7q/v7cSeJERATT847OPMlf6PbaTFA0yPdcMBq4ZzXAEPPzl6H/BqEeUB7C1
GEvn/Uy6+PP6x+BVQfmPCIvufggi7Kom6lhGL671BFD8iANMnKmrStTNQo98
toiczCfHFEY65Lp5/Kv4rLPR/9hRDuQHXrM555CHrv8pZDr9zCh+QG7JgZvV
C+PmxVUowM1ZDiotxVCEo+zfW8DO+/yWE/xftLJLjorguWkefwef/sPR/+LR
Dq9lzoMfQs2OXjaa+w/4IVsjW/M/c26ty63X1SgvpuYBen7ot8pV4mYab/ki
vSX1PrzBzZqLcGNzhYc/Ndp4VBpt17pdR2/4+dHfvNxubKkPDj39vvdqDKDn
X4cx8OUSlULzk9D8ZK9NGnTcNo+/DXT8w9H/lhdlADH7eDQyHVJyV4YUaRAp
/ikvffkl/Qn7i2accVrkH0Bp/AKrkRMEAy0u1vO4uGO0xreAi78/+p9ytQcZ
VDd7vw2g+dkRyEEOFjAY/oxd/fUKtdGvGnix1AaA8fcAjDvej1d4NDheLgrk
SBz6dRehZMag5AAo+VdH/7Ou4kB6Y6YfPUEo+dwIbtQl0cIHjGxUmlb9aoQX
SYMAI38NdDRNpQmccYlwbcZKRSfviIiuscF4EYzMGOx8A3j5V0b/E6/SgHJY
LDxbCzW49rOXfc+OqbJ1nHNFgZpDx6ZF2aX9o+DF0S5AzV/AGVniKCc0rvsM
QwhQafM8pcwumxFOZs3jXwZOfjz6HzX6QQL+2sWcDTZ7Pns5WZUwXESNanmj
c8hmhWY5n5Z4MTBiQl22uH2hgBXnTumPZjbGj6WEiwCTuq1s2rioUXAyZ3TL
LwEzfzr6HzqqAXvr1wb0WTVrqQY7si9sBcSwo/qBcwfgyrJLzmtVvQjWGPDy
J8DLxxH3vc80QhbYp9kUszqlSRDhmYogsmAg8nVA5Guj/23VY1jNDWjW3hjk
jTrU4DaYtC5vfsqVCqGE7C4iyOJV55f2q69ZgJJfKsvU57L2c0HziD/zuoaM
tSLykTo1p851GFUttWi3s7m1u0xso4ev4cuejn4yeo3BNUV4Z7A3FoYLcarP
XGaA2YFI4+gPQLUPWBUvuIgKuerqB6D6eu+sJHd1+FT2qJ0aHD1wbuNM6u9P
GE4thlOb4XSQ0fE2KaqOQdGSUVRfxYJc+c6RFkH9IwrKY2PY1V65wsdHlzU7
2XeNZ4D6oQaGDsU8ISLNv/eieLjKeKqtoKToEpEB6yB9MhuduHT/AfClqoqm
uUNTfJTB6gCEtR0ha9k83nuxTcBePRfo2s3LulUDLVJWq5fmLRWUVXYDH7D9
T6u/U1BYFwfI1bUEAbBTKKvPBK0TajK5PM89ZEV2CszQIE9zgrcAsFbiqduO
ukysGKX0i5j4Xx/9Lx6YGJFT9IeX/q1RTpLI7DK+l7myEzTSsWgkWvXdbNXj
CwahUa6qVgJgflAIxJFKmdAgg08YZ+B5lyQlvc+ooUxZcholfkjtHLrGPtKl
xD2hD3b27z3z+OeBoO+PfgouLMOki744ujsI5kCSQehRrwrkwX2tm4q0zYHb
E9KM3zgIbXE1NQ7A8z34PT9zVlbFTEVHmQNUUDcdDmerA0S0s5fNXISV14zm
2QVWjkb/i883CCC/cLG0zWCGi/hMnKDLMNVCICkOaP+xE9jsFfTOoET+6kEH
sPkOYGNDcO+bODZplqYGuFcZQZ3UIEiMNkJZR43dPWjvHfSfVxTdN4+/AhR9
e/QT0M+AjH698GwBSpeXnsnXkWVLgMj38HFkKVSCsh5E+wKjnaGA6OoZcADR
N2G43TaG27saCyhUsJHzvMbuD4J0LsJSZMs1GFjjFlj7rKGaBk8fMxrqy8DW
L49+XnoPCgvcqQuYyw6TeeIzyHq0PnS/SJHlJrLv/7PYEd5zrKR2zIQNUqlc
LQUFXO1j4Xlv54ZBVKqFTlwKukqpDzdOkxdrJlVN48Ey3gWGdmMEPTAI2rn6
wTgSxvlzCJfEti/jFsuL0dBZYNhuUd7Ab2m024lH/Ie7nkf1qsHK/lXSUcDR
a+gr0ACOEvx3BWaf1Pkwjt49CzVxVOeTGOpLmPrc29mYjDWWx1qTKVOdKdfI
CCtNBXS2s/jHzeMvAW0D2MuladSLp1Ll83Iduc8BgGOqVb6kGECh/oDywetD
DX/jO9o5Ieho+IkCeR5sB6BcvXDQiubqKC6A7WNnNfoVzPje+2kqMVcxGU9L
8bfBFuMa539Zs4VpzxuNGQbH1WTc8fMfnQ2D5lKrvnmCV39fxK3uDGY+Lg5I
+vGvDwYilwvIuGaO0LjRdVPohb+RvqOZQ2InH1ZvZFLwVM3JOug5n8F7NRAJ
NL5eI8vLDRBePzPNQxzHOtTgFDuC613Je1s7k30Xp0BeDMeWQDAVCO6KStyr
hqAtmv1Z3OCFG2mU9SKoD0Fkbd8In3PR4TT3995lINAxhUbJ2IcOtskwnbgq
lUhf/8fBi6cQo1WKvSB4Pi1+FaxQQPC+sTv5vzfw31UOx4ec47opoGgF+uJ1
I/oM6m+izAQlI2jq2DjMFIVMs79BfQZh2OJB87rKNrAqv21IzudHM1cQnrXh
oOFEoXcZwUHUQWyr6uHV2+yy7fviP86VCEMrgt2BSIODabrfE3ar7rywuwra
D7DbhIlJlUrtkEFGFH89p9naYZXIZXBv6euk8MqUW/b+yRTzuC+zeqwKzp68
SSXvKcNsLSrO/QLE5NOXOSkErl9XiRnGF5g2IENHmYvsS16Qz/ESbrlheX1l
QAvB/3kOTu4h8eyEc+myajXkGg9cIxO3Xz3f/Yxav3E/h/eAsnWN5CvK1lCO
HUo0IphRma3ALGV1l5LpHuMslW2J1nRv8tQeUaY6BzR4iavcV2XRqLr3AbWH
lzAdl9Y2VLFG0/Mup/aH+2W0eI8Cujm4sTkkd85x6HS8GGUD2o7IBxGoNTLm
nVHu7QYJsH42GplY/sp5b2yUeAPU3gHU3jvzFR6heEDdqLWzkoLCzrFfNGbH
NwPw2HsrtSYl+3Ytb7efyITTjEzyJz3Q2V0yoNzCWr49vEnBL99SIb2MZbAp
Z/ry9WHG8mkZKQ32HqPu2G+mGsaXCuomizkkSEmq3gin41gcCH63t3BrRyIP
1R+eAfC7JCRVHV7qjNEZlqzr3ma7kDQLBzIkfvKOsScl2e2gA98+k9rf2BVu
OdQnbsOnIy+wyWkH0oNFRSixUGzPbxxkYGVLnqFIsKaJJ1Oz48TUJCd/LRt2
98rnsQxD2yIlgRYCxShK3S8FjJEaPHa6B28Yrh0O3BI1WEjq0n0s5N38LcPM
5TiEliAQkmhcxAcYlSIMIMxgQsVajz58T+3OoA6jfN0nz4oVJi3dw59iCneF
UynYp4X6pBcpjlWwSLlLBrnTlN3rMAofy8R7FK4JCjcw0SsGhZ8FCpcvMAcU
lmypTNK/9HPft4IaFmn4kUZXUt3z7toQ/T+1bTqqGI8ltuxAp4P+Yo/DKsUo
0YA5ogKNBmwDjKdQi1VQJH2YMhA3MGuH57/J0ahFTax7LdiweT+rHulxkzaR
USjkgajRuMCSjHqEXmRjWcHLJhQfyTIT4TJaU0TYvNrslARE4TCkxmFobYkX
fySAHSfArjldDIwVY8duArMX7mcULNS4NXJsuTq3KtOUTUbyYAgaO649Zs05
vEQ5c+9E4IjsGzOsvE0F+psDz0V4uJJTQ/BsVEnFsVD5vkQWbm7DZGMqrwBt
gx3I767D+2VZOf/djkKLsgZd8V3USuEq+2+QHGhlo/nAyySXWhpLN4lz9Ii+
UFino3Gfwsa2VGC8K77ox1lDHwHJonlbZZq3dWxdj+wrMxw3ecUePnfYts0L
1MjWp7mJ5aQVivTvZ4DljQvOoss/rsJyO5u+zgMDaRqE6pXz+6v5xoCkcTeG
FgRyEQnnMbw3cH+UJaGA4bIIfMINy/hIc9a7m4DwKQQi/8nMqGvUCZCu+M5m
aVuSq4xgV1/lpqzXVsUU1eEmVgGaVfw/k8M5g+c05Pg38X4C8gTbPUUwdzik
RFBmJi8Dcie/dNm6kgGbcOqEmLexjTt6glU7Uhi7JnuwG7SkBPZN3rMnKvnT
gzSjeZBMpPaP61Yo14pT2VmFHLX4iQDtX6or6PlNjceOa3mHIDhlHuQ79H1H
fovxYPMmBMsj4QsNMpbpYe6ydsSRjQYbaHNkoD3JcPzw+XFBwz7A5JNwkGhs
ISKWCYf71sXu+HJNaOD4k9DCLZZFMj9dKxvjeTlb9Q4tDNS8QsYBC6ZotcWr
yhGgN8/Kq8Kx7S8V/KbBA37AdMIQBgXzxcUkKKmgCSf57UMfHt4BrtIn2dKd
MMD4ZldxO0S9LuFVg/rOHocN7QLtjUFo6GqxzP89ueYhzKOBueYtKmIA3TDz
XaJmmTnzmyUeDitOm1vHh6FG5NDvGx9kqR1DGQpXFHJBGlLWB8dxdDh7NJ0Z
Oveo4u4xVHI0a40H3lhTKG+zWFwQy5ermBXLXvU2GXTrEoPV4Tpr0uCeTWXy
JFIVOtElFtiizX01bFu3e2ywo7yqr1dYSHQPx6Kg96Gi13wxIJapYSD+mG3u
iKFTZ3r44X9jmaK+R/fwxD368JSpi/mYlpHsqi183rYs5GvG8H4PgvT+cNag
COt47jH/bTqOxomTvynTaPR5G2tAIdKWxXsr5+W8x7bRMHFdrqIptrQ5MAMB
weteuE5YPvDbidhvZcu/khsZsOny8Mk+skX/J9Wcsmu9DfH45kVv/PI0tSuF
NiBMHV8Z0usmbsSWCDT1GstbarRK+INkzJQfQb1L5RFFta6VmdyWaieC0g10
/zE2BCJoE4hP2QpPvQVO35ZB+V72/wmG86Pnj7N/yGVISebp7omWx5mWt+ER
7PCj+0ZTv3vJmtpO+JpMORhng5+IJpzEtWnQ3TBzXra38ZNb+JDB/gzH1Ozn
3uhru4R7A0wiRbgWL4xw3Y4FCb95tgTO0XiYCYYJW2YamzQVY1uFg5yzTDC+
tVXot3F10V2lszegFcKAJdjZEC6j18lKoZ8LvK5D75HZHtRMwqKXiJCma65Y
0Zs6zuOTaH6CY+FQ42V19DHY98XX/liJHj9F7AN6PDlhdZ2tzU2COMXeKSxC
NkVHIb4hi4if41DE6JLtqFHBQyD8rWEsAk3SjRjg8dzTaK3DrmTjkOM7G5jy
Tl67N2TahY6TtYD2vAJvb+HTfZCdpPqtQQAvT9WS7H9biwHJMB6cn22Abj21
TAwSQNvr594gz/410Q/UJLI959o09TvO6SBZORiEAFyGhQ6Uv2VQLr42YkoT
rMI5Q7uZiVYKTbrFPqq80FkPJntr3Xl7fFyU9jbAiCivtxlJkufh2pfmjycZ
zociD3uStWTYUUlxQHSb1PdjWOfEGBkS7mFtSXNPE6wf/gTriz0Fq8JDG0LM
FtUUVMnulXb7Rt181gHvoXSKLoZfHcC7CT51N3TmN8TA4AqGTY/89jqigkq7
FA6M4pR59d3cFtuYA3NcdY2atAzdM/3ce6MiaUQ08rbWPzKcD1HtOwhf2yGi
7tFMy/2gAq9d8Qws3yOy1wr+NeOaNXcw0xhJ9vgbg1jp4WtsVwrkaRKoTXHl
4gEMjzuI1o5zUpO9CUvRjeeVjOP3T8bqP1U/jNb9TqgWUb1dNmB+sujRuMl3
nKprVRr/nAwu3l721n3REMAp6lyJEZCtZLFwmXsQaGCKHmfancQCwWgOkLKN
hlnY9LOwQ7vQaekzOnjdsMCnzoa2F6GKBTLryU0WV45mF2TV1D5U2d+teM2c
rhmtZcqPT+1ez9BzPmWnPh9KTcpyckQTU10oIc2b8euWCrgvze5AkmG65rTY
H++uuTFc5WucFr3HuUb8wnRVkipwy1UwKP39baZgkpFBLP2w1Xs5JSRiKk5k
v+7Whuj1nWx19o2GsSJHMnSTcc91H0ESCxVjE6Fmc13i2eukciPPfiLgH030
qqyAKYt6ViTsxd9T2EPEDdJvmMctd8978ZkNkLIXz8An6zjdhF7dApY69NN3
nZP4/C5jXwz8t4H994awQCUo0EAHrQJZlu4OyBoEtetXaRsoiteJmOyaE9vG
WaY3yvl2jP9NWZJ8JJAzFCbwGsjAGTJI2aKvMAaIAd7UBCiv4P4AnHhZ4drq
vvQ98HFyBgH5QxARxHaAfzIQf5UNgl3fsW4w6B+2UcDof9Ogvy37f7aYAMjY
GWdB08HJhV205EjZJNiCEDYV8RuOw3dCIqSjcqXbdKDAkeN8N4x2SRTBSs0e
J+x4TpRZBw1El1ur4kRktzBekhvnyvEj6dPTSrHTiStlFrH5wyX7qD5FAQYV
QBAfNAw3XAc/cHiPQgBEFhQACEBKXAjZb9JUicbdRYUcfQWZh3sutC0UQ2EN
ZPHmENYzYbbMk0WmodxUvIycJaJbNQu5DcafYoNwS9DPi65gnYhLtjnYl7l3
2SdQImZ6VUoAy7OvTaZ1JoRKU+7jYZ8GkwIZB0Ro/Tv8ECX6gQeokzjAcs8c
weORoF4PWkB9g30qIYfw4fMtxUfC1hRycBsap9+BpmiwADj0a9itXdEwSlqo
poRtaELX2aL0hbcHNPDK+sbKl3AAxEfyWX7OCoWppHdusGGwIzonH8XiGGGq
KamJNdmmKBb7eJA1OAoawivsAJnicJ90spHQAX3hXf6h4/yj7MBukfQwn89/
DKU2LqQxhhshC4JJ4x4Vtrd2MTe77tHzXeIHUhbNDbem5jdNUovtR1YhdBGs
9j3WJg+MkfHJyzcytth3oEWfVMLgWXG6Y5vWczKvIzbDuo/zum+5vA5ghuZ4
5Iasri42GZQdDVuozdHRJWfy9499SsLxkkf+xUogkl2noYbNmrunEm49lXB5
q+vQ4wNEnfJZ3/RU0wQrzMI5zyK7LCUe2sucCRRQZzfT2pYgphNPos2SoEYm
hOGbKgz7A8upDMupKOUO9ty3OXs5wfLEI8VP3Qe4WhyUZyVE0tZmqdmWsBbR
T7Hjdkc3nmjQisSmGXwPqGmJfrHJms8ycLg7XZP6KbInCuYEogupoQxWR4gu
XIeM0N03WUYADa9xsL+Fg1GnkaxAfAUM8E50W9oR9mlfP5DtR/vypRIghTuy
ifAxCVBbjQ2ePdI1tiXem8Phi/KKW9gZ2yLDZuHIKBrf82SqnUfpJ2RvpWnn
NxMztqXkwdLElG3dsivYXRWfs63ey0aILRdSGqlf4JNqu4MU0DzbNRqIOMat
bnWtTkcchFZ/T1Z/L2aMNot3W3WH2BwNlgDbZQu5VJ9V5A5HN4+kFOgQeywO
EdFgi5t1CFMswtK7YmYwZfAOmr0BpmGHY3IwZawayuiwFm7ugAoRWKFmBakT
gyPDFWHtQNUPyVxT1BQN/L0DctmWqS7mAju6jVunsrUpCTINYJAaosqEazTN
divommOiIAOjYF+01L5Qqjj2CsfRAYPZj5yK9UlDCQL7bvA/NlwyU0XSmKHu
sMHROSrn5J3C9NGYrXXno7REDCkrDTbuhZlIcTM9iBuyetn0wLkTwvk25gAG
TvPA9yHYtYuJxaO/J3khOcSWr71kYrAriaUc15i2C9FpWs2Wk/iycH8ghYLd
0GQyQH6JsNpRJ8QGN2ZRmoBvCcGXssHKDVSR7EnJtmg+rQo7ZULQu/D9hk/C
T2ZuwJuoWIh4Ee7Jrhf/bZDBBJNB/OUkCl8f3EIPw4goZQM2IAjp9MuUFLah
DfbBiJltpV0qd53hjYR5g/+mPE3qpMlQaeHlZCqitCvBSTFiky0IzpYXKYqk
dwrOiVYlrntHpYs90Upl1UnqgeBDSVk42LOQuAciqpzb2ytQB5eGN1WrsDsS
9mSxvknV8JDyxkS2ddA3TJwIj2jzJZoqOK2OBSfJ0ccnjHXxBuhjddBSQJMx
WeSUp6ADsiWsBEhM2nOINlNI9U2NbcnebsvVnMktBKWnbfGvtSg5vs/BLEmI
JRxAhQHSsmIgy46iNZiaTfo85pdKq6PBIahx7bBKK8k+KRuJEgQntmlZcSDf
4FY3stHhg12HRl5Yq2hnkoTtDNFE4BctnUNUnsnGn3F/CLuGzwbikCfdTcLS
eSDc5r5+MNAisEHzTZFryFnppPefOQ3hItFHpJNiKtn8OpBSYOLuRFrBUT54
MpW0j78SBkB5LdICWwZq0FIM1BrNwY+2wfuW1FFJzJFDIaCeY6lUyhhgIipR
ZKYJwTTppE1b/Y4gGNfi7B0zzjpEbAd8k6pbk727uU9rT7s9E977St+MPw+l
guokUIxzwcnJ6CZ7ZyZl2Rsb4h+pqTLBVGP9AyjGTxhL5RNnQ+mmWGapMNPY
dYTmQEjmgEFE6qbFzbSYOVs7UBA7XgCEQrH+hbrFG4Fm9iRJvWbWHtW9iCJq
fmZ8A7NkS2TX8RF2b18pvcCncIHX4JnssuKB0qEVfxC2SM/o35zhYCko5xjm
lfHi02LXIKzupAzniNRb40jkI/G806GNaocCKkRnyWWSzzHU0uC4y74T3O2z
Zz1IWRisewNueaNoxzzDBvtsBeZ3ROOqDWOp5UDymZEUZktMISMJC6LGoazT
G21HOhbh2pVIKszoJGwnQEqG6IU297ajgg+UAtBNbqB0Ixe4KGxtQF6PhIy/
FMYyCdZMkVbigSat2VeQzTy+z86BBDFuqB45RMzVBtxYcnRrFneFaIBSxjWJ
4dTpYTpJFbDJoQsHdJjjA3Au/ED1SqlYigHT2aWKwoI2oeWye790ydnBzR5N
c/CyrDtpqG1lTtmXeOo6zN8mW3VbfuXFjkm4fiwuGknXxbhxLt502LYclp5I
Po+/k9PAHOXkfZt5VrmeZ5VtSL23VugD5jx9VLpQhmI0a6VJHdwCG7ywUJie
D9FJhkllutxOAsGk7IglfA2k5auDlYlB2i6ulFvEbmF2oJHsiq9wiOgTh0yk
+rm5K64Q/T9ltzRVG7VYN622yr5kShBo3TGMss0Jgij7I1548I82WFpsOT3Z
Km1LJRxPp71R89lf93qTyCq8tB0vRx3jIV0zjxv7wQzmnG/Cdqx4DQ+fX9uX
UJ6IAgpHGoZ+3jDE8frZQPqq1yeOXbOy7NtzQsq1+O5YdL1Juut0/fF2WuKU
gcMGQ2SP+MI5hwBHyMnvSNRtm20Sio/FGb50E3tbQr0fd/OIuYOU1HietHih
3VR5GVY5jbQtjTBTueU6DlDFe0ji20XbJWHCuOEgFtXXJwXioMdfI4NnkFIx
SMukq1XSZteAEHKkjHGojIGspAqfJKYSmccGkFPaaWRabZEDE7Vm34jEi4gj
kbBtcwvlVlHqGF42edwpC5bESTUUxt5Ow6GG+6brQRaaMySjdjcOw06B/m7y
M7TmZE5I4YD3aA+wzok0T8qYYdU4KB8bRkWH7wM4UUYJtF5K8B1dLrYcAfhW
yA3tIfVY1XiLeqxPh92RYaHYQCUP2C4U/dvZlJQuV4lsUkq7UWIzKNHTj7jd
u/bKQz0H/dRJhSq5IyR6s/3Bnk9gqk8OrgB8BMvit+yroypqhLFCU/CLgxWD
QTEAGw6fQBJiPJgM4Vc1WGoOfcYp4dKoQ6gNVoV7ygaJRLTTkOrkUGdkJ05o
4IGrBdh6aKj5QUwgNREtZwIgxAUTcezDafl2g63PU9nPQe6JL+F0vEtrkh6X
WAsJKgawuxGfySUsERM0sdQt88x1ekziwNHQBuSAzYYDKSdKjrikXR4fOwmO
2hNrHZ3TVH+1kBxUtEs544plgPLLmBliSHARNDHEpBNb4SCypLGETTal9yut
wGtqJexHa7nK4fQQmXcuSvFza6lNDZ1LXINFzO6YTngZF/sv2FSS8MFSKQiZ
D70jeam7eRPGE1np/p6qQSXiHBO52Y1YxMX3nIEKxWFwxmCcDuaM+dwGz8Q0
TdLH48aUaKne5NiPmzgUQtFBcKFI4j4iBxr8g+dFzwHZpQbFVCp8koqtKv1W
OOImMRX4Jin7JigbCRLJ2UEflzoW/4Oj7qjgsnvDrms1F9J9OfmaynUxcrzD
b1esCet9TDOHwPyW6IZKgXRhZ8bN7scaFa+dNzxR3PJdjziwcNesBogHy62l
Ch+YO3Aa2IXjFAUMyMC4GZpcWVvQRtqd7K5zkiH2NYObsAyDaiILA0itWcdd
OhAyUNVAuw2uU4RV17DCXViuF5sofZ6+8O4eeKKGcyIUwTOPB+4Xj4fQWfLi
pgVTBJ+s2+lCDlNsboSyyhRkyPGaJq8shCzhMwePJJ6o+7W58ONQgu6OoweF
su+pYHAcOhMBpRx5Q8P0mhyksKivTvROLYcHXLRRZDIbbfAD/T0Gc+LaKj5u
XYRmj9DTYAIrC0G01GUkuwA/4KZSgSTmUg1qZjzwluGBFfDAvX6XJtdCEeq1
rglhSl9Rz5bd3c0yPjgUVCvsDQVUtZGlVKtW4PJ2D41XOo5aTO1IZEoT0jpQ
eG2KiFP2Pg7YvD/nJo9ABvpng5OtE2VOJG1L7Ng13xelv1yPBcp8lbLrqUa0
nqfCLOG+7gRARI5Xz5Yo2hH5tsb6eMImSg68cjx2E9x+mGWPdE3HSUJOB4q0
05rmwxHmTzcwNDlKhnioG9fYJnu7EpHUVi/XDS0k8jx0Z/b4GpeHlQcgKHuf
6kbthP0I42Wk/Ezz0XOvXa9zTJK96lSpgbxqX7+lPsby+XyMdg78cNTLjYiC
sZAeeBv2mKqjKOiuZ8xzcLWjySwdCbBaMA6mg3FwGMUgZdtEc08YwaFTPPdB
klmkCOi+CAJPz0wtHnAe7GGPl4zGpvYucFp5kY9FestBSnWWe9d+VUIYhkXV
q0wE3QhFA9u844ipgMsDeRfNVbMZmAo+LnVd90mRB+sg5EAP5SfQL0qkH14a
jGWJ3qfQnvIHX8rqIOEAQXHTKPaG+XKI7J1T1h61cXaSvHauFADFzFy6ld8f
grRTKMU6pe3lCWghgeoijXV9vZIdYFLQJzc10JULTYxrgsI/M6G2xH5cc9zy
QYymNAFGvJ2ZI3VSGK7WxdKgk6A9icNnVRzbPbq840fSnD7YFyEBzA5Go8Ku
oH09N5w7Fqvi2Ok2cjL+dEmTvVA0H1ZVqbh9IFQmMUsokLKNYH6feDbnKT5S
Ks64Qj/hQi2lCw5MjGuzJydZ7x2Oot2uxxjFXEcVHyhflAQ2Jsq+h6Sixclc
pgtiuy9fJc6wdFGwEFIOydPN81mSR0IbdqTMHE01V4986sz5TELU2Y1Mheum
ogHypNuGUsgS6SQupdlF8CHxEPT1by31kzVOfCS9J5UgHkOYvXkhvwJk1uBI
CH8CCcqEilfUa8E53gO17szWQ87KNnYj9uAEqDU5kCqlXWk74nlzUJtep3jF
hGb4tT8M3TXFPXxXDltJsXjpJOKTMbzyCRc2qg3MakP7eqnaQOiJIxiHsvYV
xog2ptEivW0piuBFx/beZA90rdXcSUzVnJhVHdySOkpLV4k2/z+W2gVRarIb
ilPt0ngncWF3qez3uMVp4O7uAd3gfD/RCvqlVKy36bh1k0PupMFZlxvdvJkT
/n0c0F11toELk8rWRUXivD5IOYGwvaFyAugRF06VEYgTO6QZlBPkCPbtiQvZ
iILTQdbGNdZLhzJNx9BQXOm9T+ITsgpGgUfbx7hkV1KeCavARNLo9A1trZ6Q
jF72XMpxlVQFyUqQNixBnaKV20l4IRShnNKqTz0hjTTpow/XudJmDdsdeBca
FyjtQBQ7+2JbkZkhtaDtuHe+bN83RLIfHa42P1gi6Wb+qjVyJBl8kYBrZRJA
Xs2RxKoqqSTKfrVOhIAYQkQtx3A6nexs4bjBjW2ZuyojYHxfLFsYw1jrBltz
3LLrBOwSlr/pX/dfTUkYBFiYPXR7Ou81vt7dosBNLvYT1gjygiLlRLrnNNQs
WkP0BBGcTH5SCCHdSDt8yQmQybWia3C+og7u75fZzpdjkLDz8sCQCZ3b2WFr
hKecFoa60rTZ9PAmSDMkQg5ltRjRUcV2Ig3xmC10KSmUyZUAeNYxpjSxNZnT
6umBvKnBMqh7Thu5nSGJVnZy/o3LtplhaJcZGz97jiMhjR3tZqD7Gv13prAt
bOnVhCSTOSHILaLpU6+tZsIQr5xmTjYLAtEUn1YYjcSc+vfJns61YP2swr6m
CoFtxAhuG+9mbjR8oq2ej7Hux+KQ4++O5ROJ7QuTkPB4o6SsmBs122qbyLQk
HDJxErYkvYtppRDGner67djF4BoeMVIT1jZIrQdNcihS04ilBtGH02DK4Oce
inOXo5hy6yOmmDqhk5hiEhOiefjch2haQb42KFQszLfF1vGOiwrhvTY9hZb3
pfaJdEMVMWvzZ4PAGlrp3qvs5zx2S45n0vvgGTVaEAQU85Hy8i0nIkb/pppO
oUVIXaFggmyUa/ka7hMXkvs0B5MnQiHxxhDW2xqgsLzT0IKpsJ9V75AFyBdH
yCyn2a3glhqxAJlNIiGJ0pA6jEA4snMyNO+gZbpu7/bRh4XwSoMjsNzbM4iE
iIHs9HPOsyEalrYgYc28HlrjpCQklIuA+GfTJqLmow8fPieD5tGHYtA8GBQB
0Wxdr3pRGejY8b5WmmzKtjQ1Ishsw9t1Dn0VApNOoXanpWJBdANXx2xFmzUB
UfxXhaICx3R9ebFlqLs2FlUQlMSJ3lIZkhI3sluvd7dIIBO361ktfjdu2KjP
G6RaG7JjWE8lahLHmFCwxHroLdztPdGW1848prHp/E6dRDbxpBCujhUuvTKU
KvtupkTImTHlT2vq34Ypt1+abL+o2cVhTB2ks1onQjAnvCckSNSxC/lbMaKt
1UG2zWKRaFgeutZq5rimA365ue8L2Q+l4koKcOHos6ywSIu1zu+w1ko75GFN
ljblmLO26oAJdOK4adim7PpvoPmYm86bMOaexVx1jrsF0P2nG3CClH+h39ON
4F97j4oGOu9vKCMZWkm94g3JdXGZZs8G2Hy4+zmMTDDHuDlmdpaRySASeNno
oCOvsKTMpmQPEbssE2L4O42xesTlki9TDEd2JSzn0FTO1vVUTPGb31rmNNnG
eSxWRA1mmm6hE3zz3XrGC1NfoBp2BegDph7jsK4nmBPVbBTzw2bPtcy4WeP+
dxETJzw7zNCindAsX02YdWmcI/qfGE3yDPZEl1LOITJ4DRLrxaJ/zgHlvG4o
Z+oMB84+w09P+VCeG5Zy7NAwpN2mnBiX3Zs3p/zzKJDb9GoMa5rqfpKyqlAL
X3ZPdX8SUpUVxRx2P8m+IpVs30Mpdw/2CsuVjcW2CqpGzGha+yfZ27Nx/Ske
n0IPad8JLYelCN26Zw0RCWQ9nXpFDJZVx8dvreFf2d71GGWzj7GtOd7/RaOz
bugIH5byD2KhSI/DrlMirgIPDegUk948FNmN3SRIOKlMggrkFKUBaE2myxPH
VZXqTP76t6tI7NarDuGudmXkkb12i1MD3VPLpaxUzVKwgQ7F1oBAZoIIlyH7
d8IKJPe0YXu5/fD5ZtgAxM3PWmGumMIrJJKK7lQpxtXeUg80wT6YSrbViLTm
96VX0gXYyZXSU0vyS145SdME9upPpA3miUhYKjxVkLDUhTNYxSIah8czxTtW
elJSwsbCJijJhoinQEA34qQDe2ClhJWwmuPcCC/tU3DNU2iOp/irlf0x+QRM
qu2FuFyOCGebiRRVsu1cDYwvh8ge0HJ1mGVI23BRHdm+0hc+fzwJbCTn/D67
NJzEcSq7EkdLMndP/UL3ophyLXVYNIDm1L+uU6VSagcRt7DPERej1eMay011
qswK19PELJfTSC2qgQxKWjHTd5kYNp7h2adkFzQzQUyeiYSeIm2qUa9d7V0z
372wx46wA2QV6ZgnkM1TU/TpdAf0hvgcOLlAFOCeVYByggDDH7MQZKbfSE85
9yRsGpG83GTiSCWMwjHlIx895LBoMH7YWzbYpBMOJspoBoUv1vTRrjKU3LQ8
w7Hd7mbQeNmraoqoSXkkipVsnAYvr3MfZC98gMcf0G+m56BnHgsDMd88fG5r
7ia4XBOK9gkoBvuFZJcJNgrSkTToiLbteIO31RlqujRNlHhmcFFibNepESU+
dVMnctSCsgvMYUMgqCjSQ2RPnYZD3HKfte6eRB5gbYhK5m34Zq1H9zITpl3q
J0xrR1p9ce8PwHqXe08nXqCusUA9yw1wCGp3lmgqMvI4V3Vw08wm2c6ptidt
2OZgJH10Kk+bfXtOR5iNHsfOdxAeCHV8DFX319RgeSYGC9q+nIpknWL7tY3G
Ko1o7aaYexM54uDHDOPb1U7TumEOJH7iWG3IKesznYKhEsLGjM/HhBHRBx8Q
SbQ+YPEbk5VIsIx6m2Nqh4SNgPe4WzusV8oabYMgtqSpEiK308UjU+D1lQTd
PD0nBc4YiCXSq0gzcney27lxYgK8PulyJO5MZm68dqzmRV+CHte6pd1iMNfy
SiOP16X+iuDDiGim34+Ay1ZtvBgxm2BVBHPD0wW++1luZpC+rrGpgC6+Xk3C
0FQiiNJKnQ/vGA9ej5R9Orv5xyuue6QCBsAYXprpxPNUjA2I+a1im4ZC2wYu
OGGj19dGJAI8mjmrq8eBSfIQ5sqskG5U0tCOY1XuTFLd7SNxUW4qCSUU3ILq
MVsgHzBEqKb0A/BFIuf8XIuphGIAHTI2wt4hrn3ZEj2g/U7a3AFjJ6b9K0cj
pV2HT8LfbfWqxSyJOgTC/uhia/dgGZIMU2/PQfMSfpmwBorKhfBKv+EUV+SV
fs0Xuvh2TdemYSt2oNEeQ3Ywd0t5+8SyDbRaBS/jDmpOOn3RjccirGFjfdyg
h3Rgm5/addGG1CHyDWBFBrCUnNzoxjap8wUw/uDsZtjroWEVbwmk8jgCL8Us
7mqAqkaPEIQixJqxjs00JKi7ZZPuhzS3rHeqKmb8A9xKKpYLgSB/m+a34FJt
EdfwbUy3tVPKuD1nYUfcrdps8+5lsA39hJvPXFnLsqj9CJe1aMRRA+r7KMjf
NzW0kJdiOLaSWtzKjrK0lLNW7uZJuEqVyW01UkP9kAVffx6zZT94WAvnMX00
HXHCZTmUQJhlscvTTUQ1lqDp+tfLLZfeJK/96oRx8tKacIiFa09VO+bFddkK
VH9xXKaa+4ZqrrFpw872taiywVWf8IIu/dobl0tlEmZebS8CmErovYG9H0n2
e6e5PLyUT1C1JzX6bt30HckV/F7E2OHIrjBiyobtk7wDlRj2Mb+J9zYr9UzJ
XtjHst2OGnt0yNyxTT0Sdnk38VPItS8wT+Zx0WrYwO3dQTFP96CtMk+qzEOs
MXUiIbJC2tlFG6ew/9IwjpwAzpVhjsvyvMwfO6kvSJEilg5ZWrQfpWYTZ4uv
tVE/lVNWlNQHZJ/T5OGP6GLy9P4IunhS/7R7ox5LhrI83uLJhYC22Ld9yMO7
n0Q/vpluJouEtg5vcAnySHZ4W+3wCmU4OHZxHHBJiVuFXXLYRbMtu/nHiBRv
+KHG6zk16PyxdexZhX1ALW5jwCcXWFEi5baDr90TUkil10iPJJFvtUp3HdVb
PY4tFnpztphjefPEP07BF5IO4lirbIdLRRm0tv1ZPuzbcrMDSTLmzZSILO4P
gCwQvOrtFsEHnuS1kRa7goJ93wAfoOmwiZfqhozExQ2eGyE3eBrZPqEtP5Wv
7cpCcrJh0+m2Hs8J3dAJZPXyWLrkfZbqeT3F13NkFH9FTBH5yMoHfPEH+QBs
TQ+SLr5W/jLfh2jiZugYoYcRaaBW4yrDNTqmUqGFUO/FA84LE5Q2FUcftD0G
JmGV246Yg0hQfOdzFqfSU++x1F47qVrblYaJ/hg5kl7bwqy84s2wVRK3POue
4bHBWuKLZlhqfA398/D5B7RsTcMU02AKijFLfg0F/KavJKqxkx0Xn93gjwHb
FV7Xajhkh8uNjAGUwvU2MpQ1eBMnQTJdE/sO5i+3TYWtFI6D3JOtfR5Q3Pla
ausjKkEqKIl7vLdKyu2dVAftOC23v9aNCkrtiboZ4KSKeGqYIzRDXSIo5VFa
kq82YieeSsispehd5+HzZ1EQhSZysoJFoHLL2AZtbTcle8NVnvti2Itq3VGz
I9XIH5ZUddlg2eQ1wybXs9HWrI4UydDvGLf1arwJiFtlSVC5yRv8/C7ghhQ5
4n9c4aP7CfObBZXAZReEL1jNleg3tNeHkyIRb3O4Qq0bh00soxTDJknOCkm4
LCWRHy8LjoqVRx/CrekYexP/BvuE47mGeBruXsrHeKRbWk/J5npHG9rasz7U
byUQp3toFBNXvZ19FKWO7wwmdVynT4dQTspBi06+Ap+2wmxSBQOK0Nnh5O65
W7r6onMIZNq8sqkbkY6dnNPA2SSxYFIXld83THPkbnBvlNFMXdoRG+U8dSlM
cPN1iS0XtW3pxjlYco/h5iTOF2XSjpBs2blC5RlnJaHtadD3dgr0Ai5L97kh
7w68Q25711Ca4T69KoHoL7It4GW1dxDUnkRlCbpWMvqJzJbzzE3NAvUox09k
82aDi2PWXHQCb7BlWQEihpqokeNCt9RD3XxijnZAXMYmleRcBJ6/nANjnXbL
Lc0+4yjTrJj8ATe++lH2aDyWDrMcBXj0nIio9SxKHVHl0hMIC4UT7sneG+5D
kLIDh42MvPhy89JHAM0jmqJqpGEl5k6MnSQuhStlnofDZx6R7ZxSpQBHy3KQ
RDzW5AA02S3RRGTVixBxEw6KZ6tOY9tN3panvcX94Q4HQgct3UTpfJMEkopr
3eikEP3oK6Kav7gfS6kiaFPvHmDX80Ozs4ybW/AMwHM+BhehUiLRajkrkSkk
0qf3TsFqYlOG7cVOQ1Kh04iRS9g9sGIZ0HuBitx9rYEbJBdNcoZIT9BGuD8x
gdQ27+j0u/AwV7luKOvaDUVtom3YR0kIvSFsAn9Mk0nSkTfhmhia9fzRVxM5
1qgwd6YKWaKJOOIyHg5H4s3ialCljz7kwpeUrZ+UzF6EcR+zPaZuwbH0fzAb
t1taTYpOM7tsu9g1belxoMis78oxeOpn7eV1TLWd89pF2YZovl1CL4uu76iA
putyxtADsE2Dd8BsSPPYxobumOAgPGRFOKehO86JdW4e9DYauoZVe4EcP/Z8
lpHllXo57zyv3Or1FaA+zr2FZmxccEu+WML7k9gSCmdKNkwV0rHzG6lTrUxN
vBF5KA4wJzbZmJzguw2N1yTnidbNrAl9W1SSzuWLMs5N3vJIYg2hboB1mraD
LQhoXLyIMaf55TFV+/fcdLmpxDlG2Qgqpwk3CqYSvyHfjiPZqwzUWkZpdy30
rxPOyaeS2kJmOGL6yGmTSThjuVZFDd04c+zETgIHKznJeYCtcIg2r3GqEilG
bzOFCOwI/mAi21qnanvnjRqr7PKPg8QUWmM3XK80RXWhHJHZZNkrkldOVSIa
npDWpAcOZs2QlReHjLsTc2zpjovOWslRT38uUgn11DWJqmmrxi10jVd3vwOO
3NDj0NiOSYmPcKLXdbNFEm1dOmHtmpjQxiH3iPWnuhywI5HqT/DWj0R8mqXK
cTlvMNcP9DD9ZA5XyptaUjF7OIYZN9h3+fpWLhhJzTOwjpRyVrVXRSemo1i6
uA+lHK+zJXGOhotau5QGipm3bFVdVWTHUlWu1PfRhygQ1j3/RzknUDbcK5fQ
+uXXzheIpPsS+5StuykvX6rONCJ2e6I8ijUxNmh8+6zGYV6c+avPKzgXvJ/k
Z9EIqt/FFrZsrqYlTy6cfG7qIdbrUEIoduJ2GKgHuxPKXnpX5PewYro2wr9Q
dfDiechPuGQu/7ptmFl2C8kBz5KecHsku5GOvIGkQbGJshvwp91KnDNl70pi
jVFSA+QS19z1Ty431JYpJ5e2MW+uIUPDdS30zGSeWkxj60Iz9Fir+YO6knXZ
gO58Ax7ZcLQK65u9N5jim46P7y5uB7Ap7DoRnardScFto57a9BJHX9IDbjRi
dmtPc8iyzQ2Etbkvx5mk4SdphiYHtbi5UQ1SudFr2RqxRdObVfT5LqxA61td
hx4qRKuSJfTare5uWNhE1tQuS0wofES5cxKR5toX36qg5LDpsPussS19VGNi
qY/yqrBL/VqZvppQ5Yila0K+mmRKG+Ok/hTCibLvpks6fGN6tBa/GzsVWVTJ
qG4qkx+5gfHLTUMmqecafYZb8zKF6EE6Y5yD8c/b8pEmksK5NDHp9agc92Z5
p4aIjnCwFz1e9a+zHahO/m6eRJKyWhlrvORcMDBLZsG4/bKMuv2osGcy1RUS
FZHqCa0p21vQLXWI5EL7A7pHeGMuYTPkPEbIiiteWy+ao10DEt6pWyjRzdNI
6ckcCcwejjBzbZS7ISmISljWtETKX/eg79+QyRNGd4KJTwwqJ5t6PwHXTpa/
zrEZPdaO7qnBYtrk/qRG512cRVZMMR3tQmql94F+7PCbiMkikTCwCyfxMK04
BGhu9aIGEQ53t+plLdtApFja/O8JiJtdIZ6PstiAsS2ZIbcphQ3CrxUjxmK2
HMpCwGpMeWUSPokg3ZfO9j25YuUiXEE6vbK/nAmZlBdjhbRn11KMxZqkUHbt
rTqkkmcMU+BvNhs59ZVKfCdOn0uE7t42TJrisWB9wG6h+vXq0aPSr5o3pEdC
jyrBquudjxX3ukGYgOZMrpRDKHsCIi5QO3YVtFE/eJujDUlbJzg+JDYpWhC/
vEmhjzV84vidUaAl5cecSFqq7hDVbQcjAnuUakq4bV2+w3YxaDJRKIdpsy/S
5JM9MK3WLCn1iJA1OxLnJeF6g+YuXuaujyeBMWxM9dbFc8j1TpjBHd6pi/my
YEhdyii/ts71fG04B6yHGVLCGvw/XylBURV2irEBhmzy6V1X1bY/0ES/Bknq
+tg35Mov1BOP65XM0IUlBwv0vLjh9Kgell2S07ZWW8vJLQOniltncmAItxiZ
iLe/2LYHUy6EPSypTNjNehzzj9LOnTwTQJCUFDROEvodUcO9TWk8Y0s3fZ1e
PuBRZVnkUtHkczQfRgeIldKNxj4Q2pbypGTfuiNd2OICtW69y2pjZkGxTeup
FFkRLCGx5zAd7rHtUIMGEAcq4YVZ83cvnyiiC16aaipZi3sxppwqXMd1aNXY
4OM3ZurjrGeAtmfb3NJrw6noXYO7i+dzqTj6H36i7H4Jmy/8Jiuv1gZCFcuG
Ku4qVXwA2UtAGC6RJc/tfIkipCWWRLzD1/ZMCybJGGTjZrU94aNrqaaQV30C
MVmTyCv2jvgAJTu9cg5xzrLIhVoROg2nm3cxMqz3E8KuzXByn9ZkIZjFWTpP
59Vk8tnLIhMmFK0gp9vPFvYO1Uw94x0bXdnkokZF+bW9yYSuHS97PhTfOR9f
T9acP506faDGyAPpaC8GSaN0f4Lz54GkpQzS316hMgYpIj6wiX0d186XsEMv
RmmSyFexjXQ657C+hErxCj2+z8f4cE38oJiEGhVOOimrzW2RTLiEFK91nsFZ
IcoYE7OjAQvDGhy2p0rbEE9iniejpBlYA60YndkuELYMSIgs4URwM7Sf0foD
53wyuJICiicWKY+khX2IEzYxjBhHeiDVd7KtDmWyR07qTKQMR6IaNy+fKMT6
kDq8p9jNRgV5CXdo1sJwWJSdZwbhrrdp0IMd+rkeDkMfbOJfT4pxD+GJVZ/M
4Y71G2KxarKYC7xJSmQzwa06BIEbrc8fgRskiNH/VkVxp2bq0hdJZZIXyn3H
jVwk7Jat07lKPzw5JDgCmYJQdmM5V5tPSJOYiCvAAR+wnKW8nd/bD/0aGcVt
/mS2jBdtDvFXkg1TuMaqJC5cE5NDGjrslZTm5yKmaD+A//U2LMyr7DOmpvhD
+v+lskklvd8u0MX2eeniYgfm6tFgh6aNbYtWVvfCEm8+E/KQLpgTVe7KRYyG
PC3Uup4uvNHt4yWpi2iTGqZVWd+1oGlYrfAGmG1xe8UIga2a5umhLt4RqYvt
iPofUBmV7XU5ABdqP6KmNdL4yV2cL5aMMSGGhQp/6ttJcvtLovNMmKbZTS50
ZKAx/oyDos5pRjbyZqqMilzsNIl9HaEhJo40b2wom2j9EW9/1nObNvR0uE2l
FlUpOXJQThHrInfMWGnBGfZyOUQ4wsnw46ZzlGyIcEXe+OJoeIO5wwvYvgvn
PyKUxCc3POEi7FPZl5Tpi5Rtk6fiprKmaHrHdU46G9TmgotYFBVxmR6Xw6ro
lfhdddL1IldTnaiyYglLOF1zbdtVewv0fTPlLki5q9Fws9l9zjC/1fRFCt/Y
si/6oscDY3MchIjGwGjjHj82GcuoH3NyDCSEHmv0mOr2eeMv73+knvDWHmmo
7xJMEt2lGyyMCoMjF1LFY+IcetzO19CzEaLLXKilTtflRO3UtNURJ7aBSZcS
UY4eZZYHZWGnZDYW3DxaUs7qaGR/JvKkJZTg58SbFg+c7uOhhroVRsgIySQQ
Ck3eZJmcqiTKKT3RZkPsK0vhASVPECoxAXTXfhqHTNKLGByLNViiKhl8u8vr
dphKNYejJ1xhyxAEK41P8JKKRhwD18AZum5pp9AWznWhkn2gOZuc7BbmScaa
GZOQwM1l/1WZY6U7nwGm1EfC91aeoch3EAlmysc4LrvC7jwadUIaRSq5z52m
DTIafiebNKrlPbzYiPjU6X7p8SeRTeKi8MczjcWBSVAAYiMdRYNjyjxWM4UI
JO/2qG80Rgs/VRZcNUzSVCYJW3Waas+KCcvl0Vu+pYJOQ8YqyNYuZOu6KLbV
Iv5mLpmF9miDZOay/zO/ZK+18JZFsj+Vln2RWapOREQ2zDQp7JaOCaPeANMc
npchLs4yRfOljk0tHQttt7WGbW5z4rSR3VNVOZCdlOUleco+Fb10Vzsddgni
KsEguHgOM6VZad70IJ+SAG6+RN8Eb9c4zN8J7lQ4dzDVXAAxVEu3UNOerXBY
LssYb6FdyMRrkXhngamHJDFx/J7APPP4N4FCJJFcQNRE/aLea8pnNrYOxNBG
y1uaq/OwDkhn0ZDOgzLSSSTaeCDVUnpgLRsxjdDeOfQksqRE1s1TcFEjNplD
yQjcEev5mPRvPg3EVa7sONmTN5Ai1vVNdX35o21Ba1XLBS2Yp/VVA2cO6zWP
FV3MvmmJ9JEsMF6eJdWSuDleUrZyWrSkixJmXCjU2Udk09aDFY8hQSU8843z
88wguYYEpatckgKYrpZaUV5yLkgmOc3HgrhnLuyfJ0PoqUZpVFLIFlp5Ku8+
j+kSu1h9lMGh5qI+8zg5fku3SBd6NeTrV9rhbzriFM4V0UYQOAdKKaUTFkEH
FoF2uwtxo5/aM4kUNtgc4l8OohwOgkqyD1g1TlCupDsfn0y4WSN+OdvBTlq/
NLSbghxU1NHGQ+bkAHhD4nBbimgUD6awtkpTOIc4JOcypVyNdLd+HRorVT36
GH7YPJF7mq3GUvbnUraQ3hJlO3QeCzgPjTFGq5eKOSMKxPHaLyAOb6O7LV8E
3+SGJ+xGsEF4DHgUCeRrozdUqkkkl6bowTHmMUxYfsj7G1NOGnh/6ljVE59V
k5pwcPpMGMfdDIZMKHjJje6uVhdCqA7Q9LicLpzuQnP+1EMXqCRXb9uiuD/n
qvOEssT2shBK0zlvJzdEic1DHBfcDRFJJ/96YtFlQgCyzDWKT7ymze2FCEs/
bpG1UN7kjXaltVlT+/R7ZMusnqtKZysrVlQcvBAkT+IOrBPPmADof2OlEVum
DRux1RI22V7jjZOmeb4Qt20qg1B/tWyxWj6L7HS1GtlSBQ2wwAySXy0mfCUc
rFKsOSImSbgSvk1IOfKJE14vTsVzgDYikN2rRCA0cqTRPRaYjwv2caYERQo7
R2J3KFP47lN0ruRjaTar4kO2igSCZ5+qtVIP/WVs0f16F9hivvrlykGxJvre
B5ntQadNZkPsE+QMJRJM5q8T9miK/UtyxtLHwbxMMlNDHYl62iJ/bZFFJRFa
hZu9vJzjHIuwZTKfF4XecVpmkAXDIGvGPJku1a6GT/LR3M6+N9gJMI9NKzJu
ydI5hTQEayWJI7jWspUIbhd7JHF+Y7A5ia+DP1cePn/0IR1OTxWUy5oJgiEp
POJiIlkKvgt9IBEJrVtHzJAFXaHUEEiKdXf5unh0gEiPolKzlonGXgdz/ML5
TIThsIYO9Keul0tgUNbnl0AhdOG18pf9KTWhryd18GGhga0cAnWuw4YJ55yo
WsGU5zKOmxXw78UiShv9Vs9I9og56+HzBnlJyykkbDETxgVkLIzBsezYZV6E
ScGhV08ZHdFfXvQSI3r0eI7fUDc2wjO6EvDZP18U6OIdQxdc4GlpYbJQ750p
jmxJcQIg/vcMyuOJkw5jWtCUsNnBBZJECikv+zNPGDL5Fv+pM3VrefuiKY8l
GUTvbQpFcIQl826IKYgO2vBOeMHYaSkSBTtQbGrQajWEuz1HNKELHD6KOWPM
Lco2JHX4pPrdHrCZHBcrzpgvvnMV+UKtmS6edEnxZC/CCJ6Pq0UosefT1oPs
T6GDEMht2cMNEo6wqHyRQKVMHre1ALcH4qu9lx6MkYh5DLLIBMy2aMWXMmVk
skYA1wIlIQxml0VQAodMZyXewe7yPCd2CtbuEsSwKeyxsOPQy2zcSZ8vM5uY
vrAy2oXXLQ2MMB4awmiqTdHo1UYj3/6wzRUJXDoxcQwD/YnkCN108RQQacoN
E7SJQIZtZTTucs3Ukoc/IW6I9uLwwmTcIO8DP2C64W1jkpdp5RYlfG2ZIRFm
aMLiC8SwKOxPt724JY3zEz62zzW2UUDvBAT40W12432SokgTC+dV+wNoU98P
V5SbD730mLYzrfBwupMF7I5uXJJpp86hFCI4jo0js8NBNzItuLqFDAxbbMCO
jWRyXIVNUc4QqSEEOu+xe6cUErQV5pBlUURLmZQuCk8sQKDIqCAG8dZsBUuo
G0L/TnrvRUcmkFGvQJ0RXz8ne8QSdUiysXR0EZrgWtRHqEvNlWsnZWVVcSsM
W9epfbMlmp46OW2JCluvaTXJE0nn2UPJElYDuq5kOLS0+SsBPzXkYNMr02AR
MT2ydVqWQa4H8e8y3q9WRDN7dgwLuMj8gXB1S9YGNl2L3zlueAIR03VUHrlx
m5ELFdK+EFb6p2FhSJqVfW384hro4rfPg+DLYYpe1kU1YwCMdRghfj2/jbTu
F9t4657kcui5I6ljiQ/apnQyy51UtHSeUZ2B2LclsVbTj4QpI0P77RpOjDoy
TfM3nWLVFPFcpsBGsBGWgW+JyFfIZMY1bEyoQGaPeY/5A9lwTMVx4UQoLrRN
d/gMA451ljFE73inU4rwsvzpimxsrlybHzN35bomJ8awQKtiOYLgKMQwUs2/
sWvyBH9Sp/1QQWLjF9SGX3kAlPHwObFFFLiIttckuRe880gjIw0OUy6Jq7jM
C6TlHMzpYY0WHSy/lqwNVocMk2tYstLtfKYZH7ZeSS++HqTxg6tPGjxqpGUr
3JOeO1L72j9iLZCZOjaOZzIuID6WEDR5M6b/NlekaBIw4fMfpN62wWFWCl/S
GRG1giB0e7N9uDQLYBDvGS+LNWvs3wbn72zUomXt3wTeMVkemQgX08JaTJto
Lz/ndD4WzsMiBRL5bJyNTbV7RbELoI1rFLejThVoKM1l3pITXUZuUx1XhTDP
UMwjsy2yBbOB0MzSbOUNEVt5xn2h590ijAzmijEYH0uSOJ3XnAitxVT21Jih
cMnEMlWkYgUukq+Tms56finc5JrYHqFm5Jj+HC/QxPdeFJooowpjQ9S3BMr3
i9YJYWDm57p9ctmgi6a6eDOhme2hhJmOuZageSqLyAUmZFIkwibWsWmZGoJm
KTl0Jwo2W4gmFkUc4SSr5Zu9NmdFs+U0GbJkM3xLcK+vO469LVcQWOMB5w7j
MpLSxEhdc2POMMVWLrWaO7cljbsRFyOfnl2sq+IZAgYKh6UoJvno+RPP9FMn
/vzCDyTN9oEWjGF+xWBs9NqQ5xx3PhwnUyFbEjb5VkpoGzGLjk9wLwWuDgFQ
WpRl9hqVjMYce0iF9iONMnbou0b0cmKZ1YN+YsWObt76VVrWXg3t7gTheaTP
ve6RD1M/eKoONT+mdCefB6JnssmBCloDG1UreimUKH7TVMAmsIiLaKXbzJ/h
A1ek7SXT00TTCqRxiG1EnhhissJUQdynyk3SLYKl9kSv2IVnCX9+Q3ofTFFw
QGy4s9RqSAot/HL724u1HDBPmC447sGOzIHuxuMiBsq+8qLw//yZhZKpb51K
STy9NJ4r8egQffBEI5nqENJoSp57IbBFy1RoLabeCllyiTwmpmjFZFSysy84
HBLUnAZXzPWLVRKvXx4lWdSNO5SYC3X8g/LralxbeV13wuA4JT0iS4HilN2v
9H3KZRt5dCwZ2x8qdGRkpEwUkxVlIUYExQnOG7YNzo42g7ZyOXZgwWMzhR4/
rGXARLTVLzuwEUFNiFvheBeEN22T4m2NYyQxIUwUTIiwm7TaKUmYvpHYLG5l
T/Y1wkEm+6lkx7Agx9Jy5DFze6o1GohtqckhNaVOajWg7LNlgFn28CdsTXCI
IsGaaLHEkhBBxxO7jETowLZSlTp2fcmVMsJpPQshkPqorQd7T2UIE2D2l+6M
Ad3PtUUiqBeUYGWvjykS2QdhVe774yM4IJUpFzapIEokI5GqjuSpbpp44is+
SCAXvYNBUU1v0yYm5+HLJ5aQcFuKBHMBgtlnwQd/QCVB1DAdOjh7pW3YoGEe
f6mwX7Z7yCGfMTXGw0T8Uo4orNVR9FOSfSmBP3BC6sQAvBgpSJ0q05shl6IV
G2yrcQ7EZfSwIpzMzN2Ito6Q3dBExkNzIzrijSxTxrMZS5xueAntvCKW+Ftl
DFHNEqOLPnRjCvrpc/VVNY+0/KLuF3a5qJojUie5JiGEW3UuTM7vpZD+k+OZ
eZ/eY9mbR3E1aizbYa/liTNFhjBsFyV+4Kg6EHbEIudIk3gLUxPhSCYHlUNX
RgC5Qd/zejfy6Nd0GIdp0MJ/7bEpX8YzVr3nMqL1Kze9XUAdwZkO8g0+O2WX
OptQOZSwkh7cfex4yzbdks+VKBc0s7kYy1bgJz7sMC98EJGBmgtL1mQQLnGy
j8U/bjmTU8nTRZLex6wlBXoYL5l4sg0fl5sQV48gqs2JcmzRtNypq/IbavJL
dKDQYLc3bgtRhds1rwXn1ftNYZAE3K03GditGXwUZFaajzm9xiLG2VGfbauQ
0DsaAzPqqjQvSx/51nmdjW7RSu9jKDnwwZGJeWY3LtLMBRW6OB8cYAAtRCzQ
3ld/sMA2dYIcoevHIRwPh7j0Ced1KMqzjCAvvAkqol0Mi7DAVt0SQsV+yjUm
sYz/S5mG83tnfcCBMyXe29DTYiQsOXWe3OZVZATPY5XRylI494aYwrIfytkL
oQPhgFt1LryIe3LeeEqVe0INLJgYOk7yF8hoLHDo64YPfS1JuLxEazVdKOuA
mdVnJgXu8N14jbvRAhsQs4YFftGwQKtrerPc17AmAV3Z4kwlHQtQOJjRuhuT
hbLw4GKEzRMar1mR1CXqplCBnYJ1OYw4Jo6dUDTmdRlZH62ccXFpZ0PiCGIC
dApw/9v9wKrce7g6I7c5Y65fFJwrB1kaEOh9aZVb0/1aT1xd6zMqias+kWTv
M4jngAIlzeZTX8Y3UYb1xC2Te9w2lVxOYhRTRSXPA3GEbivbU//PQOd/HdEE
m4asiiHC43f7Umxg0doENquYIenODGlF1TazwhJMf/rNKxLE5V0xalhpfnEZ
rwaIU54xkS0+jSeoserYbclPZeOhM1XcNwtA/2G/QB81mOuDvR54LhIotPgu
9e/z1/btL5ijic7FQJU5jR4MlDDUxYRU4ZQ9WdA/C7KlE5jv5DGfCWfyWHsF
PdGMZ0E+ERqov7q9NfuM0ez7FfZ9l6ig86GUlBOID5/nMJ+U6eyaIYdAIkIN
xKUrhfmlAseFMLeaJUwM9vnxyqlkoWm7+ok7sY2YtEhK6rrEv58E5v/oZcN8
DdyfK/CXd9MLJnrZpWlvZ6Ccheb6ZaHcb6p3IX1TaZZSaoic2Jk+mZ397jRI
oitqITnjvaXVwRRjpFt76/yLWR0FLKD8l6Hjx5H5txrd2PJSC9C9rGCyNkNU
GvJNYUGuB+Btk9JKATWIBTi3ZRJ1XwQsCGlZnH38/QJy/6D+JF5VD7z6fnN2
ae0dBznzPgfY3tdWWtzdLj03n5yr4mmm1+1ANJcYvg3ZKIkNj/DIK9FLj1sk
fJa8LnTOXD0Us7K+a2D8LVXWDDAOwHEBIdQxx+AfPbdGdtGMb9dRvhU2QVpq
wTOcGc2yRxGWj9Zu0tOT3hlyHsrLfPlqAcJ/9fJCOA/j+vLdd6LMwK+//k9z
1Z9Zfqt00Ww/zCBVQUv9UQN6IAHACcnakjY/WBQINxDcXRaBXHECY91P59zm
cFa0hya2ED6siqeHXJok1rWnYVUurVk4mLc0VDZdRD5F2KdomhIUU/JuUNTb
TEkB5XIerBm23y6g9Mf9ofTlRGqli9vt0nOnqGbrgdg/57+oH7fdfFFtowI1
ueYVgR/vGMSukOCsfSWSMqMO3Mow17LKMY70LAV73a8UdvbYipdOEVH1slmT
Bby39ss1bRHtKaM9FffjHpQtGj1MSdXiEncsgm9CcfDl1K18yoSyJl524zi6
d2L7lpVWa/XSlpWbvbGQR1wdMOCamerPLI5mFayrIcs31g8R7LHjVbXLQM3d
lZA/UcCi3G2RpIte+NJVguwdo1e/ZyDrXVrOPjcKSMp5pkkhOJWWuclVxbPF
lBfr5RU5nWZF3NlFDRG0UPDKKCXPoojSP6w7RS9K4KnbQJadThhXDTpMZTjb
nzKMkVYzj1y4txrFLqW0UZlLz9tuPquE6LKUugfTzX1+uGtYH6bHvBPuIZCJ
vuDU/Z16CaUxotKC6mwA1WmF0vQecS4OXcxo5aCOieTtbSuB+ha57J9Cdyso
Ch5rupV3Cjh9+qrglDTmtfIG72to399gb47/V1cn6eiSzj13nKj8G8VR7ScD
XNccLtBGgoM3V4wGQNbSCxa3AyUz7erg81dYxGHnykaTB3oOb/KAj69qypnw
m27b0Wn34zGgrD2c22OSiy3l7OFcbGmyi/s7GcO+iW0yYz43vqy14ks+/oRF
wIQTba6sG2d2HFD+nZcZylCrZT8lD+aE+9OiHct6Bux0JyPMXWdPCqpWj/Vw
VY72XshK3OVYyXTNRGGeOOLk7ThRt21J5sLrIsAMH8lVsSZG8m2D5G8aJE+z
1uVFxi8sdnNZx3lzyTaOBnLNbCQ7TsvbigbzVAz6ngbzZMwEpIf5ZsXnWAmQ
XTKQJadlDAoYCroI29+sN28vii/Lrmnvd8LHeVA8+ALAxbbkDenIQyPBgV+0
vne3C40bq2Ck8Om74KOWuVztZdeq9aBrSggtv+gSJ1lOANhUdhDQ/1ZQor3i
toa/quWItYBN7zscJyFZ2A+Ru72VPXfXzZQfjqFN7bmvCs0GDhGk9irUZwUn
fNFCW6XZqA45uULIabLQloIDYXc8amPXNjR1QCPLFT646R5bzw8LsP3+iw9b
mBPn6JhJFsvd1M1Qb8VET0jKRsLQZdMxfh7nTcBNXuPj7Rs7WK0YGpUucRcV
WalWqxEMTp6pvqb4ffQlhaNv6oPXaoZUEjossSvu/XrniQ4DwEWVu2sQvAST
FAjGMYkzfMjQHBpqcoc8mpbbVfCm1ki02Axjc+Rpwa4u1mN7y5m+udF182fq
zwBRRHNZi253Q3Eb4bzl/IaU7BcW8PwrLyKeSdd+7IIkQHN8t5H9h+A8gzWe
TaX/P3V1dQn3Jssr6hYvL/lQO7HWrGlFQwPWMWkbbq6N26R2SQu93s2Dbuj+
RafXxUGqRb9ByudjyfXdqnNazTDwC/jeMvD9orGYXxdQ3MXKzqRY1HCMD5aV
uqGVQ5cYMmGPKV8+lRRixxAVtLKiz+ZDVYkkxmx7FO9msK39Ogx6xiPbN0up
V7st9YPPPnr04bqJWXUgrwf11m708CT9+sYgP9Kp6k1zGJVjwiKAmrbFrhmg
ir7F17tpu34sZ2lhNg+dQB26+SDnWTlZ15xZxw6R2FR+U+CgJ50+OmfVQbog
V9sqcPTOYaO27PMLiN0yiH0zr3ADZlPBLNDU5uKkB07P+MoeTMY6l1d6Ly5u
LFrPHJOGFEk/1vlMivRk3BlHGh+SQO1WzUk/yz4z5GTTQYZruv3QbBdhaJw9
I2RJFo/Gt1KjfdcK8P7q1YU3nNt3hvbpUMWuVBfzaUtod6unGyvOJ1Qx0zO6
9gTy1gBs62b2reMiEgztArAXG96k5da9bw9ncax9F+IscXnUtuoNvmi4tnUt
hD8yJvV6mU7GFI/x8kIpz2rxITkd1Xa1x3jSNWLdFIyiDUzLH81VADe3isGs
crkox7VoOsc+CWgLd/LuJa+spd9A6DEgWP5kAddfuVq4hvf76cv5LpiSRm/T
7M5hwbNlafoWwQulR8G2OLh5fkMbuQ59Xgkf8pDy6aNtA2w+J53BvagxEadp
2CFBO5sfhXbiI6dfkq3Arr/mIYNGtIshnd3OOwbSnwE0xlRlO7/A80rZ3Nz1
hgKa/q20uHeKFveEbixsMDv4tWNbvlRRw0xoeqOb3RQF6Zs5y9sl8jZ5k+wc
jhqfv1kA8806AMve9/aQAbx1WQCuBnPHrzS32pLZ58PLcMRIDtSolCBIbyBV
sdtTIdNETvNLRZ/X6alHQS70PNCgrGetIe4+o5DmAtmhITo2BRMvX6yr389f
MSxcFz+XMX3TqOk32bhjVL8vwjsDaFnSnldME2mPO3/8rVfNKUKc1ASYWXtD
tDQDuFHYJSxhLUhKU5Zxjk+On4FkzfpTXed9lQy3/8D6pff5zMp7Yh2FViCs
qFfkCEnunW4PTHrTPG4D05+rgbmBh78IxF+6fAiXQdoxpolUp7DWcxbVfERh
Qg154VsjV8HnR3CeCkjcdI3tbJ7zmIbVVy9GDTXRLOBYaL4hXj+dfmjadvFe
0aFpZ1YZRdWcyVzZm4fjWteB8evGn97B82M5FHfE9GL9vKAnso9xc+XEhSNB
+PwWyiFnz1LGUQpAqpLCiRpXcmQlszJ916wTp24MoRFx6ptqbzsnWQH+DW8h
DhDYkyY9ddw0GkCeNMh9o4DijctCMSH350eP3C4obhoUN+DIehwzsrc5p5zQ
iXObTo/22tHTvZoBm2V5pp479eCWYVGoGs8ieiYgGjISDLeAaCLz9eHmGzRB
5W1ABrdPlFRdOXiA1wE3ZaR4w342fqFUR6st5tEdTiZd4HPSERQhq2nXmaVO
C8liDlNL30HpsLrYsBqaIc3RztjCWvRHPZCd9anIe/b5KNLZY3Ce700bEH+8
AOieJvT5WR8m9P6oUdsL0QzohvGb5zjmzcc/ORkmIr6wD/ymVv3W2lyrj0lk
xguzRdIhTTMR6Z6FdX0XUpgaCXCP5HgwNMoYLoDd+RA8eGu7CsE3DIJnjef8
SwX1nCCJoOcKz6PFkDG9eJlTmWSyxNKKvf2ge3S+ibGLBZoV2qDs1AzjNpHz
phdl2bB1/x1vVyOboJCV1v3XjEf8cfO4BTF5Y7CQBUy/NWooDgCyTZg9HrBQ
fYmsbVplInepc+wZhYAkCGTZdJ6BnU7uVZk1/Z7jxrdDzvKbtPKyWtQuDl1f
DmzzirwI2RvWMf52Qekmkvibl5WclFB2MLJmTUhR3rrguKflGDqo2OprrhK5
A39DzuJi3CKGifTIDFYuNXEuPsGLgFuBWc5V3bNtsV4vYPZWHcwi11bxMoH0
u6OH33kh6wJmU8VsAkVnTSoEk1LEjINv7NDFbK6846YTdTrX7y1pVxWhc9Kw
QC+Ri5eAzGxf8AfqDRu1AGjaJ2AHC9pywCYuannLGwqy/04ad/h7BX0bLXUT
Sz3mV9VZR9U5PQeVVShvkqC6qxYqPx1fFOnXu6Jfc/6N5i8ZsOvChRwTjJRs
BtjbBqT3C4CVysX8IRfd29kTSH8wesANELCSBEBNnktE07KJJLqV3cyWLgM9
x1y8gOugB2d8CwCEGS4IlEjnNsXX7SISjy4HwGovJ+eA8OCc3goIW/yy/uMj
c+wLqfWATwrKOG9vAdSJgDo/7x7W8x7WwTzi6rElsZ0XwPbs74z5GoVU8gtq
QXM8awy4fkj0c0+7J0gamaB9x7i3rxUgfacepLP7zWB8jsO7r/YIhnPm+jCm
Q3XVvFbcSkmIms1aHjTHKzHjPpFvlHyREQE5EXe3gXrRnMOLQ5YvY56KAL4I
+M4zygEskT7eyxehNwOa+Lw4cZ76MVdp4UQiC8HgGnPB1pkUxI4JjGfFIP5E
WKi8ApYv6IgMzcsZgmPv4ialoKMBb4TV7r1Zg9B75nETP+96XrHmEEpa53ft
My/XiPUuIzSRfL/3cvlc8llfBzvbkCofzRPzMhFYVwcJ1uz2qtVuRNe4G5UH
WrLPXMb0QQuExOQ50FuGvv5HbI0zehuwl5vmyJm/XVCvbhpFzTlWdlwtyRrV
L7lreGvMFTk6oWXnyJFElYOCnVEZs15udj/v0Xs5arDC2znvzRkFulKAaq2e
z1ehTHoYw+jSRIIQieHBOUHjnKnBc361sEZv0UcM+KYCPC1NR/7sZ9jjvaRZ
4i1wX9aeTOfB48W92/h63ZSUifxvFZRl5Ox0chCcCwXTTeHaMfZvUE1BsEKj
Rjm9FQsRXopWgY/Nc+l9oO5eYtOvCwZ1S+dDHY+XT0XmUKfaccJx+bCizm8n
G7c+aQF+g79Dqx21qEJXPnaOLhuGlODfOT8EizC6yLXmVIXfKGrBRLRgWFkD
QV3ZSbOycyYS7BGXfe4qbGMG43wOqD4YmXLUGAh770y3GPB+ggyZywaMCxcB
owow/ftyAFPAmHgwzmaMqb7GTFR+zuvDK7DGKzD4O4p0X1OwF7kpCYB3iZPv
eIOfAO/8n3MRm9ReC+DNa8DH4QjPogbMmzOMMoryyJri+GEf18teodaQb+oK
CNHN0G8PjnwRZ87ibMVgyyrAFLc5VfXzfDMSIlP7AjkdJ6NGyCBGBcpaijIl
xKYhxIYkzWZ5VYdYVS9WzpxPnszYNXc/UlP4kmfMn/J1sc86L+zsdez+TbPE
n0mb3+ggYntc+a+VqUM2dDoulHbNSsy9E2lBhPA0j5UtxicDJ86Ku24JMezX
xVdvIGLDW+gIka8ZRM4VELncfQXwy114bAcCAt8fPbIuKGOwIcqU34xRfo9c
2NjGCmnYSIzjc3ejyAzd0WdHAMfGIHRgGbjOcw3weN3oQIvFjuKUo6vc7S3o
R17usa62zpyxdbQSiGro27BC51U3knKMXMIYh87j0CYmZws4fK37Dw9dxasE
j8D4vRfVJHU+Ww+FOKtx60Q0ElwGMvkL4dIk8gZpEtaGdZsWlzOa4PBL784u
G5CQG+jHwXxe/35hUT9SLV1LcxpIwBlQTsJT/FXBBei1zByasebQZE4zjokA
ZIv9NjDOYGSXcaYYKoOAjGXv/Ay+PMPhA4O9GaMbOS0z3WW2kSkXgcUB2L1W
Z9SwOq9U+UCHCzBselQ6l+aI0umSuE8NwyHUUQrARhkrfPbyw9WQiJ3zR2XK
Rr+IDO8HGB9A5L9TxFus+GYKio/tHJuAWDNYm/OvZQ5jCItFdSOb8qU4X/YT
BnF3CojrO/bSbbx4aQouV+SUOfo4eGeAB2vGcsUnq5ShwK0P9z7LkBfVWbo/
98s/giW4SDi0avQDvvBeVoNvsLIxuu+XLApL7ZzEcS+kytU2QW+F5dtKiplV
GuLUpoDKgDK9/9mzjxJ3z+4Euz1cNKqEvzi6kNF4TdA4GyExoFGj22x1zImi
nPkpEjGFK4P/zPq+Yh6JbwGJ38ijb8qizwyt2Wjn0hKMu/Vgg8xIN4dcZJpp
Ofu2zwL794Ase+rbzctAnEjKC6ELi/qvadaDi1Pvqt8eEyNB8NMKvWEanjpK
kNdS5InD0oAn+NIAj0Y98OWB97ZRfl9nr9B7dmM0ixMl8CuaOlw0Neu0Qmnm
IUIwbKWqykty8TGJm+O7f8MA7oYxRBsA36eGuSQkvNg0eXWRqOhjDy4xei2h
aVRlF5ISXB+8QStxGfcXKuC4H9Yddfn+0gjJC2Jb1B/1TE/FJeNtXfGW3nd7
ObwBGWVuRd6QaUp8hZD2rgEafchd57oC7TcNuK4XgDawU2S7yDLh7aujX72K
uwtQm42ghk3hyAjdDdaEG7ckKCsmrt7G5dzyK4k8Gr3RFyPvPaPpUvP4i3mt
pwX7EQrdTEkMS5tSKBZRXabJ2bsm5yAyJFWogrjpAvqGZmMWhMaVPx7t4C5J
mknvZP/lpMtdNjgqsJbZlpdgU8pclYAt9up+9LLCjUZ3yMVwewSPLuGEXgnQ
HKu1jpDrLJLeZVE0Ti6Jwtsote6jFVCoPTYW5dTooKaiDfG5wlBrKdSU6fJw
01jzJcKNFvsVhlsvn47hyHDbpKAhemQ1DcQmyGSRhe1tsjzC1YxHMSPDbEtt
DCBkoWW7V42NAlo8riq0KOCb8NOShwbaImDR+z99mbfYG1VXZjaHNaqRZVH1
eSgxq7igh7IVlKSB9n6uNE40BbBhsEXIbMYu2tjvGRiNXw1IqTiPfrGcBBU5
/IFBjtk4PeT3RAzXNGtB4rwlCZcBb//pNWKQpVjwVwRd1aaiRdcXzszO2vcN
yECdGXOymxa2qJs2+t7My57fBKMRpABQ4wQrvNzvGwOwU4DXz4xYvElGvjDC
78fk3rLw0uFl2bjAdhXe14jvZd+184UP2R0outyfM7uOXvwvY5RBzMLrZ02Q
4/N5FebRFQ6pqDD4PboQ0lB0STaIXDv3BwZc7bOPxh4+z2DFyKrRvXQwI8kV
fbXsi43R4Qvz67PVgisjxgZX7Wj+GZSfu3xk0XLPgEwJWGa5Xwm9paMILhJw
BtZnFFiuuLPAVzOn9+k0CnQwnckbLgkRq2SWy/Qb+1r8/OeA3FlBbrYc+XSm
+0MDv2YMv5+7bGGvjnQAlZ+/bEdNZp8m90as28K7ynQbMd4XJMJ0yWYjD6vc
Glh08jJ+fBWs8csceTeN/jbhxaiz0gSe+rTXauxYt+yyN3Mqr4xy1WPb9MAT
tUfAa3rgOffM2JFpjLsfX+Ysdd/+Y99zWaNE6cU3Uw64L/LKjEranORssNB/
KQv9iuGNhsVcb6XHqKPwxiQKiWdc3oloGS1nugnQG7eU6MaMj+w/2gKscUXs
yi91v6B7t8LBjULFVVegyc65q4KvbJkzT+2VxBYNxVfA1h4wxIWG2XjHa6mZ
qNXTTLurx8aLvaX2O7tqJhiisPqjOBk29uhDxtTXRj811YPm592hS6jkHxlM
M8UXy7TWtht4Y6H+BqmrBIYiGPRVhlbw2x4+Z2h93aiqT3lFVIYrbDuNdhnT
n1+AFTgTvOEcmP7kDP206bHi6EofwECDsLQ+zC8gRLSzSZosPq1zLBBCUsx9
YZTzwWY9w0ezYX/+KoU6ygbBSCH0y7mwxps59ZRIdKKT006WJNX++wLeMyPp
5TtMXdw+6IwtPEXRN0Y9BfUGDLF3huNgRXgp9GSx+ujnvLk9lFY/fU5IUEcc
uXi1IodV05LJNi3aN2HrvWlUUdPNdEQB3c0poOzpn8E7bSAIiCGQ/FB9ouzF
F+Y4ERqEmbfM3AzEWiHRp/DMRNlLXInpvnw1MJLd0V2Kj2A1/+xVBkfKPj0t
0aGx1GyA4TWjbrI1HM9pmZalvp+NwZIwFeFjKEre1INPMtXG9W5/MeoJ6H8M
NsSgWoQ4Zbr6ZQQ+vzJqT0fuidf3ttLh33l1AESuRhnBCYR+JY4j3DeBt2x9
J2IlEw5g+aLkqe54G/huev/JmTkoCG3C3dHoJ+B8gyblvYGInsKhIozGQbkm
LLIrgZUz3tACnDx+WXGS0bq7VeetAMl3AZL7Rqtk2Jg8i8v5BBuPPiRstLOn
xzw2nDs9M8d2cNn6vzbqObiokFz0M3ohQ5JCsMJ26c3DOh28zx9O63k7UyTu
N0itjP6GBjNITSyec0YAkuPQGUN2b8zHtQpTJYAZc3cfffgleUHcP29/fTdn
f712Jg1RRz9bFx2kXs69QzkAp3JFtADnCuEG9307ydb36EVFDWHkwaA+DKD5
gfFaFs50JwavrsVLqvHjRx+6Lwms8nD5pjW/3gRWXor+ujTQ/u+cMtdFwdAA
VhL4Kuj9eWXQghNu77hvvBhoIaYeXodGgOU7oXQHuqZtwEN9N1PkYzIATReQ
M6bIkUnVy/asXfYuMPObo57J/oct5MlLC6LNb/YXbXZ8pHVX0Chq/hF/4VVB
DW6NPP07VxE2hJFHlzgVgM23M8Xl+FAyKXtzEhFDKfYd79aMuWsFE81xmnKH
oYd5HfuyVTSfxwf+zejntj8Z6Q4aHv1Dpvt3CmL+3hVFzJVw9cnEGmluVwPL
+VJRbnF7WwJitNoWLL7+neFCVdRio/E2pabqGLHf8BWjnuv+BumRT9CD3iek
1Nu6Th94o3vEi3P9fwVz+O5Vgw07NKOADYHkK6P+8bmVKrXQrmOL+XV9jP1E
GvMZa5iish0NAWTYemRtsr2zEW9mvSxJ6v46sNJjBYCVM+e3rQ7qtOJB/cLL
wAq8kK+P+rf2uEdA5fcAimnVJ9m/OX2S5OGRve0Ou8HB+vrmqwEPmbhKtVIb
Hl8NsYCrBQ9x1N4Y7KcCDoej/mX9DuDjqTr3mdiPewXSNArEAuTnTCjgY1Z/
fA8A+Tuj/1GXKkaL57qSIfI7VxgiF3bpyXL6/uh/yIUnAhD5l43QJ+bxTXHW
EcNJK1Ayn0uu/AYE4Nnof9vlDkLLWX/SpTOrf181lPQtTASK3x71XQxjACV/
rEJP7kUVMr5jjarfxXv/ZPT3PxJpIET8Qe13v9BYgHn0+6O/j+EPIOFPczoi
kdVrGiDsW+Pp2YsY2x2wiNR0WQk1B+GJq40DIvxXld6AhDNf9YgUiPe8z6TP
r4DhKzkb6YfAw49G/ytGPaAkjrq/K0bOVQIEif9fjPomrsoAHn4MPFwz+sHC
4Au5BMZfAwb/0+jv/WqMbiriqoCARP4no56oqzu8P51AKTTQDCzk/sYrgPFp
ayz9DVDxd0f/Yy5/kJSXZQVJp+6Uvz38fVmgIFv/H456pl6c4QrOs91h1TKP
rxlEvG396H8Tl/316H/L5Y8qRMjckvn0uW6fMCxQkB74t0Y/PS/uACqelZaH
6B/p/QmDiAc54+nfBSiukDV8OUM5v1fxCKmMt8teGgwiEOv890Y9GS/XYE3x
R4oJydSpdugYLCxZe+nfBxD+6ejv/yqPMqCcBwmIdP6T0f+el3kwDv5+4YBg
W+d029pH/xwI+Mejv/OrP4I9RaM3Akjc/5PR3/arNSD//wDyb73kCcv6/wVk
/t8Z/c2+KEM1QFHmyZT5r0Z/g6/6YNr/R5JRCL1Ho8zBfwux/zdGf7cv1qBO
BNns/Q+jv5OfjvyA2Lux/x94Kku1\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p5B", "=", 
  RowBox[{"SlideView", "[", 
   RowBox[{"{", 
    RowBox[{"p5Ba", ",", "p5Bb"}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.40014088975*^9, 3.400140893171875*^9}, {
  3.400143819921875*^9, 3.400143823109375*^9}, {3.400657867953125*^9, 
  3.400657878125*^9}}],

Cell[BoxData[
 TagBox[
  DynamicModuleBox[{BoxForm`var$$ = 1}, 
   InterpretationBox[
    StyleBox[
     PanelBox[
      TagBox[GridBox[{
         {
          ItemBox[
           TagBox[GridBox[{
              {
               TagBox[GridBox[{
                  {
                   TagBox[
                    TooltipBox[
                    ButtonBox[
                    StyleBox["\<\"\[FirstPage]\"\>",
                    StripOnInput->False,
                    FontSize->18],
                    Appearance->"Palette",
                    ButtonFrame->"Palette",
                    
                    ButtonFunction:>If[
                    BoxForm`var$$ =!= 1, BoxForm`var$$ = 1],
                    Enabled->Automatic,
                    Evaluator->Automatic,
                    ImageSize->Small,
                    Method->"Preemptive"],
                    "\"First Slide\""],
                    Annotation[#, "First Slide", "Tooltip"]& ], 
                   TagBox[
                    TooltipBox[
                    ButtonBox[
                    StyleBox["\<\"\[LeftPointer]\"\>",
                    StripOnInput->False,
                    FontSize->18],
                    Appearance->"Palette",
                    ButtonFrame->"Palette",
                    ButtonFunction:>If[BoxForm`var$$ > 1, 
                    PreDecrement[BoxForm`var$$]],
                    Enabled->Automatic,
                    Evaluator->Automatic,
                    ImageSize->Small,
                    Method->"Preemptive"],
                    "\"Previous Slide\""],
                    Annotation[#, "Previous Slide", "Tooltip"]& ], 
                   TagBox[
                    TooltipBox[
                    ButtonBox[
                    StyleBox["\<\"\[RightPointer]\"\>",
                    StripOnInput->False,
                    FontSize->18],
                    Appearance->"Palette",
                    ButtonFrame->"Palette",
                    ButtonFunction:>If[BoxForm`var$$ < 2, 
                    PreIncrement[BoxForm`var$$]],
                    Enabled->Automatic,
                    Evaluator->Automatic,
                    ImageSize->Small,
                    Method->"Preemptive"],
                    "\"Next Slide\""],
                    Annotation[#, "Next Slide", "Tooltip"]& ], 
                   TagBox[
                    TooltipBox[
                    ButtonBox[
                    StyleBox["\<\"\[LastPage]\"\>",
                    StripOnInput->False,
                    FontSize->18],
                    Appearance->"Palette",
                    ButtonFrame->"Palette",
                    
                    ButtonFunction:>If[
                    BoxForm`var$$ =!= 2, BoxForm`var$$ = 2],
                    Enabled->Automatic,
                    Evaluator->Automatic,
                    ImageSize->Small,
                    Method->"Preemptive"],
                    "\"Last Slide\""],
                    Annotation[#, "Last Slide", "Tooltip"]& ]}
                 },
                 ColumnsEqual->False,
                 
                 GridBoxItemSize->{
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}},
                 RowsEqual->False],
                "Grid"]}
             },
             ColumnsEqual->False,
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxItemSize->{
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
             RowsEqual->False],
            "Grid"],
           Alignment->Left,
           StripOnInput->False]},
         {
          ItemBox[
           StyleBox[Cell[BoxData[
             PaneSelectorBox[{1->
              GraphicsBox[{{{}, 
                 {RGBColor[0, 0, 1], PointSize[0.02], 
                  PointBox[{{300., 4.}, {330., 4.}, {360., 4.}, {390., 4.}, {
                   420., 4.}, {450., 4.}, {480., 4.}, {510., 4.}, {540., 
                   4.}, {570., 4.}, {600., 4.}}]}, {}}, {{}, 
                 {RGBColor[1, 0, 0], PointSize[0.02], 
                  PointBox[{{300., 3.}, {330., 3.}, {360., 3.}, {390., 3.}, {
                   420., 3.}, {450., 3.}, {480., 3.}, {510., 3.}, {540., 
                   3.}, {570., 3.}, {600., 3.}}]}, {}}},
               AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
               Axes->True,
               AxesLabel->{
                 FormBox[
                  InterpretationBox[
                   Cell[
                    BoxData[
                    FormBox[
                    StyleBox[
                    "\"Number of vertices\"", Italic, 16, StripOnInput -> 
                    False], TraditionalForm]], "Text", "TR"], 
                   Text[
                    Style["Number of vertices", Italic, 16]]], 
                  TraditionalForm], 
                 FormBox[
                  InterpretationBox[
                   Cell[
                    BoxData[
                    FormBox[
                    StyleBox[
                    "\"Number of used colours\"", Italic, 16, StripOnInput -> 
                    False], TraditionalForm]], "Text", "TR"], 
                   Text[
                    Style["Number of used colours", Italic, 16]]], 
                  TraditionalForm]},
               AxesOrigin->{300., 0},
               ImageSize->500,
               PlotLabel->FormBox[
                 RowBox[{"{", 
                   RowBox[{
                    InterpretationBox[
                    Cell[
                    BoxData[
                    FormBox[
                    StyleBox["\"EdgeColoring\"", 
                    RGBColor[0, 0, 1], 20, StripOnInput -> False], 
                    TraditionalForm]], "Text", "TR"], 
                    Text[
                    Style["EdgeColoring", 
                    RGBColor[0, 0, 1], 20]]], ",", 
                    InterpretationBox[
                    Cell[
                    BoxData[
                    FormBox[
                    StyleBox["\"Vizing\"", 
                    RGBColor[1, 0, 0], 20, StripOnInput -> False], 
                    TraditionalForm]], "Text", "TR"], 
                    Text[
                    Style["Vizing", 
                    RGBColor[1, 0, 0], 20]]]}], "}"}], TraditionalForm],
               PlotRange->{{299, 601}, {0, 4.8}},
               PlotRangeClipping->True,
               PlotRangePadding->{Automatic, Automatic}], 2->
              Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJztnXGIXNtdx0MVneTNS/btezwXKcOzaDcMpQSZ7CaTTDI7Ozu7MzuV8HxI
ECnps0qs76Wbl2dd47NOQ5EgoosUGYrURQYp4pZFigRZZRGRpT5kKVJKLRJE
JA5FgohEKSK8Od8L873nw4TNJJlsbv653A9fzpzznZtzz3x/5979sTc/+/ov
fOjIkSNvHj1y5AeO6N8vVQfHUjhOVYf5PPAy8Arwapx3FkC/CPo66BugXwZ9
MxxfMX0L9G3Qf2JYv/tWOC8BnwdeBl4BXo1z9zPRL4K+DvoG6JdB3wR9C/Rt
0Juf1bVwXgI+D7wMvAK8GufuZ6JfBH0d9A3QL4O+CfoW6NugNz9feyecl4DP
Ay8DrwCvxrn7megXQV8HfQP0y6Bvgr4F+jbozc8j74ajz5/iPn+K+/wp7vOn
uM+fgafmT+l9/pTe50/pff6U3udP6Zug9/lT+jbozc+7vxLOS8DngZeBV4BX
49z9TPSLoK+DvgH6ZdA3Qd8CfRv08jPcp3Z/NZz7/Ujc70fifj8S9/uRuN+P
Ak/dj6T3+5H0fj+S3u9H0vv9SHq/H0nv9yPp/X4kvV2fm78WzkvA54GXgVeA
V+Pc/Uz0i6Cvg74B+mXQN0HfAn0b9OZn59fDeQn4PPAy8Arwapy7n4l+EfR1
0DdAvwz6JuhboG+D3vy88hvhvAR8HngZeAV4Nc7dz0S/CPo66BugXwZ9E/Qt
0LdB7+vP3wznvv4U9/WnuK8/xX39Ke7rz8BT60/pff0pva8/pff1p/S+/pTe
15/S+/pTel9/Sm9+bnTCeQn4PPAy8Arwapy7n4l+EfR10DdALz9fMX0T9K04
dz8Tvc+fXwjnPn+K+/wp7vOnuM+f4j5/Bp6aP6X3+VN6nz+l9/lTep8/pff5
U3qfP6X3+VN683PtVjgvAZ8HXgZeAV6Nc/cz0S+Cvg76BuiXQd8EfQv0bdD7
7yPPl3LGD3u+ZOMdmS95+wfNl3LGs3xpoB93vpQznuVLg/Nx50s5489rvpQz
Pu58ydrP8qVwPu58KWf6Zy1f0rw66flSzvRZvjQ4H3e+lDP9pOZLOePPWr5k
/c/ypXA+7nwpZ/osXxrox50v5Uyf5UuD81H5kutH5Us50x80X8oZf1L5kn/u
pOZL1s8sXwrn486Xgs952FeTh5wkD3lIHvKQPOQhechD8pCH5CEPyUMekoc8
JG95yK7rW6Bvg96uz5nPhvN54CXgZeAV4NU4dz8T/SLo66BvgH4Z9E3Qt0Df
Br35OX09nM8DLwEvA68Ar8a5+5noF0FfB30D9Mugb4K+Bfo26M3PLuRIXcid
upAvdWH/UhfypS7kS13Il7qQL3UhX+pCvtSFfKkL+VIX8qUu5EsFyJF6kIcU
PI9yfQn0ZdCXQV8BfQX0VdBX43r/Hnuw/6cAeVcPcpsC5GA9yHMKkI/1IOcp
QG7Wg/ynAHlaD3KhAuRsPciLCpC/9SBHKlguV/X2A++8PDgWIUcqQu5UhHyp
CPlSEfKlIuRLRc+XXF8HfQP0y6Bvgr4F+jbo5fNLg+P2etCZnwkvAS8DrwCv
xrn7megXQV8HfQP0y6Bvgr4F+jbobf6cuxnO54GXgJeBV4BX49z9TPSLoK+D
vgH6ZdA3Qd8CfRv05ucO5HI1yJd2YP9YDXKqHcj3apBT7UDuV4P8agfywBrk
WjuQE9Yg79qB/LAGOdgO5Io1yMd2YD9bDXKzHcgha56nefvNuN75DuSWNcjf
diDPrEEutwM5Zw3yur3Ph/N54CXgZeAV4NU49+sh0S+Cvg76BuiXQd8EfQv0
bdCbn7OQy81CjjcLed0s5HWzkNfNQl43C3ndLOR1s5DXzVpeV502fRP0rTh3
P2chr+uDn33wsw9+9sHPPvjZBz/74Gcf/OyDn33zszNt+iboW3HufvbBzy3I
Obc8F3VeBl4BXo1z93ML8s8tyD+3IP/cgvxzC/LPLcg/tzz/dL35qdxpbQ74
WeDngV+M8zOQy92pgR5yuTtLoIdc7s4K6INvu65fBf0nhvXKl+6eHtYn/Azw
c8AvxPl9yOXWaqCHXG5tCfSQy62tgB5yubVV0EOOdOk08DPAzwG/EOdfhfzt
ZA30kL+dXAI95G8nV0AP+dvJVdBDXrQLedou5G+7kLPtQs52BXK2u5CzXYGc
7S7kbFcgZ7sLOdsVyNnuQs52BfKNU5CPbc6BHvK3zbOghzxt8zzoIU/bvBjX
z0CedgnysS7kafs1aB/ytEuQj3UhT9tfiutnIE+7BPlYF/K0/ZW4fgbytEuQ
j3UhT9tfjetnwnVV9fYhH5uy6yrhZ4GfB34xznOQg92ugR5ysNtLoIcc7PYK
6CEHu70KeluHJHnOaeBngJ8DfiHOdyEHq9ZADzlYdQn0kINVV0APOVh1FfSQ
29yHXOs+5GD3Ie+6D3nXOuRdDyDvWoe86wHkXeuQdz2AvGsd8q4HkHetQ85w
BXKq/TnQQw62fxb0kGvtnwc95Fr7F+P6U5BrXYWcahtyrXs1aB9yrauQU21D
rnVvKa4/BbnWVciptiHXurcS15+CXOsq5FTbkGvdW43rT0GudRVyquoc8LPA
zwO/GOevQR61WQM95FGbS6CHPGpzBfSQR22ugh7yqO3TwM8APwf8Qpx/G/Ko
yzXQQx51eQn04Tr33OnyCughj7q8CnrIT147DfwM8HPAL8T5BuROUzXQQ+40
tQR6yJ2mgm+eO21A7jS1GucbkJNsQI60AbnTBuRLG5AvrUC+tAf50grkS3uQ
L61AvrQH+dIK5Et7kC+tmG++76tz1Hjws3Pc+CHZ9+XjGrXvK9X+qH1fLxof
te/rBePZvq/B+QH3fXVeMB787OSNZ/u+Bufy87jxUfu+jhmXn9ZOtu8rnGte
zZle/p8w/RPa95Xqj75H64++x86JYX3y/R619rN9X1H+qPu+Uu0bn5R9X50X
TR++984x00/ovi/xid/3lTd9Pc6ftX1fun4mZd+Xrlvf9+X9fOb2fR01vfw/
Yfps31eUp/Z9uZ+6TszP5Do5Ye1rn0bO2s/2fQ3OJ3Xf13HT63s5Zvps39fg
fMS+r5Rev9/zpg9+6nffY9v39aLxce/78vbHvO8rpR+17+sF08tP6+dB930p
d3pc+75S7U/ovi/vZ/Ich+VUyb4ve37zsO/7ch9G7fsSf+h9Xznj2b6vD44H
3veVM57t+xrwg+77yg3zw77vy/OoZN+X5VETu+/L+p/s+8oN67N9X6H9Me/7
SrUP+dhT3/eVM3227+uD44H3feVMn+37+uB44H1fOdM/7X1flqto35fnKtm+
r9D+uPd95ax9e99Xtu/L+KTu+8qZPtv3NdBDHjVy31fO9JO678tym6ka6Me8
7yulH7XvK2f6Efu+PD95Uvu+/HMndt+XvUfdnx/c9Xxpaljvz8dJ71x6f/5L
eufS+/NN0juX3p+vST7X32f7Vlyf9Mf0asefy5DeedJ/eH+7c+l9X730zqX3
fdfivu9a7bhe3PVqJ7kvvDys933C0mve231pWO/7YKXX/+uO6X2fp/S6bqvW
H9/HqPeo+3Ur7tenuF+H4n69ifv1k7Tj7/8M3K+TpH14L71/7+L+PYr79yju
35e4fy/i7r+4+6z3q7vP4u6zuPv8mudaxt3npJ2FOHefk/bhffXus7j7LO4+
i7vP4u6zuPss7j7rveupeTjw1HwbeGpeDTw1f8LziUk7Ph8Gnpr31D68xz41
jylPg/fYp+alwFPzT+CpeSbw1HwSuPus97G7z+Lus7j7LO4+i7vPdz0PNO4+
J+3D++3dZ3H3Wdx9Fnefxd1ncfdZXD7v6r4TcqTUeiPw1Loi8NT6IfDUOiHw
1P1d7fh6AJ67TNqHv6uYul8HnrrPBp66LwfuPou7z+Lus7hfz3p/u/ss7j6L
u8/i7rO4+5y0sxDn7nPSPrwP330Wd5/F3Wdx91ncfRZ3n8XdZ73X3X0Wd5/F
3Wdx91ncfU7aWYhz9zlpH96T7z53POcx7j6Lu8/i7rO4+yzuPut97+6zuPss
7j6Lu8/i7nPSzkKcu89J+/D+fPdZ3H2+4nmacfdZ3H0Wd5/FU+vn8B741Po5
8NT6OfDU+jnw1Po58NT6We34+jnw1PpZ7cN79VPr58BT6+fAU+vnwFPr58BT
6+fAU+vnwN1nvR/efRZ3n8XdZ3H3Wdx9TtpZiHP3OWkf3rfvPovL545x+bz7
8jBPfH5pmLvPG54LGU/NzyH3SM3Pgafm58BT83Pgqfk58NT8rHZ8fg48NT+r
fXgPf2p+Djw1Pweemp8DT83Pgafm58BT8zM8P6j3ybvP4u6zuPss7j6Lu89J
Owtx7j4n7cP7+d1ncfdZ3H0Wd5/F3Wdx91ncfV6BnOqLkOe8r30+9r384Fq8
nTeC3n37yFq8/Y2g9/H+3fX4574VuF8P/6p9Qdaf374e78+pwP17/BD8Tv/q
9Xg/fypw/17+5Ea8/+0b8f7/J+Qbf3sjPq7P3IiPa+pGfFx/AXnFvwS9j/d2
4D7ejwfu4/1HyCX+Bn4n/iL8jvsi/M76Y/gdtAK/gxrw++V7oZ7u/n8afncc
g98dt+D3wkn4vfAP4XPdt4/C+v/9m/F+vhO4Xyd1WM/3b8b7vxG4Xydvwvo8
B+vzr92Mj+uNwP16+LdQ70vNJ7B++wisr34e1j9zsP55B9YtS7Bu+QKsN97w
9UbQ/zSsEz4K64T/gfXYm3DfPw33/Rzc96/Dfbzu9/GwXvoRuI8v3oqP69Vb
8XH9O6x/dmD983pox8f7E4H7eB/AeP8e1jmfCu24D6XA/Xv84cDdh+/Aesbr
X9pX7PUv1fUeuv714rA+q3/F+cTXv44N60fVv/QcysPWv7w/o+pfrj9w/euF
Ya7rsGM8q38NjuOuf+k6SdW/jg3zrP41OPr8/Mj1L2tHPmufear+dWKYZ/Wv
wfGg9S/tz0zVv44Oc/ms56mf1fpXMm9PeP1Lz7On6l/5YZ7VvwbHsde/8sNc
Put7mfT6l+bnZ7X+pXkmVf86Oszls+axrP5l7R+0/nVimCc+29+PTnw+Psyz
+tfgOPb617Fh7r93svrXMHefvf7l3OcNr3/pd1mq/mV8VP0rmZ8fU/0rmQ89
Bzs6zH1dN/H1L+unfFYulNW/hvm461+6brP61+CY1b8Gx6z+NThm9a/BMat/
DY5e/0rG9aTrX+H++NjqX4E/bP1L95FXb8XH9bjqX1rnTFr96/IvD47uQ+8z
YVzmw32oT52HOtSXQvupfeyhfffhY4G7D+tQ99kP7bsPHw7cn0u6Gtp3H74O
zxl9+trg6D5svx3aNR++D/W1zWvx8X7v7fh4z7wdH+93rw2PK5m3r8XH9e7b
w+MSv7MW7/8n1+L9/9ZavJ/vrcX7+V9r8f58eS3enwtQ7/g5qEfchHrBb0GO
/THIsb8J9YJ1eF6mBc9l3If8/w8g/z8P+f9VyJ+PQ/78dcj5f9Zy/t3A85Az
//nnBkf34XLg7sP/wfMs+9KbD58L3H34cODuw38E7uP9UuA+3nLgfj38/np8
XGf0Xg4b1z9Dfv4z6/H+fx9y73fX4/380fV4P2e0nrH+/DXkzN+FHPh/Iaf9
IcgP/+y9wdGvh9cDd98eQE77Fchpfxzyw2+E9lO/TwP36+fVwN3/e4H7/5ff
Ddyvn1Lg/r18B3LX3wnrPffnJwN3f74N+ernIV/909CO+3ApcPfhvyFH/UN4
juBaaMd9eCVw9+EvIRc9Cuu9O5BzfhJyzhnI074FueV7llt2dH+BvPHLkDe+
DznhH0FO+E+Q730N8r2/gvzt92B/+Fcgv3pe1mPKjR92PSaerccGx2d1Pabf
X8/7ekw8W48Njs/7ekz/L7L12OCYrccGx0lfjyX3l8e0HlM98Wmtx/JQb8pD
vWkG6k3i3s4M1JvEqX3//zUN9aZpqDdNQ71pGupN01BvEvd+TkO9aRrqTV3Y
T9uF/bRdqDd1YX9sF/bHdmF/bBfqTV2or3VhH2wX9sF2od5UsP2uzt2HAqyX
CrBeKvi+VuPuTwHWUQVYRxVgHVWAfa09qK8VYL9rAfa7FmDdVbB1VzXwItTv
ilC/K0L9rgj1O7331dvfhvqduH+uuH8v4t4fceqP+6b3rKbqUFC/m4P6XcIX
4tz7Pwf1O3Efl7iPaw7qd3NQv9uBeqW4j1c8VQ+CdVeiX4hz9yFpB/7ekP//
Eqe/r+3+iLs/4uSP3zf3oO4p7uMV937qvZfejrj7L+7ti7uf4vpc/3vN7k8f
+tOH/vRh3dWHfvahn31Yd/Wh/33v/0vD3L9fve/RxyXu49qCuucW1D0T/UKc
+3i3oO65BXVPcb9+xP17FCcf/DrX+s19SNZ75+LcfchDviTuPiTtwN81dh/E
aV3qPogndU/j5IPXiZL1qvkg7j6Ip35fSA9/38THK+7jFffvV9zHJe7zWLKO
rcS591/c+ynu/RT3/oh7f7qQs3UhZ+tCztaDumcPcrYePL/Tg+d3epAv9SB/
68FzOj14TqcHz+n0IH/rQf7Wg+dxevY8jq7zIuRvRXjupgjP3RQhpyr6czTG
3Yci5FdFeC6mCM/FFOG5mG3I37YhfxP3cW1D/ibu/d+G/G0b8rc5yN/EvT/i
/rni3n7N8jfnfj2Iu281yJd2IH+rQe5Ug1xO3P9/JZ8L7/n376UGeZS4//8S
9+tN3L/HGuRUe5DX7UFeJ+5+irtve5DX7UFeJ+7+iLs/e5DX7UFeJ+4+zMK6
UdzHK+7jnYV1o7iPS9zrp+Lef3Hvfx/62Yd+9qE/feuPc//cLcjrth5TXqcc
flLyOvXnsOV1Gtdhy+s0rkfN67wd+eP8sOd1vp4ZldfJn0nJ69Sfw5bXaVxP
Oq/T5056Xuf9TJ5jNT6peZ36+aTzOufyR/15bHmd/R2cg+Z1zilvTPZBhXF5
Xud83Hmd3ifgeZ2eU5iUvM7/zq+viw5bXufjGpXX+TrT11eHLa/z9fDTzut8
HXvgvO7EMB93Xqd+el7nfFLzOl+/Pam8zteThyWv83Xp087rfD05Kq/TvqDn
Ja+TP57XOc/yusHR76fPal7n3NdFj5rX6f/Ro+Z1vl59iLzu/wH6sVyz
                "], {{
                  {RGBColor[0, 0, 1], EdgeForm[None], 
                   GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwt2Qf8TfUfx/Hz/Trnd75W9iYUDSojpESEkEgI7dLee+8d0d577y2FsglF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                    "]], Polygon3DBox[CompressedData["
1:eJwtmnXgVkUWhu+d77u/CxiEhI0I2ILdgYWCIoio2IidqOjqqru6q66Bgd3d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                    "]], Polygon3DBox[CompressedData["
1:eJwt1wncVdMax/HTeTvto9FwpUFXdWUoNNxKoYEiSSLj/VzzkFCRyDxmrijK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                    "]]}]}, 
                  {RGBColor[1, 0, 0], EdgeForm[None], 
                   GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxFmXf8jtUbx5+vw3Ofo63SNhMhslKohLIJGdkrKSspoxAi7WVERiIlUdp7
7z2MopBQVEbaafzen9fneb1+f1zO+3uc+37u59zXua7PdT3l+4/oOLxYLpdr
xD+BsVrK5W7Icrnziudy9fK53O1wuaJc7mB4NLyfNRtK5HKD4HVwA+bvhE9k
zWnwHXB5uC7cgXuUhWvCtzB/HHwuPBuuCX/BfS6C13KfhszPgCsxfyp8K3w8
XAu+DT4Bbgb34Z414HVc+y8PvIZrv4EHs2Y9vB7uAb8D/wgPgTfCX8I94Xfh
1fBern0TXgtfyPxb8Odwd/ht+Ae4P/wx/B18KfwlvBG+GP4c3gZfAm+Ad8ED
4E/gPfBA+FN4C9wbfh8+m+efCVfl+avDN8NHwf/xLDWxbawpzverC++EA1wH
3gH/yVgl+Lvoe9fAtsL7Gatim+G/GathX8MHcu2Z8L6cbsqewtvBg+Cz4J/h
DK4P/whH+HR4F9yYZ5vFs1Xj2VowPyH4/ZZi/lj+LoLLwtey5kC4GnwTXBo+
HK5eWFM5b186HK4K3wgfCZ8EXw+XgivB0+HD4ArwdfAh8JHwM1iAyzNOY/5g
+ES4Kfc/FC4HT2X+IHgn+9wP/ojn3w73hT+Et8J94A/gfqxfDrdkfV/4QbgF
3BteBjeHj4CfxorBOcYV2F6wiHEl9hNcLO/91d6WgB/GfoH7Mz7EfVpx7X4+
dzl/f8/8b/Ay+Fu9I/gh+AfdnvER7Fd4gD6La1tz7WDNw+3hSfBz8CB4Mvw8
fDF8HfwCPAQeCj8KXwBfAF+pdw+3h+czfwbcA14KN4Mv1jPD7eCL9C5Y3wYe
pO/IfFu4J3w/fC7cC35AMQHO4FXYbzzzIYxPYP/ChzI+if0H/8J3HJ7Zn38u
4b2Sr/4Kj8jsh//Cl2f2vf/gUZl9L+n54d/l/wV/0z5vZk0v5t+D98LDMvt8
K9bcBdfh2YrDV2T27d2sGQpv0tmBL8t8jv6CR2Y+Xzvg+7nmK/gAxsewP+Hf
mX8Q/g4uqb3F/oAPY3wqL2fgOzE+jv2lZ+YZz+CM7IZvYu5F7j+SNWsKcUYx
al8hXmkfZumzuGYca35i/gH+/ob52xlf4tormd/E/FL+/oL5aYz3sf5S5v/i
HicHf6958iNsEvPH61os6Yywthtr/mFNVbhn8DPX5v9fxcrAx+k5sQgfJR/D
SsDHyMewvOIw1/YPPoNV4O7B77cG3Df4jBwrP8SyIp/73sFnvzY8EC6u8w53
CfaTOoXzq7zQBH4bOwU+nfF1rCJcn/E1rALctJBHFPPPg9/BToXbMn6InQ6f
z/gR1kDxivE9rDZ8K+NW+QTcnPFdrBbchvEDrD7cmvF97DT4TMY3sZPhUxhf
kf/BDfj8ocF7dT1zm7ER8A2MX2OXwbfoHWKj4OmMm7Dh8FTG2YV3Nwr+HOsO
j2RuGfdsqDMIL4TrwTfz/1uwy3VOmZ8f/GyXwIuCn3kIvDj4uzeChwe/92u5
biN2CXxF4Vz30N7q84Pf0Wnw4OD3WxceFPzeO7D+47yfpyPjJ1gjuFPeOVfx
ZBy8HusHd2b8FDsLnqIzhA2Gx8pnsb7wBMYN2EB4IuOX2EXwOYxvYdX1/Ixv
YFXgOxi3YaPhJYz7sOk6IzxjuWCdsI+xfLD2uK9wjq4v8jkrUzhrpZl/Nm/f
q8//DwnOO0/FXO6azHvwM3MVgvN4Q/4eEZyLz4CHBeeyp1k/KfP+PQ5PzLxn
v/H/lYLz/mI+5yfsOtbPZfweuwZewLgLmwLPZ/wRmwzfxbgDmwD/zj1OCtYV
sxVvsPHMz2D8FhsL38u4F5sG/6o8HKxzFjG3B5vK/MxCfFA8WQjvxq6FV/HM
V2c+r4/C4zOf6TrYxcF5+WHmr8ocJ6phfYLzb0W4M1xSZwHuF5xzV7J+XOZ4
cDLWKzgvr2B+bOazfiefvx0bw3xp/m7Omr955sryx+B8XQnuGqwfHuLaMZnj
1iPRn6dYotjfphBPjoTPC9afz7JmSmbfPxe7KlhzngmPhI+GH2PNhMxx6Bl4
cuZzPIfn2olNZE0z7Vmwvj0bviJYo9aEBwRrEsWqscHxqhZ8UbBuaQxfGaxR
z4FHB2vULtz7M+xseLz8kM8dAF+mfAF3VR5n/fPB+Xo+/EVwvpAPly3o0huY
fx3uyfyN8BtwL/gm+E24d5HP92vBZ3wq/FLw/XUm9gSfiynwC3BnaQb4FfhC
eBr8MtxNcRJ+F+4PL4K/Cs5B8qmvg/2qo85ZsG5XPJ4eHJMHwvPgJorJ8LXB
+rYdPDVYQ3aBbw7O0V3hW+C68CT4ObgTvBTeAl8Ff8n7uo+9mlDcsWd2cPzp
Id8K1jMfs2ZO5th5G/Ze8D7fBX8WrIvejI7t3fSd4LU6m/A70fmip/Y4Oi9c
AG+Kjs/Tta/RuaYTvDw6t1bQHkfHq9bw29E5qDv8anQuO1/7Gp1H2mi/o2Nd
++LOA58G54K3onPQhXq30Tmrs74f9mGw3psBfxSs9+bAq+GhcC94RnD87A3P
DM6h2qtZhffyfnR87qu9iY7nWvtudJzXPT6I9tV++kx4NdxfnwmvgQfI9xU7
gjXh58yPLm59qfGRYN1YDK4VrFWk9RoVdI70TvVCTC7JfEN4i7QW3CBY8+Th
esEaTHs6GT6m4GPXFc7dP/p+2Oqc93dasIbR/k4KztHN4avhI4r8Pm4PzuOH
wGcHa+8ycPtg7XoM3CpYzx8NtwjW+UfBLeE98BFws2CtfjjcNFjPHwo3DtaH
ilGtgzVqebhjsIYsB3cI1o3ym07BWvF4uG1wvXAC3C5Y/8sPbg3Og/LX2+DK
RfbLG4K10Fr2/57M2uFy7KHgWuNSeEmwPr8CXhlcR6xj/SLWj2JuPPZkcE2x
gfklzF+t2APfC4+BP4HnZtYdV2GPB9cIE+Gn4fPh9axZzJpxzA3G7g2uET5l
/u7MOmUQtiC41qiYdzxX7jiLcRTzB8BVmH857/clv78xWPsp3o4p5JoXozWh
3u0RyTWC8slq5hfAw+Ch2NLg2u0z5udl1kfDsQeC67vL4AeD6741rFnImhHy
F+79TOa490K05lTf4/londwEnhtd98ln74jW5L8Ex9jdhdh4d3QNeLBiYXRN
J7+bH10ryV+WRNeVx2nPomsl+d2j2K7gXL84ur6Qb94XXf/KX5ZG6xn5y6Lo
mkt+emd0/fIH18+IriN0VnSG5wRrXZ3tu4I18/3ROl/nQGd7brBOHpj3edZZ
nsX4cbBGnRldtxYprkTXRMUKceyTQt6ZE10j63zPjq55S+gzo+tcne+bFStZ
30G6KLqeKsXcPdE1lM5ZK+wa6SE9J7wVHlbIQZsLMbMlPDG4RzSa657KnB/H
wE9nzo9XFvS2nm2Y9GHm3PcAc98Ea/KRzD+ROfddDj+ZOScOgVdlzkcLo+tB
nftl2LZgzb8C3hGs8xfC64P17SPwD8HadRX8Y7D+uQfeEKx758HrgvXz3fCa
YJ08F14L95EWgr8L1v8PwtuD64sl8KZgbb8Y3hist1fCO4NrnFvgt+CO8B3w
+3CXgk54tRCrD02uweWrKblvpj5TTO5r6V0fllwvHwaXSq6X9b4OSa7r1UM6
OLkGV+17YHKfTf2kLLk3qJ7TAcl9M/nDQcn1uPpMJZP7Zup17Y/uuUnX55P7
geqH/RPdr9NZK0ru58jPN0fXF/KpjfA6aV04JPfrVB8XT+7FqTdWIrkXp95Y
seQekXppf0f3CVUH/BvdW5C+/i+6XyeNn0vuHUmn/xXdJ1Qt8md0baKz+3V0
TaS9/za6NtS7/Tla8+t9/hJdC8h3fo/W8/KXfdH1+3J4T3RdID/dG61R5Xc/
RdcU8gVpl2f5/Ka8x9+i9f/DinPRNXtZxbnoul65aFl0ba5c9Gt0XSB/2R1d
a+ic7YquNeRf30XXs/LT7dE1rHzz++g6Wr68I7o+XSC/i655dQ6ei66XFeP/
iK6JdA62RNeAt+tMRNcF8t9t0bWq4s0P0XXfvTqj0XWi/HdrdF05E+6atz5p
XGS/bBLcI1Icvz+49u+U3DeTRm6T3NOTbzROzhfKCR2Te1/S1Ocn99yk9y5I
PvvSwi2Te2XSp+cm50fpoGbp/9qnaXJuVb5tndwfk9Y+Lzk/Kn+2T+4HSnd3
y1tTncNzlkmuxVRPVEyuTVSD1knun0tzVkiuPVWPtkvuW0qzl0uuQ+vBdZN7
79LXbZP7maoDTkvuM0sv10vuq0t3l0+uf1UTt0ru76kWaZGst5XnmydrA+mF
o5J7/qoFuyXHTGnSC5Njpt5L6eR+nXzvyeicrmfrnhyfpcd7JMdnadgOyT1G
1Te9kusj+VLv5D6n6o+eyXlZtVGf5J6nfKNvcs9TtUK/5D6bzk7X5NpK2rlL
csyXv3VO7ouqPjgzWRtILzRK1irSTQ2TNY+0TIPkmkL65fTk3ymkn89K7qNK
b9RP7o2rdjgjufeoGqh/cu9O5/GE5LpbdWSTZM0mvXZccq2tOrtyck9btePh
yb1Q1bg1k38rUS1VI/k3AuVGabXHgv3/yOQ+p7TEqcm/lajeKptc86q+Pym5
N646tVbybyiqQWon/6ajeu7E5DpadbP03KrgulV11xPBvlo1uVevOvvk5F69
6uYqyb16aSTpy+XB/SLpyIeD+0LVk3v++g1heN6xWvnokrxrMeWpc5L1mDRa
peTfFFSLn5L8m4Jy/vHJ/QDpSJ2/FYV68JjknoP6Cscm9yXUkzg6uZ+gHsP/
AJPGa18=
                    "]], Polygon3DBox[CompressedData["
1:eJwtmXnAllP6x5+n+7yn97Hv22DKkoRUkqJVRbskUWnPFpIk+14YESrLGDNm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                    "]], Polygon3DBox[CompressedData["
1:eJwt13n8lsMax/EnPf2e+8exk7IXheIoKVQqoRKKyNoeKqWylaR9IZQ22qSS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                    "]]}]}, {}, {}, {}}, {
                  Line3DBox[{1203, 1, 394, 15, 408, 29, 422, 43, 436, 57, 451,
                    452, 71, 478, 85, 492, 99, 506, 113, 521, 522, 127, 548, 
                   141, 562, 155, 576, 169, 590, 183, 1398, 184, 1399, 185, 
                   1400, 186, 1401, 187, 1402, 1403, 188, 1404, 189, 1405, 
                   190, 1406, 191, 1407, 1408, 192, 1409, 193, 1410, 194, 
                   1411, 195, 1412, 196, 602, 182, 588, 168, 574, 154, 560, 
                   140, 546, 545, 126, 518, 112, 504, 98, 490, 84, 476, 475, 
                   70, 448, 56, 434, 42, 420, 28, 406, 14, 1231, 13, 1229, 12,
                    1227, 11, 1225, 10, 1222, 1221, 9, 1219, 8, 1217, 7, 1215,
                    6, 1212, 1211, 5, 1209, 4, 1207, 3, 1205, 2, 1203}], 
                  Line3DBox[{1491, 197, 799, 211, 813, 225, 827, 239, 841, 
                   253, 856, 857, 267, 883, 281, 897, 295, 911, 309, 926, 927,
                    323, 953, 337, 967, 351, 981, 365, 995, 379, 1686, 380, 
                   1687, 381, 1688, 382, 1689, 383, 1690, 1691, 384, 1692, 
                   385, 1693, 386, 1694, 387, 1695, 1696, 388, 1697, 389, 
                   1698, 390, 1699, 391, 1700, 392, 1007, 378, 993, 364, 979, 
                   350, 965, 336, 951, 950, 322, 923, 308, 909, 294, 895, 280,
                    881, 880, 266, 853, 252, 839, 238, 825, 224, 811, 210, 
                   1519, 209, 1517, 208, 1515, 207, 1513, 206, 1510, 1509, 
                   205, 1507, 204, 1505, 203, 1503, 202, 1500, 1499, 201, 
                   1497, 200, 1495, 199, 1493, 198, 1491}], {
                   Line3DBox[{1203, 603, 1204, 1985, 1415, 1233, 1990, 1420, 
                    1248, 1998, 1428, 1263, 2009, 1809, 2118, 1278, 2024, 
                    1440, 1293, 2028, 1444, 1308, 2035, 1451, 1323, 2045, 
                    1842, 2152, 1338, 2058, 1461, 1353, 2061, 1464, 1368, 
                    2067, 1470, 1383, 2076, 1479, 1398}], 
                   Line3DBox[{1205, 1779, 2088, 1206, 617, 1234, 1991, 1421, 
                    1249, 1999, 1429, 1264, 2010, 1810, 2119, 1279, 1821, 
                    2131, 1294, 2029, 1445, 1309, 2036, 1452, 1324, 2046, 
                    1843, 2153, 1339, 1855, 2167, 1354, 2062, 1465, 1369, 
                    2068, 1471, 1384, 2077, 1480, 1399}], 
                   Line3DBox[{1207, 1780, 2089, 1208, 1791, 2100, 1235, 631, 
                    1250, 2000, 1430, 1265, 2011, 1811, 2120, 1280, 1822, 
                    2132, 1295, 1831, 2141, 1310, 2037, 1453, 1325, 2047, 
                    1844, 2154, 1340, 1856, 2168, 1355, 1866, 2178, 1370, 
                    2069, 1472, 1385, 2078, 1481, 1400}], 
                   Line3DBox[{1209, 1781, 2090, 1210, 1792, 2101, 1236, 1800, 
                    2109, 1251, 645, 1266, 2012, 1812, 2121, 1281, 1823, 2133,
                     1296, 1832, 2142, 1311, 1838, 2148, 1326, 2048, 1845, 
                    2155, 1341, 1857, 2169, 1356, 1867, 2179, 1371, 1874, 
                    2186, 1386, 2079, 1482, 1401}], 
                   Line3DBox[{1211, 1782, 2091, 1213, 1793, 2102, 1237, 1801, 
                    2110, 1252, 1806, 2115, 1267, 663, 2122, 1282, 1824, 2134,
                     1297, 1833, 2143, 1312, 1839, 2149, 1327, 1846, 2156, 
                    2157, 1342, 1858, 2170, 1357, 1868, 2180, 1372, 1875, 
                    2187, 1387, 1879, 2191, 1402}], 
                   Line3DBox[{1215, 1783, 2092, 1216, 1987, 1417, 1239, 1993, 
                    1423, 1254, 2002, 1432, 1269, 2014, 1813, 2123, 1284, 686,
                     1299, 2031, 1447, 1314, 2039, 1455, 1329, 2050, 1848, 
                    2159, 1344, 1859, 2171, 1359, 2064, 1467, 1374, 2071, 
                    1474, 1389, 2081, 1484, 1404}], 
                   Line3DBox[{1217, 1784, 2093, 1218, 1794, 2103, 1240, 1994, 
                    1424, 1255, 2003, 1433, 1270, 2015, 1814, 2124, 1285, 
                    1825, 2135, 1300, 700, 1315, 2040, 1456, 1330, 2051, 1849,
                     2160, 1345, 1860, 2172, 1360, 1869, 2181, 1375, 2072, 
                    1475, 1390, 2082, 1485, 1405}], 
                   Line3DBox[{1219, 1785, 2094, 1220, 1795, 2104, 1241, 1802, 
                    2111, 1256, 2004, 1434, 1271, 2016, 1815, 2125, 1286, 
                    1826, 2136, 1301, 1834, 2144, 1316, 714, 1331, 2052, 1850,
                     2161, 1346, 1861, 2173, 1361, 1870, 2182, 1376, 1876, 
                    2188, 1391, 2083, 1486, 1406}], 
                   Line3DBox[{1221, 1786, 2095, 1223, 1796, 2105, 1242, 1803, 
                    2112, 1257, 1807, 2116, 1272, 2017, 1816, 2126, 1287, 
                    1827, 2137, 1302, 1835, 2145, 1317, 1840, 2150, 1332, 736,
                     2162, 1347, 1862, 2174, 1362, 1871, 2183, 1377, 1877, 
                    2189, 1392, 1880, 2192, 1407}], 
                   Line3DBox[{1225, 1787, 2096, 1226, 1989, 1419, 1244, 1996, 
                    1426, 1259, 2006, 1436, 1274, 2020, 1817, 2127, 1289, 
                    2027, 1443, 1304, 2033, 1449, 1319, 2042, 1458, 1334, 
                    2054, 1851, 2163, 1349, 755, 1364, 2066, 1469, 1379, 2074,
                     1477, 1394, 2085, 1488, 1409}], 
                   Line3DBox[{1227, 1788, 2097, 1228, 1797, 2106, 1245, 1997, 
                    1427, 1260, 2007, 1437, 1275, 2021, 1818, 2128, 1290, 
                    1828, 2138, 1305, 2034, 1450, 1320, 2043, 1459, 1335, 
                    2055, 1852, 2164, 1350, 1863, 2175, 1365, 769, 1380, 2075,
                     1478, 1395, 2086, 1489, 1410}], 
                   Line3DBox[{1229, 1789, 2098, 1230, 1798, 2107, 1246, 1804, 
                    2113, 1261, 2008, 1438, 1276, 2022, 1819, 2129, 1291, 
                    1829, 2139, 1306, 1836, 2146, 1321, 2044, 1460, 1336, 
                    2056, 1853, 2165, 1351, 1864, 2176, 1366, 1872, 2184, 
                    1381, 783, 1396, 2087, 1490, 1411}], 
                   Line3DBox[{1231, 1790, 2099, 1232, 1799, 2108, 1247, 1805, 
                    2114, 1262, 1808, 2117, 1277, 2023, 1820, 2130, 1292, 
                    1830, 2140, 1307, 1837, 2147, 1322, 1841, 2151, 1337, 
                    2057, 1854, 2166, 1352, 1865, 2177, 1367, 1873, 2185, 
                    1382, 1878, 2190, 1397, 797, 1412}], 
                   Line3DBox[{1403, 1483, 2080, 1388, 1473, 2070, 1373, 1466, 
                    2063, 1358, 1462, 2059, 1343, 2158, 1847, 2049, 1328, 
                    1454, 2038, 1313, 1446, 2030, 1298, 1441, 2025, 1283, 664,
                     2013, 1268, 1431, 2001, 1253, 1422, 1992, 1238, 1416, 
                    1986, 1214, 1413, 1983, 1212}], 
                   Line3DBox[{1408, 1487, 2084, 1393, 1476, 2073, 1378, 1468, 
                    2065, 1363, 1463, 2060, 1348, 737, 2053, 1333, 1457, 2041,
                     1318, 1448, 2032, 1303, 1442, 2026, 1288, 1439, 2019, 
                    2018, 1273, 1435, 2005, 1258, 1425, 1995, 1243, 1418, 
                    1988, 1224, 1414, 1984, 1222}], 
                   Line3DBox[{1491, 1008, 1492, 2195, 1703, 1521, 2200, 1708, 
                    1536, 2208, 1716, 1551, 2219, 1911, 2328, 1566, 2234, 
                    1728, 1581, 2238, 1732, 1596, 2245, 1739, 1611, 2255, 
                    1944, 2362, 1626, 2268, 1749, 1641, 2271, 1752, 1656, 
                    2277, 1758, 1671, 2286, 1767, 1686}], 
                   Line3DBox[{1493, 1881, 2298, 1494, 1022, 1522, 2201, 1709, 
                    1537, 2209, 1717, 1552, 2220, 1912, 2329, 1567, 1923, 
                    2341, 1582, 2239, 1733, 1597, 2246, 1740, 1612, 2256, 
                    1945, 2363, 1627, 1957, 2377, 1642, 2272, 1753, 1657, 
                    2278, 1759, 1672, 2287, 1768, 1687}], 
                   Line3DBox[{1495, 1882, 2299, 1496, 1893, 2310, 1523, 1036, 
                    1538, 2210, 1718, 1553, 2221, 1913, 2330, 1568, 1924, 
                    2342, 1583, 1933, 2351, 1598, 2247, 1741, 1613, 2257, 
                    1946, 2364, 1628, 1958, 2378, 1643, 1968, 2388, 1658, 
                    2279, 1760, 1673, 2288, 1769, 1688}], 
                   Line3DBox[{1497, 1883, 2300, 1498, 1894, 2311, 1524, 1902, 
                    2319, 1539, 1050, 1554, 2222, 1914, 2331, 1569, 1925, 
                    2343, 1584, 1934, 2352, 1599, 1940, 2358, 1614, 2258, 
                    1947, 2365, 1629, 1959, 2379, 1644, 1969, 2389, 1659, 
                    1976, 2396, 1674, 2289, 1770, 1689}], 
                   Line3DBox[{1499, 1884, 2301, 1501, 1895, 2312, 1525, 1903, 
                    2320, 1540, 1908, 2325, 1555, 1068, 2332, 1570, 1926, 
                    2344, 1585, 1935, 2353, 1600, 1941, 2359, 1615, 1948, 
                    2366, 2367, 1630, 1960, 2380, 1645, 1970, 2390, 1660, 
                    1977, 2397, 1675, 1981, 2401, 1690}], 
                   Line3DBox[{1503, 1885, 2302, 1504, 2197, 1705, 1527, 2203, 
                    1711, 1542, 2212, 1720, 1557, 2224, 1915, 2333, 1572, 
                    1091, 1587, 2241, 1735, 1602, 2249, 1743, 1617, 2260, 
                    1950, 2369, 1632, 1961, 2381, 1647, 2274, 1755, 1662, 
                    2281, 1762, 1677, 2291, 1772, 1692}], 
                   Line3DBox[{1505, 1886, 2303, 1506, 1896, 2313, 1528, 2204, 
                    1712, 1543, 2213, 1721, 1558, 2225, 1916, 2334, 1573, 
                    1927, 2345, 1588, 1105, 1603, 2250, 1744, 1618, 2261, 
                    1951, 2370, 1633, 1962, 2382, 1648, 1971, 2391, 1663, 
                    2282, 1763, 1678, 2292, 1773, 1693}], 
                   Line3DBox[{1507, 1887, 2304, 1508, 1897, 2314, 1529, 1904, 
                    2321, 1544, 2214, 1722, 1559, 2226, 1917, 2335, 1574, 
                    1928, 2346, 1589, 1936, 2354, 1604, 1119, 1619, 2262, 
                    1952, 2371, 1634, 1963, 2383, 1649, 1972, 2392, 1664, 
                    1978, 2398, 1679, 2293, 1774, 1694}], 
                   Line3DBox[{1509, 1888, 2305, 1511, 1898, 2315, 1530, 1905, 
                    2322, 1545, 1909, 2326, 1560, 2227, 1918, 2336, 1575, 
                    1929, 2347, 1590, 1937, 2355, 1605, 1942, 2360, 1620, 
                    1141, 2372, 1635, 1964, 2384, 1650, 1973, 2393, 1665, 
                    1979, 2399, 1680, 1982, 2402, 1695}], 
                   Line3DBox[{1513, 1889, 2306, 1514, 2199, 1707, 1532, 2206, 
                    1714, 1547, 2216, 1724, 1562, 2230, 1919, 2337, 1577, 
                    2237, 1731, 1592, 2243, 1737, 1607, 2252, 1746, 1622, 
                    2264, 1953, 2373, 1637, 1160, 1652, 2276, 1757, 1667, 
                    2284, 1765, 1682, 2295, 1776, 1697}], 
                   Line3DBox[{1515, 1890, 2307, 1516, 1899, 2316, 1533, 2207, 
                    1715, 1548, 2217, 1725, 1563, 2231, 1920, 2338, 1578, 
                    1930, 2348, 1593, 2244, 1738, 1608, 2253, 1747, 1623, 
                    2265, 1954, 2374, 1638, 1965, 2385, 1653, 1174, 1668, 
                    2285, 1766, 1683, 2296, 1777, 1698}], 
                   Line3DBox[{1517, 1891, 2308, 1518, 1900, 2317, 1534, 1906, 
                    2323, 1549, 2218, 1726, 1564, 2232, 1921, 2339, 1579, 
                    1931, 2349, 1594, 1938, 2356, 1609, 2254, 1748, 1624, 
                    2266, 1955, 2375, 1639, 1966, 2386, 1654, 1974, 2394, 
                    1669, 1188, 1684, 2297, 1778, 1699}], 
                   Line3DBox[{1519, 1892, 2309, 1520, 1901, 2318, 1535, 1907, 
                    2324, 1550, 1910, 2327, 1565, 2233, 1922, 2340, 1580, 
                    1932, 2350, 1595, 1939, 2357, 1610, 1943, 2361, 1625, 
                    2267, 1956, 2376, 1640, 1967, 2387, 1655, 1975, 2395, 
                    1670, 1980, 2400, 1685, 1202, 1700}], 
                   Line3DBox[{1691, 1771, 2290, 1676, 1761, 2280, 1661, 1754, 
                    2273, 1646, 1750, 2269, 1631, 2368, 1949, 2259, 1616, 
                    1742, 2248, 1601, 1734, 2240, 1586, 1729, 2235, 1571, 
                    1069, 2223, 1556, 1719, 2211, 1541, 1710, 2202, 1526, 
                    1704, 2196, 1502, 1701, 2193, 1500}], 
                   Line3DBox[{1696, 1775, 2294, 1681, 1764, 2283, 1666, 1756, 
                    2275, 1651, 1751, 2270, 1636, 1142, 2263, 1621, 1745, 
                    2251, 1606, 1736, 2242, 1591, 1730, 2236, 1576, 1727, 
                    2229, 2228, 1561, 1723, 2215, 1546, 1713, 2205, 1531, 
                    1706, 2198, 1512, 1702, 2194, 1510}]}, {
                   Line3DBox[{394, 603, 393, 2088, 604, 395, 2089, 605, 396, 
                    2090, 606, 397, 2091, 607, 1983, 398, 2092, 608, 399, 
                    2093, 609, 400, 2094, 610, 401, 2095, 611, 1984, 402, 
                    2096, 612, 403, 2097, 613, 404, 2098, 614, 405, 2099, 615,
                     406}], 
                   Line3DBox[{408, 616, 1985, 407, 617, 409, 2100, 618, 410, 
                    2101, 619, 411, 2102, 620, 1986, 412, 621, 1987, 413, 
                    2103, 622, 414, 2104, 623, 415, 2105, 624, 1988, 416, 625,
                     1989, 417, 2106, 626, 418, 2107, 627, 419, 2108, 628, 
                    420}], Line3DBox[{422, 629, 1990, 421, 630, 1991, 423, 
                    631, 424, 2109, 632, 425, 2110, 633, 1992, 426, 634, 1993,
                     427, 635, 1994, 428, 2111, 636, 429, 2112, 637, 1995, 
                    430, 638, 1996, 431, 639, 1997, 432, 2113, 640, 433, 2114,
                     641, 434}], 
                   Line3DBox[{436, 642, 1998, 435, 643, 1999, 437, 644, 2000, 
                    438, 645, 439, 2115, 646, 2001, 440, 647, 2002, 441, 648, 
                    2003, 442, 649, 2004, 443, 2116, 650, 2005, 444, 651, 
                    2006, 445, 652, 2007, 446, 653, 2008, 447, 2117, 654, 
                    448}], Line3DBox[{452, 2118, 656, 450, 2119, 658, 454, 
                    2120, 660, 456, 2121, 662, 458, 2122, 664, 460, 2123, 666,
                     462, 2124, 668, 464, 2125, 670, 466, 2126, 672, 2019, 
                    468, 2127, 674, 470, 2128, 676, 472, 2129, 678, 474, 2130,
                     680, 476}], 
                   Line3DBox[{475, 2023, 679, 473, 2022, 677, 471, 2021, 675, 
                    469, 2020, 673, 467, 2018, 2017, 671, 465, 2016, 669, 463,
                     2015, 667, 461, 2014, 665, 459, 2013, 663, 457, 2012, 
                    661, 455, 2011, 659, 453, 2010, 657, 449, 2009, 655, 
                    451}], Line3DBox[{478, 681, 2024, 477, 2131, 682, 479, 
                    2132, 683, 480, 2133, 684, 481, 2134, 685, 2025, 482, 686,
                     483, 2135, 687, 484, 2136, 688, 485, 2137, 689, 2026, 
                    486, 690, 2027, 487, 2138, 691, 488, 2139, 692, 489, 2140,
                     693, 490}], 
                   Line3DBox[{492, 694, 2028, 491, 695, 2029, 493, 2141, 696, 
                    494, 2142, 697, 495, 2143, 698, 2030, 496, 699, 2031, 497,
                     700, 498, 2144, 701, 499, 2145, 702, 2032, 500, 703, 
                    2033, 501, 704, 2034, 502, 2146, 705, 503, 2147, 706, 
                    504}], Line3DBox[{506, 707, 2035, 505, 708, 2036, 507, 
                    709, 2037, 508, 2148, 710, 509, 2149, 711, 2038, 510, 712,
                     2039, 511, 713, 2040, 512, 714, 513, 2150, 715, 2041, 
                    514, 716, 2042, 515, 717, 2043, 516, 718, 2044, 517, 2151,
                     719, 518}], 
                   Line3DBox[{522, 2152, 721, 520, 2153, 723, 524, 2154, 725, 
                    526, 2155, 727, 528, 2157, 2158, 729, 530, 2159, 731, 532,
                     2160, 733, 534, 2161, 735, 536, 2162, 737, 538, 2163, 
                    739, 540, 2164, 741, 542, 2165, 743, 544, 2166, 745, 
                    546}], Line3DBox[{545, 2057, 744, 543, 2056, 742, 541, 
                    2055, 740, 539, 2054, 738, 537, 2053, 736, 535, 2052, 734,
                     533, 2051, 732, 531, 2050, 730, 529, 2049, 728, 2156, 
                    527, 2048, 726, 525, 2047, 724, 523, 2046, 722, 519, 2045,
                     720, 521}], 
                   Line3DBox[{548, 746, 2058, 547, 2167, 747, 549, 2168, 748, 
                    550, 2169, 749, 551, 2170, 750, 2059, 552, 2171, 751, 553,
                     2172, 752, 554, 2173, 753, 555, 2174, 754, 2060, 556, 
                    755, 557, 2175, 756, 558, 2176, 757, 559, 2177, 758, 
                    560}], Line3DBox[{562, 759, 2061, 561, 760, 2062, 563, 
                    2178, 761, 564, 2179, 762, 565, 2180, 763, 2063, 566, 764,
                     2064, 567, 2181, 765, 568, 2182, 766, 569, 2183, 767, 
                    2065, 570, 768, 2066, 571, 769, 572, 2184, 770, 573, 2185,
                     771, 574}], 
                   Line3DBox[{576, 772, 2067, 575, 773, 2068, 577, 774, 2069, 
                    578, 2186, 775, 579, 2187, 776, 2070, 580, 777, 2071, 581,
                     778, 2072, 582, 2188, 779, 583, 2189, 780, 2073, 584, 
                    781, 2074, 585, 782, 2075, 586, 783, 587, 2190, 784, 
                    588}], Line3DBox[{590, 785, 2076, 589, 786, 2077, 591, 
                    787, 2078, 592, 788, 2079, 593, 2191, 789, 2080, 594, 790,
                     2081, 595, 791, 2082, 596, 792, 2083, 597, 2192, 793, 
                    2084, 598, 794, 2085, 599, 795, 2086, 600, 796, 2087, 601,
                     797, 602}], 
                   Line3DBox[{799, 1008, 798, 2298, 1009, 800, 2299, 1010, 
                    801, 2300, 1011, 802, 2301, 1012, 2193, 803, 2302, 1013, 
                    804, 2303, 1014, 805, 2304, 1015, 806, 2305, 1016, 2194, 
                    807, 2306, 1017, 808, 2307, 1018, 809, 2308, 1019, 810, 
                    2309, 1020, 811}], 
                   Line3DBox[{813, 1021, 2195, 812, 1022, 814, 2310, 1023, 
                    815, 2311, 1024, 816, 2312, 1025, 2196, 817, 1026, 2197, 
                    818, 2313, 1027, 819, 2314, 1028, 820, 2315, 1029, 2198, 
                    821, 1030, 2199, 822, 2316, 1031, 823, 2317, 1032, 824, 
                    2318, 1033, 825}], 
                   Line3DBox[{827, 1034, 2200, 826, 1035, 2201, 828, 1036, 
                    829, 2319, 1037, 830, 2320, 1038, 2202, 831, 1039, 2203, 
                    832, 1040, 2204, 833, 2321, 1041, 834, 2322, 1042, 2205, 
                    835, 1043, 2206, 836, 1044, 2207, 837, 2323, 1045, 838, 
                    2324, 1046, 839}], 
                   Line3DBox[{841, 1047, 2208, 840, 1048, 2209, 842, 1049, 
                    2210, 843, 1050, 844, 2325, 1051, 2211, 845, 1052, 2212, 
                    846, 1053, 2213, 847, 1054, 2214, 848, 2326, 1055, 2215, 
                    849, 1056, 2216, 850, 1057, 2217, 851, 1058, 2218, 852, 
                    2327, 1059, 853}], 
                   Line3DBox[{857, 2328, 1061, 855, 2329, 1063, 859, 2330, 
                    1065, 861, 2331, 1067, 863, 2332, 1069, 865, 2333, 1071, 
                    867, 2334, 1073, 869, 2335, 1075, 871, 2336, 1077, 2229, 
                    873, 2337, 1079, 875, 2338, 1081, 877, 2339, 1083, 879, 
                    2340, 1085, 881}], 
                   Line3DBox[{880, 2233, 1084, 878, 2232, 1082, 876, 2231, 
                    1080, 874, 2230, 1078, 872, 2228, 2227, 1076, 870, 2226, 
                    1074, 868, 2225, 1072, 866, 2224, 1070, 864, 2223, 1068, 
                    862, 2222, 1066, 860, 2221, 1064, 858, 2220, 1062, 854, 
                    2219, 1060, 856}], 
                   Line3DBox[{883, 1086, 2234, 882, 2341, 1087, 884, 2342, 
                    1088, 885, 2343, 1089, 886, 2344, 1090, 2235, 887, 1091, 
                    888, 2345, 1092, 889, 2346, 1093, 890, 2347, 1094, 2236, 
                    891, 1095, 2237, 892, 2348, 1096, 893, 2349, 1097, 894, 
                    2350, 1098, 895}], 
                   Line3DBox[{897, 1099, 2238, 896, 1100, 2239, 898, 2351, 
                    1101, 899, 2352, 1102, 900, 2353, 1103, 2240, 901, 1104, 
                    2241, 902, 1105, 903, 2354, 1106, 904, 2355, 1107, 2242, 
                    905, 1108, 2243, 906, 1109, 2244, 907, 2356, 1110, 908, 
                    2357, 1111, 909}], 
                   Line3DBox[{911, 1112, 2245, 910, 1113, 2246, 912, 1114, 
                    2247, 913, 2358, 1115, 914, 2359, 1116, 2248, 915, 1117, 
                    2249, 916, 1118, 2250, 917, 1119, 918, 2360, 1120, 2251, 
                    919, 1121, 2252, 920, 1122, 2253, 921, 1123, 2254, 922, 
                    2361, 1124, 923}], 
                   Line3DBox[{927, 2362, 1126, 925, 2363, 1128, 929, 2364, 
                    1130, 931, 2365, 1132, 933, 2367, 2368, 1134, 935, 2369, 
                    1136, 937, 2370, 1138, 939, 2371, 1140, 941, 2372, 1142, 
                    943, 2373, 1144, 945, 2374, 1146, 947, 2375, 1148, 949, 
                    2376, 1150, 951}], 
                   Line3DBox[{950, 2267, 1149, 948, 2266, 1147, 946, 2265, 
                    1145, 944, 2264, 1143, 942, 2263, 1141, 940, 2262, 1139, 
                    938, 2261, 1137, 936, 2260, 1135, 934, 2259, 1133, 2366, 
                    932, 2258, 1131, 930, 2257, 1129, 928, 2256, 1127, 924, 
                    2255, 1125, 926}], 
                   Line3DBox[{953, 1151, 2268, 952, 2377, 1152, 954, 2378, 
                    1153, 955, 2379, 1154, 956, 2380, 1155, 2269, 957, 2381, 
                    1156, 958, 2382, 1157, 959, 2383, 1158, 960, 2384, 1159, 
                    2270, 961, 1160, 962, 2385, 1161, 963, 2386, 1162, 964, 
                    2387, 1163, 965}], 
                   Line3DBox[{967, 1164, 2271, 966, 1165, 2272, 968, 2388, 
                    1166, 969, 2389, 1167, 970, 2390, 1168, 2273, 971, 1169, 
                    2274, 972, 2391, 1170, 973, 2392, 1171, 974, 2393, 1172, 
                    2275, 975, 1173, 2276, 976, 1174, 977, 2394, 1175, 978, 
                    2395, 1176, 979}], 
                   Line3DBox[{981, 1177, 2277, 980, 1178, 2278, 982, 1179, 
                    2279, 983, 2396, 1180, 984, 2397, 1181, 2280, 985, 1182, 
                    2281, 986, 1183, 2282, 987, 2398, 1184, 988, 2399, 1185, 
                    2283, 989, 1186, 2284, 990, 1187, 2285, 991, 1188, 992, 
                    2400, 1189, 993}], 
                   Line3DBox[{995, 1190, 2286, 994, 1191, 2287, 996, 1192, 
                    2288, 997, 1193, 2289, 998, 2401, 1194, 2290, 999, 1195, 
                    2291, 1000, 1196, 2292, 1001, 1197, 2293, 1002, 2402, 
                    1198, 2294, 1003, 1199, 2295, 1004, 1200, 2296, 1005, 
                    1201, 2297, 1006, 1202, 1007}]}, {}, {}, {}, {}, {}}},
                VertexNormals->CompressedData["
1:eJztfXk8ldv3v6mQFFEJTa40zzKWVVJpppIGJWSIKElIwxFCEm5UZCgpGihD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                 "]],
               Axes->True,
               BoxRatios->{1, 1},
               Method->{"RotationControl" -> "Globe"},
               PlotRange->{{200., 590.}, {20., 59.}, {3., 5.}},
               PlotRangePadding->{
                 Scaled[0.02], 
                 Scaled[0.02], 
                 Scaled[0.02]},
               ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]}, Dynamic[BoxForm`var$$],
              Alignment->Automatic,
              ImageSize->All]],
             Background->GrayLevel[1]],
            Deployed->False,
            StripOnInput->False],
           Background->GrayLevel[1],
           Frame->True,
           FrameStyle->GrayLevel[0.8235294117647058],
           StripOnInput->False]}
        },
        ColumnsEqual->False,
        GridBoxAlignment->{"Columns" -> {{Left}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        RowsEqual->False],
       "Grid"],
      BaselinePosition->Automatic,
      DefaultBaseStyle->"SlideView",
      FrameMargins->6,
      ImageMargins->Automatic],
     Deployed->True,
     StripOnInput->False],
    SlideView[{
      Graphics[{{{{}, {
           Hue[0.67, 0.6, 0.6], 
           PointSize[0.02], 
           RGBColor[0, 0, 1], 
           
           Point[{{300., 4.}, {330., 4.}, {360., 4.}, {390., 4.}, {420., 
            4.}, {450., 4.}, {480., 4.}, {510., 4.}, {540., 4.}, {570., 4.}, {
            600., 4.}}]}, {}}}, {{{}, {
           Hue[0.67, 0.6, 0.6], 
           PointSize[0.02], 
           RGBColor[1, 0, 0], 
           
           Point[{{300., 3.}, {330., 3.}, {360., 3.}, {390., 3.}, {420., 
            3.}, {450., 3.}, {480., 3.}, {510., 3.}, {540., 3.}, {570., 3.}, {
            600., 3.}}]}, {}}}}, {PlotLabel -> {
          Text[
           Style["EdgeColoring", 
            RGBColor[0, 0, 1], 20]], 
          Text[
           Style["Vizing", 
            RGBColor[1, 0, 0], 20]]}, AxesLabel -> {
          Text[
           Style["Number of vertices", Italic, 16]], 
          Text[
           Style["Number of used colours", Italic, 16]]}, ImageSize -> 500, 
        AspectRatio -> GoldenRatio^(-1), Axes -> True, 
        AxesOrigin -> {300., 0}, PlotRange -> {{299, 601}, {0, 4.8}}, 
        PlotRangeClipping -> True, 
        PlotRangePadding -> {Automatic, Automatic}}], 
      Graphics3D[
       GraphicsComplex[CompressedData["
1:eJztnXGIXNtdx0MVneTNS/btezwXKcOzaDcMpQSZ7CaTTDI7Ozu7MzuV8HxI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        "], {{{
           EdgeForm[], 
           RGBColor[0, 0, 1], 
           GraphicsGroup[{
             Polygon[CompressedData["
1:eJwt2Qf8TfUfx/Hz/Trnd75W9iYUDSojpESEkEgI7dLee+8d0d577y2FsglF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              "]], 
             Polygon[CompressedData["
1:eJwtmnXgVkUWhu+d77u/CxiEhI0I2ILdgYWCIoio2IidqOjqqru6q66Bgd3d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              "]], 
             Polygon[CompressedData["
1:eJwt1wncVdMax/HTeTvto9FwpUFXdWUoNNxKoYEiSSLj/VzzkFCRyDxmrijK
VaIoQxmipKJZqTQjLnVlqChuuEoT8n3uOp/P+3/Xen7r/6y9z95r2vUuvbZ7
n3wul1tKBXrFv0bUV31XuVzuvWjMcrl3yudy+6k+jV2DzRLPw3upl1POFL8q
7wi6nm8n33xt7+NztF+mvqtCLrdAvEc5Tbkv30i+q7XNEM/mu0j9V+3vincq
31PuxTeU71JtO7C5WBEbgl2CbcOml0/3Pxi7EDtNX2cAw7HW4j/oF74pfGXY
QL7zsTK++dgB2GjsWmyCvMOoN7YNm4NtlTuVz19uEHYB9hu2BKiMDcOuwLrq
73S5w7BW4t/j2nwr+KpiT/JdGc+P50oaj7UXl3dTL4sPoQZ0iR84Cz9Qf93V
P5f3Gb2EjdN+IF0m9wfsbax2/F6+f4s/pRewWnEv2Cfi1TQWq4Gdhn0oXkWj
sTOwc/U3Un9t45m4l9Oxc7ARWBssj30oHkDzsPPi3rCj+frorzf1iuvj43kO
pV58W11jNnameB/te9S7xW8Sz6Gr6BW+4/EK+tvuWc0u//8hl3tM7sXxDLFl
WBVsONYDe03ekdQP240twHbzLearhD2BXY610NE1rltVvQp9Qq/La0KN6Qpt
C7GJ6k2pv9w/5C7C3hA3o5uwPdhibJK4Jd2K5cVL49m4xjzXrY49yxcT6lKe
mvqu7Dedrf0S8TnKHsqX+U7l2VvbzHiPNA47JuYadgxfebkHxPuidaXfEYO+
WuTRp7QP9hnNdc15NATbV/w5LRC/T49jY/Vfgy7UxUZsEnaA+KcsjbFGyuri
GYV033GvD5be1fOF5I32f2Bv5tM7L6e+T1yPPqNWWB7bT/0vtIamRw6Nct2m
MXepOd+eLL2LeCeraRrPefQ0XzPxdmrDU9TfQep16Vtqi+2F1VOvT5voOCzD
6qj/lTbQGH1VobP194XfOx47lq8CX+0Yt/QNtcbKsP3Vq9N/6O/YH1RJvTJ9
RM3Ev8d11Iu0iqYW0piOcXynPv6HPae+b4zzeNfYa9gU9c402L0cLN6cT++3
bzFdM679RfSLfWwM1eMb755vxt6S14pux8qLl9Nk8dF0WwwV8bK4T7lfyD0c
e1Pu3dhoniJlhTTfx8R74VtLi3k+oCfjPclbgt2hXinGjnj/6I+W8Synkdq6
i/+pr9Gu0UGcGac1sW76/pjnI3ou5hi2Th8N+SZh95Te+dXF9DzjuX5MZ2EX
628sX6fg+qsY41luA+w1ubfjF8TYk1vUfqb288XvFBKP+n3adpfe5XXFNPZi
DK6ld2PM0xj9tYz1ujROry2mcRvj9/P4LdhK1z2Qb5zr3hBrEbYcq42Nxfph
b8ezpK4x//WxBVvEMz+uHWu4cqH4E1qkfgu2l3J17E3Kpcpa+ntef9drq4cV
ok9sPTaxNKdP0vf82HvpMewFnjp0Od/32FTsKfE2/bXFpmEP5tN76yJ3qXgJ
jcin8bgl9m/1w7M0No9SHhT7j9zfY53Q9qz4N/11xGZhg7Ej+WrHmoDtiDUG
GyXexXcCNgMbiPXC6sY88o7OjfVW/Azt5uvAN5NvUKw52rryrRSvoGfiGfD9
mqU1uLGyrvhx+l5uc7mv892pbSi2GdtE7YtpvB7Gv3esMXw/8k3HTsROiPUL
ayT+mYbHWifvGGwy3wCsI1a5NG9PktMh1h/aybcjnoO2R7R10NYev1/u4eIf
6ZR4ztgQrLl4Jw0WfyXvCOwF1+iPPYH9gLXAJmJ3YYfKrRbrHbYFm4Y9Kf6Z
71hsCnYfNgz7EWuNvYXdi42IZ4W1w6ZjD2EN9bd/zAfsF2wm1hRriF2HVRCv
oL7ig/2mmt7ReTFexQfFOq7swveV3Ff5HhSvco062FNYz3w6k+zkXaLeJEvn
kyOUtWKv4NvONzef5ka10nw8NUvz5DHaqL8mfBP4btXWRdup+FCshXgXPVJI
a1GsP62LaT6VYZuytI7Wjf1FvJ/y5GLa22KPeyKf9vJypbNHyyzt60PoW301
jTMt3235tB5uztIe9rcsrY3/oq18v8RY1ccD2h7FNojXx/wqpnk8EtseY09/
7+jvYeyhQprrMb9bFtNZuEHsHbE38G3iews7GKsYewX2HTa5tBZ3lrNIvJCG
x/6VpUP4KYovsVewh8Wf6r8+NgrrnU/3tipL91o1S/d5iLIy71l8m/mmaDsZ
64QNxBqLt5X2yxuKaQ+MvXA9zePpTa/zdYw1yxh5T9yHJmInYhWxuYU012N+
Dyytye+r96PJfJ3jfrCV4ntoDnYOVgtbJr6DZmJnxlqALRT3p6nYabH2laU1
4sssnU3jjPpsaU++qpj23tiDP6QF8q6nSXJPjn1H7vxCGucxtgeXzl4r1O+m
u2JMlMZ/nCP6F9O5Is4X31H9OB/wdNPfBtd9A6se47SY9sDYC5/GXiykNSvW
qYuKaV0N37osrWmxto3CXtJen3rq7yfsXeyBQtovYo9oXEzfRKuwe2ku37nx
Ttzf7MijCVg7rFCWziA95VSM90Mr8+mMdGMxnXvi/LOROsX+IfcRuUeJt9Ly
OKPQLOwscQ39fc33TZbOBfFN8BUN4vnSvTXie9E936jtA+yW2HOx02Pcyl0s
vpmmY91iv8XaiSuV9sQT9NVW3FF5vPIBvob4T9Q55i82CGsi/pXeFLeg5tSj
mNaZOnFOdC+d+da5lwn5dLbtVExn3TjzDs2nc10/rJZ6Tfqa9sa2yG0ldw7f
o/n0fbQxS99Q8S31IjbQ9dbG3OEbg/XFlmC3xf4ea1dpT1uqfjvN4Ose77t0
9lmfpe+q+L56Pp++tzZk6fsrvsPGYfcX0rdyfB83Kqbv23Y8x8Yc0V8D8fdx
jhDfRNOwrvFby9K337e0Rl9r6eV82gNXZ2lvqpal/fB4ZRu5A+Qeiv+X2mPH
xdjCDhH/kE9r55osrTex7gzD/gRt1vdi
              "]]}]}, {
           EdgeForm[], 
           RGBColor[1, 0, 0], 
           GraphicsGroup[{
             Polygon[CompressedData["
1:eJxFmXf8jtUbx5+vw3Ofo63SNhMhslKohLIJGdkrKSspoxAi7WVERiIlUdp7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              "]], 
             Polygon[CompressedData["
1:eJwtmXnAllP6x5+n+7yn97Hv22DKkoRUkqJVRbskUWnPFpIk+14YESrLGDNm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              "]], 
             Polygon[CompressedData["
1:eJwt13n8lsMax/EnPf2e+8exk7IXheIoKVQqoRKKyNoeKqWylaR9IZQ22qSS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              "]]}]}, {}, {}, {}}, {{
           
           Line[{1203, 1, 394, 15, 408, 29, 422, 43, 436, 57, 451, 452, 71, 
            478, 85, 492, 99, 506, 113, 521, 522, 127, 548, 141, 562, 155, 
            576, 169, 590, 183, 1398, 184, 1399, 185, 1400, 186, 1401, 187, 
            1402, 1403, 188, 1404, 189, 1405, 190, 1406, 191, 1407, 1408, 192,
             1409, 193, 1410, 194, 1411, 195, 1412, 196, 602, 182, 588, 168, 
            574, 154, 560, 140, 546, 545, 126, 518, 112, 504, 98, 490, 84, 
            476, 475, 70, 448, 56, 434, 42, 420, 28, 406, 14, 1231, 13, 1229, 
            12, 1227, 11, 1225, 10, 1222, 1221, 9, 1219, 8, 1217, 7, 1215, 6, 
            1212, 1211, 5, 1209, 4, 1207, 3, 1205, 2, 1203}]}, {
           
           Line[{1491, 197, 799, 211, 813, 225, 827, 239, 841, 253, 856, 857, 
            267, 883, 281, 897, 295, 911, 309, 926, 927, 323, 953, 337, 967, 
            351, 981, 365, 995, 379, 1686, 380, 1687, 381, 1688, 382, 1689, 
            383, 1690, 1691, 384, 1692, 385, 1693, 386, 1694, 387, 1695, 1696,
             388, 1697, 389, 1698, 390, 1699, 391, 1700, 392, 1007, 378, 993, 
            364, 979, 350, 965, 336, 951, 950, 322, 923, 308, 909, 294, 895, 
            280, 881, 880, 266, 853, 252, 839, 238, 825, 224, 811, 210, 1519, 
            209, 1517, 208, 1515, 207, 1513, 206, 1510, 1509, 205, 1507, 204, 
            1505, 203, 1503, 202, 1500, 1499, 201, 1497, 200, 1495, 199, 1493,
             198, 1491}]}, {
           
           Line[{1203, 603, 1204, 1985, 1415, 1233, 1990, 1420, 1248, 1998, 
            1428, 1263, 2009, 1809, 2118, 1278, 2024, 1440, 1293, 2028, 1444, 
            1308, 2035, 1451, 1323, 2045, 1842, 2152, 1338, 2058, 1461, 1353, 
            2061, 1464, 1368, 2067, 1470, 1383, 2076, 1479, 1398}], 
           
           Line[{1205, 1779, 2088, 1206, 617, 1234, 1991, 1421, 1249, 1999, 
            1429, 1264, 2010, 1810, 2119, 1279, 1821, 2131, 1294, 2029, 1445, 
            1309, 2036, 1452, 1324, 2046, 1843, 2153, 1339, 1855, 2167, 1354, 
            2062, 1465, 1369, 2068, 1471, 1384, 2077, 1480, 1399}], 
           
           Line[{1207, 1780, 2089, 1208, 1791, 2100, 1235, 631, 1250, 2000, 
            1430, 1265, 2011, 1811, 2120, 1280, 1822, 2132, 1295, 1831, 2141, 
            1310, 2037, 1453, 1325, 2047, 1844, 2154, 1340, 1856, 2168, 1355, 
            1866, 2178, 1370, 2069, 1472, 1385, 2078, 1481, 1400}], 
           
           Line[{1209, 1781, 2090, 1210, 1792, 2101, 1236, 1800, 2109, 1251, 
            645, 1266, 2012, 1812, 2121, 1281, 1823, 2133, 1296, 1832, 2142, 
            1311, 1838, 2148, 1326, 2048, 1845, 2155, 1341, 1857, 2169, 1356, 
            1867, 2179, 1371, 1874, 2186, 1386, 2079, 1482, 1401}], 
           
           Line[{1211, 1782, 2091, 1213, 1793, 2102, 1237, 1801, 2110, 1252, 
            1806, 2115, 1267, 663, 2122, 1282, 1824, 2134, 1297, 1833, 2143, 
            1312, 1839, 2149, 1327, 1846, 2156, 2157, 1342, 1858, 2170, 1357, 
            1868, 2180, 1372, 1875, 2187, 1387, 1879, 2191, 1402}], 
           
           Line[{1215, 1783, 2092, 1216, 1987, 1417, 1239, 1993, 1423, 1254, 
            2002, 1432, 1269, 2014, 1813, 2123, 1284, 686, 1299, 2031, 1447, 
            1314, 2039, 1455, 1329, 2050, 1848, 2159, 1344, 1859, 2171, 1359, 
            2064, 1467, 1374, 2071, 1474, 1389, 2081, 1484, 1404}], 
           
           Line[{1217, 1784, 2093, 1218, 1794, 2103, 1240, 1994, 1424, 1255, 
            2003, 1433, 1270, 2015, 1814, 2124, 1285, 1825, 2135, 1300, 700, 
            1315, 2040, 1456, 1330, 2051, 1849, 2160, 1345, 1860, 2172, 1360, 
            1869, 2181, 1375, 2072, 1475, 1390, 2082, 1485, 1405}], 
           
           Line[{1219, 1785, 2094, 1220, 1795, 2104, 1241, 1802, 2111, 1256, 
            2004, 1434, 1271, 2016, 1815, 2125, 1286, 1826, 2136, 1301, 1834, 
            2144, 1316, 714, 1331, 2052, 1850, 2161, 1346, 1861, 2173, 1361, 
            1870, 2182, 1376, 1876, 2188, 1391, 2083, 1486, 1406}], 
           
           Line[{1221, 1786, 2095, 1223, 1796, 2105, 1242, 1803, 2112, 1257, 
            1807, 2116, 1272, 2017, 1816, 2126, 1287, 1827, 2137, 1302, 1835, 
            2145, 1317, 1840, 2150, 1332, 736, 2162, 1347, 1862, 2174, 1362, 
            1871, 2183, 1377, 1877, 2189, 1392, 1880, 2192, 1407}], 
           
           Line[{1225, 1787, 2096, 1226, 1989, 1419, 1244, 1996, 1426, 1259, 
            2006, 1436, 1274, 2020, 1817, 2127, 1289, 2027, 1443, 1304, 2033, 
            1449, 1319, 2042, 1458, 1334, 2054, 1851, 2163, 1349, 755, 1364, 
            2066, 1469, 1379, 2074, 1477, 1394, 2085, 1488, 1409}], 
           
           Line[{1227, 1788, 2097, 1228, 1797, 2106, 1245, 1997, 1427, 1260, 
            2007, 1437, 1275, 2021, 1818, 2128, 1290, 1828, 2138, 1305, 2034, 
            1450, 1320, 2043, 1459, 1335, 2055, 1852, 2164, 1350, 1863, 2175, 
            1365, 769, 1380, 2075, 1478, 1395, 2086, 1489, 1410}], 
           
           Line[{1229, 1789, 2098, 1230, 1798, 2107, 1246, 1804, 2113, 1261, 
            2008, 1438, 1276, 2022, 1819, 2129, 1291, 1829, 2139, 1306, 1836, 
            2146, 1321, 2044, 1460, 1336, 2056, 1853, 2165, 1351, 1864, 2176, 
            1366, 1872, 2184, 1381, 783, 1396, 2087, 1490, 1411}], 
           
           Line[{1231, 1790, 2099, 1232, 1799, 2108, 1247, 1805, 2114, 1262, 
            1808, 2117, 1277, 2023, 1820, 2130, 1292, 1830, 2140, 1307, 1837, 
            2147, 1322, 1841, 2151, 1337, 2057, 1854, 2166, 1352, 1865, 2177, 
            1367, 1873, 2185, 1382, 1878, 2190, 1397, 797, 1412}], 
           
           Line[{1403, 1483, 2080, 1388, 1473, 2070, 1373, 1466, 2063, 1358, 
            1462, 2059, 1343, 2158, 1847, 2049, 1328, 1454, 2038, 1313, 1446, 
            2030, 1298, 1441, 2025, 1283, 664, 2013, 1268, 1431, 2001, 1253, 
            1422, 1992, 1238, 1416, 1986, 1214, 1413, 1983, 1212}], 
           
           Line[{1408, 1487, 2084, 1393, 1476, 2073, 1378, 1468, 2065, 1363, 
            1463, 2060, 1348, 737, 2053, 1333, 1457, 2041, 1318, 1448, 2032, 
            1303, 1442, 2026, 1288, 1439, 2019, 2018, 1273, 1435, 2005, 1258, 
            1425, 1995, 1243, 1418, 1988, 1224, 1414, 1984, 1222}], 
           
           Line[{1491, 1008, 1492, 2195, 1703, 1521, 2200, 1708, 1536, 2208, 
            1716, 1551, 2219, 1911, 2328, 1566, 2234, 1728, 1581, 2238, 1732, 
            1596, 2245, 1739, 1611, 2255, 1944, 2362, 1626, 2268, 1749, 1641, 
            2271, 1752, 1656, 2277, 1758, 1671, 2286, 1767, 1686}], 
           
           Line[{1493, 1881, 2298, 1494, 1022, 1522, 2201, 1709, 1537, 2209, 
            1717, 1552, 2220, 1912, 2329, 1567, 1923, 2341, 1582, 2239, 1733, 
            1597, 2246, 1740, 1612, 2256, 1945, 2363, 1627, 1957, 2377, 1642, 
            2272, 1753, 1657, 2278, 1759, 1672, 2287, 1768, 1687}], 
           
           Line[{1495, 1882, 2299, 1496, 1893, 2310, 1523, 1036, 1538, 2210, 
            1718, 1553, 2221, 1913, 2330, 1568, 1924, 2342, 1583, 1933, 2351, 
            1598, 2247, 1741, 1613, 2257, 1946, 2364, 1628, 1958, 2378, 1643, 
            1968, 2388, 1658, 2279, 1760, 1673, 2288, 1769, 1688}], 
           
           Line[{1497, 1883, 2300, 1498, 1894, 2311, 1524, 1902, 2319, 1539, 
            1050, 1554, 2222, 1914, 2331, 1569, 1925, 2343, 1584, 1934, 2352, 
            1599, 1940, 2358, 1614, 2258, 1947, 2365, 1629, 1959, 2379, 1644, 
            1969, 2389, 1659, 1976, 2396, 1674, 2289, 1770, 1689}], 
           
           Line[{1499, 1884, 2301, 1501, 1895, 2312, 1525, 1903, 2320, 1540, 
            1908, 2325, 1555, 1068, 2332, 1570, 1926, 2344, 1585, 1935, 2353, 
            1600, 1941, 2359, 1615, 1948, 2366, 2367, 1630, 1960, 2380, 1645, 
            1970, 2390, 1660, 1977, 2397, 1675, 1981, 2401, 1690}], 
           
           Line[{1503, 1885, 2302, 1504, 2197, 1705, 1527, 2203, 1711, 1542, 
            2212, 1720, 1557, 2224, 1915, 2333, 1572, 1091, 1587, 2241, 1735, 
            1602, 2249, 1743, 1617, 2260, 1950, 2369, 1632, 1961, 2381, 1647, 
            2274, 1755, 1662, 2281, 1762, 1677, 2291, 1772, 1692}], 
           
           Line[{1505, 1886, 2303, 1506, 1896, 2313, 1528, 2204, 1712, 1543, 
            2213, 1721, 1558, 2225, 1916, 2334, 1573, 1927, 2345, 1588, 1105, 
            1603, 2250, 1744, 1618, 2261, 1951, 2370, 1633, 1962, 2382, 1648, 
            1971, 2391, 1663, 2282, 1763, 1678, 2292, 1773, 1693}], 
           
           Line[{1507, 1887, 2304, 1508, 1897, 2314, 1529, 1904, 2321, 1544, 
            2214, 1722, 1559, 2226, 1917, 2335, 1574, 1928, 2346, 1589, 1936, 
            2354, 1604, 1119, 1619, 2262, 1952, 2371, 1634, 1963, 2383, 1649, 
            1972, 2392, 1664, 1978, 2398, 1679, 2293, 1774, 1694}], 
           
           Line[{1509, 1888, 2305, 1511, 1898, 2315, 1530, 1905, 2322, 1545, 
            1909, 2326, 1560, 2227, 1918, 2336, 1575, 1929, 2347, 1590, 1937, 
            2355, 1605, 1942, 2360, 1620, 1141, 2372, 1635, 1964, 2384, 1650, 
            1973, 2393, 1665, 1979, 2399, 1680, 1982, 2402, 1695}], 
           
           Line[{1513, 1889, 2306, 1514, 2199, 1707, 1532, 2206, 1714, 1547, 
            2216, 1724, 1562, 2230, 1919, 2337, 1577, 2237, 1731, 1592, 2243, 
            1737, 1607, 2252, 1746, 1622, 2264, 1953, 2373, 1637, 1160, 1652, 
            2276, 1757, 1667, 2284, 1765, 1682, 2295, 1776, 1697}], 
           
           Line[{1515, 1890, 2307, 1516, 1899, 2316, 1533, 2207, 1715, 1548, 
            2217, 1725, 1563, 2231, 1920, 2338, 1578, 1930, 2348, 1593, 2244, 
            1738, 1608, 2253, 1747, 1623, 2265, 1954, 2374, 1638, 1965, 2385, 
            1653, 1174, 1668, 2285, 1766, 1683, 2296, 1777, 1698}], 
           
           Line[{1517, 1891, 2308, 1518, 1900, 2317, 1534, 1906, 2323, 1549, 
            2218, 1726, 1564, 2232, 1921, 2339, 1579, 1931, 2349, 1594, 1938, 
            2356, 1609, 2254, 1748, 1624, 2266, 1955, 2375, 1639, 1966, 2386, 
            1654, 1974, 2394, 1669, 1188, 1684, 2297, 1778, 1699}], 
           
           Line[{1519, 1892, 2309, 1520, 1901, 2318, 1535, 1907, 2324, 1550, 
            1910, 2327, 1565, 2233, 1922, 2340, 1580, 1932, 2350, 1595, 1939, 
            2357, 1610, 1943, 2361, 1625, 2267, 1956, 2376, 1640, 1967, 2387, 
            1655, 1975, 2395, 1670, 1980, 2400, 1685, 1202, 1700}], 
           
           Line[{1691, 1771, 2290, 1676, 1761, 2280, 1661, 1754, 2273, 1646, 
            1750, 2269, 1631, 2368, 1949, 2259, 1616, 1742, 2248, 1601, 1734, 
            2240, 1586, 1729, 2235, 1571, 1069, 2223, 1556, 1719, 2211, 1541, 
            1710, 2202, 1526, 1704, 2196, 1502, 1701, 2193, 1500}], 
           
           Line[{1696, 1775, 2294, 1681, 1764, 2283, 1666, 1756, 2275, 1651, 
            1751, 2270, 1636, 1142, 2263, 1621, 1745, 2251, 1606, 1736, 2242, 
            1591, 1730, 2236, 1576, 1727, 2229, 2228, 1561, 1723, 2215, 1546, 
            1713, 2205, 1531, 1706, 2198, 1512, 1702, 2194, 1510}]}, {
           
           Line[{394, 603, 393, 2088, 604, 395, 2089, 605, 396, 2090, 606, 
            397, 2091, 607, 1983, 398, 2092, 608, 399, 2093, 609, 400, 2094, 
            610, 401, 2095, 611, 1984, 402, 2096, 612, 403, 2097, 613, 404, 
            2098, 614, 405, 2099, 615, 406}], 
           
           Line[{408, 616, 1985, 407, 617, 409, 2100, 618, 410, 2101, 619, 
            411, 2102, 620, 1986, 412, 621, 1987, 413, 2103, 622, 414, 2104, 
            623, 415, 2105, 624, 1988, 416, 625, 1989, 417, 2106, 626, 418, 
            2107, 627, 419, 2108, 628, 420}], 
           
           Line[{422, 629, 1990, 421, 630, 1991, 423, 631, 424, 2109, 632, 
            425, 2110, 633, 1992, 426, 634, 1993, 427, 635, 1994, 428, 2111, 
            636, 429, 2112, 637, 1995, 430, 638, 1996, 431, 639, 1997, 432, 
            2113, 640, 433, 2114, 641, 434}], 
           
           Line[{436, 642, 1998, 435, 643, 1999, 437, 644, 2000, 438, 645, 
            439, 2115, 646, 2001, 440, 647, 2002, 441, 648, 2003, 442, 649, 
            2004, 443, 2116, 650, 2005, 444, 651, 2006, 445, 652, 2007, 446, 
            653, 2008, 447, 2117, 654, 448}], 
           
           Line[{452, 2118, 656, 450, 2119, 658, 454, 2120, 660, 456, 2121, 
            662, 458, 2122, 664, 460, 2123, 666, 462, 2124, 668, 464, 2125, 
            670, 466, 2126, 672, 2019, 468, 2127, 674, 470, 2128, 676, 472, 
            2129, 678, 474, 2130, 680, 476}], 
           
           Line[{475, 2023, 679, 473, 2022, 677, 471, 2021, 675, 469, 2020, 
            673, 467, 2018, 2017, 671, 465, 2016, 669, 463, 2015, 667, 461, 
            2014, 665, 459, 2013, 663, 457, 2012, 661, 455, 2011, 659, 453, 
            2010, 657, 449, 2009, 655, 451}], 
           
           Line[{478, 681, 2024, 477, 2131, 682, 479, 2132, 683, 480, 2133, 
            684, 481, 2134, 685, 2025, 482, 686, 483, 2135, 687, 484, 2136, 
            688, 485, 2137, 689, 2026, 486, 690, 2027, 487, 2138, 691, 488, 
            2139, 692, 489, 2140, 693, 490}], 
           
           Line[{492, 694, 2028, 491, 695, 2029, 493, 2141, 696, 494, 2142, 
            697, 495, 2143, 698, 2030, 496, 699, 2031, 497, 700, 498, 2144, 
            701, 499, 2145, 702, 2032, 500, 703, 2033, 501, 704, 2034, 502, 
            2146, 705, 503, 2147, 706, 504}], 
           
           Line[{506, 707, 2035, 505, 708, 2036, 507, 709, 2037, 508, 2148, 
            710, 509, 2149, 711, 2038, 510, 712, 2039, 511, 713, 2040, 512, 
            714, 513, 2150, 715, 2041, 514, 716, 2042, 515, 717, 2043, 516, 
            718, 2044, 517, 2151, 719, 518}], 
           
           Line[{522, 2152, 721, 520, 2153, 723, 524, 2154, 725, 526, 2155, 
            727, 528, 2157, 2158, 729, 530, 2159, 731, 532, 2160, 733, 534, 
            2161, 735, 536, 2162, 737, 538, 2163, 739, 540, 2164, 741, 542, 
            2165, 743, 544, 2166, 745, 546}], 
           
           Line[{545, 2057, 744, 543, 2056, 742, 541, 2055, 740, 539, 2054, 
            738, 537, 2053, 736, 535, 2052, 734, 533, 2051, 732, 531, 2050, 
            730, 529, 2049, 728, 2156, 527, 2048, 726, 525, 2047, 724, 523, 
            2046, 722, 519, 2045, 720, 521}], 
           
           Line[{548, 746, 2058, 547, 2167, 747, 549, 2168, 748, 550, 2169, 
            749, 551, 2170, 750, 2059, 552, 2171, 751, 553, 2172, 752, 554, 
            2173, 753, 555, 2174, 754, 2060, 556, 755, 557, 2175, 756, 558, 
            2176, 757, 559, 2177, 758, 560}], 
           
           Line[{562, 759, 2061, 561, 760, 2062, 563, 2178, 761, 564, 2179, 
            762, 565, 2180, 763, 2063, 566, 764, 2064, 567, 2181, 765, 568, 
            2182, 766, 569, 2183, 767, 2065, 570, 768, 2066, 571, 769, 572, 
            2184, 770, 573, 2185, 771, 574}], 
           
           Line[{576, 772, 2067, 575, 773, 2068, 577, 774, 2069, 578, 2186, 
            775, 579, 2187, 776, 2070, 580, 777, 2071, 581, 778, 2072, 582, 
            2188, 779, 583, 2189, 780, 2073, 584, 781, 2074, 585, 782, 2075, 
            586, 783, 587, 2190, 784, 588}], 
           
           Line[{590, 785, 2076, 589, 786, 2077, 591, 787, 2078, 592, 788, 
            2079, 593, 2191, 789, 2080, 594, 790, 2081, 595, 791, 2082, 596, 
            792, 2083, 597, 2192, 793, 2084, 598, 794, 2085, 599, 795, 2086, 
            600, 796, 2087, 601, 797, 602}], 
           
           Line[{799, 1008, 798, 2298, 1009, 800, 2299, 1010, 801, 2300, 1011,
             802, 2301, 1012, 2193, 803, 2302, 1013, 804, 2303, 1014, 805, 
            2304, 1015, 806, 2305, 1016, 2194, 807, 2306, 1017, 808, 2307, 
            1018, 809, 2308, 1019, 810, 2309, 1020, 811}], 
           
           Line[{813, 1021, 2195, 812, 1022, 814, 2310, 1023, 815, 2311, 1024,
             816, 2312, 1025, 2196, 817, 1026, 2197, 818, 2313, 1027, 819, 
            2314, 1028, 820, 2315, 1029, 2198, 821, 1030, 2199, 822, 2316, 
            1031, 823, 2317, 1032, 824, 2318, 1033, 825}], 
           
           Line[{827, 1034, 2200, 826, 1035, 2201, 828, 1036, 829, 2319, 1037,
             830, 2320, 1038, 2202, 831, 1039, 2203, 832, 1040, 2204, 833, 
            2321, 1041, 834, 2322, 1042, 2205, 835, 1043, 2206, 836, 1044, 
            2207, 837, 2323, 1045, 838, 2324, 1046, 839}], 
           
           Line[{841, 1047, 2208, 840, 1048, 2209, 842, 1049, 2210, 843, 1050,
             844, 2325, 1051, 2211, 845, 1052, 2212, 846, 1053, 2213, 847, 
            1054, 2214, 848, 2326, 1055, 2215, 849, 1056, 2216, 850, 1057, 
            2217, 851, 1058, 2218, 852, 2327, 1059, 853}], 
           Line[{857, 2328, 1061, 855, 2329, 1063, 859, 2330, 1065, 861, 2331,
             1067, 863, 2332, 1069, 865, 2333, 1071, 867, 2334, 1073, 869, 
            2335, 1075, 871, 2336, 1077, 2229, 873, 2337, 1079, 875, 2338, 
            1081, 877, 2339, 1083, 879, 2340, 1085, 881}], 
           
           Line[{880, 2233, 1084, 878, 2232, 1082, 876, 2231, 1080, 874, 2230,
             1078, 872, 2228, 2227, 1076, 870, 2226, 1074, 868, 2225, 1072, 
            866, 2224, 1070, 864, 2223, 1068, 862, 2222, 1066, 860, 2221, 
            1064, 858, 2220, 1062, 854, 2219, 1060, 856}], 
           
           Line[{883, 1086, 2234, 882, 2341, 1087, 884, 2342, 1088, 885, 2343,
             1089, 886, 2344, 1090, 2235, 887, 1091, 888, 2345, 1092, 889, 
            2346, 1093, 890, 2347, 1094, 2236, 891, 1095, 2237, 892, 2348, 
            1096, 893, 2349, 1097, 894, 2350, 1098, 895}], 
           
           Line[{897, 1099, 2238, 896, 1100, 2239, 898, 2351, 1101, 899, 2352,
             1102, 900, 2353, 1103, 2240, 901, 1104, 2241, 902, 1105, 903, 
            2354, 1106, 904, 2355, 1107, 2242, 905, 1108, 2243, 906, 1109, 
            2244, 907, 2356, 1110, 908, 2357, 1111, 909}], 
           
           Line[{911, 1112, 2245, 910, 1113, 2246, 912, 1114, 2247, 913, 2358,
             1115, 914, 2359, 1116, 2248, 915, 1117, 2249, 916, 1118, 2250, 
            917, 1119, 918, 2360, 1120, 2251, 919, 1121, 2252, 920, 1122, 
            2253, 921, 1123, 2254, 922, 2361, 1124, 923}], 
           
           Line[{927, 2362, 1126, 925, 2363, 1128, 929, 2364, 1130, 931, 2365,
             1132, 933, 2367, 2368, 1134, 935, 2369, 1136, 937, 2370, 1138, 
            939, 2371, 1140, 941, 2372, 1142, 943, 2373, 1144, 945, 2374, 
            1146, 947, 2375, 1148, 949, 2376, 1150, 951}], 
           
           Line[{950, 2267, 1149, 948, 2266, 1147, 946, 2265, 1145, 944, 2264,
             1143, 942, 2263, 1141, 940, 2262, 1139, 938, 2261, 1137, 936, 
            2260, 1135, 934, 2259, 1133, 2366, 932, 2258, 1131, 930, 2257, 
            1129, 928, 2256, 1127, 924, 2255, 1125, 926}], 
           
           Line[{953, 1151, 2268, 952, 2377, 1152, 954, 2378, 1153, 955, 2379,
             1154, 956, 2380, 1155, 2269, 957, 2381, 1156, 958, 2382, 1157, 
            959, 2383, 1158, 960, 2384, 1159, 2270, 961, 1160, 962, 2385, 
            1161, 963, 2386, 1162, 964, 2387, 1163, 965}], 
           
           Line[{967, 1164, 2271, 966, 1165, 2272, 968, 2388, 1166, 969, 2389,
             1167, 970, 2390, 1168, 2273, 971, 1169, 2274, 972, 2391, 1170, 
            973, 2392, 1171, 974, 2393, 1172, 2275, 975, 1173, 2276, 976, 
            1174, 977, 2394, 1175, 978, 2395, 1176, 979}], 
           
           Line[{981, 1177, 2277, 980, 1178, 2278, 982, 1179, 2279, 983, 2396,
             1180, 984, 2397, 1181, 2280, 985, 1182, 2281, 986, 1183, 2282, 
            987, 2398, 1184, 988, 2399, 1185, 2283, 989, 1186, 2284, 990, 
            1187, 2285, 991, 1188, 992, 2400, 1189, 993}], 
           
           Line[{995, 1190, 2286, 994, 1191, 2287, 996, 1192, 2288, 997, 1193,
             2289, 998, 2401, 1194, 2290, 999, 1195, 2291, 1000, 1196, 2292, 
            1001, 1197, 2293, 1002, 2402, 1198, 2294, 1003, 1199, 2295, 1004, 
            1200, 2296, 1005, 1201, 2297, 1006, 1202, 
            1007}]}, {}, {}, {}, {}, {}}}, VertexNormals -> CompressedData["
1:eJztfXk8ldv3v6mQFFEJTa40zzKWVVJpppIGJWSIKElIwxFCEm5UZCgpGihD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         "]], {
       Axes -> True, BoxRatios -> {1, 1}, 
        Method -> {"RotationControl" -> "Globe"}, 
        PlotRange -> {{200., 590.}, {20., 59.}, {3., 5.}}, 
        PlotRangePadding -> {
          Scaled[0.02], 
          Scaled[0.02], 
          Scaled[0.02]}}]}]],
   DynamicModuleValues:>{}],
  Setting[#, {0}]& ]], "Output",
 CellChangeTimes->{3.4022421395695*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Running time: GeneralizedPetersenGraph, 1 parameter", "Subsection",
 CellChangeTimes->{{3.400141061234375*^9, 3.400141067171875*^9}, {
  3.400657885890625*^9, 3.40065788740625*^9}, {3.400847491671875*^9, 
  3.4008475005625*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"min", "=", "300"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"max", "=", "600"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"step", "=", "30"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"times", "=", "3"}], ";"}], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"par", "=", "5"}], ";"}],
  FontColor->RGBColor[1, 0.5, 0]]}], "Input",
 CellChangeTimes->{{3.399722338015625*^9, 3.399722338859375*^9}, {
  3.399731030953125*^9, 3.3997310323125*^9}, {3.39973114990625*^9, 
  3.399731175078125*^9}, {3.39973136615625*^9, 3.399731366734375*^9}, {
  3.39973145396875*^9, 3.399731454796875*^9}, {3.399732404703125*^9, 
  3.399732435515625*^9}, {3.40014093365625*^9, 3.400140936125*^9}, {
  3.400142142734375*^9, 3.400142148890625*^9}, {3.400142257546875*^9, 
  3.400142303453125*^9}, {3.4001423598125*^9, 3.40014236146875*^9}, {
  3.400142405578125*^9, 3.40014241403125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphs", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"i", ",", 
       StyleBox[
        RowBox[{"GeneralizedPetersenGraph", "[", 
         RowBox[{"i", ",", "par"}], "]"}],
        FontColor->RGBColor[1, 0.5, 0]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "min", ",", "max", ",", "step"}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4022343148195*^9, 3.402234383507*^9}, 
   3.40223452735075*^9, 3.402242180522625*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dataEC", "=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
       ",", 
       RowBox[{
        RowBox[{"Timing", "[", 
         RowBox[{"EdgeColoring", "[", 
          RowBox[{"#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
           "]"}], "]"}], "\[LeftDoubleBracket]", "1", 
        "\[RightDoubleBracket]"}]}], "}"}], "&"}], ",", "graphs"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.402234408257*^9, 3.40223451072575*^9}, {
  3.40223455510075*^9, 3.402234555303875*^9}, {3.402236698507*^9, 
  3.402236701803875*^9}, {3.402237676928875*^9, 3.40223768078825*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"300", ",", "0.37500000000003375`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"330", ",", "0.4370000000000336`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"360", ",", "0.5630000000001356`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"390", ",", "0.5780000000000336`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"420", ",", "0.6870000000000589`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"450", ",", "0.7500000000001608`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"480", ",", "0.8290000000001609`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"510", ",", "0.9369999999999825`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"540", ",", "1.0310000000000845`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"570", ",", "1.2500000000001354`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"600", ",", "1.3130000000001356`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.40224219197575*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dataV", "=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
       ",", 
       RowBox[{
        RowBox[{"Timing", "[", 
         RowBox[{"Vizing", "[", 
          RowBox[{"#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
           "]"}], "]"}], "\[LeftDoubleBracket]", "1", 
        "\[RightDoubleBracket]"}]}], "}"}], "&"}], ",", "graphs"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4022345601945*^9, 3.402234575335125*^9}, {
  3.402236704835125*^9, 3.402236707928875*^9}, {3.4022377069445*^9, 
  3.402237710491375*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"300", ",", "0.11000000000011001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"330", ",", "0.12499999999998268`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"360", ",", "0.12499999999998268`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"390", ",", "0.1399999999999828`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"420", ",", "0.15700000000011016`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"450", ",", "0.1559999999999575`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"480", ",", "0.17200000000000815`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"510", ",", "0.18699999999998296`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"540", ",", "0.20300000000008467`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"570", ",", "0.21900000000011`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"600", ",", "0.21900000000005937`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.402242193882*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"maxplot", "=", 
   RowBox[{"Max", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Max", "[", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         "&"}], ",", "dataEC"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Max", "[", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         "&"}], ",", "dataV"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.399731584109375*^9, 3.399731614328125*^9}, {
   3.39973174615625*^9, 3.399731748296875*^9}, {3.399732118578125*^9, 
   3.399732160890625*^9}, {3.399732228265625*^9, 3.399732238953125*^9}, 
   3.40013821925*^9, {3.40014001153125*^9, 3.40014001371875*^9}, {
   3.402242190366375*^9, 3.402242191210125*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"plotEC", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"dataEC", ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.02", "]"}], ",", "Blue"}], "}"}]}], ",", 
     
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"min", "-", "1"}], ",", 
          RowBox[{"max", "+", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"1.2", " ", "maxplot"}]}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plotV", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"dataV", ",", "\[IndentingNewLine]", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.02", "]"}], ",", "Red"}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"min", "-", "1"}], ",", 
          RowBox[{"max", "+", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"1.2", " ", "maxplot"}]}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.399731762515625*^9, 3.3997318274375*^9}, {
  3.399731879609375*^9, 3.399731925703125*^9}, {3.399732258765625*^9, 
  3.399732300203125*^9}, {3.399732370046875*^9, 3.399732374359375*^9}, {
  3.39973407359375*^9, 3.3997341183125*^9}, {3.39973426796875*^9, 
  3.3997343069375*^9}, {3.399734351203125*^9, 3.3997343548125*^9}, {
  3.39973443225*^9, 3.399734432484375*^9}, {3.399736510453125*^9, 
  3.399736510703125*^9}, {3.3998266130625*^9, 3.3998266133125*^9}, {
  3.40014002884375*^9, 3.400140042234375*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p6Ba", "=", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"plotEC", ",", "plotV"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<EdgeColoring\>\"", ",", "Blue", ",", "20"}], "]"}], 
        "]"}], ",", 
       RowBox[{"Text", "[", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<Vizing\>\"", ",", "Red", ",", "20"}], "]"}], "]"}]}], 
      "\[IndentingNewLine]", "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<Number of vertices\>\"", ",", "Italic", ",", "16"}], 
         "]"}], "]"}], ",", 
       RowBox[{"Text", "[", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<Running time\>\"", ",", "Italic", ",", "16"}], "]"}], 
        "]"}]}], "\[IndentingNewLine]", "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.399732304515625*^9, 3.399732305875*^9}, {
  3.399732359421875*^9, 3.39973237709375*^9}, {3.3997324489375*^9, 
  3.39973245290625*^9}, {3.399826029515625*^9, 3.3998260299375*^9}, {
  3.400138305671875*^9, 3.40013830621875*^9}, {3.4001398620625*^9, 
  3.400139869265625*^9}, {3.40014013853125*^9, 3.400140142890625*^9}, {
  3.40014095609375*^9, 3.400140958671875*^9}, {3.4006578943125*^9, 
  3.400657895578125*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, 
    {RGBColor[0, 0, 1], PointSize[0.02], 
     PointBox[{{300., 0.37500000000003375`}, {330., 0.4370000000000336}, {
      360., 0.5630000000001356}, {390., 0.5780000000000336}, {420., 
      0.6870000000000589}, {450., 0.7500000000001608}, {480., 
      0.8290000000001609}, {510., 0.9369999999999825}, {540., 
      1.0310000000000845`}, {570., 1.2500000000001354`}, {600., 
      1.3130000000001356`}}]}, {}}, {{}, 
    {RGBColor[1, 0, 0], PointSize[0.02], 
     PointBox[{{300., 0.11000000000011001`}, {330., 0.12499999999998268`}, {
      360., 0.12499999999998268`}, {390., 0.1399999999999828}, {420., 
      0.15700000000011016`}, {450., 0.1559999999999575}, {480., 
      0.17200000000000815`}, {510., 0.18699999999998296`}, {540., 
      0.20300000000008467`}, {570., 0.21900000000011}, {600., 
      0.21900000000005937`}}]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
     InterpretationBox[
      Cell[
       BoxData[
        FormBox[
         StyleBox[
         "\"Number of vertices\"", Italic, 16, StripOnInput -> False], 
         TraditionalForm]], "Text", "TR"], 
      Text[
       Style["Number of vertices", Italic, 16]]], TraditionalForm], 
    FormBox[
     InterpretationBox[
      Cell[
       BoxData[
        FormBox[
         StyleBox["\"Running time\"", Italic, 16, StripOnInput -> False], 
         TraditionalForm]], "Text", "TR"], 
      Text[
       Style["Running time", Italic, 16]]], TraditionalForm]},
  AxesOrigin->{300., 0},
  ImageSize->500,
  PlotLabel->FormBox[
    RowBox[{"{", 
      RowBox[{
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"EdgeColoring\"", 
             RGBColor[0, 0, 1], 20, StripOnInput -> False], TraditionalForm]],
           "Text", "TR"], 
         Text[
          Style["EdgeColoring", 
           RGBColor[0, 0, 1], 20]]], ",", 
        InterpretationBox[
         Cell[
          BoxData[
           FormBox[
            StyleBox["\"Vizing\"", 
             RGBColor[1, 0, 0], 20, StripOnInput -> False], TraditionalForm]],
           "Text", "TR"], 
         Text[
          Style["Vizing", 
           RGBColor[1, 0, 0], 20]]]}], "}"}], TraditionalForm],
  PlotRange->{{299, 601}, {0, 1.5756000000001626`}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.402242197553875*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Running time: GeneralizedPetersenGraph, 2 parameter", "Subsection",
 CellChangeTimes->{{3.400141084890625*^9, 3.40014108996875*^9}, {
  3.400657902671875*^9, 3.40065790484375*^9}, {3.400847513453125*^9, 
  3.400847515828125*^9}}],

Cell[BoxData[{
 StyleBox[
  RowBox[{
   RowBox[{"mini", "=", "200"}], ";"}],
  FontColor->RGBColor[1, 0.5, 0]], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"maxi", "=", "300"}], ";"}],
  FontColor->RGBColor[1, 0.5, 0]], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"stepi", "=", "20"}], ";"}],
  FontColor->RGBColor[1, 0.5, 0]], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"minj", "=", "5"}], ";"}],
  FontColor->RGBColor[1, 0.5, 0]], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"maxj", "=", "15"}], ";"}],
  FontColor->RGBColor[1, 0.5, 0]], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{"stepj", "=", "2"}], ";"}],
  FontColor->RGBColor[1, 0.5, 0]]}], "Input",
 CellChangeTimes->{{3.399736537828125*^9, 3.399736543515625*^9}, {
   3.3997365784375*^9, 3.399736590125*^9}, {3.399736736046875*^9, 
   3.39973676965625*^9}, {3.39973682825*^9, 3.3997368286875*^9}, {
   3.39973695203125*^9, 3.39973695609375*^9}, {3.3997370938125*^9, 
   3.399737100265625*^9}, {3.39973750321875*^9, 3.39973755965625*^9}, {
   3.399737988125*^9, 3.399737991609375*^9}, {3.399738022296875*^9, 
   3.399738044234375*^9}, {3.399738515515625*^9, 3.399738526125*^9}, {
   3.400138948328125*^9, 3.40013895584375*^9}, 3.4001390534375*^9, {
   3.400139085328125*^9, 3.40013912934375*^9}, {3.400139181046875*^9, 
   3.40013918534375*^9}, {3.4001392518125*^9, 3.400139262828125*^9}, 
   3.40013963215625*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphs", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"i", ",", "j", ",", 
         StyleBox[
          RowBox[{"GeneralizedPetersenGraph", "[", 
           RowBox[{"i", ",", "j"}], "]"}],
          FontColor->RGBColor[1, 0.5, 0]]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "mini", ",", "maxi", ",", "stepi"}], "}"}]}], "]"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "minj", ",", "maxj", ",", "stepj"}], "}"}]}], "]"}]}],
   ";"}]], "Input",
 CellChangeTimes->{{3.402234719178875*^9, 3.402234786132*^9}, 
   3.402235486632*^9, 3.402237980585125*^9, 3.40224376147575*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dataEC", "=", 
  RowBox[{"Map", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"Function", "[", 
      RowBox[{"x", ",", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
            "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
            
            RowBox[{
            "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",", 
            
            RowBox[{
             RowBox[{"Timing", "[", 
              RowBox[{"EdgeColoring", "[", 
               RowBox[{
               "#", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
               "]"}], "]"}], "\[LeftDoubleBracket]", "1", 
             "\[RightDoubleBracket]"}]}], "}"}], "&"}], ",", "x"}], "]"}]}], 
      "]"}], ")"}], ",", "graphs"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.40223489653825*^9, {3.402235357272625*^9, 3.4022354193195*^9}, {
   3.40223550160075*^9, 3.402235542507*^9}, {3.402235578460125*^9, 
   3.402235608007*^9}, {3.4022356384445*^9, 3.402235646647625*^9}, {
   3.4022357249445*^9, 3.402235752678875*^9}, {3.402235787210125*^9, 
   3.40223582928825*^9}, {3.402235886210125*^9, 3.402235891007*^9}, 
   3.4022359453195*^9, {3.40224381428825*^9, 3.402243829085125*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "5", ",", "0.18799999999963557`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"220", ",", "5", ",", "0.2030000000004435`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"240", ",", "5", ",", "0.2500000000000142`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "5", ",", "0.2650000000000139`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"280", ",", "5", ",", "0.3439999999996868`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"300", ",", "5", ",", "0.3279999999996357`"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "7", ",", "0.18800000000011607`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"220", ",", "7", ",", "0.21800000000001418`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"240", ",", "7", ",", "0.250000000000167`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "7", ",", "0.266000000000167`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"280", ",", "7", ",", "0.29699999999963556`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"300", ",", "7", ",", "0.34400000000006514`"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "9", ",", "0.20300000000001406`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"220", ",", "9", ",", "0.20299999999958462`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"240", ",", "9", ",", "0.25000000000006484`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "9", ",", "0.26600000000006485`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"280", ",", "9", ",", "0.3120000000004435`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"300", ",", "9", ",", "0.3439999999996357`"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "11", ",", "0.20299999999958462`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"220", ",", "11", ",", "0.20300000000006513`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"240", ",", "11", ",", "0.24999999999963585`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "11", ",", "0.28099999999963554`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"280", ",", "11", ",", "0.2969999999996866`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"300", ",", "11", ",", "0.34400000000011577`"}], "}"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "13", ",", "0.20300000000006513`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"220", ",", "13", ",", "0.2029999999996357`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"240", ",", "13", ",", "0.2500000000001159`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "13", ",", "0.2660000000001159`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"280", ",", "13", ",", "0.29699999999958493`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"300", ",", "13", ",", "0.3430000000000142`"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "15", ",", "0.1880000000001667`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"220", ",", "15", ",", "0.20300000000006513`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"240", ",", "15", ",", "0.24999999999963585`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "15", ",", "0.24999999999963585`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"280", ",", "15", ",", "0.31299999999963557`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"300", ",", "15", ",", "0.29600000000044346`"}], "}"}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.402243841147625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dataV", "=", 
  RowBox[{"Map", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"Function", "[", 
      RowBox[{"x", ",", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
            "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
            
            RowBox[{
            "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",", 
            
            RowBox[{
             RowBox[{"Timing", "[", 
              RowBox[{"Vizing", "[", 
               RowBox[{
               "#", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
               "]"}], "]"}], "\[LeftDoubleBracket]", "1", 
             "\[RightDoubleBracket]"}]}], "}"}], "&"}], ",", "x"}], "]"}]}], 
      "]"}], ")"}], ",", "graphs"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.402236314710125*^9, 3.402236333022625*^9}, {
  3.40224383641325*^9, 3.4022438494445*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "5", ",", "0.06300000000011563`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"220", ",", "5", ",", "0.07800000000001406`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"240", ",", "5", ",", "0.07799999999958462`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "5", ",", "0.0940000000000647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"280", ",", "5", ",", "0.09400000000001407`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"300", ",", "5", ",", "0.09299999999996311`"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "7", ",", "0.07900000000011564`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"220", ",", "7", ",", "0.07800000000039242`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"240", ",", "7", ",", "0.07799999999996299`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "7", ",", "0.07800000000044305`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"280", ",", "7", ",", "0.09400000000001407`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"300", ",", "7", ",", "0.10899999999996313`"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "9", ",", "0.0629999999995845`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"220", ",", "9", ",", "0.07800000000039242`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"240", ",", "9", ",", "0.07799999999996299`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "9", ",", "0.09400000000044306`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"280", ",", "9", ",", "0.0930000000003921`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"300", ",", "9", ",", "0.0779999999996357`"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "11", ",", "0.07900000000011564`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"220", ",", "11", ",", "0.06200000000039241`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"240", ",", "11", ",", "0.09399999999958464`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "11", ",", "0.07800000000044305`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"280", ",", "11", ",", "0.09400000000001407`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"300", ",", "11", ",", "0.10899999999996313`"}], "}"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "13", ",", "0.0629999999995845`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"220", ",", "13", ",", "0.07800000000039242`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"240", ",", "13", ",", "0.07799999999996299`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "13", ",", "0.09400000000044306`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"280", ",", "13", ",", "0.0930000000003921`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"300", ",", "13", ",", "0.09399999999963571`"}], "}"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"200", ",", "15", ",", "0.0629999999995845`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"220", ",", "15", ",", "0.07800000000039242`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"240", ",", "15", ",", "0.07799999999996299`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"260", ",", "15", ",", "0.10900000000044319`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"280", ",", "15", ",", "0.0940000000000647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"300", ",", "15", ",", "0.09400000000001407`"}], "}"}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.402243854991375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p6Bb", "=", 
  RowBox[{"ListPlot3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"dataEC", ",", "dataV"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
    RowBox[{"BoxRatios", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}]}], ",", 
    RowBox[{"DataRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.39973796165625*^9, 3.39973796434375*^9}, {
  3.4001393685625*^9, 3.400139369453125*^9}, {3.400139444640625*^9, 
  3.4001394459375*^9}, {3.400139550859375*^9, 3.40013959584375*^9}, {
  3.40014082390625*^9, 3.400140826890625*^9}, {3.40065790671875*^9, 
  3.40065790765625*^9}}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1XH9c1GXyRyVFNI+zdWWFNliXD+yCe5x5nvkjx19ppV+pTMkoOc+KzIw4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   "], {{
     {RGBColor[0, 0, 1], EdgeForm[None], 
      GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtlnus13MYxz+XyKXcb5FLYUxrYzZmYzbGWMayrK2jozo5nJyco6OcnJx0
dHSULGNzGbNF5FYR5ZYU0Z10lG46HB0OXZQyYzOv996fP977vH6f7+/3/X4/
z/N+nufXb1TdrfemEMJ7KKOnYggvs7KEXmxM5eIOuCe8lXUL6gFPYX8zvA3N
RGfqN+w/zP4m+Cj4EXg7/AOahc5CR2b/Rvfag2aj83SN/UM89Bd9hv+Cf4N7
w63cZye8iL3FrMeiZ+E5rEegC7LvtRstZH8POgY+jf2D8M/wcfCj3KcD7g8/
DnfrN9G/1Tt0Rz/3XLgr+n36wytY96GT4eWse9FJcGf0/fvBm1kPoL46W/QZ
FZMO+E90DtyX507nuV1wH/gxeBd8NjwD/hU+EZ4G/wSfn32m39F/7E1G7fAp
7LfBnfBK7r1Ke+gi9l8Jjsvl8Ei+8xZ8M3wP/BF8DVwNvwNfBY+G58PXwXcn
++BGuAb+AL4NroM/hYfDDfDn8DD4Pvgz+Ba4Fv4Yvhq+E14AXwrfAb8B3wAv
Cs7fFfAo9t+GB8K3w6/BQ2CZcQl8YbYPdZ5L4Er2X4dHwOPhL+Fx8EPwt/AJ
2XH+Eb4YHs7+XHgAXAG/Cl8Gj4DfhK+Eq+B58D+sf0Tf5/DsPH6vuCfnXc+q
Y7+Jz1/DjcX/+k5TqQvle3x2jr6Dq+CVwbmpgRvZXwuPgSfC6+DR8AR4Nbwh
+h1Oh9tZ96Mz4H+53ow2Fh+8WHylGNWg4+U9ro8p+dLZhqj+5Nvk+CtuW1nH
lhztY32gPFfv1IRORXuT31fvvTt5/QodTD77en1OjqFyeoh1EvomOC7Nqjm0
P/m8a+ADrA+W8+rejcWrivtQdHRwngarNygOyT5cCK9nvQu9C69J9pW8ui7Z
w/LYlmRvf1i8VVX6g7xerbpHm5KvyX/tyev7quVk78kbS5O9Js99kewfeXJZ
cj3p2upkz8i3qp9hqJfilexn1Vp3sj9XBNdGrbyJtid7+5PgXE4O7iGKXYvq
vjz7puDeq77wTLAHtkXnXnlXb20N7kXqxW0lnuoXTwb7R73yadQH/Z1cIxvK
mSuCe+YL0Z/Fim8l6qmzo7HB/VO5byjxXIbqUW80O7o/KF9zo2tffpsX3SuU
U8VsULl/B3vjku+hHvd8cJ/sTO4ny+EdrPWlz+xM7i1L4S7W+5PfqzbbS/Lh
kug6kv9XRcdCcZgT3fd6qBai+9th8kN0rckPz0X3BM29xdHn1BnXwi3JtfBS
dM/RTByZ/R3VgzZUm6rxa7P9Ka+2lr6tnjw4u9aU68rs95cfqrPrTnWxMXlO
qd/OLPNI8+767LzIo81lhmr+PpHtAc2Diux4Km4zyuzQLGsrM0XzZVB2T1Bd
zCpzRHOupczTDnhidtzUvyZln13zekKZ45rvU8vcVF9tyO5FmkH12bUvX00r
80hzdmh2HpW76WXeaaZPKf8l9F9gV/IM1Rz5H+OfMmM=
         "]], Polygon3DBox[CompressedData["
1:eJw1l3ccUFUVx+97140KIi4cgLhbakPTLGe5cKA5EpSlhAbkAlELcKCIo9wT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         "]], Polygon3DBox[CompressedData["
1:eJw1lVlsUFUQhu+5R3wQJCBGwKgo+gZEgcgSXKLigxoRZAv7YgstLS2lbAJF
9p24RKPggwTCJsjqA4uAQEHZKQUqCrRQWihGdogiUb8/Mz58mTn/uffcc+bM
zH1mcP77eWmSJBlQC9aFJDmLsAM/H7uW8RDs6zFJXoNXYT1zw9DewX8b3oLN
aP3QXsB/HlrACrThaF3wO8N7sA1tPtoC/PkwD2rQHsc+AdX4c5hvjF+A7Y3t
BT1hJ3M5aJ3w3432/S1oh9AOp7avTOxBGAztmW8HbWGNz2n/r8DLsA5tMefb
i74Kvz/2m2DnKIbOaF1gJcxkPJ13psFUqEDrm9o5m0MzWI72KPYxqMSfxXwD
/KPYEtiENhR7BJ5Efwouoc1N7exPQ1OPxzy0Jvj7sQfgu8TO9DMsYo+7U/te
H+xCxlewv8M+tNHYGqjN+3XgLNo0xg/hD8C2xraCltHOPRttFv5MmOF7P49W
CbvxR2IrtDb8BN8mto7iVpfn63k8ZjB+GH86dgp2Mkzy7xei9cPvC32irXub
fVfChWDfv4h2C78CyoPF+7zHZy7+HJjtOTIeLRc/B4bBYbRnsc/BFc8xxfIu
69TA5WA5p7mBzLXBfzFaLHSehthGvgfFQ3d4h3eqoSrY93VXKpZu+F2j5fUP
aH+h3YPj+EXYP2FEajnbA7pHq6d/VWj4JzEf4f+jvA12L2fQpjI+xPgctjy1
fNc6qkfd6UDdH/SHvcyNSs3PU51BcWK1qlrohd8bNsA15TgUB1tDOTKOZ27A
ePwJqiG45Hnz/9rVMFFnUd5rf3BMd4R2W3ns93ATrvt6B9HGYq/Bb3AmtRip
D/yaWi7p/gt0NtgFk9HGKP+UQ3AKjqOVwvf4WV4/tXjmQfgFbQrjB6LlnOrx
C7TPodxrR33la/xFcNnPm42WBUOi7VN9Rvn0Ff6XUAWT0AqVu7ojKFV80PIV
52g5p3NfVQ3CrmB5vcfrXfXzGf6ncCGxWlANfoz/CZyDbcHicwB/DHZrsJxU
bXVF6war/YzjeHdstPiUof3Bs5tgI7wZLT4Xea4qtT0Uet2qz7yhfFFfg41w
33PuhJ/zb6jPM494nanH1fO+q/zLQcuFH73vnoZM5RhshVXB7lQ9PRe7Mlif
Uc0XwUTPa92f9tox2p7UBz9Aewm/Q7Q+rf62x/vuCu+t6nF5nkNZaNmw3Wtn
NO+MinZXOs9Svl2W2n8oG7uE8U1pcCpYHJU3a4L9H9T7M7CrGd+AE1AabF3V
5/JgvVb/jUHYZYzTaDlX5jkbtKbHRf8h/RO1hx3BakI96UPs9mA5pJopUuzh
KFxHL4FjMDJa/7jr/aMksdq7k1pP0XxBtFos8fjpv9ADvyes9bpTbmdCRrT8
+g/vyiJB
         "]]}]}, 
     {RGBColor[1, 0, 0], EdgeForm[None], 
      GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtlWuIVlUUhs/ZZxWKoRiJYhgO1kxTTk7a2JQ1poyNjY2NMzrjTJk23W/a
/X6/37ybpmlapmmapmlaphRFQRREQRRFQRREQRSEYozY8/KeH+vbz36/dfbZ
e+211qnomdc2N2VZtgsrsK/42YFwb55lxzO+io1CP5HxJrQx8EnwJuwseDZa
v9x8vZ7BRsMTIsvewucO5qtYcxk8DV4BL4anwhWMW7A6/FeiL4EvQT8vrN8G
t2O9mfcwNvzeeWjHMb6CnYGeMXajjdQ+8XmZ+azcWlbqlejr0HuYd2IFdjr6
cPQ1yef4gz3MhJ+FBzAux6rxOcR8MnYKfGzy+jXwEbT5cCXcl3EpdqriyLgI
q4Irwvucg28rdjjznpfzroXoF6Mthi8q3/EEdg52Pj6PM9ZhE+Fmxr8zn2UD
/tN4tgvtGmwQdib6IvliE+AB4f1PZ34/dprWRZ/POB67AH5OsdYcfppxLNYA
r2b9F3m2LfedDynvfQ96G/p1zDfCl5YxXgu/hD4D7sCO4luLXQb3KZ9dj88q
fGYyXwevTL6HNfCKcp/3YCdj9fjfyViFnQ0vLXx+xWgZvAD/KXALdjDzXYzj
vG+i31rG8Z/M9zU+OS6Kyfc8+zD8EPaI8rTUv0V/B78HmP9Q+D/57YPfQL8B
/hJ+O3mPyukRih3P/oi+G/1R5t/AO5Pj/Wnh/L8d3lI4xy6HP4G3lrn9Gbwt
+awfF97/LbnPMBwbx/q70TegX8v8Q3gu483YgcKj7mcn/HpyLuyFNybX4g54
PXxV7rzvn7vWtqO/hn4l84/gzWVNXY0NVB7gsxV9bZm32wrXzhVwTXL8zsXn
c/TtzO9SjYXfpTX+RT8AL4APqd5z38FP8Lvoj+l+4P3J+Tg0nEvKlyVYk+6Q
9QeHc0Z5Xsu4Kzkmhwv7ad0TwrmnvNuMvrqs/U2F19O6s8Lv0n6qwj1NZ/8L
nw/g5+FR4Tgrt4cmP6u8HR3OgRuZD06uO/W3unD8dR+/s8776M/A++H20v9P
eF9ynfXmzmHV78/oe5Jr/Tf4veT6+wXeCz+pWoe74BfKfK0pY673DSu5f7hO
1SP/K5z3qpF+4X6r+h0Yri/V5ojwneoej5Z1pP5zTLgnq/dWh3NDOVMTzivl
3pTwPlQX3eFzKW5Dwj1Ace4Mn0VxaA3Xhe56crguVF/Tw2fXGQeF+4B6wrDw
3alGvmZvM+D74BTuk6r13rJPKo5HCvde9YGRyXFRTCqTe5R6SN9wT9Z35yD+
3fBCeFK4lvWNK8K9Wt+j6uS7U5+sU09K7off8WwH/KBqMpnVPxvD+X83ekNy
31A/6RP+lqnf1yefRT22Nlyb6ie/smYn/BTcEb538exw7WifXeG80veoJRx7
veOLwnvTexuT12lUvw3ns3KmOTl/LkRvCn/TFc854VpU7TSH+57O1ZIcnyb5
J38HJ8GtybWmemwI9y71tDHh3qMaqA/3EPWunvDaeqY9XO/6jk0M9zr1iqnh
WlbP/B/71vP3
         "]], Polygon3DBox[CompressedData["
1:eJxFmHdsntUVh9/3fi8hISaEEBIyHJyQOHaW7Qxn2HES4yxGyYAEQlpopFaq
1FJVaqVKldpKrVSpEhKjpS1QCp20dBco0AHde+89oHsQSiHYMaHP43Os/vHz
d857zz13nHm9+NjLD1xXqqo6r66qht/D/LkSbILfCAqDBf5S6NWMj7Wq6iR4
Evo/4HLGrgADjG8Be+qQcewJcDv0bWAM+iS4Cn3H4Xcgtwv+Wua+EIzAXwhu
YuxmsBf6Rn6PIP90K8Z3I9+F7AowA/5M8FKwDn5eHWeYjfxs+EPQvchfDH0J
6IFfA65k/O/oG4LeyfgNdezBtYedA90HZkOfA45AX92E/FbvAHoNmAs9B5wB
3QZG0fUM2IH+g/BvUB/8DPgZ8Afhe+Dfxdp3gGehT4GGsSngaeinwAcYuxtc
jfz7+f0o+Ahoy/O+G/q94D3gLvAO8HZwItd3TJkK2RocZv3HWmHPkSp0u8YU
+NPBZay9H6yF7gP3MPYhMM2zgVYTe3Rv/wVnQc9swpba9HlN6HBuLzgXeg44
TX8Cz6LrFHgc2X9XMXcWGE9/OMj+Psf4fGQ3V2F7fUBZ50xlfCry+7Qf/C2M
vbUVe3FP6tZxj6f8tCZs4l14J8ub8Bnvzju8DX0Lmji//twB3wl/DH4D/A/Q
9z2wAn4l+Ab0t8A3wdfBV8FXwGLGloCHoR8BL4P+PL9fAl8Ei+DPB/eWuCPv
ZqAKXepcCr8MPAn9lOcxZsAx79M5JeJiP7/v43tBdq02hh4FN8Kf4Pcexgeb
WM/93w3fD78Afj38vcjcD+4DnwKfBQ+1IlYmYsbYaUK//tLO/A74a3K+d+Gd
fB98N/fqnoczXv+lbbUX+GfSftvG2HbwF+i/gb+CP4M/gEfBH8Hv9eESNmrL
+PgJ334Gfgp+DH4JfgVex/gvWmG7hU34rjZ8NHX2Z756KM/4GfAg+C34DVjn
eeqwlTbzfhbWods1etP/1b0ITM348K69853mK/2b/X4S/sXKs9918L+Df6P5
Ab4f/k/wb4IfqsIWG5tYyzU9m2dcnfnohhIxpj8vB5vh/8H4mxnbBj8I/wT8
9d4nfA/8APKvSH9aDL2kiVg1ZqWXgukZv0fSxtrWnHAB81fBvwi6v4rcub6J
+NMf9kDvBavS/19bRw51r+55J/Qu0Jn+e0uJnGAu6AZbobeBjvT/MXAn+z+s
PsY/Af1xcBb8zDp8Ux+dlfn2jhJnmpbxrm+rU136+HmMP4D8SzIe1sLvYPyV
8INV3PVm0J72vblETjAXdIHrS+Qk80snWAH/I/jXZP5ZDv8d+FfDb4JfCv81
+FfpX/DD1grQDd9Vh2/r44NZHzYxtiX34F6eD17QRL0zHo56v+jcU6KuGOPG
urXNGmdcH8vv1+bci0vUSnU4x7nWLmvSUIl4NHdszVppjBqbI2lv89WXwZIS
MsrqU/qWuaiz5FmRv8Z6WWJN175Ke7teib7gsYxfY82asqnE+Y3tjVlbvRPv
wv19O/OnvqLPbCgRr8b++qT9NhErddjTeP016CuRf7pL2Mac7BznGnPGnmu6
tjFn7HXmmczVy0pAWhsuzVxqjTQezHkn66ij+uhY1tdxfldVES/WSnsga4X5
ZjxlnOPcT2d+1XftGazV1nxzWVvmo/nw67LHmlvC383Fc6APlNAxO/3Nemf9
/SA4HfpoHTXbXDQ164U231FFDt5SIu+aM8wd5t6BErnCHKwudRpLxtTxzNH6
ov50prWR8bYSfcxA6lCnuusSfYh5pCpxF96J3+q0vT4wkavqsJ02NBbNua/P
HGtutccYacKG2u7C7D225Xkc3wd/IL9flvT2EjL7M/aca641Bu1NS+6ztu+w
NmRPNdlbTUn72WMpo6xnsW+wt/B+vGvn2bvZw7nmgexth91rFT2udejS7CnN
ixc1cU/e/d7MnZvzPsyhh9xzCR3q2t2Ez+qru1LPYNrLHtVv/RkPnXl/Qxm3
riuknXNJntW9e0bPOr0Jm7ZlHzTR1JfwZ3uklSXqqjnP3LemRF01z68uUQsn
akwVNXFViXrlHOd2legDzJHmyu6MUb91paxztlRRL3pSp2u41g9b0U9YW7yf
n2e9t754fnOMuWakivziOdrSf0ezv7Ye2/tsTztJ28frI8+1wsae+1TWbucM
V1HDb8qabi3fXcc7Y7wVb5rJt81Y1irfOOMZ535z7KLMASdznjFsLNsTnJux
bYxbm2blevtK9HTmdXODOeLDrYg7+8YNWYOtxQtL9JG+axZAn5/fpO1L7M/s
X5Txe0d+W5iyy6yVypboA9qb+L6o+X9vsyDzkfnE3GSOsleaV+Kt4h7dm35k
r/1cHb2JPYpvr8Ulek3fYN3wK5v43pW0dUYZvzlXHW8Bp+rYk3uzt7RH8e1y
WonabI22N7FmqUNdvrXM29Ze31yevT3n20/Za3fkfuwPrHXOt7exR3dMmS+0
4l58G/pGPEc08c6a30QPbJ/k20U72tv5hvFtoA7nerdzm7C5Msqe3YQe3zS+
bbSlcWJsrc8x15pVQuZo3rl37brX1dGT2qu0T+6lRJ8zb3Jf6U/WK3Woy/ri
G+qCtLn3uiT1GX/uYdKv3Iv10x7Pu/bO3waaEm8v+2V7P8fXNhHHxnZf7kXf
sOdyH8/U8S73nX+iDhllrV3WMN9uo3X0VvZYo/nNOc69vERPYG4zx9krmRfM
PfZM9rY9mZccGzL/N9FT2geeXeL9/E4ws8SYfUJvCRnRm/nLHlSdqzMfeb/G
r2/MxzMf2jtar/pSV08TPYM+p+/Zq+ov/i/BnnV6if9n3ArOgD5UIoeZu8zh
yjrnY62w+xWZ88x11gT37hlWVPE/AHWpszvf0/8DSgayJw==
         "]], Polygon3DBox[CompressedData["
1:eJw1lWdwVkUUhm/uLi0YElr8gRoSWiiCMECQXgSkQ0Ia0kQQkBkRG0r5QVNU
SADpoPTem4CUGZo6FoY2wA9FBpVBcQQdYWSA4PPOWX48s+99z/3227t7ztn0
YWOzX4+jKBoOpSCNh2MuisYmRNFG9DOQCy0gC7r6KJpA7Ah6ELo9uh3Mhv54
zaApvEBsPF4xOkYnwCPm7YmXh9cKWkJ3/Ml4h9AD0G3QreFjuMP7d6EYfZT4
v+g94Tfd4EWYRGx3bLo+uh5MhJ14nfFqoWvCezAXrxSeBwe98TbjnWDeNHR1
GCeP5y0wGL2c+Cb0AsYK/CYJykM2sf14/dEt0c/DdPgCL0dx6AtT8dbgNdD6
oC4Mx1vGnMudzTOf+FL0AcY84rne5p1B7HP8FZCLXkT8M/Q6xkbEG8KzMJLY
Kvw1UIBeQnwlOl/nAJ3CvB8Q24a/HV5Gr8Dfiv4d/oCP8L7Eu+FsLOQ3BZAP
M4mtx3sOXRldCUbDAt5dGM61iPh89NrY1pWKVxVehV0hd7p4O5f3wzqr6jzQ
DvIhG6821ArfOApvA7oJurG3/38N72Bs68pCN4cPYR5eWbwy3s65D14OXl3I
DHOMwVvMGpc4iysnFjnb24rEUyBZ+0+sQGuGLmEvtD+J4az6oT9Fl4MMOIn3
Jt4WdDr8yfNf8EnI7ZvobYxfMWbg1YC39R08H3L2TdrfAyHXlBv3qccHkBO+
TWv+j+d70BfvMN5A1vWSt9rRf113dn4zwx79hj4NZ5ztueriB7QP360amIN2
cNxZLbyBtyn0gVtwG2aF/9M3XYVrzvJTNfAz+jv43lnN78D7Fp0U8muo8hj9
hPI3ttpKxCsPQ6Ay3g68V5TH6ErK39jyNAmvAgxTbfG831lOqAb2of9x1heK
Qk/6G704tpopYZ8eQR6xtaobKEQvja1WVPutVL/Qwtt3p4Qa0/kvRCfDTzxf
cVbL+3j+MZxlB/U/aAtvESsTesUg1Te6dGx7oV7YCTrCu8QK1cOgWzg/7e0p
Z7mhebaGfFJ91iCeAene9lG9ZBexFHRFGBH6h3pSIpTzlpvqW0+jn4Jq3tZ0
lt+dc9a/VY9nwl5VUU17y3/1mZ3O/kN9anU4m36MT0KqRm/7qDOqrR7rbZ3q
KZd497Kznq5efVH9JrZvz8SrA++EM9A8qd56QEHoH7ojSuAh9MD7hfFXZ71L
/VF5pzWpj2ZCHW95oz3TObSB1t5qcQBeL+gJQ7zdIyUJ1qM092z8h4zfOMtX
nY3W+rXuGWf5pd6qfrbb2R2keQZ7u/uKQp0od7Kgubd78zDvHnHWa9S7VN+N
Q95MwdurPhrb3ajeeYccvQu9Qn7p3uij+8nb+7pTlH9N0c1gWoLVUXXiad7O
WXfVBWf7/fhOPI/+H5qC72o=
         "]]}]}, {}, {}, {}}, {
     Line3DBox[{403, 1, 76, 77, 78, 7, 94, 95, 96, 13, 112, 113, 114, 19, 130,
       131, 132, 25, 148, 149, 150, 31, 478, 479, 480, 32, 481, 482, 483, 33, 
      484, 485, 486, 34, 487, 488, 489, 35, 490, 491, 492, 36, 162, 161, 160, 
      30, 144, 143, 142, 24, 126, 125, 124, 18, 108, 107, 106, 12, 90, 89, 88,
       6, 429, 428, 427, 5, 423, 422, 421, 4, 417, 416, 415, 3, 411, 410, 409,
       2, 405, 404, 403}], 
     Line3DBox[{503, 37, 241, 242, 243, 43, 259, 260, 261, 49, 277, 278, 279, 
      55, 295, 296, 297, 61, 313, 314, 315, 67, 578, 579, 580, 68, 581, 582, 
      583, 69, 584, 585, 586, 70, 587, 588, 589, 71, 590, 591, 592, 72, 327, 
      326, 325, 66, 309, 308, 307, 60, 291, 290, 289, 54, 273, 272, 271, 48, 
      255, 254, 253, 42, 529, 528, 527, 41, 523, 522, 521, 40, 517, 516, 515, 
      39, 511, 510, 509, 38, 505, 504, 503}], {
      Line3DBox[{403, 163, 808, 809, 406, 718, 615, 835, 836, 433, 736, 626, 
       859, 860, 448, 757, 636, 880, 881, 463, 781, 645, 898, 899, 478}], 
      Line3DBox[{409, 603, 811, 812, 814, 412, 181, 838, 839, 436, 742, 628, 
       862, 863, 451, 763, 638, 883, 884, 466, 787, 647, 901, 902, 481}], 
      Line3DBox[{415, 606, 817, 818, 820, 418, 617, 841, 842, 844, 439, 199, 
       865, 866, 454, 769, 640, 886, 887, 469, 793, 649, 904, 905, 484}], 
      Line3DBox[{421, 609, 823, 824, 826, 424, 620, 847, 848, 850, 442, 630, 
       868, 869, 871, 457, 217, 889, 890, 472, 799, 651, 907, 908, 487}], 
      Line3DBox[{427, 612, 829, 830, 832, 430, 623, 853, 854, 856, 445, 633, 
       874, 875, 877, 460, 642, 892, 893, 895, 475, 235, 910, 911, 490}], 
      Line3DBox[{480, 499, 786, 785, 783, 465, 496, 762, 761, 759, 450, 494, 
       741, 740, 738, 435, 493, 723, 722, 720, 408, 165, 705, 704, 405}], 
      Line3DBox[{483, 500, 792, 791, 789, 468, 497, 768, 767, 765, 453, 495, 
       747, 746, 744, 438, 183, 726, 725, 414, 816, 605, 708, 707, 411}], 
      Line3DBox[{486, 501, 798, 797, 795, 471, 498, 774, 773, 771, 456, 201, 
       750, 749, 441, 846, 619, 729, 728, 420, 822, 608, 711, 710, 417}], 
      Line3DBox[{489, 502, 804, 803, 801, 474, 219, 777, 776, 459, 873, 632, 
       753, 752, 444, 852, 622, 732, 731, 426, 828, 611, 714, 713, 423}], 
      Line3DBox[{492, 237, 807, 806, 477, 897, 644, 780, 779, 462, 879, 635, 
       756, 755, 447, 858, 625, 735, 734, 432, 834, 614, 717, 716, 429}], 
      Line3DBox[{503, 328, 1018, 1019, 506, 928, 665, 1045, 1046, 533, 946, 
       676, 1069, 1070, 548, 967, 686, 1090, 1091, 563, 991, 695, 1108, 1109, 
       578}], Line3DBox[{509, 653, 1021, 1022, 1024, 512, 346, 1048, 1049, 
       536, 952, 678, 1072, 1073, 551, 973, 688, 1093, 1094, 566, 997, 697, 
       1111, 1112, 581}], 
      Line3DBox[{515, 656, 1027, 1028, 1030, 518, 667, 1051, 1052, 1054, 539, 
       364, 1075, 1076, 554, 979, 690, 1096, 1097, 569, 1003, 699, 1114, 1115,
        584}], Line3DBox[{521, 659, 1033, 1034, 1036, 524, 670, 1057, 1058, 
       1060, 542, 680, 1078, 1079, 1081, 557, 382, 1099, 1100, 572, 1009, 701,
        1117, 1118, 587}], 
      Line3DBox[{527, 662, 1039, 1040, 1042, 530, 673, 1063, 1064, 1066, 545, 
       683, 1084, 1085, 1087, 560, 692, 1102, 1103, 1105, 575, 400, 1120, 
       1121, 590}], 
      Line3DBox[{580, 599, 996, 995, 993, 565, 596, 972, 971, 969, 550, 594, 
       951, 950, 948, 535, 593, 933, 932, 930, 508, 330, 915, 914, 505}], 
      Line3DBox[{583, 600, 1002, 1001, 999, 568, 597, 978, 977, 975, 553, 595,
        957, 956, 954, 538, 348, 936, 935, 514, 1026, 655, 918, 917, 511}], 
      Line3DBox[{586, 601, 1008, 1007, 1005, 571, 598, 984, 983, 981, 556, 
       366, 960, 959, 541, 1056, 669, 939, 938, 520, 1032, 658, 921, 920, 
       517}], Line3DBox[{589, 602, 1014, 1013, 1011, 574, 384, 987, 986, 559, 
       1083, 682, 963, 962, 544, 1062, 672, 942, 941, 526, 1038, 661, 924, 
       923, 523}], 
      Line3DBox[{592, 402, 1017, 1016, 577, 1107, 694, 990, 989, 562, 1089, 
       685, 966, 965, 547, 1068, 675, 945, 944, 532, 1044, 664, 927, 926, 
       529}], Line3DBox[{404, 703, 164, 810, 407, 719, 721, 616, 837, 434, 
       737, 739, 627, 861, 449, 758, 760, 637, 882, 464, 782, 784, 646, 900, 
       479}], Line3DBox[{410, 706, 604, 813, 815, 413, 724, 182, 840, 437, 
       743, 745, 629, 864, 452, 764, 766, 639, 885, 467, 788, 790, 648, 903, 
       482}], Line3DBox[{416, 709, 607, 819, 821, 419, 727, 618, 843, 845, 
       440, 748, 200, 867, 455, 770, 772, 641, 888, 470, 794, 796, 650, 906, 
       485}], Line3DBox[{422, 712, 610, 825, 827, 425, 730, 621, 849, 851, 
       443, 751, 631, 870, 872, 458, 775, 218, 891, 473, 800, 802, 652, 909, 
       488}], Line3DBox[{428, 715, 613, 831, 833, 431, 733, 624, 855, 857, 
       446, 754, 634, 876, 878, 461, 778, 643, 894, 896, 476, 805, 236, 912, 
       491}], Line3DBox[{504, 913, 329, 1020, 507, 929, 931, 666, 1047, 534, 
       947, 949, 677, 1071, 549, 968, 970, 687, 1092, 564, 992, 994, 696, 
       1110, 579}], 
      Line3DBox[{510, 916, 654, 1023, 1025, 513, 934, 347, 1050, 537, 953, 
       955, 679, 1074, 552, 974, 976, 689, 1095, 567, 998, 1000, 698, 1113, 
       582}], Line3DBox[{516, 919, 657, 1029, 1031, 519, 937, 668, 1053, 1055,
        540, 958, 365, 1077, 555, 980, 982, 691, 1098, 570, 1004, 1006, 700, 
       1116, 585}], 
      Line3DBox[{522, 922, 660, 1035, 1037, 525, 940, 671, 1059, 1061, 543, 
       961, 681, 1080, 1082, 558, 985, 383, 1101, 573, 1010, 1012, 702, 1119, 
       588}], Line3DBox[{528, 925, 663, 1041, 1043, 531, 943, 674, 1065, 1067,
        546, 964, 684, 1086, 1088, 561, 988, 693, 1104, 1106, 576, 1015, 401, 
       1122, 591}]}, {
      Line3DBox[{78, 809, 810, 165, 75, 814, 815, 816, 168, 81, 820, 821, 822,
        171, 84, 826, 827, 828, 174, 87, 832, 833, 834, 177, 90}], 
      Line3DBox[{88, 716, 715, 175, 829, 85, 713, 712, 172, 823, 82, 710, 709,
        169, 817, 79, 707, 706, 166, 811, 73, 704, 703, 163, 76}], 
      Line3DBox[{96, 836, 837, 180, 723, 93, 839, 840, 183, 99, 844, 845, 846,
        186, 102, 850, 851, 852, 189, 105, 856, 857, 858, 192, 108}], 
      Line3DBox[{106, 734, 733, 190, 853, 103, 731, 730, 187, 847, 100, 728, 
       727, 184, 841, 97, 725, 724, 181, 91, 720, 719, 718, 178, 94}], 
      Line3DBox[{114, 860, 861, 195, 741, 111, 863, 864, 198, 747, 117, 866, 
       867, 201, 120, 871, 872, 873, 204, 123, 877, 878, 879, 207, 126}], 
      Line3DBox[{124, 755, 754, 205, 874, 121, 752, 751, 202, 868, 118, 749, 
       748, 199, 115, 744, 743, 742, 196, 109, 738, 737, 736, 193, 112}], 
      Line3DBox[{132, 881, 882, 210, 762, 129, 884, 885, 213, 768, 135, 887, 
       888, 216, 774, 138, 890, 891, 219, 141, 895, 896, 897, 222, 144}], 
      Line3DBox[{142, 779, 778, 220, 892, 139, 776, 775, 217, 136, 771, 770, 
       769, 214, 133, 765, 764, 763, 211, 127, 759, 758, 757, 208, 130}], 
      Line3DBox[{150, 899, 900, 225, 786, 147, 902, 903, 228, 792, 153, 905, 
       906, 231, 798, 156, 908, 909, 234, 804, 159, 911, 912, 237, 162}], 
      Line3DBox[{160, 806, 805, 235, 157, 801, 800, 799, 232, 154, 795, 794, 
       793, 229, 151, 789, 788, 787, 226, 145, 783, 782, 781, 223, 148}], 
      Line3DBox[{243, 1019, 1020, 330, 240, 1024, 1025, 1026, 333, 246, 1030, 
       1031, 1032, 336, 249, 1036, 1037, 1038, 339, 252, 1042, 1043, 1044, 
       342, 255}], 
      Line3DBox[{253, 926, 925, 340, 1039, 250, 923, 922, 337, 1033, 247, 920,
        919, 334, 1027, 244, 917, 916, 331, 1021, 238, 914, 913, 328, 241}], 
      Line3DBox[{261, 1046, 1047, 345, 933, 258, 1049, 1050, 348, 264, 1054, 
       1055, 1056, 351, 267, 1060, 1061, 1062, 354, 270, 1066, 1067, 1068, 
       357, 273}], 
      Line3DBox[{271, 944, 943, 355, 1063, 268, 941, 940, 352, 1057, 265, 938,
        937, 349, 1051, 262, 935, 934, 346, 256, 930, 929, 928, 343, 259}], 
      Line3DBox[{279, 1070, 1071, 360, 951, 276, 1073, 1074, 363, 957, 282, 
       1076, 1077, 366, 285, 1081, 1082, 1083, 369, 288, 1087, 1088, 1089, 
       372, 291}], 
      Line3DBox[{289, 965, 964, 370, 1084, 286, 962, 961, 367, 1078, 283, 959,
        958, 364, 280, 954, 953, 952, 361, 274, 948, 947, 946, 358, 277}], 
      Line3DBox[{297, 1091, 1092, 375, 972, 294, 1094, 1095, 378, 978, 300, 
       1097, 1098, 381, 984, 303, 1100, 1101, 384, 306, 1105, 1106, 1107, 387,
        309}], Line3DBox[{307, 989, 988, 385, 1102, 304, 986, 985, 382, 301, 
       981, 980, 979, 379, 298, 975, 974, 973, 376, 292, 969, 968, 967, 373, 
       295}], Line3DBox[{315, 1109, 1110, 390, 996, 312, 1112, 1113, 393, 
       1002, 318, 1115, 1116, 396, 1008, 321, 1118, 1119, 399, 1014, 324, 
       1121, 1122, 402, 327}], 
      Line3DBox[{325, 1016, 1015, 400, 322, 1011, 1010, 1009, 397, 319, 1005, 
       1004, 1003, 394, 316, 999, 998, 997, 391, 310, 993, 992, 991, 388, 
       313}], Line3DBox[{77, 808, 164, 705, 74, 812, 813, 167, 708, 80, 818, 
       819, 170, 711, 83, 824, 825, 173, 714, 86, 830, 831, 176, 717, 89}], 
      Line3DBox[{95, 835, 179, 721, 722, 92, 838, 182, 726, 98, 842, 843, 185,
        729, 101, 848, 849, 188, 732, 104, 854, 855, 191, 735, 107}], 
      Line3DBox[{113, 859, 194, 739, 740, 110, 862, 197, 745, 746, 116, 865, 
       200, 750, 119, 869, 870, 203, 753, 122, 875, 876, 206, 756, 125}], 
      Line3DBox[{131, 880, 209, 760, 761, 128, 883, 212, 766, 767, 134, 886, 
       215, 772, 773, 137, 889, 218, 777, 140, 893, 894, 221, 780, 143}], 
      Line3DBox[{149, 898, 224, 784, 785, 146, 901, 227, 790, 791, 152, 904, 
       230, 796, 797, 155, 907, 233, 802, 803, 158, 910, 236, 807, 161}], 
      Line3DBox[{242, 1018, 329, 915, 239, 1022, 1023, 332, 918, 245, 1028, 
       1029, 335, 921, 248, 1034, 1035, 338, 924, 251, 1040, 1041, 341, 927, 
       254}], Line3DBox[{260, 1045, 344, 931, 932, 257, 1048, 347, 936, 263, 
       1052, 1053, 350, 939, 266, 1058, 1059, 353, 942, 269, 1064, 1065, 356, 
       945, 272}], 
      Line3DBox[{278, 1069, 359, 949, 950, 275, 1072, 362, 955, 956, 281, 
       1075, 365, 960, 284, 1079, 1080, 368, 963, 287, 1085, 1086, 371, 966, 
       290}], Line3DBox[{296, 1090, 374, 970, 971, 293, 1093, 377, 976, 977, 
       299, 1096, 380, 982, 983, 302, 1099, 383, 987, 305, 1103, 1104, 386, 
       990, 308}], 
      Line3DBox[{314, 1108, 389, 994, 995, 311, 1111, 392, 1000, 1001, 317, 
       1114, 395, 1006, 1007, 320, 1117, 398, 1012, 1013, 323, 1120, 401, 
       1017, 326}]}, {}, {}, {}, {}, {}}},
   VertexNormals->CompressedData["
1:eJxsvHc819/7P25VklUpUbKz9xbPyygrM3vvkWSEkJnKCJWWkTJaUhQKUc+T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    "]],
  Axes->True,
  BoxRatios->{1, 1},
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{{200., 300.}, {5., 15.}, {0.06200000000039241, 
   0.34400000000011577`}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.402243857866375*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p6B", "=", 
  RowBox[{"SlideView", "[", 
   RowBox[{"{", 
    RowBox[{"p6Ba", ",", "p6Bb"}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.40014088975*^9, 3.400140893171875*^9}, {
  3.40065791125*^9, 3.400657916515625*^9}}],

Cell[BoxData[
 TagBox[
  DynamicModuleBox[{BoxForm`var$$ = 1}, 
   InterpretationBox[
    StyleBox[
     PanelBox[
      TagBox[GridBox[{
         {
          ItemBox[
           TagBox[GridBox[{
              {
               TagBox[GridBox[{
                  {
                   TagBox[
                    TooltipBox[
                    ButtonBox[
                    StyleBox["\<\"\[FirstPage]\"\>",
                    StripOnInput->False,
                    FontSize->18],
                    Appearance->"Palette",
                    ButtonFrame->"Palette",
                    
                    ButtonFunction:>If[
                    BoxForm`var$$ =!= 1, BoxForm`var$$ = 1],
                    Enabled->Automatic,
                    Evaluator->Automatic,
                    ImageSize->Small,
                    Method->"Preemptive"],
                    "\"First Slide\""],
                    Annotation[#, "First Slide", "Tooltip"]& ], 
                   TagBox[
                    TooltipBox[
                    ButtonBox[
                    StyleBox["\<\"\[LeftPointer]\"\>",
                    StripOnInput->False,
                    FontSize->18],
                    Appearance->"Palette",
                    ButtonFrame->"Palette",
                    ButtonFunction:>If[BoxForm`var$$ > 1, 
                    PreDecrement[BoxForm`var$$]],
                    Enabled->Automatic,
                    Evaluator->Automatic,
                    ImageSize->Small,
                    Method->"Preemptive"],
                    "\"Previous Slide\""],
                    Annotation[#, "Previous Slide", "Tooltip"]& ], 
                   TagBox[
                    TooltipBox[
                    ButtonBox[
                    StyleBox["\<\"\[RightPointer]\"\>",
                    StripOnInput->False,
                    FontSize->18],
                    Appearance->"Palette",
                    ButtonFrame->"Palette",
                    ButtonFunction:>If[BoxForm`var$$ < 2, 
                    PreIncrement[BoxForm`var$$]],
                    Enabled->Automatic,
                    Evaluator->Automatic,
                    ImageSize->Small,
                    Method->"Preemptive"],
                    "\"Next Slide\""],
                    Annotation[#, "Next Slide", "Tooltip"]& ], 
                   TagBox[
                    TooltipBox[
                    ButtonBox[
                    StyleBox["\<\"\[LastPage]\"\>",
                    StripOnInput->False,
                    FontSize->18],
                    Appearance->"Palette",
                    ButtonFrame->"Palette",
                    
                    ButtonFunction:>If[
                    BoxForm`var$$ =!= 2, BoxForm`var$$ = 2],
                    Enabled->Automatic,
                    Evaluator->Automatic,
                    ImageSize->Small,
                    Method->"Preemptive"],
                    "\"Last Slide\""],
                    Annotation[#, "Last Slide", "Tooltip"]& ]}
                 },
                 ColumnsEqual->False,
                 
                 GridBoxItemSize->{
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}},
                 RowsEqual->False],
                "Grid"]}
             },
             ColumnsEqual->False,
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxItemSize->{
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
             RowsEqual->False],
            "Grid"],
           Alignment->Left,
           StripOnInput->False]},
         {
          ItemBox[
           StyleBox[Cell[BoxData[
             PaneSelectorBox[{1->
              GraphicsBox[{{{}, 
                 {RGBColor[0, 0, 1], PointSize[0.02], 
                  PointBox[{{300., 0.37500000000003375`}, {330., 
                   0.4370000000000336}, {360., 0.5630000000001356}, {390., 
                   0.5780000000000336}, {420., 0.6870000000000589}, {450., 
                   0.7500000000001608}, {480., 0.8290000000001609}, {510., 
                   0.9369999999999825}, {540., 1.0310000000000845`}, {570., 
                   1.2500000000001354`}, {600., 
                   1.3130000000001356`}}]}, {}}, {{}, 
                 {RGBColor[1, 0, 0], PointSize[0.02], 
                  PointBox[{{300., 0.11000000000011001`}, {330., 
                   0.12499999999998268`}, {360., 0.12499999999998268`}, {390.,
                    0.1399999999999828}, {420., 0.15700000000011016`}, {450., 
                   0.1559999999999575}, {480., 0.17200000000000815`}, {510., 
                   0.18699999999998296`}, {540., 0.20300000000008467`}, {570.,
                    0.21900000000011}, {600., 0.21900000000005937`}}]}, {}}},
               AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
               Axes->True,
               AxesLabel->{
                 FormBox[
                  InterpretationBox[
                   Cell[
                    BoxData[
                    FormBox[
                    StyleBox[
                    "\"Number of vertices\"", Italic, 16, StripOnInput -> 
                    False], TraditionalForm]], "Text", "TR"], 
                   Text[
                    Style["Number of vertices", Italic, 16]]], 
                  TraditionalForm], 
                 FormBox[
                  InterpretationBox[
                   Cell[
                    BoxData[
                    FormBox[
                    StyleBox[
                    "\"Running time\"", Italic, 16, StripOnInput -> False], 
                    TraditionalForm]], "Text", "TR"], 
                   Text[
                    Style["Running time", Italic, 16]]], TraditionalForm]},
               AxesOrigin->{300., 0},
               ImageSize->500,
               PlotLabel->FormBox[
                 RowBox[{"{", 
                   RowBox[{
                    InterpretationBox[
                    Cell[
                    BoxData[
                    FormBox[
                    StyleBox["\"EdgeColoring\"", 
                    RGBColor[0, 0, 1], 20, StripOnInput -> False], 
                    TraditionalForm]], "Text", "TR"], 
                    Text[
                    Style["EdgeColoring", 
                    RGBColor[0, 0, 1], 20]]], ",", 
                    InterpretationBox[
                    Cell[
                    BoxData[
                    FormBox[
                    StyleBox["\"Vizing\"", 
                    RGBColor[1, 0, 0], 20, StripOnInput -> False], 
                    TraditionalForm]], "Text", "TR"], 
                    Text[
                    Style["Vizing", 
                    RGBColor[1, 0, 0], 20]]]}], "}"}], TraditionalForm],
               PlotRange->{{299, 601}, {0, 1.5756000000001626`}},
               PlotRangeClipping->True,
               PlotRangePadding->{Automatic, Automatic}], 2->
              Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1XH9c1GXyRyVFNI+zdWWFNliXD+yCe5x5nvkjx19ppV+pTMkoOc+KzIw4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                "], {{
                  {RGBColor[0, 0, 1], EdgeForm[None], 
                   GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtlnus13MYxz+XyKXcb5FLYUxrYzZmYzbGWMayrK2jozo5nJyco6OcnJx0
dHSULGNzGbNF5FYR5ZYU0Z10lG46HB0OXZQyYzOv996fP977vH6f7+/3/X4/
z/N+nufXb1TdrfemEMJ7KKOnYggvs7KEXmxM5eIOuCe8lXUL6gFPYX8zvA3N
RGfqN+w/zP4m+Cj4EXg7/AOahc5CR2b/Rvfag2aj83SN/UM89Bd9hv+Cf4N7
w63cZye8iL3FrMeiZ+E5rEegC7LvtRstZH8POgY+jf2D8M/wcfCj3KcD7g8/
DnfrN9G/1Tt0Rz/3XLgr+n36wytY96GT4eWse9FJcGf0/fvBm1kPoL46W/QZ
FZMO+E90DtyX507nuV1wH/gxeBd8NjwD/hU+EZ4G/wSfn32m39F/7E1G7fAp
7LfBnfBK7r1Ke+gi9l8Jjsvl8Ei+8xZ8M3wP/BF8DVwNvwNfBY+G58PXwXcn
++BGuAb+AL4NroM/hYfDDfDn8DD4Pvgz+Ba4Fv4Yvhq+E14AXwrfAb8B3wAv
Cs7fFfAo9t+GB8K3w6/BQ2CZcQl8YbYPdZ5L4Er2X4dHwOPhL+Fx8EPwt/AJ
2XH+Eb4YHs7+XHgAXAG/Cl8Gj4DfhK+Eq+B58D+sf0Tf5/DsPH6vuCfnXc+q
Y7+Jz1/DjcX/+k5TqQvle3x2jr6Dq+CVwbmpgRvZXwuPgSfC6+DR8AR4Nbwh
+h1Oh9tZ96Mz4H+53ow2Fh+8WHylGNWg4+U9ro8p+dLZhqj+5Nvk+CtuW1nH
lhztY32gPFfv1IRORXuT31fvvTt5/QodTD77en1OjqFyeoh1EvomOC7Nqjm0
P/m8a+ADrA+W8+rejcWrivtQdHRwngarNygOyT5cCK9nvQu9C69J9pW8ui7Z
w/LYlmRvf1i8VVX6g7xerbpHm5KvyX/tyev7quVk78kbS5O9Js99kewfeXJZ
cj3p2upkz8i3qp9hqJfilexn1Vp3sj9XBNdGrbyJtid7+5PgXE4O7iGKXYvq
vjz7puDeq77wTLAHtkXnXnlXb20N7kXqxW0lnuoXTwb7R73yadQH/Z1cIxvK
mSuCe+YL0Z/Fim8l6qmzo7HB/VO5byjxXIbqUW80O7o/KF9zo2tffpsX3SuU
U8VsULl/B3vjku+hHvd8cJ/sTO4ny+EdrPWlz+xM7i1L4S7W+5PfqzbbS/Lh
kug6kv9XRcdCcZgT3fd6qBai+9th8kN0rckPz0X3BM29xdHn1BnXwi3JtfBS
dM/RTByZ/R3VgzZUm6rxa7P9Ka+2lr6tnjw4u9aU68rs95cfqrPrTnWxMXlO
qd/OLPNI8+767LzIo81lhmr+PpHtAc2Diux4Km4zyuzQLGsrM0XzZVB2T1Bd
zCpzRHOupczTDnhidtzUvyZln13zekKZ45rvU8vcVF9tyO5FmkH12bUvX00r
80hzdmh2HpW76WXeaaZPKf8l9F9gV/IM1Rz5H+OfMmM=
                    "]], Polygon3DBox[CompressedData["
1:eJw1l3ccUFUVx+97140KIi4cgLhbakPTLGe5cKA5EpSlhAbkAlELcKCIo9wT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                    "]], Polygon3DBox[CompressedData["
1:eJw1lVlsUFUQhu+5R3wQJCBGwKgo+gZEgcgSXKLigxoRZAv7YgstLS2lbAJF
9p24RKPggwTCJsjqA4uAQEHZKQUqCrRQWihGdogiUb8/Mz58mTn/uffcc+bM
zH1mcP77eWmSJBlQC9aFJDmLsAM/H7uW8RDs6zFJXoNXYT1zw9DewX8b3oLN
aP3QXsB/HlrACrThaF3wO8N7sA1tPtoC/PkwD2rQHsc+AdX4c5hvjF+A7Y3t
BT1hJ3M5aJ3w3432/S1oh9AOp7avTOxBGAztmW8HbWGNz2n/r8DLsA5tMefb
i74Kvz/2m2DnKIbOaF1gJcxkPJ13psFUqEDrm9o5m0MzWI72KPYxqMSfxXwD
/KPYEtiENhR7BJ5Efwouoc1N7exPQ1OPxzy0Jvj7sQfgu8TO9DMsYo+7U/te
H+xCxlewv8M+tNHYGqjN+3XgLNo0xg/hD8C2xraCltHOPRttFv5MmOF7P49W
CbvxR2IrtDb8BN8mto7iVpfn63k8ZjB+GH86dgp2Mkzy7xei9cPvC32irXub
fVfChWDfv4h2C78CyoPF+7zHZy7+HJjtOTIeLRc/B4bBYbRnsc/BFc8xxfIu
69TA5WA5p7mBzLXBfzFaLHSehthGvgfFQ3d4h3eqoSrY93VXKpZu+F2j5fUP
aH+h3YPj+EXYP2FEajnbA7pHq6d/VWj4JzEf4f+jvA12L2fQpjI+xPgctjy1
fNc6qkfd6UDdH/SHvcyNSs3PU51BcWK1qlrohd8bNsA15TgUB1tDOTKOZ27A
ePwJqiG45Hnz/9rVMFFnUd5rf3BMd4R2W3ns93ATrvt6B9HGYq/Bb3AmtRip
D/yaWi7p/gt0NtgFk9HGKP+UQ3AKjqOVwvf4WV4/tXjmQfgFbQrjB6LlnOrx
C7TPodxrR33la/xFcNnPm42WBUOi7VN9Rvn0Ff6XUAWT0AqVu7ojKFV80PIV
52g5p3NfVQ3CrmB5vcfrXfXzGf6ncCGxWlANfoz/CZyDbcHicwB/DHZrsJxU
bXVF6war/YzjeHdstPiUof3Bs5tgI7wZLT4Xea4qtT0Uet2qz7yhfFFfg41w
33PuhJ/zb6jPM494nanH1fO+q/zLQcuFH73vnoZM5RhshVXB7lQ9PRe7Mlif
Uc0XwUTPa92f9tox2p7UBz9Aewm/Q7Q+rf62x/vuCu+t6nF5nkNZaNmw3Wtn
NO+MinZXOs9Svl2W2n8oG7uE8U1pcCpYHJU3a4L9H9T7M7CrGd+AE1AabF3V
5/JgvVb/jUHYZYzTaDlX5jkbtKbHRf8h/RO1hx3BakI96UPs9mA5pJopUuzh
KFxHL4FjMDJa/7jr/aMksdq7k1pP0XxBtFos8fjpv9ADvyes9bpTbmdCRrT8
+g/vyiJB
                    "]]}]}, 
                  {RGBColor[1, 0, 0], EdgeForm[None], 
                   GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtlWuIVlUUhs/ZZxWKoRiJYhgO1kxTTk7a2JQ1poyNjY2NMzrjTJk23W/a
/X6/37ybpmlapmmapmlaphRFQRREQRRFQRREQRSEYozY8/KeH+vbz36/dfbZ
e+211qnomdc2N2VZtgsrsK/42YFwb55lxzO+io1CP5HxJrQx8EnwJuwseDZa
v9x8vZ7BRsMTIsvewucO5qtYcxk8DV4BL4anwhWMW7A6/FeiL4EvQT8vrN8G
t2O9mfcwNvzeeWjHMb6CnYGeMXajjdQ+8XmZ+azcWlbqlejr0HuYd2IFdjr6
cPQ1yef4gz3MhJ+FBzAux6rxOcR8MnYKfGzy+jXwEbT5cCXcl3EpdqriyLgI
q4Irwvucg28rdjjznpfzroXoF6Mthi8q3/EEdg52Pj6PM9ZhE+Fmxr8zn2UD
/tN4tgvtGmwQdib6IvliE+AB4f1PZ34/dprWRZ/POB67AH5OsdYcfppxLNYA
r2b9F3m2LfedDynvfQ96G/p1zDfCl5YxXgu/hD4D7sCO4luLXQb3KZ9dj88q
fGYyXwevTL6HNfCKcp/3YCdj9fjfyViFnQ0vLXx+xWgZvAD/KXALdjDzXYzj
vG+i31rG8Z/M9zU+OS6Kyfc8+zD8EPaI8rTUv0V/B78HmP9Q+D/57YPfQL8B
/hJ+O3mPyukRih3P/oi+G/1R5t/AO5Pj/Wnh/L8d3lI4xy6HP4G3lrn9Gbwt
+awfF97/LbnPMBwbx/q70TegX8v8Q3gu483YgcKj7mcn/HpyLuyFNybX4g54
PXxV7rzvn7vWtqO/hn4l84/gzWVNXY0NVB7gsxV9bZm32wrXzhVwTXL8zsXn
c/TtzO9SjYXfpTX+RT8AL4APqd5z38FP8Lvoj+l+4P3J+Tg0nEvKlyVYk+6Q
9QeHc0Z5Xsu4Kzkmhwv7ad0TwrmnvNuMvrqs/U2F19O6s8Lv0n6qwj1NZ/8L
nw/g5+FR4Tgrt4cmP6u8HR3OgRuZD06uO/W3unD8dR+/s8776M/A++H20v9P
eF9ynfXmzmHV78/oe5Jr/Tf4veT6+wXeCz+pWoe74BfKfK0pY673DSu5f7hO
1SP/K5z3qpF+4X6r+h0Yri/V5ojwneoej5Z1pP5zTLgnq/dWh3NDOVMTzivl
3pTwPlQX3eFzKW5Dwj1Ace4Mn0VxaA3Xhe56crguVF/Tw2fXGQeF+4B6wrDw
3alGvmZvM+D74BTuk6r13rJPKo5HCvde9YGRyXFRTCqTe5R6SN9wT9Z35yD+
3fBCeFK4lvWNK8K9Wt+j6uS7U5+sU09K7off8WwH/KBqMpnVPxvD+X83ekNy
31A/6RP+lqnf1yefRT22Nlyb6ie/smYn/BTcEb538exw7WifXeG80veoJRx7
veOLwnvTexuT12lUvw3ns3KmOTl/LkRvCn/TFc854VpU7TSH+57O1ZIcnyb5
J38HJ8GtybWmemwI9y71tDHh3qMaqA/3EPWunvDaeqY9XO/6jk0M9zr1iqnh
WlbP/B/71vP3
                    "]], Polygon3DBox[CompressedData["
1:eJxFmHdsntUVh9/3fi8hISaEEBIyHJyQOHaW7Qxn2HES4yxGyYAEQlpopFaq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                    "]], Polygon3DBox[CompressedData["
1:eJw1lWdwVkUUhm/uLi0YElr8gRoSWiiCMECQXgSkQ0Ia0kQQkBkRG0r5QVNU
SADpoPTem4CUGZo6FoY2wA9FBpVBcQQdYWSA4PPOWX48s+99z/3227t7ztn0
YWOzX4+jKBoOpSCNh2MuisYmRNFG9DOQCy0gC7r6KJpA7Ah6ELo9uh3Mhv54
zaApvEBsPF4xOkYnwCPm7YmXh9cKWkJ3/Ml4h9AD0G3QreFjuMP7d6EYfZT4
v+g94Tfd4EWYRGx3bLo+uh5MhJ14nfFqoWvCezAXrxSeBwe98TbjnWDeNHR1
GCeP5y0wGL2c+Cb0AsYK/CYJykM2sf14/dEt0c/DdPgCL0dx6AtT8dbgNdD6
oC4Mx1vGnMudzTOf+FL0AcY84rne5p1B7HP8FZCLXkT8M/Q6xkbEG8KzMJLY
Kvw1UIBeQnwlOl/nAJ3CvB8Q24a/HV5Gr8Dfiv4d/oCP8L7Eu+FsLOQ3BZAP
M4mtx3sOXRldCUbDAt5dGM61iPh89NrY1pWKVxVehV0hd7p4O5f3wzqr6jzQ
DvIhG6821ArfOApvA7oJurG3/38N72Bs68pCN4cPYR5eWbwy3s65D14OXl3I
DHOMwVvMGpc4iysnFjnb24rEUyBZ+0+sQGuGLmEvtD+J4az6oT9Fl4MMOIn3
Jt4WdDr8yfNf8EnI7ZvobYxfMWbg1YC39R08H3L2TdrfAyHXlBv3qccHkBO+
TWv+j+d70BfvMN5A1vWSt9rRf113dn4zwx79hj4NZ5ztueriB7QP360amIN2
cNxZLbyBtyn0gVtwG2aF/9M3XYVrzvJTNfAz+jv43lnN78D7Fp0U8muo8hj9
hPI3ttpKxCsPQ6Ay3g68V5TH6ErK39jyNAmvAgxTbfG831lOqAb2of9x1heK
Qk/6G704tpopYZ8eQR6xtaobKEQvja1WVPutVL/Qwtt3p4Qa0/kvRCfDTzxf
cVbL+3j+MZxlB/U/aAtvESsTesUg1Te6dGx7oV7YCTrCu8QK1cOgWzg/7e0p
Z7mhebaGfFJ91iCeAene9lG9ZBexFHRFGBH6h3pSIpTzlpvqW0+jn4Jq3tZ0
lt+dc9a/VY9nwl5VUU17y3/1mZ3O/kN9anU4m36MT0KqRm/7qDOqrR7rbZ3q
KZd497Kznq5efVH9JrZvz8SrA++EM9A8qd56QEHoH7ojSuAh9MD7hfFXZ71L
/VF5pzWpj2ZCHW95oz3TObSB1t5qcQBeL+gJQ7zdIyUJ1qM092z8h4zfOMtX
nY3W+rXuGWf5pd6qfrbb2R2keQZ7u/uKQp0od7Kgubd78zDvHnHWa9S7VN+N
Q95MwdurPhrb3ajeeYccvQu9Qn7p3uij+8nb+7pTlH9N0c1gWoLVUXXiad7O
WXfVBWf7/fhOPI/+H5qC72o=
                    "]]}]}, {}, {}, {}}, {
                  Line3DBox[{403, 1, 76, 77, 78, 7, 94, 95, 96, 13, 112, 113, 
                   114, 19, 130, 131, 132, 25, 148, 149, 150, 31, 478, 479, 
                   480, 32, 481, 482, 483, 33, 484, 485, 486, 34, 487, 488, 
                   489, 35, 490, 491, 492, 36, 162, 161, 160, 30, 144, 143, 
                   142, 24, 126, 125, 124, 18, 108, 107, 106, 12, 90, 89, 88, 
                   6, 429, 428, 427, 5, 423, 422, 421, 4, 417, 416, 415, 3, 
                   411, 410, 409, 2, 405, 404, 403}], 
                  Line3DBox[{503, 37, 241, 242, 243, 43, 259, 260, 261, 49, 
                   277, 278, 279, 55, 295, 296, 297, 61, 313, 314, 315, 67, 
                   578, 579, 580, 68, 581, 582, 583, 69, 584, 585, 586, 70, 
                   587, 588, 589, 71, 590, 591, 592, 72, 327, 326, 325, 66, 
                   309, 308, 307, 60, 291, 290, 289, 54, 273, 272, 271, 48, 
                   255, 254, 253, 42, 529, 528, 527, 41, 523, 522, 521, 40, 
                   517, 516, 515, 39, 511, 510, 509, 38, 505, 504, 503}], {
                   Line3DBox[{403, 163, 808, 809, 406, 718, 615, 835, 836, 
                    433, 736, 626, 859, 860, 448, 757, 636, 880, 881, 463, 
                    781, 645, 898, 899, 478}], 
                   Line3DBox[{409, 603, 811, 812, 814, 412, 181, 838, 839, 
                    436, 742, 628, 862, 863, 451, 763, 638, 883, 884, 466, 
                    787, 647, 901, 902, 481}], 
                   Line3DBox[{415, 606, 817, 818, 820, 418, 617, 841, 842, 
                    844, 439, 199, 865, 866, 454, 769, 640, 886, 887, 469, 
                    793, 649, 904, 905, 484}], 
                   Line3DBox[{421, 609, 823, 824, 826, 424, 620, 847, 848, 
                    850, 442, 630, 868, 869, 871, 457, 217, 889, 890, 472, 
                    799, 651, 907, 908, 487}], 
                   Line3DBox[{427, 612, 829, 830, 832, 430, 623, 853, 854, 
                    856, 445, 633, 874, 875, 877, 460, 642, 892, 893, 895, 
                    475, 235, 910, 911, 490}], 
                   Line3DBox[{480, 499, 786, 785, 783, 465, 496, 762, 761, 
                    759, 450, 494, 741, 740, 738, 435, 493, 723, 722, 720, 
                    408, 165, 705, 704, 405}], 
                   Line3DBox[{483, 500, 792, 791, 789, 468, 497, 768, 767, 
                    765, 453, 495, 747, 746, 744, 438, 183, 726, 725, 414, 
                    816, 605, 708, 707, 411}], 
                   Line3DBox[{486, 501, 798, 797, 795, 471, 498, 774, 773, 
                    771, 456, 201, 750, 749, 441, 846, 619, 729, 728, 420, 
                    822, 608, 711, 710, 417}], 
                   Line3DBox[{489, 502, 804, 803, 801, 474, 219, 777, 776, 
                    459, 873, 632, 753, 752, 444, 852, 622, 732, 731, 426, 
                    828, 611, 714, 713, 423}], 
                   Line3DBox[{492, 237, 807, 806, 477, 897, 644, 780, 779, 
                    462, 879, 635, 756, 755, 447, 858, 625, 735, 734, 432, 
                    834, 614, 717, 716, 429}], 
                   Line3DBox[{503, 328, 1018, 1019, 506, 928, 665, 1045, 1046,
                     533, 946, 676, 1069, 1070, 548, 967, 686, 1090, 1091, 
                    563, 991, 695, 1108, 1109, 578}], 
                   Line3DBox[{509, 653, 1021, 1022, 1024, 512, 346, 1048, 
                    1049, 536, 952, 678, 1072, 1073, 551, 973, 688, 1093, 
                    1094, 566, 997, 697, 1111, 1112, 581}], 
                   Line3DBox[{515, 656, 1027, 1028, 1030, 518, 667, 1051, 
                    1052, 1054, 539, 364, 1075, 1076, 554, 979, 690, 1096, 
                    1097, 569, 1003, 699, 1114, 1115, 584}], 
                   Line3DBox[{521, 659, 1033, 1034, 1036, 524, 670, 1057, 
                    1058, 1060, 542, 680, 1078, 1079, 1081, 557, 382, 1099, 
                    1100, 572, 1009, 701, 1117, 1118, 587}], 
                   Line3DBox[{527, 662, 1039, 1040, 1042, 530, 673, 1063, 
                    1064, 1066, 545, 683, 1084, 1085, 1087, 560, 692, 1102, 
                    1103, 1105, 575, 400, 1120, 1121, 590}], 
                   Line3DBox[{580, 599, 996, 995, 993, 565, 596, 972, 971, 
                    969, 550, 594, 951, 950, 948, 535, 593, 933, 932, 930, 
                    508, 330, 915, 914, 505}], 
                   Line3DBox[{583, 600, 1002, 1001, 999, 568, 597, 978, 977, 
                    975, 553, 595, 957, 956, 954, 538, 348, 936, 935, 514, 
                    1026, 655, 918, 917, 511}], 
                   Line3DBox[{586, 601, 1008, 1007, 1005, 571, 598, 984, 983, 
                    981, 556, 366, 960, 959, 541, 1056, 669, 939, 938, 520, 
                    1032, 658, 921, 920, 517}], 
                   Line3DBox[{589, 602, 1014, 1013, 1011, 574, 384, 987, 986, 
                    559, 1083, 682, 963, 962, 544, 1062, 672, 942, 941, 526, 
                    1038, 661, 924, 923, 523}], 
                   Line3DBox[{592, 402, 1017, 1016, 577, 1107, 694, 990, 989, 
                    562, 1089, 685, 966, 965, 547, 1068, 675, 945, 944, 532, 
                    1044, 664, 927, 926, 529}], 
                   Line3DBox[{404, 703, 164, 810, 407, 719, 721, 616, 837, 
                    434, 737, 739, 627, 861, 449, 758, 760, 637, 882, 464, 
                    782, 784, 646, 900, 479}], 
                   Line3DBox[{410, 706, 604, 813, 815, 413, 724, 182, 840, 
                    437, 743, 745, 629, 864, 452, 764, 766, 639, 885, 467, 
                    788, 790, 648, 903, 482}], 
                   Line3DBox[{416, 709, 607, 819, 821, 419, 727, 618, 843, 
                    845, 440, 748, 200, 867, 455, 770, 772, 641, 888, 470, 
                    794, 796, 650, 906, 485}], 
                   Line3DBox[{422, 712, 610, 825, 827, 425, 730, 621, 849, 
                    851, 443, 751, 631, 870, 872, 458, 775, 218, 891, 473, 
                    800, 802, 652, 909, 488}], 
                   Line3DBox[{428, 715, 613, 831, 833, 431, 733, 624, 855, 
                    857, 446, 754, 634, 876, 878, 461, 778, 643, 894, 896, 
                    476, 805, 236, 912, 491}], 
                   Line3DBox[{504, 913, 329, 1020, 507, 929, 931, 666, 1047, 
                    534, 947, 949, 677, 1071, 549, 968, 970, 687, 1092, 564, 
                    992, 994, 696, 1110, 579}], 
                   Line3DBox[{510, 916, 654, 1023, 1025, 513, 934, 347, 1050, 
                    537, 953, 955, 679, 1074, 552, 974, 976, 689, 1095, 567, 
                    998, 1000, 698, 1113, 582}], 
                   Line3DBox[{516, 919, 657, 1029, 1031, 519, 937, 668, 1053, 
                    1055, 540, 958, 365, 1077, 555, 980, 982, 691, 1098, 570, 
                    1004, 1006, 700, 1116, 585}], 
                   Line3DBox[{522, 922, 660, 1035, 1037, 525, 940, 671, 1059, 
                    1061, 543, 961, 681, 1080, 1082, 558, 985, 383, 1101, 573,
                     1010, 1012, 702, 1119, 588}], 
                   Line3DBox[{528, 925, 663, 1041, 1043, 531, 943, 674, 1065, 
                    1067, 546, 964, 684, 1086, 1088, 561, 988, 693, 1104, 
                    1106, 576, 1015, 401, 1122, 591}]}, {
                   Line3DBox[{78, 809, 810, 165, 75, 814, 815, 816, 168, 81, 
                    820, 821, 822, 171, 84, 826, 827, 828, 174, 87, 832, 833, 
                    834, 177, 90}], 
                   Line3DBox[{88, 716, 715, 175, 829, 85, 713, 712, 172, 823, 
                    82, 710, 709, 169, 817, 79, 707, 706, 166, 811, 73, 704, 
                    703, 163, 76}], 
                   Line3DBox[{96, 836, 837, 180, 723, 93, 839, 840, 183, 99, 
                    844, 845, 846, 186, 102, 850, 851, 852, 189, 105, 856, 
                    857, 858, 192, 108}], 
                   Line3DBox[{106, 734, 733, 190, 853, 103, 731, 730, 187, 
                    847, 100, 728, 727, 184, 841, 97, 725, 724, 181, 91, 720, 
                    719, 718, 178, 94}], 
                   Line3DBox[{114, 860, 861, 195, 741, 111, 863, 864, 198, 
                    747, 117, 866, 867, 201, 120, 871, 872, 873, 204, 123, 
                    877, 878, 879, 207, 126}], 
                   Line3DBox[{124, 755, 754, 205, 874, 121, 752, 751, 202, 
                    868, 118, 749, 748, 199, 115, 744, 743, 742, 196, 109, 
                    738, 737, 736, 193, 112}], 
                   Line3DBox[{132, 881, 882, 210, 762, 129, 884, 885, 213, 
                    768, 135, 887, 888, 216, 774, 138, 890, 891, 219, 141, 
                    895, 896, 897, 222, 144}], 
                   Line3DBox[{142, 779, 778, 220, 892, 139, 776, 775, 217, 
                    136, 771, 770, 769, 214, 133, 765, 764, 763, 211, 127, 
                    759, 758, 757, 208, 130}], 
                   Line3DBox[{150, 899, 900, 225, 786, 147, 902, 903, 228, 
                    792, 153, 905, 906, 231, 798, 156, 908, 909, 234, 804, 
                    159, 911, 912, 237, 162}], 
                   Line3DBox[{160, 806, 805, 235, 157, 801, 800, 799, 232, 
                    154, 795, 794, 793, 229, 151, 789, 788, 787, 226, 145, 
                    783, 782, 781, 223, 148}], 
                   Line3DBox[{243, 1019, 1020, 330, 240, 1024, 1025, 1026, 
                    333, 246, 1030, 1031, 1032, 336, 249, 1036, 1037, 1038, 
                    339, 252, 1042, 1043, 1044, 342, 255}], 
                   Line3DBox[{253, 926, 925, 340, 1039, 250, 923, 922, 337, 
                    1033, 247, 920, 919, 334, 1027, 244, 917, 916, 331, 1021, 
                    238, 914, 913, 328, 241}], 
                   Line3DBox[{261, 1046, 1047, 345, 933, 258, 1049, 1050, 348,
                     264, 1054, 1055, 1056, 351, 267, 1060, 1061, 1062, 354, 
                    270, 1066, 1067, 1068, 357, 273}], 
                   Line3DBox[{271, 944, 943, 355, 1063, 268, 941, 940, 352, 
                    1057, 265, 938, 937, 349, 1051, 262, 935, 934, 346, 256, 
                    930, 929, 928, 343, 259}], 
                   Line3DBox[{279, 1070, 1071, 360, 951, 276, 1073, 1074, 363,
                     957, 282, 1076, 1077, 366, 285, 1081, 1082, 1083, 369, 
                    288, 1087, 1088, 1089, 372, 291}], 
                   Line3DBox[{289, 965, 964, 370, 1084, 286, 962, 961, 367, 
                    1078, 283, 959, 958, 364, 280, 954, 953, 952, 361, 274, 
                    948, 947, 946, 358, 277}], 
                   Line3DBox[{297, 1091, 1092, 375, 972, 294, 1094, 1095, 378,
                     978, 300, 1097, 1098, 381, 984, 303, 1100, 1101, 384, 
                    306, 1105, 1106, 1107, 387, 309}], 
                   Line3DBox[{307, 989, 988, 385, 1102, 304, 986, 985, 382, 
                    301, 981, 980, 979, 379, 298, 975, 974, 973, 376, 292, 
                    969, 968, 967, 373, 295}], 
                   Line3DBox[{315, 1109, 1110, 390, 996, 312, 1112, 1113, 393,
                     1002, 318, 1115, 1116, 396, 1008, 321, 1118, 1119, 399, 
                    1014, 324, 1121, 1122, 402, 327}], 
                   Line3DBox[{325, 1016, 1015, 400, 322, 1011, 1010, 1009, 
                    397, 319, 1005, 1004, 1003, 394, 316, 999, 998, 997, 391, 
                    310, 993, 992, 991, 388, 313}], 
                   Line3DBox[{77, 808, 164, 705, 74, 812, 813, 167, 708, 80, 
                    818, 819, 170, 711, 83, 824, 825, 173, 714, 86, 830, 831, 
                    176, 717, 89}], 
                   Line3DBox[{95, 835, 179, 721, 722, 92, 838, 182, 726, 98, 
                    842, 843, 185, 729, 101, 848, 849, 188, 732, 104, 854, 
                    855, 191, 735, 107}], 
                   Line3DBox[{113, 859, 194, 739, 740, 110, 862, 197, 745, 
                    746, 116, 865, 200, 750, 119, 869, 870, 203, 753, 122, 
                    875, 876, 206, 756, 125}], 
                   Line3DBox[{131, 880, 209, 760, 761, 128, 883, 212, 766, 
                    767, 134, 886, 215, 772, 773, 137, 889, 218, 777, 140, 
                    893, 894, 221, 780, 143}], 
                   Line3DBox[{149, 898, 224, 784, 785, 146, 901, 227, 790, 
                    791, 152, 904, 230, 796, 797, 155, 907, 233, 802, 803, 
                    158, 910, 236, 807, 161}], 
                   Line3DBox[{242, 1018, 329, 915, 239, 1022, 1023, 332, 918, 
                    245, 1028, 1029, 335, 921, 248, 1034, 1035, 338, 924, 251,
                     1040, 1041, 341, 927, 254}], 
                   Line3DBox[{260, 1045, 344, 931, 932, 257, 1048, 347, 936, 
                    263, 1052, 1053, 350, 939, 266, 1058, 1059, 353, 942, 269,
                     1064, 1065, 356, 945, 272}], 
                   Line3DBox[{278, 1069, 359, 949, 950, 275, 1072, 362, 955, 
                    956, 281, 1075, 365, 960, 284, 1079, 1080, 368, 963, 287, 
                    1085, 1086, 371, 966, 290}], 
                   Line3DBox[{296, 1090, 374, 970, 971, 293, 1093, 377, 976, 
                    977, 299, 1096, 380, 982, 983, 302, 1099, 383, 987, 305, 
                    1103, 1104, 386, 990, 308}], 
                   Line3DBox[{314, 1108, 389, 994, 995, 311, 1111, 392, 1000, 
                    1001, 317, 1114, 395, 1006, 1007, 320, 1117, 398, 1012, 
                    1013, 323, 1120, 401, 1017, 326}]}, {}, {}, {}, {}, {}}},
                VertexNormals->CompressedData["
1:eJxsvHc819/7P25VklUpUbKz9xbPyygrM3vvkWSEkJnKCJWWkTJaUhQKUc+T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                 "]],
               Axes->True,
               BoxRatios->{1, 1},
               Method->{"RotationControl" -> "Globe"},
               
               PlotRange->{{200., 300.}, {5., 15.}, {0.06200000000039241, 
                0.34400000000011577`}},
               PlotRangePadding->{
                 Scaled[0.02], 
                 Scaled[0.02], 
                 Scaled[0.02]},
               ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]}, Dynamic[BoxForm`var$$],
              Alignment->Automatic,
              ImageSize->All]],
             Background->GrayLevel[1]],
            Deployed->False,
            StripOnInput->False],
           Background->GrayLevel[1],
           Frame->True,
           FrameStyle->GrayLevel[0.8235294117647058],
           StripOnInput->False]}
        },
        ColumnsEqual->False,
        GridBoxAlignment->{"Columns" -> {{Left}}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        RowsEqual->False],
       "Grid"],
      BaselinePosition->Automatic,
      DefaultBaseStyle->"SlideView",
      FrameMargins->6,
      ImageMargins->Automatic],
     Deployed->True,
     StripOnInput->False],
    SlideView[{
      Graphics[{{{{}, {
           Hue[0.67, 0.6, 0.6], 
           PointSize[0.02], 
           RGBColor[0, 0, 1], 
           
           Point[{{300., 0.37500000000003375`}, {330., 0.4370000000000336}, {
            360., 0.5630000000001356}, {390., 0.5780000000000336}, {420., 
            0.6870000000000589}, {450., 0.7500000000001608}, {480., 
            0.8290000000001609}, {510., 0.9369999999999825}, {540., 
            1.0310000000000845`}, {570., 1.2500000000001354`}, {600., 
            1.3130000000001356`}}]}, {}}}, {{{}, {
           Hue[0.67, 0.6, 0.6], 
           PointSize[0.02], 
           RGBColor[1, 0, 0], 
           
           Point[{{300., 0.11000000000011001`}, {330., 
            0.12499999999998268`}, {360., 0.12499999999998268`}, {390., 
            0.1399999999999828}, {420., 0.15700000000011016`}, {450., 
            0.1559999999999575}, {480., 0.17200000000000815`}, {510., 
            0.18699999999998296`}, {540., 0.20300000000008467`}, {570., 
            0.21900000000011}, {600., 0.21900000000005937`}}]}, {}}}}, {
       PlotLabel -> {
          Text[
           Style["EdgeColoring", 
            RGBColor[0, 0, 1], 20]], 
          Text[
           Style["Vizing", 
            RGBColor[1, 0, 0], 20]]}, AxesLabel -> {
          Text[
           Style["Number of vertices", Italic, 16]], 
          Text[
           Style["Running time", Italic, 16]]}, ImageSize -> 500, AspectRatio -> 
        GoldenRatio^(-1), Axes -> True, AxesOrigin -> {300., 0}, 
        PlotRange -> {{299, 601}, {0, 1.5756000000001626`}}, 
        PlotRangeClipping -> True, 
        PlotRangePadding -> {Automatic, Automatic}}], 
      Graphics3D[
       GraphicsComplex[CompressedData["
1:eJx1XH9c1GXyRyVFNI+zdWWFNliXD+yCe5x5nvkjx19ppV+pTMkoOc+KzIw4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        "], {{{
           EdgeForm[], 
           RGBColor[0, 0, 1], 
           GraphicsGroup[{
             Polygon[CompressedData["
1:eJwtlnus13MYxz+XyKXcb5FLYUxrYzZmYzbGWMayrK2jozo5nJyco6OcnJx0
dHSULGNzGbNF5FYR5ZYU0Z10lG46HB0OXZQyYzOv996fP977vH6f7+/3/X4/
z/N+nufXb1TdrfemEMJ7KKOnYggvs7KEXmxM5eIOuCe8lXUL6gFPYX8zvA3N
RGfqN+w/zP4m+Cj4EXg7/AOahc5CR2b/Rvfag2aj83SN/UM89Bd9hv+Cf4N7
w63cZye8iL3FrMeiZ+E5rEegC7LvtRstZH8POgY+jf2D8M/wcfCj3KcD7g8/
DnfrN9G/1Tt0Rz/3XLgr+n36wytY96GT4eWse9FJcGf0/fvBm1kPoL46W/QZ
FZMO+E90DtyX507nuV1wH/gxeBd8NjwD/hU+EZ4G/wSfn32m39F/7E1G7fAp
7LfBnfBK7r1Ke+gi9l8Jjsvl8Ei+8xZ8M3wP/BF8DVwNvwNfBY+G58PXwXcn
++BGuAb+AL4NroM/hYfDDfDn8DD4Pvgz+Ba4Fv4Yvhq+E14AXwrfAb8B3wAv
Cs7fFfAo9t+GB8K3w6/BQ2CZcQl8YbYPdZ5L4Er2X4dHwOPhL+Fx8EPwt/AJ
2XH+Eb4YHs7+XHgAXAG/Cl8Gj4DfhK+Eq+B58D+sf0Tf5/DsPH6vuCfnXc+q
Y7+Jz1/DjcX/+k5TqQvle3x2jr6Dq+CVwbmpgRvZXwuPgSfC6+DR8AR4Nbwh
+h1Oh9tZ96Mz4H+53ow2Fh+8WHylGNWg4+U9ro8p+dLZhqj+5Nvk+CtuW1nH
lhztY32gPFfv1IRORXuT31fvvTt5/QodTD77en1OjqFyeoh1EvomOC7Nqjm0
P/m8a+ADrA+W8+rejcWrivtQdHRwngarNygOyT5cCK9nvQu9C69J9pW8ui7Z
w/LYlmRvf1i8VVX6g7xerbpHm5KvyX/tyev7quVk78kbS5O9Js99kewfeXJZ
cj3p2upkz8i3qp9hqJfilexn1Vp3sj9XBNdGrbyJtid7+5PgXE4O7iGKXYvq
vjz7puDeq77wTLAHtkXnXnlXb20N7kXqxW0lnuoXTwb7R73yadQH/Z1cIxvK
mSuCe+YL0Z/Fim8l6qmzo7HB/VO5byjxXIbqUW80O7o/KF9zo2tffpsX3SuU
U8VsULl/B3vjku+hHvd8cJ/sTO4ny+EdrPWlz+xM7i1L4S7W+5PfqzbbS/Lh
kug6kv9XRcdCcZgT3fd6qBai+9th8kN0rckPz0X3BM29xdHn1BnXwi3JtfBS
dM/RTByZ/R3VgzZUm6rxa7P9Ka+2lr6tnjw4u9aU68rs95cfqrPrTnWxMXlO
qd/OLPNI8+767LzIo81lhmr+PpHtAc2Diux4Km4zyuzQLGsrM0XzZVB2T1Bd
zCpzRHOupczTDnhidtzUvyZln13zekKZ45rvU8vcVF9tyO5FmkH12bUvX00r
80hzdmh2HpW76WXeaaZPKf8l9F9gV/IM1Rz5H+OfMmM=
              "]], 
             Polygon[CompressedData["
1:eJw1l3ccUFUVx+97140KIi4cgLhbakPTLGe5cKA5EpSlhAbkAlELcKCIo9wT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              "]], 
             Polygon[CompressedData["
1:eJw1lVlsUFUQhu+5R3wQJCBGwKgo+gZEgcgSXKLigxoRZAv7YgstLS2lbAJF
9p24RKPggwTCJsjqA4uAQEHZKQUqCrRQWihGdogiUb8/Mz58mTn/uffcc+bM
zH1mcP77eWmSJBlQC9aFJDmLsAM/H7uW8RDs6zFJXoNXYT1zw9DewX8b3oLN
aP3QXsB/HlrACrThaF3wO8N7sA1tPtoC/PkwD2rQHsc+AdX4c5hvjF+A7Y3t
BT1hJ3M5aJ3w3432/S1oh9AOp7avTOxBGAztmW8HbWGNz2n/r8DLsA5tMefb
i74Kvz/2m2DnKIbOaF1gJcxkPJ13psFUqEDrm9o5m0MzWI72KPYxqMSfxXwD
/KPYEtiENhR7BJ5Efwouoc1N7exPQ1OPxzy0Jvj7sQfgu8TO9DMsYo+7U/te
H+xCxlewv8M+tNHYGqjN+3XgLNo0xg/hD8C2xraCltHOPRttFv5MmOF7P49W
CbvxR2IrtDb8BN8mto7iVpfn63k8ZjB+GH86dgp2Mkzy7xei9cPvC32irXub
fVfChWDfv4h2C78CyoPF+7zHZy7+HJjtOTIeLRc/B4bBYbRnsc/BFc8xxfIu
69TA5WA5p7mBzLXBfzFaLHSehthGvgfFQ3d4h3eqoSrY93VXKpZu+F2j5fUP
aH+h3YPj+EXYP2FEajnbA7pHq6d/VWj4JzEf4f+jvA12L2fQpjI+xPgctjy1
fNc6qkfd6UDdH/SHvcyNSs3PU51BcWK1qlrohd8bNsA15TgUB1tDOTKOZ27A
ePwJqiG45Hnz/9rVMFFnUd5rf3BMd4R2W3ns93ATrvt6B9HGYq/Bb3AmtRip
D/yaWi7p/gt0NtgFk9HGKP+UQ3AKjqOVwvf4WV4/tXjmQfgFbQrjB6LlnOrx
C7TPodxrR33la/xFcNnPm42WBUOi7VN9Rvn0Ff6XUAWT0AqVu7ojKFV80PIV
52g5p3NfVQ3CrmB5vcfrXfXzGf6ncCGxWlANfoz/CZyDbcHicwB/DHZrsJxU
bXVF6war/YzjeHdstPiUof3Bs5tgI7wZLT4Xea4qtT0Uet2qz7yhfFFfg41w
33PuhJ/zb6jPM494nanH1fO+q/zLQcuFH73vnoZM5RhshVXB7lQ9PRe7Mlif
Uc0XwUTPa92f9tox2p7UBz9Aewm/Q7Q+rf62x/vuCu+t6nF5nkNZaNmw3Wtn
NO+MinZXOs9Svl2W2n8oG7uE8U1pcCpYHJU3a4L9H9T7M7CrGd+AE1AabF3V
5/JgvVb/jUHYZYzTaDlX5jkbtKbHRf8h/RO1hx3BakI96UPs9mA5pJopUuzh
KFxHL4FjMDJa/7jr/aMksdq7k1pP0XxBtFos8fjpv9ADvyes9bpTbmdCRrT8
+g/vyiJB
              "]]}]}, {
           EdgeForm[], 
           RGBColor[1, 0, 0], 
           GraphicsGroup[{
             Polygon[CompressedData["
1:eJwtlWuIVlUUhs/ZZxWKoRiJYhgO1kxTTk7a2JQ1poyNjY2NMzrjTJk23W/a
/X6/37ybpmlapmmapmlaphRFQRREQRRFQRREQRSEYozY8/KeH+vbz36/dfbZ
e+211qnomdc2N2VZtgsrsK/42YFwb55lxzO+io1CP5HxJrQx8EnwJuwseDZa
v9x8vZ7BRsMTIsvewucO5qtYcxk8DV4BL4anwhWMW7A6/FeiL4EvQT8vrN8G
t2O9mfcwNvzeeWjHMb6CnYGeMXajjdQ+8XmZ+azcWlbqlejr0HuYd2IFdjr6
cPQ1yef4gz3MhJ+FBzAux6rxOcR8MnYKfGzy+jXwEbT5cCXcl3EpdqriyLgI
q4Irwvucg28rdjjznpfzroXoF6Mthi8q3/EEdg52Pj6PM9ZhE+Fmxr8zn2UD
/tN4tgvtGmwQdib6IvliE+AB4f1PZ34/dprWRZ/POB67AH5OsdYcfppxLNYA
r2b9F3m2LfedDynvfQ96G/p1zDfCl5YxXgu/hD4D7sCO4luLXQb3KZ9dj88q
fGYyXwevTL6HNfCKcp/3YCdj9fjfyViFnQ0vLXx+xWgZvAD/KXALdjDzXYzj
vG+i31rG8Z/M9zU+OS6Kyfc8+zD8EPaI8rTUv0V/B78HmP9Q+D/57YPfQL8B
/hJ+O3mPyukRih3P/oi+G/1R5t/AO5Pj/Wnh/L8d3lI4xy6HP4G3lrn9Gbwt
+awfF97/LbnPMBwbx/q70TegX8v8Q3gu483YgcKj7mcn/HpyLuyFNybX4g54
PXxV7rzvn7vWtqO/hn4l84/gzWVNXY0NVB7gsxV9bZm32wrXzhVwTXL8zsXn
c/TtzO9SjYXfpTX+RT8AL4APqd5z38FP8Lvoj+l+4P3J+Tg0nEvKlyVYk+6Q
9QeHc0Z5Xsu4Kzkmhwv7ad0TwrmnvNuMvrqs/U2F19O6s8Lv0n6qwj1NZ/8L
nw/g5+FR4Tgrt4cmP6u8HR3OgRuZD06uO/W3unD8dR+/s8776M/A++H20v9P
eF9ynfXmzmHV78/oe5Jr/Tf4veT6+wXeCz+pWoe74BfKfK0pY673DSu5f7hO
1SP/K5z3qpF+4X6r+h0Yri/V5ojwneoej5Z1pP5zTLgnq/dWh3NDOVMTzivl
3pTwPlQX3eFzKW5Dwj1Ace4Mn0VxaA3Xhe56crguVF/Tw2fXGQeF+4B6wrDw
3alGvmZvM+D74BTuk6r13rJPKo5HCvde9YGRyXFRTCqTe5R6SN9wT9Z35yD+
3fBCeFK4lvWNK8K9Wt+j6uS7U5+sU09K7off8WwH/KBqMpnVPxvD+X83ekNy
31A/6RP+lqnf1yefRT22Nlyb6ie/smYn/BTcEb538exw7WifXeG80veoJRx7
veOLwnvTexuT12lUvw3ns3KmOTl/LkRvCn/TFc854VpU7TSH+57O1ZIcnyb5
J38HJ8GtybWmemwI9y71tDHh3qMaqA/3EPWunvDaeqY9XO/6jk0M9zr1iqnh
WlbP/B/71vP3
              "]], 
             Polygon[CompressedData["
1:eJxFmHdsntUVh9/3fi8hISaEEBIyHJyQOHaW7Qxn2HES4yxGyYAEQlpopFaq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              "]], 
             Polygon[CompressedData["
1:eJw1lWdwVkUUhm/uLi0YElr8gRoSWiiCMECQXgSkQ0Ia0kQQkBkRG0r5QVNU
SADpoPTem4CUGZo6FoY2wA9FBpVBcQQdYWSA4PPOWX48s+99z/3227t7ztn0
YWOzX4+jKBoOpSCNh2MuisYmRNFG9DOQCy0gC7r6KJpA7Ah6ELo9uh3Mhv54
zaApvEBsPF4xOkYnwCPm7YmXh9cKWkJ3/Ml4h9AD0G3QreFjuMP7d6EYfZT4
v+g94Tfd4EWYRGx3bLo+uh5MhJ14nfFqoWvCezAXrxSeBwe98TbjnWDeNHR1
GCeP5y0wGL2c+Cb0AsYK/CYJykM2sf14/dEt0c/DdPgCL0dx6AtT8dbgNdD6
oC4Mx1vGnMudzTOf+FL0AcY84rne5p1B7HP8FZCLXkT8M/Q6xkbEG8KzMJLY
Kvw1UIBeQnwlOl/nAJ3CvB8Q24a/HV5Gr8Dfiv4d/oCP8L7Eu+FsLOQ3BZAP
M4mtx3sOXRldCUbDAt5dGM61iPh89NrY1pWKVxVehV0hd7p4O5f3wzqr6jzQ
DvIhG6821ArfOApvA7oJurG3/38N72Bs68pCN4cPYR5eWbwy3s65D14OXl3I
DHOMwVvMGpc4iysnFjnb24rEUyBZ+0+sQGuGLmEvtD+J4az6oT9Fl4MMOIn3
Jt4WdDr8yfNf8EnI7ZvobYxfMWbg1YC39R08H3L2TdrfAyHXlBv3qccHkBO+
TWv+j+d70BfvMN5A1vWSt9rRf113dn4zwx79hj4NZ5ztueriB7QP360amIN2
cNxZLbyBtyn0gVtwG2aF/9M3XYVrzvJTNfAz+jv43lnN78D7Fp0U8muo8hj9
hPI3ttpKxCsPQ6Ay3g68V5TH6ErK39jyNAmvAgxTbfG831lOqAb2of9x1heK
Qk/6G704tpopYZ8eQR6xtaobKEQvja1WVPutVL/Qwtt3p4Qa0/kvRCfDTzxf
cVbL+3j+MZxlB/U/aAtvESsTesUg1Te6dGx7oV7YCTrCu8QK1cOgWzg/7e0p
Z7mhebaGfFJ91iCeAene9lG9ZBexFHRFGBH6h3pSIpTzlpvqW0+jn4Jq3tZ0
lt+dc9a/VY9nwl5VUU17y3/1mZ3O/kN9anU4m36MT0KqRm/7qDOqrR7rbZ3q
KZd497Kznq5efVH9JrZvz8SrA++EM9A8qd56QEHoH7ojSuAh9MD7hfFXZ71L
/VF5pzWpj2ZCHW95oz3TObSB1t5qcQBeL+gJQ7zdIyUJ1qM092z8h4zfOMtX
nY3W+rXuGWf5pd6qfrbb2R2keQZ7u/uKQp0od7Kgubd78zDvHnHWa9S7VN+N
Q95MwdurPhrb3ajeeYccvQu9Qn7p3uij+8nb+7pTlH9N0c1gWoLVUXXiad7O
WXfVBWf7/fhOPI/+H5qC72o=
              "]]}]}, {}, {}, {}}, {{
           
           Line[{403, 1, 76, 77, 78, 7, 94, 95, 96, 13, 112, 113, 114, 19, 
            130, 131, 132, 25, 148, 149, 150, 31, 478, 479, 480, 32, 481, 482,
             483, 33, 484, 485, 486, 34, 487, 488, 489, 35, 490, 491, 492, 36,
             162, 161, 160, 30, 144, 143, 142, 24, 126, 125, 124, 18, 108, 
            107, 106, 12, 90, 89, 88, 6, 429, 428, 427, 5, 423, 422, 421, 4, 
            417, 416, 415, 3, 411, 410, 409, 2, 405, 404, 403}]}, {
           
           Line[{503, 37, 241, 242, 243, 43, 259, 260, 261, 49, 277, 278, 279,
             55, 295, 296, 297, 61, 313, 314, 315, 67, 578, 579, 580, 68, 581,
             582, 583, 69, 584, 585, 586, 70, 587, 588, 589, 71, 590, 591, 
            592, 72, 327, 326, 325, 66, 309, 308, 307, 60, 291, 290, 289, 54, 
            273, 272, 271, 48, 255, 254, 253, 42, 529, 528, 527, 41, 523, 522,
             521, 40, 517, 516, 515, 39, 511, 510, 509, 38, 505, 504, 
            503}]}, {
           
           Line[{403, 163, 808, 809, 406, 718, 615, 835, 836, 433, 736, 626, 
            859, 860, 448, 757, 636, 880, 881, 463, 781, 645, 898, 899, 478}],
            
           
           Line[{409, 603, 811, 812, 814, 412, 181, 838, 839, 436, 742, 628, 
            862, 863, 451, 763, 638, 883, 884, 466, 787, 647, 901, 902, 481}],
            
           
           Line[{415, 606, 817, 818, 820, 418, 617, 841, 842, 844, 439, 199, 
            865, 866, 454, 769, 640, 886, 887, 469, 793, 649, 904, 905, 484}],
            
           
           Line[{421, 609, 823, 824, 826, 424, 620, 847, 848, 850, 442, 630, 
            868, 869, 871, 457, 217, 889, 890, 472, 799, 651, 907, 908, 487}],
            
           
           Line[{427, 612, 829, 830, 832, 430, 623, 853, 854, 856, 445, 633, 
            874, 875, 877, 460, 642, 892, 893, 895, 475, 235, 910, 911, 490}],
            
           
           Line[{480, 499, 786, 785, 783, 465, 496, 762, 761, 759, 450, 494, 
            741, 740, 738, 435, 493, 723, 722, 720, 408, 165, 705, 704, 405}],
            
           
           Line[{483, 500, 792, 791, 789, 468, 497, 768, 767, 765, 453, 495, 
            747, 746, 744, 438, 183, 726, 725, 414, 816, 605, 708, 707, 411}],
            
           
           Line[{486, 501, 798, 797, 795, 471, 498, 774, 773, 771, 456, 201, 
            750, 749, 441, 846, 619, 729, 728, 420, 822, 608, 711, 710, 417}],
            
           
           Line[{489, 502, 804, 803, 801, 474, 219, 777, 776, 459, 873, 632, 
            753, 752, 444, 852, 622, 732, 731, 426, 828, 611, 714, 713, 423}],
            
           
           Line[{492, 237, 807, 806, 477, 897, 644, 780, 779, 462, 879, 635, 
            756, 755, 447, 858, 625, 735, 734, 432, 834, 614, 717, 716, 429}],
            
           
           Line[{503, 328, 1018, 1019, 506, 928, 665, 1045, 1046, 533, 946, 
            676, 1069, 1070, 548, 967, 686, 1090, 1091, 563, 991, 695, 1108, 
            1109, 578}], 
           
           Line[{509, 653, 1021, 1022, 1024, 512, 346, 1048, 1049, 536, 952, 
            678, 1072, 1073, 551, 973, 688, 1093, 1094, 566, 997, 697, 1111, 
            1112, 581}], 
           
           Line[{515, 656, 1027, 1028, 1030, 518, 667, 1051, 1052, 1054, 539, 
            364, 1075, 1076, 554, 979, 690, 1096, 1097, 569, 1003, 699, 1114, 
            1115, 584}], 
           
           Line[{521, 659, 1033, 1034, 1036, 524, 670, 1057, 1058, 1060, 542, 
            680, 1078, 1079, 1081, 557, 382, 1099, 1100, 572, 1009, 701, 1117,
             1118, 587}], 
           
           Line[{527, 662, 1039, 1040, 1042, 530, 673, 1063, 1064, 1066, 545, 
            683, 1084, 1085, 1087, 560, 692, 1102, 1103, 1105, 575, 400, 1120,
             1121, 590}], 
           
           Line[{580, 599, 996, 995, 993, 565, 596, 972, 971, 969, 550, 594, 
            951, 950, 948, 535, 593, 933, 932, 930, 508, 330, 915, 914, 505}],
            
           
           Line[{583, 600, 1002, 1001, 999, 568, 597, 978, 977, 975, 553, 595,
             957, 956, 954, 538, 348, 936, 935, 514, 1026, 655, 918, 917, 
            511}], 
           
           Line[{586, 601, 1008, 1007, 1005, 571, 598, 984, 983, 981, 556, 
            366, 960, 959, 541, 1056, 669, 939, 938, 520, 1032, 658, 921, 920,
             517}], 
           
           Line[{589, 602, 1014, 1013, 1011, 574, 384, 987, 986, 559, 1083, 
            682, 963, 962, 544, 1062, 672, 942, 941, 526, 1038, 661, 924, 923,
             523}], 
           
           Line[{592, 402, 1017, 1016, 577, 1107, 694, 990, 989, 562, 1089, 
            685, 966, 965, 547, 1068, 675, 945, 944, 532, 1044, 664, 927, 926,
             529}], 
           
           Line[{404, 703, 164, 810, 407, 719, 721, 616, 837, 434, 737, 739, 
            627, 861, 449, 758, 760, 637, 882, 464, 782, 784, 646, 900, 479}],
            
           
           Line[{410, 706, 604, 813, 815, 413, 724, 182, 840, 437, 743, 745, 
            629, 864, 452, 764, 766, 639, 885, 467, 788, 790, 648, 903, 482}],
            
           
           Line[{416, 709, 607, 819, 821, 419, 727, 618, 843, 845, 440, 748, 
            200, 867, 455, 770, 772, 641, 888, 470, 794, 796, 650, 906, 485}],
            
           
           Line[{422, 712, 610, 825, 827, 425, 730, 621, 849, 851, 443, 751, 
            631, 870, 872, 458, 775, 218, 891, 473, 800, 802, 652, 909, 488}],
            
           
           Line[{428, 715, 613, 831, 833, 431, 733, 624, 855, 857, 446, 754, 
            634, 876, 878, 461, 778, 643, 894, 896, 476, 805, 236, 912, 491}],
            
           
           Line[{504, 913, 329, 1020, 507, 929, 931, 666, 1047, 534, 947, 949,
             677, 1071, 549, 968, 970, 687, 1092, 564, 992, 994, 696, 1110, 
            579}], 
           
           Line[{510, 916, 654, 1023, 1025, 513, 934, 347, 1050, 537, 953, 
            955, 679, 1074, 552, 974, 976, 689, 1095, 567, 998, 1000, 698, 
            1113, 582}], 
           
           Line[{516, 919, 657, 1029, 1031, 519, 937, 668, 1053, 1055, 540, 
            958, 365, 1077, 555, 980, 982, 691, 1098, 570, 1004, 1006, 700, 
            1116, 585}], 
           
           Line[{522, 922, 660, 1035, 1037, 525, 940, 671, 1059, 1061, 543, 
            961, 681, 1080, 1082, 558, 985, 383, 1101, 573, 1010, 1012, 702, 
            1119, 588}], 
           
           Line[{528, 925, 663, 1041, 1043, 531, 943, 674, 1065, 1067, 546, 
            964, 684, 1086, 1088, 561, 988, 693, 1104, 1106, 576, 1015, 401, 
            1122, 591}]}, {
           
           Line[{78, 809, 810, 165, 75, 814, 815, 816, 168, 81, 820, 821, 822,
             171, 84, 826, 827, 828, 174, 87, 832, 833, 834, 177, 90}], 
           
           Line[{88, 716, 715, 175, 829, 85, 713, 712, 172, 823, 82, 710, 709,
             169, 817, 79, 707, 706, 166, 811, 73, 704, 703, 163, 76}], 
           
           Line[{96, 836, 837, 180, 723, 93, 839, 840, 183, 99, 844, 845, 846,
             186, 102, 850, 851, 852, 189, 105, 856, 857, 858, 192, 108}], 
           
           Line[{106, 734, 733, 190, 853, 103, 731, 730, 187, 847, 100, 728, 
            727, 184, 841, 97, 725, 724, 181, 91, 720, 719, 718, 178, 94}], 
           
           Line[{114, 860, 861, 195, 741, 111, 863, 864, 198, 747, 117, 866, 
            867, 201, 120, 871, 872, 873, 204, 123, 877, 878, 879, 207, 126}],
            
           
           Line[{124, 755, 754, 205, 874, 121, 752, 751, 202, 868, 118, 749, 
            748, 199, 115, 744, 743, 742, 196, 109, 738, 737, 736, 193, 112}],
            
           
           Line[{132, 881, 882, 210, 762, 129, 884, 885, 213, 768, 135, 887, 
            888, 216, 774, 138, 890, 891, 219, 141, 895, 896, 897, 222, 144}],
            
           
           Line[{142, 779, 778, 220, 892, 139, 776, 775, 217, 136, 771, 770, 
            769, 214, 133, 765, 764, 763, 211, 127, 759, 758, 757, 208, 130}],
            
           
           Line[{150, 899, 900, 225, 786, 147, 902, 903, 228, 792, 153, 905, 
            906, 231, 798, 156, 908, 909, 234, 804, 159, 911, 912, 237, 162}],
            
           
           Line[{160, 806, 805, 235, 157, 801, 800, 799, 232, 154, 795, 794, 
            793, 229, 151, 789, 788, 787, 226, 145, 783, 782, 781, 223, 148}],
            
           
           Line[{243, 1019, 1020, 330, 240, 1024, 1025, 1026, 333, 246, 1030, 
            1031, 1032, 336, 249, 1036, 1037, 1038, 339, 252, 1042, 1043, 
            1044, 342, 255}], 
           
           Line[{253, 926, 925, 340, 1039, 250, 923, 922, 337, 1033, 247, 920,
             919, 334, 1027, 244, 917, 916, 331, 1021, 238, 914, 913, 328, 
            241}], 
           
           Line[{261, 1046, 1047, 345, 933, 258, 1049, 1050, 348, 264, 1054, 
            1055, 1056, 351, 267, 1060, 1061, 1062, 354, 270, 1066, 1067, 
            1068, 357, 273}], 
           
           Line[{271, 944, 943, 355, 1063, 268, 941, 940, 352, 1057, 265, 938,
             937, 349, 1051, 262, 935, 934, 346, 256, 930, 929, 928, 343, 
            259}], 
           
           Line[{279, 1070, 1071, 360, 951, 276, 1073, 1074, 363, 957, 282, 
            1076, 1077, 366, 285, 1081, 1082, 1083, 369, 288, 1087, 1088, 
            1089, 372, 291}], 
           
           Line[{289, 965, 964, 370, 1084, 286, 962, 961, 367, 1078, 283, 959,
             958, 364, 280, 954, 953, 952, 361, 274, 948, 947, 946, 358, 
            277}], 
           
           Line[{297, 1091, 1092, 375, 972, 294, 1094, 1095, 378, 978, 300, 
            1097, 1098, 381, 984, 303, 1100, 1101, 384, 306, 1105, 1106, 1107,
             387, 309}], 
           
           Line[{307, 989, 988, 385, 1102, 304, 986, 985, 382, 301, 981, 980, 
            979, 379, 298, 975, 974, 973, 376, 292, 969, 968, 967, 373, 295}],
            
           
           Line[{315, 1109, 1110, 390, 996, 312, 1112, 1113, 393, 1002, 318, 
            1115, 1116, 396, 1008, 321, 1118, 1119, 399, 1014, 324, 1121, 
            1122, 402, 327}], 
           
           Line[{325, 1016, 1015, 400, 322, 1011, 1010, 1009, 397, 319, 1005, 
            1004, 1003, 394, 316, 999, 998, 997, 391, 310, 993, 992, 991, 388,
             313}], 
           
           Line[{77, 808, 164, 705, 74, 812, 813, 167, 708, 80, 818, 819, 170,
             711, 83, 824, 825, 173, 714, 86, 830, 831, 176, 717, 89}], 
           
           Line[{95, 835, 179, 721, 722, 92, 838, 182, 726, 98, 842, 843, 185,
             729, 101, 848, 849, 188, 732, 104, 854, 855, 191, 735, 107}], 
           
           Line[{113, 859, 194, 739, 740, 110, 862, 197, 745, 746, 116, 865, 
            200, 750, 119, 869, 870, 203, 753, 122, 875, 876, 206, 756, 125}],
            
           
           Line[{131, 880, 209, 760, 761, 128, 883, 212, 766, 767, 134, 886, 
            215, 772, 773, 137, 889, 218, 777, 140, 893, 894, 221, 780, 143}],
            
           
           Line[{149, 898, 224, 784, 785, 146, 901, 227, 790, 791, 152, 904, 
            230, 796, 797, 155, 907, 233, 802, 803, 158, 910, 236, 807, 161}],
            
           
           Line[{242, 1018, 329, 915, 239, 1022, 1023, 332, 918, 245, 1028, 
            1029, 335, 921, 248, 1034, 1035, 338, 924, 251, 1040, 1041, 341, 
            927, 254}], 
           
           Line[{260, 1045, 344, 931, 932, 257, 1048, 347, 936, 263, 1052, 
            1053, 350, 939, 266, 1058, 1059, 353, 942, 269, 1064, 1065, 356, 
            945, 272}], 
           
           Line[{278, 1069, 359, 949, 950, 275, 1072, 362, 955, 956, 281, 
            1075, 365, 960, 284, 1079, 1080, 368, 963, 287, 1085, 1086, 371, 
            966, 290}], 
           
           Line[{296, 1090, 374, 970, 971, 293, 1093, 377, 976, 977, 299, 
            1096, 380, 982, 983, 302, 1099, 383, 987, 305, 1103, 1104, 386, 
            990, 308}], 
           
           Line[{314, 1108, 389, 994, 995, 311, 1111, 392, 1000, 1001, 317, 
            1114, 395, 1006, 1007, 320, 1117, 398, 1012, 1013, 323, 1120, 401,
             1017, 326}]}, {}, {}, {}, {}, {}}}, 
        VertexNormals -> CompressedData["
1:eJxsvHc819/7P25VklUpUbKz9xbPyygrM3vvkWSEkJnKCJWWkTJaUhQKUc+T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         "]], {
       Axes -> True, BoxRatios -> {1, 1}, 
        Method -> {"RotationControl" -> "Globe"}, 
        PlotRange -> {{200., 300.}, {5., 15.}, {0.06200000000039241, 
         0.34400000000011577`}}, PlotRangePadding -> {
          Scaled[0.02], 
          Scaled[0.02], 
          Scaled[0.02]}}]}]],
   DynamicModuleValues:>{}],
  Setting[#, {0}]& ]], "Output",
 CellChangeTimes->{3.402243861616375*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Animation", "Section",
 CellChangeTimes->{{3.400149425984375*^9, 3.40014943590625*^9}},
 CellTags->"animation"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MyHighlightEdges", "[", 
   RowBox[{"G_Graph", ",", "colourlist_List", ",", "highlight___List", ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], ":=", "\[IndentingNewLine]",
   
  RowBox[{"ShowGraph", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Highlight", "[", "\[IndentingNewLine]", 
     RowBox[{"G", ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Edges", "[", "G", "]"}], "\[LeftDoubleBracket]", "highlight",
         "\[RightDoubleBracket]"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"HighlightedEdgeStyle", "\[Rule]", "Thick"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Edges", "[", "G", "]"}], "\[LeftDoubleBracket]", "#", 
          "\[RightDoubleBracket]"}], ",", 
         RowBox[{"EdgeColor", "\[Rule]", 
          RowBox[{"Hue", "[", 
           RowBox[{
            RowBox[{
            "colourlist", "\[LeftDoubleBracket]", "#", 
             "\[RightDoubleBracket]"}], "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", 
               RowBox[{"Degrees", "[", "G", "]"}], "]"}], "+", "1"}], ")"}]}],
            "]"}]}]}], "}"}], "&"}], ",", 
      RowBox[{"Range", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Position", "[", 
          RowBox[{"colourlist", ",", 
           RowBox[{"_", "?", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"#", "\[Equal]", "0"}], "&"}], ")"}]}], ",", "1", ",", 
           "1"}], "]"}], "\[LeftDoubleBracket]", 
         RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "-", "1"}], 
       "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"VertexNumber", "->", "True"}], ",", "\[IndentingNewLine]", 
    "opts"}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.4001494381875*^9, 3.40014943890625*^9}, {
  3.40014986059375*^9, 3.400149860984375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"AnimationVizing", "::", "usage"}], "=", 
   "\"\<Vizing[G_]: Animate Vizing's algorithm.\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"AnimationVizing", "[", "G_Graph", "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "VG", ",", "MG", ",", "edgesG", ",", "delta", ",", "colourlist", ",", 
      "h", ",", "i", ",", "v", ",", "ulist", ",", "utemp", ",", "elist", ",", 
      "etemp", ",", "hlist", ",", "htemp", ",", "count", ",", 
      "\[IndentingNewLine]", "hend", ",", "forward", ",", "sszm", ",", "c1", 
      ",", "c2", ",", "G2", ",", "ua", ",", "ub", ",", "cc", ",", "uc", ",", 
      "vertices2", ",", "edges2", ",", 
      StyleBox["plots",
       FontColor->RGBColor[1, 0.5, 0]]}], "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"VG", "=", 
      RowBox[{"V", "[", "G", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"MG", "=", 
      RowBox[{"M", "[", "G", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"edgesG", "=", 
      RowBox[{"Edges", "[", "G", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"delta", "=", 
      RowBox[{"Max", "[", 
       RowBox[{"Degrees", "[", "G", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"colourlist", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"MG", "+", "1"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"h", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"delta", "+", "1"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "VG"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      StyleBox[
       RowBox[{
        StyleBox["plo",
         FontColor->RGBColor[1, 0.501961, 0]], 
        StyleBox["ts",
         FontColor->RGBColor[1, 0.439216, 0.168627]]}]], 
      StyleBox["=",
       FontColor->RGBColor[1, 0.439216, 0.168627]], 
      StyleBox[
       RowBox[{"{", "}"}],
       FontColor->RGBColor[1, 0.439216, 0.168627]]}], 
     StyleBox[";",
      FontColor->RGBColor[1, 0.501961, 0]], "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "\[LessEqual]", "MG"}], ",", 
       RowBox[{"i", "++"}], ",", 
       StyleBox["\[IndentingNewLine]",
        FontColor->GrayLevel[0.500008]], 
       RowBox[{
        RowBox[{"v", "=", 
         RowBox[{"edgesG", "\[LeftDoubleBracket]", 
          RowBox[{"i", ",", "1"}], "\[RightDoubleBracket]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"ulist", "=", 
         RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"utemp", "=", 
         RowBox[{"edgesG", "\[LeftDoubleBracket]", 
          RowBox[{"i", ",", "2"}], "\[RightDoubleBracket]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"elist", "=", 
         RowBox[{"{", "i", "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"etemp", "=", "0"}], ";", "\[IndentingNewLine]", 
        RowBox[{"hlist", "=", 
         RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"htemp", "=", "0"}], ";", "\[IndentingNewLine]", 
        RowBox[{"count", "=", "1"}], ";", "\[IndentingNewLine]", 
        StyleBox[
         RowBox[{"AppendTo", "[", 
          RowBox[{"plots", ",", 
           RowBox[{"MyHighlightEdges", "[", 
            RowBox[{"G", ",", "colourlist", ",", "elist"}], "]"}]}], "]"}],
         FontColor->RGBColor[1, 0.501961, 0]], 
        StyleBox[";",
         FontColor->RGBColor[1, 0.501961, 0]], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"While", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Intersection", "[", 
              RowBox[{
               RowBox[{
               "h", "\[LeftDoubleBracket]", "v", "\[RightDoubleBracket]"}], 
               ",", 
               RowBox[{
               "h", "\[LeftDoubleBracket]", "utemp", 
                "\[RightDoubleBracket]"}]}], "]"}], "\[Equal]", 
             RowBox[{"{", "}"}]}], ")"}], "&&", 
           RowBox[{"(", 
            RowBox[{"!", 
             RowBox[{"MemberQ", "[", 
              RowBox[{"ulist", ",", "utemp"}], "]"}]}], ")"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"AppendTo", "[", 
            RowBox[{"ulist", ",", "utemp"}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"htemp", "=", 
            RowBox[{"h", "\[LeftDoubleBracket]", 
             RowBox[{"utemp", ",", "1"}], "\[RightDoubleBracket]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"hlist", ",", "htemp"}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"etemp", "=", 
            RowBox[{
             RowBox[{"Select", "[", 
              RowBox[{
               RowBox[{"Range", "[", 
                RowBox[{"i", "-", "1"}], "]"}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                  "colourlist", "\[LeftDoubleBracket]", "#", 
                   "\[RightDoubleBracket]"}], "\[Equal]", "htemp"}], "&&", 
                 RowBox[{"MemberQ", "[", 
                  RowBox[{
                   RowBox[{
                   "edgesG", "\[LeftDoubleBracket]", "#", 
                    "\[RightDoubleBracket]"}], ",", "v"}], "]"}]}], "&"}]}], 
              "]"}], "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}],
            ";", "\[IndentingNewLine]", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"elist", ",", "etemp"}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"utemp", "=", 
            RowBox[{
             RowBox[{"Select", "[", 
              RowBox[{
               RowBox[{
               "edgesG", "\[LeftDoubleBracket]", "etemp", 
                "\[RightDoubleBracket]"}], ",", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"#", "\[NotEqual]", "v"}], ")"}], "&"}]}], "]"}], 
             "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"count", "++"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
        ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"If", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"Intersection", "[", 
            RowBox[{
             RowBox[{
             "h", "\[LeftDoubleBracket]", "v", "\[RightDoubleBracket]"}], ",",
              
             RowBox[{
             "h", "\[LeftDoubleBracket]", "utemp", 
              "\[RightDoubleBracket]"}]}], "]"}], "\[NotEqual]", 
           RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{
           StyleBox[
            RowBox[{"AppendTo", "[", 
             RowBox[{"plots", ",", 
              RowBox[{"MyHighlightEdges", "[", 
               RowBox[{"G", ",", "colourlist", ",", "elist"}], "]"}]}], "]"}],
            
            FontColor->RGBColor[1, 0.501961, 0]], 
           StyleBox[";",
            FontColor->RGBColor[1, 0.501961, 0]], "\[IndentingNewLine]", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"ulist", ",", "utemp"}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"hend", "=", 
            RowBox[{
             RowBox[{"Intersection", "[", 
              RowBox[{
               RowBox[{
               "h", "\[LeftDoubleBracket]", "v", "\[RightDoubleBracket]"}], 
               ",", 
               RowBox[{
               "h", "\[LeftDoubleBracket]", "utemp", 
                "\[RightDoubleBracket]"}]}], "]"}], "\[LeftDoubleBracket]", 
             "1", "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"hlist", ",", "hend"}], "]"}], ";", "\[IndentingNewLine]",
            
           RowBox[{"forward", "=", 
            RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
           "\[IndentingNewLine]", 
           RowBox[{"Map", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"colourlist", "\[LeftDoubleBracket]", 
                  RowBox[{
                  "elist", "\[LeftDoubleBracket]", "#", 
                   "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}], "=", 
                 
                 RowBox[{
                 "hlist", "\[LeftDoubleBracket]", "#", 
                  "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"h", "\[LeftDoubleBracket]", 
                  RowBox[{
                  "ulist", "\[LeftDoubleBracket]", "#", 
                   "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}], "=", 
                 
                 RowBox[{"Union", "[", 
                  RowBox[{
                   RowBox[{"DeleteCases", "[", 
                    RowBox[{
                    RowBox[{"h", "\[LeftDoubleBracket]", 
                    RowBox[{
                    "ulist", "\[LeftDoubleBracket]", "#", 
                    "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}], ",",
                     
                    RowBox[{
                    "hlist", "\[LeftDoubleBracket]", "#", 
                    "\[RightDoubleBracket]"}]}], "]"}], ",", "forward"}], 
                  "]"}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"forward", "=", 
                 RowBox[{"{", 
                  RowBox[{
                  "hlist", "\[LeftDoubleBracket]", "#", 
                   "\[RightDoubleBracket]"}], "}"}]}]}], ")"}], "&"}], ",", 
             RowBox[{"Range", "[", "count", "]"}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
            "h", "\[LeftDoubleBracket]", "v", "\[RightDoubleBracket]"}], "=", 
            
            RowBox[{"DeleteCases", "[", 
             RowBox[{
              RowBox[{
              "h", "\[LeftDoubleBracket]", "v", "\[RightDoubleBracket]"}], 
              ",", "hend"}], "]"}]}], ";", "\[IndentingNewLine]", 
           StyleBox[
            RowBox[{"AppendTo", "[", 
             RowBox[{"plots", ",", 
              RowBox[{"MyHighlightEdges", "[", 
               RowBox[{"G", ",", "colourlist", ",", "elist"}], "]"}]}], "]"}],
            
            FontColor->RGBColor[1, 0.501961, 0]], 
           StyleBox[";",
            FontColor->RGBColor[1, 0.501961, 0]]}], "\[IndentingNewLine]", 
          "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
          RowBox[{
           StyleBox[
            RowBox[{"AppendTo", "[", 
             RowBox[{"plots", ",", 
              RowBox[{"MyHighlightEdges", "[", 
               RowBox[{"G", ",", "colourlist", ",", "elist"}], "]"}]}], "]"}],
            
            FontColor->RGBColor[1, 0.501961, 0]], 
           StyleBox[";",
            FontColor->RGBColor[1, 0.501961, 0]], "\[IndentingNewLine]", 
           RowBox[{"sszm", "=", 
            RowBox[{"Select", "[", 
             RowBox[{
              RowBox[{"Range", "[", "MG", "]"}], ",", 
              RowBox[{
               RowBox[{"MemberQ", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"c1", "=", 
                    RowBox[{"h", "\[LeftDoubleBracket]", 
                    RowBox[{"v", ",", "1"}], "\[RightDoubleBracket]"}]}], ",",
                    " ", 
                   RowBox[{"c2", "=", 
                    RowBox[{"h", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"ulist", "\[LeftDoubleBracket]", 
                    RowBox[{"-", "1"}], "\[RightDoubleBracket]"}], ",", "1"}],
                     "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
                 RowBox[{
                 "colourlist", "\[LeftDoubleBracket]", "#", 
                  "\[RightDoubleBracket]"}]}], "]"}], "&"}]}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{
            SubscriptBox["G", "2"], "=", 
            RowBox[{"ChangeEdges", "[", 
             RowBox[{"G", ",", 
              RowBox[{"Extract", "[", 
               RowBox[{"edgesG", ",", 
                RowBox[{"Partition", "[", 
                 RowBox[{"sszm", ",", "1"}], "]"}]}], "]"}]}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"ua", "=", 
            RowBox[{"ulist", "\[LeftDoubleBracket]", 
             RowBox[{"-", "1"}], "\[RightDoubleBracket]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"ub", "=", 
            RowBox[{"ulist", "\[LeftDoubleBracket]", 
             RowBox[{
              RowBox[{
               RowBox[{"Position", "[", 
                RowBox[{"ulist", ",", "utemp"}], "]"}], 
               "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "-", "1"}],
              "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"cc", "=", 
            RowBox[{"ConnectedComponents", "[", 
             SubscriptBox["G", "2"], "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"uc", "=", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"MemberQ", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{"cc", ",", 
                   RowBox[{
                    RowBox[{"MemberQ", "[", 
                    RowBox[{"#", ",", "v"}], "]"}], "&"}]}], "]"}], 
                 "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
                "ua"}], "]"}], ",", "ub", ",", "ua"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"edges2", "=", 
            RowBox[{"Select", "[", 
             RowBox[{"sszm", ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Intersection", "[", "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{
                   "edgesG", "\[LeftDoubleBracket]", "#", 
                    "\[RightDoubleBracket]"}], ",", "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"Select", "[", 
                    RowBox[{"cc", ",", 
                    RowBox[{
                    RowBox[{"MemberQ", "[", 
                    RowBox[{"#", ",", "uc"}], "]"}], "&"}]}], "]"}], 
                    "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
                  "\[IndentingNewLine]", 
                  StyleBox[
                   RowBox[{"(*", 
                    RowBox[{"Function", "[", 
                    RowBox[{"x", ",", 
                    RowBox[{"MemberQ", "[", 
                    RowBox[{"x", ",", "uc"}], "]"}]}], "]"}], "*)"}],
                   FontColor->GrayLevel[0.500008]], "\[IndentingNewLine]", 
                  "]"}], "\[NotEqual]", 
                 RowBox[{"{", "}"}]}], ")"}], "&"}]}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           StyleBox[
            RowBox[{"AppendTo", "[", 
             RowBox[{"plots", ",", 
              RowBox[{"MyHighlightEdges", "[", 
               RowBox[{"G", ",", "colourlist", ",", "edges2"}], "]"}]}], 
             "]"}],
            FontColor->RGBColor[1, 0.501961, 0]], 
           StyleBox[";",
            FontColor->RGBColor[1, 0.501961, 0]], "\[IndentingNewLine]", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"colourlist", "=", 
                RowBox[{"ReplacePart", "[", 
                 RowBox[{"colourlist", ",", 
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    "colourlist", "\[LeftDoubleBracket]", "#", 
                    "\[RightDoubleBracket]"}], "\[Equal]", "c1"}], ",", "c2", 
                    ",", "c1"}], "]"}], ",", "#"}], "]"}]}], ")"}], "&"}], 
             ",", "edges2"}], "]"}], ";", "\[IndentingNewLine]", 
           StyleBox[
            RowBox[{"AppendTo", "[", 
             RowBox[{"plots", ",", 
              RowBox[{"MyHighlightEdges", "[", 
               RowBox[{"G", ",", "colourlist", ",", "edges2"}], "]"}]}], 
             "]"}],
            FontColor->RGBColor[1, 0.501961, 0]], 
           StyleBox[";",
            FontColor->RGBColor[1, 0.501961, 0]], "\[IndentingNewLine]", 
           RowBox[{"vertices2", "=", 
            RowBox[{
             RowBox[{"Select", "[", 
              RowBox[{
               RowBox[{"ConnectedComponents", "[", 
                SubscriptBox["G", "2"], "]"}], ",", 
               RowBox[{
                RowBox[{"MemberQ", "[", 
                 RowBox[{"#", ",", "uc"}], "]"}], "&"}]}], "]"}], 
             "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                "h", "\[LeftDoubleBracket]", "#", "\[RightDoubleBracket]"}], 
                "=", 
                RowBox[{"Replace", "[", 
                 RowBox[{
                  RowBox[{
                  "h", "\[LeftDoubleBracket]", "#", "\[RightDoubleBracket]"}],
                   ",", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"c1", "\[Rule]", "c2"}], ",", 
                    RowBox[{"c2", "\[Rule]", "c1"}]}], "}"}], ",", "1"}], 
                 "]"}]}], ")"}], "&"}], ",", "vertices2"}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"i", "--"}]}]}], "\[IndentingNewLine]", "]"}], ";"}]}], 
      "\[IndentingNewLine]", "]"}], ";", 
     StyleBox["\[IndentingNewLine]",
      FontColor->RGBColor[1, 0.501961, 0]], "\[IndentingNewLine]", 
     StyleBox[
      RowBox[{"AppendTo", "[", 
       RowBox[{"plots", ",", 
        RowBox[{"MyHighlightEdges", "[", 
         RowBox[{"G", ",", "colourlist"}], "]"}]}], "]"}],
      FontColor->GrayLevel[0]], 
     StyleBox[";",
      FontColor->GrayLevel[0]], 
     StyleBox["\[IndentingNewLine]",
      FontColor->GrayLevel[0]], 
     StyleBox[
      RowBox[{"ListAnimate", "[", "plots", "]"}],
      FontColor->GrayLevel[0]]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.400149473359375*^9, 3.40014948803125*^9}, {
  3.400149541453125*^9, 3.40014954209375*^9}, {3.40014957384375*^9, 
  3.4001495939375*^9}, {3.40014975809375*^9, 3.4001497920625*^9}, {
  3.400655252890625*^9, 3.400655253125*^9}, {3.400655285296875*^9, 
  3.400655293234375*^9}, {3.40065534459375*^9, 3.400655406890625*^9}, {
  3.400655504703125*^9, 3.400655525625*^9}, {3.400655685390625*^9, 
  3.40065568875*^9}, {3.4008483874375*^9, 3.40084838884375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"graph2", "=", 
   RowBox[{"FromUnorderedPairs", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "8"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "9"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "11"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "12"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "8"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "9"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "11"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "12"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "8"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "9"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "11"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "12"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", "5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", "9"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", "11"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", "12"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"5", ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"5", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"5", ",", "8"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"5", ",", "9"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"5", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"5", ",", "11"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"5", ",", "12"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"6", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"6", ",", "9"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"6", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"6", ",", "11"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"6", ",", "12"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"7", ",", "8"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"7", ",", "9"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"7", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"7", ",", "11"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"7", ",", "12"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"8", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"8", ",", "11"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"9", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"9", ",", "12"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"10", ",", "11"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"11", ",", "12"}], "}"}]}], "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.400149695734375*^9, 3.400149702796875*^9}, {
  3.400149923765625*^9, 3.40014992659375*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p8", "=", 
  RowBox[{"AnimationVizing", "[", "graph2", "]"}]}]], "Input",
 CellChangeTimes->{{3.400149817*^9, 3.400149818703125*^9}, {
  3.4001499318125*^9, 3.40014993428125*^9}, {3.400657011046875*^9, 
  3.400657011421875*^9}, {3.40065870590625*^9, 3.40065870621875*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`i$$ = 118, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`i$$], 1, ""}, 1, 176, 1}}, Typeset`size$$ = 
    Automatic, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`i$34254$$ = 0}, 
    PaneBox[
     PanelBox[
      DynamicWrapperBox[
       TagBox[GridBox[{
          {
           ItemBox[
            ItemBox[
             StyleBox[
              TagBox[GridBox[{
                 {"\<\"\\!\\(\\*TagBox[\\\"\\\\\\\"\\\\\\\"\\\", HoldForm]\\)\
\"\>", 
                  AnimatorBox[Dynamic[$CellContext`i$$], {1, 176, 1},
                   AnimationRate->Automatic,
                   
                   AppearanceElements->{
                    "ProgressSlider", "PlayPauseButton", 
                    "FasterSlowerButtons", "DirectionButton"},
                   AutoAction->False,
                   ContinuousAction->True,
                   DisplayAllSteps->True,
                   PausedTime->4.546875]}
                },
                ColumnsEqual->False,
                
                GridBoxAlignment->{
                 "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
                
                GridBoxItemSize->{
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
                RowsEqual->False],
               "Grid"], "ManipulateLabel",
              StripOnInput->False],
             Alignment->{Automatic, Inherited},
             StripOnInput->False],
            Background->None,
            StripOnInput->False]},
          {
           ItemBox[
            TagBox[
             StyleBox[
              PaneBox[Cell[BoxData[
                TagBox[
                 PaneSelectorBox[{1->
                  GraphicsBox[{{
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 2->
                  GraphicsBox[{{
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 3->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 4->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 5->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 6->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 7->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]},
                     
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 8->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 9->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 10->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]},
                     
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 11->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 12->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 13->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 14->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 15->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 16->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 17->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 18->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 19->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 20->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 21->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 22->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 23->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 24->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 25->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 26->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 27->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 28->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 29->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 30->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 31->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 32->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 33->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 34->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 35->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 36->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 37->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 38->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 39->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 40->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 41->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]},
                     
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 42->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]},
                     
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 43->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", Scaled[{-0.02, -0.02}, 
                    {0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 44->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 45->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 46->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 47->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 48->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]},
                     
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 49->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 50->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 51->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 52->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 53->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.75, 0.9330127018922193}]}, 
                    
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 54->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 55->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 56->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]},
                     
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 57->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 58->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 59->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.75, 0.9330127018922193}]}, 
                    
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 60->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 61->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 62->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 63->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 64->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]},
                     
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 65->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]},
                     
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 66->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]},
                     
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 67->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 68->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 69->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 70->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 71->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 72->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 73->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 74->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]},
                     
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 75->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 76->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]},
                     
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 77->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 78->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 79->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 80->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 81->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]},
                     
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 82->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 83->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 84->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]},
                     
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 85->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 86->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 87->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 88->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]},
                     
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 89->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 90->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.02], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 91->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", Scaled[{-0.02, -0.02}, 
                    {0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 92->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 93->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.02], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 94->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 95->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 96->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.02], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 97->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]},
                     
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 98->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 99->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.02], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 100->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 101->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 102->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.02], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 103->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 104->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 105->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 106->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 107->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 108->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 109->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 110->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 111->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 112->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]},
                     
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 113->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 114->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 115->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 116->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 117->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 118->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 119->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.75, 0.9330127018922193}]}, 
                    
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 120->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 121->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 122->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 123->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 124->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]},
                     
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 125->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 126->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.02], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 127->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 128->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.75, 0.9330127018922193}]}, 
                    
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 129->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.02], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 130->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 131->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 132->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.02], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 133->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 134->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", Scaled[{-0.02, -0.02}, 
                    {0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 135->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.02], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 136->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 137->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.02], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", Scaled[{-0.02, -0.02}, 
                    {0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 138->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 139->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 140->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", Scaled[{-0.02, -0.02}, 
                    {0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 141->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.02], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 142->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.02], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.02], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 143->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 144->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 145->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.02], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 146->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 147->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 148->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.02], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 149->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 150->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 151->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.02], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 152->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 153->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 154->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.02], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 155->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 156->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.02], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 157->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.02], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.02], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 158->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 159->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 160->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.02], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 161->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]},
                     
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 162->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 163->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.02], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 164->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 165->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 166->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.02], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.75, 0.9330127018922193}]}, 
                    
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 167->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 168->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 169->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.02], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 170->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 171->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 172->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.02], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.005], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", Scaled[{-0.02, -0.02}, 
                    {0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 173->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 174->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], Thickness[0.02], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 175->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.005], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.005], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.005], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.005], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.02], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]},
                     
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}], 176->
                  GraphicsBox[{{
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.02], 
                    LineBox[{{0.9330127018922194, 0.75}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 1.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778076,
                     0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.06698729810778059,
                     0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.02], 
                    LineBox[{{0.75, 0.9330127018922193}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.2500000000000001, 
                    0.9330127018922194}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.06698729810778076, 
                    0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.24999999999999978`, 
                    0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.02], 
                    LineBox[{{0.5, 1.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.02], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.06698729810778076, 0.7500000000000002}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.02], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.02], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.02], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.02], 
                    LineBox[{{0.2500000000000001, 0.9330127018922194}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.06698729810778059, 0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 6], 0.8333333333333334]], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.02], 
                    LineBox[{{0.06698729810778076, 0.7500000000000002}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[7, 12], 0.5833333333333334]], Thickness[0.02], 
                    LineBox[{{0., 0.5}, {0.06698729810778059, 
                    0.2500000000000001}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.02], 
                    LineBox[{{0., 0.5}, {0.5, 0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[11, 12], 0.9166666666666666]], Thickness[0.02], 
                    LineBox[{{0., 0.5}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.02], 
                    LineBox[{{0., 0.5}, {0.9330127018922192, 
                    0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 12], 0.08333333333333333]], Thickness[0.02], 
                    LineBox[{{0., 0.5}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[3, 4], 0.75]], Thickness[0.02], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.24999999999999978`, 0.06698729810778081}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.02], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {0.5, 
                    0.}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[2, 3], 0.6666666666666666]], Thickness[0.02], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[1], Thickness[0.02], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.02], 
                    LineBox[{{0.06698729810778059, 0.2500000000000001}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 6], 0.16666666666666666`]], Thickness[0.02], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.7499999999999997, 0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 4], 0.25]], Thickness[0.02], 
                    LineBox[{{0.24999999999999978`, 0.06698729810778081}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.02], 
                    LineBox[{{0.5, 0.}, {0.7499999999999997, 
                    0.06698729810778048}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 2], 0.5]], Thickness[0.02], 
                    LineBox[{{0.5, 0.}, {1., 0.5}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[1, 3], 0.3333333333333333]], Thickness[0.02], 
                    LineBox[{{0.7499999999999997, 0.06698729810778048}, {
                    0.9330127018922192, 0.24999999999999978`}}], 
                    {GrayLevel[0]}}, 
                    {Hue[
                    NCache[
                    Rational[5, 12], 0.4166666666666667]], Thickness[0.02], 
                    LineBox[{{0.9330127018922192, 0.24999999999999978`}, {1., 
                    0.5}}], 
                    {GrayLevel[0]}}}, {
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922194, 0.75}]}, 
                    {GrayLevel[0], 
                    InsetBox["1", 
                    Scaled[{-0.02, -0.02}, {0.9330127018922194, 0.75}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.75, 0.9330127018922193}]}, 
                    {GrayLevel[0], 
                    InsetBox["2", 
                    Scaled[{-0.02, -0.02}, {0.75, 0.9330127018922193}], \
{1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 1.}]}, 
                    {GrayLevel[0], 
                    InsetBox["3", 
                    Scaled[{-0.02, -0.02}, {0.5, 1.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.2500000000000001, 0.9330127018922194}]}, 
                    {GrayLevel[0], 
                    InsetBox["4", 
                    Scaled[{-0.02, -0.02}, \
{0.2500000000000001, 0.9330127018922194}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778076, 0.7500000000000002}]}, 
                    {GrayLevel[0], 
                    InsetBox["5", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778076, 0.7500000000000002}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["6", 
                    Scaled[{-0.02, -0.02}, {0., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.06698729810778059, 0.2500000000000001}]}, 
                    {GrayLevel[0], 
                    InsetBox["7", 
                    Scaled[{-0.02, -0.02}, \
{0.06698729810778059, 0.2500000000000001}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.24999999999999978`, 0.06698729810778081}]}, 
                    {GrayLevel[0], 
                    InsetBox["8", 
                    Scaled[{-0.02, -0.02}, \
{0.24999999999999978`, 0.06698729810778081}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{0.5, 0.}]}, 
                    {GrayLevel[0], 
                    InsetBox["9", 
                    Scaled[{-0.02, -0.02}, {0.5, 0.}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.7499999999999997, 0.06698729810778048}]}, 
                    {GrayLevel[0], 
                    InsetBox["10", 
                    Scaled[{-0.02, -0.02}, \
{0.7499999999999997, 0.06698729810778048}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], 
                    PointBox[{0.9330127018922192, 0.24999999999999978`}]}, 
                    {GrayLevel[0], 
                    InsetBox["11", 
                    Scaled[{-0.02, -0.02}, \
{0.9330127018922192, 0.24999999999999978`}], {1, 0}]}, 
                    {GrayLevel[0]}}, 
                    {GrayLevel[0], 
                    {PointSize[0.025], PointBox[{1., 0.5}]}, 
                    {GrayLevel[0], 
                    InsetBox["12", 
                    Scaled[{-0.02, -0.02}, {1., 0.5}], {1, 0}]}, 
                    {GrayLevel[0]}}}},
                   AlignmentPoint->Center,
                   AspectRatio->Automatic,
                   Axes->False,
                   AxesLabel->None,
                   AxesOrigin->Automatic,
                   AxesStyle->{},
                   Background->None,
                   BaseStyle->{},
                   BaselinePosition->Automatic,
                   ColorOutput->Automatic,
                   ContentSelectable->Automatic,
                   DisplayFunction:>$DisplayFunction,
                   Epilog->{},
                   FormatType:>TraditionalForm,
                   Frame->False,
                   FrameLabel->None,
                   FrameStyle->{},
                   FrameTicks->Automatic,
                   FrameTicksStyle->{},
                   GridLines->None,
                   GridLinesStyle->{},
                   ImageMargins->0.,
                   ImagePadding->All,
                   ImageSize->Automatic,
                   LabelStyle->{},
                   Method->Automatic,
                   PlotLabel->None,
                   PlotRange->{{-0.05, 1.05}, {-0.05, 1.05}},
                   PlotRangeClipping->False,
                   PlotRangePadding->Automatic,
                   PlotRegion->Automatic,
                   PreserveImageOptions->Automatic,
                   Prolog->{},
                   RotateLabel->True,
                   Ticks->Automatic,
                   TicksStyle->{}]}, Dynamic[$CellContext`i$$],
                  Alignment->Automatic,
                  ImageSize->All],
                 Identity,
                 Editable->True,
                 Selectable->True]],
                ScriptLevel->0,
                Background->GrayLevel[1]],
               ImageMargins->10],
              Deployed->False,
              StripOnInput->False,
              GraphicsBoxOptions->{PreserveImageOptions->True},
              Graphics3DBoxOptions->{PreserveImageOptions->True}],
             Identity,
             Editable->False,
             Selectable->False],
            Alignment->{Left, Center},
            Background->GrayLevel[1],
            Frame->1,
            FrameStyle->GrayLevel[0, 0.2],
            StripOnInput->False]}
         },
         ColumnsEqual->False,
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Top}}, 
           "RowsIndexed" -> {}},
         GridBoxDividers->{
          "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}},
            "RowsIndexed" -> {}},
         GridBoxItemSize->{
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.7], {
              Offset[0.5599999999999999]}, 
             Offset[0.7]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.4], {
              Offset[0.8]}, 
             Offset[0.4]}, "RowsIndexed" -> {}},
         RowsEqual->False],
        "Grid"], If[
        CurrentValue["SelectionOver"], 
        Manipulate`Dump`ReadControllerState[
         Map[Manipulate`Dump`updateOneVar[#, 
           CurrentValue["PreviousFormatTime"], 
           CurrentValue["CurrentFormatTime"]]& , {
           
           Manipulate`Dump`controllerLink[{$CellContext`i$$, \
$CellContext`i$34254$$}, "X1", 
            If["DefaultAbsolute", True, "JB1"], False, {1, 176, 1}, 176, 
            1.]}], 
         CurrentValue[{
          "ControllerData", {
           "Gamepad", "Joystick", "Multi-Axis Controller"}}], {}]],
       ImageSizeCache->{390., {206.5, 211.5}}],
      DefaultBaseStyle->{},
      FrameMargins->{{5, 5}, {5, 5}}],
     BaselinePosition->Automatic,
     ImageMargins->0],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.400684863671875*^9, 3.400684866109375*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Edge colouring as Integer Programming Problem", "Section",
 CellChangeTimes->{{3.40014693553125*^9, 3.400146956296875*^9}},
 CellTags->"IP"],

Cell[CellGroupData[{

Cell["with Delta+1 colours", "Subsection",
 CellChangeTimes->{{3.4008475916875*^9, 3.40084759903125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Delta", "[", "g_Graph", "]"}], ":=", 
  RowBox[{"Max", "[", 
   RowBox[{"Degrees", "[", "g", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.40014698915625*^9, 3.40014698965625*^9}, {
  3.40014737459375*^9, 3.400147378328125*^9}, {3.4001482710625*^9, 
  3.400148271171875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"VariablesEC", "[", "g_Graph", "]"}], ":=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Array", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"#1", ",", "#2"}]], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"M", "[", "g", "]"}], ",", 
       RowBox[{
        RowBox[{"Delta", "[", "g", "]"}], "+", "1"}]}], "}"}]}], "]"}], "]"}],
   " "}]], "Input",
 CellChangeTimes->{{3.400147422265625*^9, 3.400147427984375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Conditions1", "[", "g_Graph", "]"}], ":=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"And", "[", 
      RowBox[{
       RowBox[{"Element", "[", 
        RowBox[{"#", ",", "Integers"}], "]"}], ",", 
       RowBox[{"0", "\[LessEqual]", "#", "\[LessEqual]", "1"}]}], "]"}], 
     "&"}], ",", 
    RowBox[{"VariablesEC", "[", "g", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{3.40014744203125*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Conditions2", "[", "g_Graph", "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Sum", "[", 
      RowBox[{
       SubscriptBox["x", 
        RowBox[{"e", ",", "c"}]], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{
          RowBox[{"Delta", "[", "g", "]"}], "+", "1"}]}], "}"}]}], "]"}], 
     "\[Equal]", "1"}], ",", 
    RowBox[{"{", 
     RowBox[{"e", ",", 
      RowBox[{"M", "[", "g", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{3.400147457578125*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Conditions3", "[", "g_Graph", "]"}], ":=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Total", "[", "#", "]"}], "\[LessEqual]", "1"}], "&"}], ",", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           SubscriptBox["x", 
            RowBox[{"#", ",", "c"}]], "&"}], ",", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Position", "[", 
            RowBox[{
             RowBox[{"Edges", "[", "g", "]"}], ",", 
             RowBox[{"_", "?", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"MemberQ", "[", 
                 RowBox[{"#", ",", "v"}], "]"}], "&"}], ")"}]}]}], "]"}], 
           "]"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"c", ",", 
          RowBox[{
           RowBox[{"Delta", "[", "g", "]"}], "+", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"v", ",", 
          RowBox[{"V", "[", "g", "]"}]}], "}"}]}], "]"}], ",", "1"}], "]"}]}],
    "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Conditions", "[", "g_Graph", "]"}], ":=", 
    RowBox[{"Union", "[", 
     RowBox[{
      RowBox[{"Conditions1", "[", "g", "]"}], ",", 
      RowBox[{"Conditions2", "[", "g", "]"}], ",", 
      RowBox[{"Conditions3", "[", "g", "]"}]}], "]"}]}], ";"}], 
  " "}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"f", "[", "g_Graph", "]"}], ":=", "1"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Cons", "[", "g_Graph", "]"}], ":=", 
  RowBox[{"Apply", "[", 
   RowBox[{"And", ",", 
    RowBox[{"Conditions", "[", "g", "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.400147505328125*^9, 3.400147508375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Solution", "[", "g_Graph", "]"}], ":=", 
   RowBox[{"NMinimize", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f", "[", "g", "]"}], ",", 
       RowBox[{"Cons", "[", "g", "]"}]}], "}"}], ",", 
     RowBox[{"VariablesEC", "[", "g", "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.40014752628125*^9, 3.400147551671875*^9}, 
   3.4008454666875*^9, 3.400845556953125*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EdgeColoringWithIP", "[", "g_Graph", "]"}], ":=", 
  RowBox[{"Cases", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Solution", "[", "g", "]"}], "\[LeftDoubleBracket]", "2", 
     "\[RightDoubleBracket]"}], ",", 
    RowBox[{
     RowBox[{"x", ":", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"e_", ",", "c_"}]], "\[Rule]", "1"}], ")"}]}], 
     "\[RuleDelayed]", "c"}]}], "]"}]}]], "Input",
 CellChangeTimes->{3.400147551359375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tests", "Subsection",
 CellChangeTimes->{{3.400849304375*^9, 3.4008493055*^9}},
 CellTags->"IPtests"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Timing", "[", 
   RowBox[{"EdgeColoringWithIP", "[", 
    RowBox[{"RandomGraph", "[", 
     RowBox[{"10", ",", "0.4"}], "]"}], "]"}], "]"}], "\[LeftDoubleBracket]", 
  "1", "\[RightDoubleBracket]"}]], "Input",
 CellChangeTimes->{{3.400147570515625*^9, 3.400147614546875*^9}, {
  3.40066009575*^9, 3.40066010071875*^9}}],

Cell[BoxData["0.04700000000000032`"], "Output",
 CellChangeTimes->{
  3.400669907421875*^9, 3.4006848668125*^9, 3.400761474984375*^9, 
   3.400844256578125*^9, 3.400845473453125*^9, {3.4008455365625*^9, 
   3.400845562984375*^9}, 3.40084761490625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Timing", "[", 
   RowBox[{"EdgeColoringWithIP", "[", 
    RowBox[{"RandomGraph", "[", 
     RowBox[{"15", ",", "0.4"}], "]"}], "]"}], "]"}], "\[LeftDoubleBracket]", 
  "1", "\[RightDoubleBracket]"}]], "Input",
 CellChangeTimes->{{3.400147620625*^9, 3.40014762640625*^9}, {
  3.400660105421875*^9, 3.40066011521875*^9}}],

Cell[BoxData["2.077999999999999`"], "Output",
 CellChangeTimes->{3.400669911234375*^9, 3.400684867109375*^9, 
  3.40076147675*^9, 3.400844260328125*^9, 3.40084761834375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Timing", "[", 
   RowBox[{"EdgeColoringWithIP", "[", 
    RowBox[{"RandomGraph", "[", 
     RowBox[{"20", ",", "0.4"}], "]"}], "]"}], "]"}], "\[LeftDoubleBracket]", 
  "1", "\[RightDoubleBracket]"}]], "Input",
 CellChangeTimes->{{3.40014763021875*^9, 3.400147631109375*^9}, {
  3.400660109171875*^9, 3.400660119453125*^9}}],

Cell[BoxData["11.985`"], "Output",
 CellChangeTimes->{3.400684887359375*^9, 3.400761493890625*^9, 
  3.400847631046875*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["with Delta colours", "Subsection",
 CellChangeTimes->{{3.40084710928125*^9, 3.400847115875*^9}, {
  3.40084760746875*^9, 3.400847608015625*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Delta", "[", "g_Graph", "]"}], ":=", 
  RowBox[{"Max", "[", 
   RowBox[{"Degrees", "[", "g", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.40014698915625*^9, 3.40014698965625*^9}, {
  3.40014737459375*^9, 3.400147378328125*^9}, {3.4001482710625*^9, 
  3.400148271171875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"VariablesECD", "[", "g_Graph", "]"}], ":=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Array", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"#1", ",", "#2"}]], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"M", "[", "g", "]"}], ",", 
       RowBox[{"Delta", "[", "g", "]"}]}], "}"}]}], "]"}], "]"}], 
  " "}]], "Input",
 CellChangeTimes->{{3.400147422265625*^9, 3.400147427984375*^9}, {
   3.400844299640625*^9, 3.40084429975*^9}, 3.400847633203125*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Conditions1D", "[", "g_Graph", "]"}], ":=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"And", "[", 
      RowBox[{
       RowBox[{"Element", "[", 
        RowBox[{"#", ",", "Integers"}], "]"}], ",", 
       RowBox[{"0", "\[LessEqual]", "#", "\[LessEqual]", "1"}]}], "]"}], 
     "&"}], ",", 
    RowBox[{"VariablesECD", "[", "g", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.40014744203125*^9, {3.400847638375*^9, 3.40084764184375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Conditions2D", "[", "g_Graph", "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Sum", "[", 
      RowBox[{
       SubscriptBox["x", 
        RowBox[{"e", ",", "c"}]], ",", 
       RowBox[{"{", 
        RowBox[{"c", ",", 
         RowBox[{"Delta", "[", "g", "]"}]}], "}"}]}], "]"}], "\[Equal]", 
     "1"}], ",", 
    RowBox[{"{", 
     RowBox[{"e", ",", 
      RowBox[{"M", "[", "g", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.400147457578125*^9, {3.4008443255*^9, 3.400844325640625*^9}, 
   3.400847644140625*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Conditions3D", "[", "g_Graph", "]"}], ":=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Total", "[", "#", "]"}], "\[LessEqual]", "1"}], "&"}], ",", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           SubscriptBox["x", 
            RowBox[{"#", ",", "c"}]], "&"}], ",", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Position", "[", 
            RowBox[{
             RowBox[{"Edges", "[", "g", "]"}], ",", 
             RowBox[{"_", "?", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"MemberQ", "[", 
                 RowBox[{"#", ",", "v"}], "]"}], "&"}], ")"}]}]}], "]"}], 
           "]"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"c", ",", 
          RowBox[{"Delta", "[", "g", "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"v", ",", 
          RowBox[{"V", "[", "g", "]"}]}], "}"}]}], "]"}], ",", "1"}], "]"}]}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.400844329078125*^9, 3.400844329203125*^9}, 
   3.400847647890625*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ConditionsD", "[", "g_Graph", "]"}], ":=", 
    RowBox[{"Union", "[", 
     RowBox[{
      RowBox[{"Conditions1D", "[", "g", "]"}], ",", 
      RowBox[{"Conditions2D", "[", "g", "]"}], ",", 
      RowBox[{"Conditions3D", "[", "g", "]"}]}], "]"}]}], ";"}], 
  " "}]], "Input",
 CellChangeTimes->{{3.400847653453125*^9, 3.40084765865625*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"f", "[", "g_Graph", "]"}], ":=", "1"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Cons", "[", "g_Graph", "]"}], ":=", 
  RowBox[{"Apply", "[", 
   RowBox[{"And", ",", 
    RowBox[{"ConditionsD", "[", "g", "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.400147505328125*^9, 3.400147508375*^9}, 
   3.40084766475*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SolutionD", "[", "g_Graph", "]"}], ":=", 
   RowBox[{"NMinimize", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f", "[", "g", "]"}], ",", 
       RowBox[{"Cons", "[", "g", "]"}]}], "}"}], ",", 
     RowBox[{"VariablesECD", "[", "g", "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.40014752628125*^9, 3.400147551671875*^9}, {
   3.400847668796875*^9, 3.40084768828125*^9}, 3.401040596796875*^9, 
   3.4010406965*^9, {3.40104104371875*^9, 3.40104105921875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EdgeColoringWithIPD", "[", "g_Graph", "]"}], ":=", 
  RowBox[{"Cases", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"SolutionD", "[", "g", "]"}], "\[LeftDoubleBracket]", "2", 
     "\[RightDoubleBracket]"}], ",", 
    RowBox[{
     RowBox[{"x", ":", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"e_", ",", "c_"}]], "\[Rule]", "1"}], ")"}]}], 
     "\[RuleDelayed]", "c"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.400147551359375*^9, {3.4008476906875*^9, 3.40084769553125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RandomBipartiteGraph", "[", 
   RowBox[{"k_", ",", "l_"}], "]"}], ":=", 
  RowBox[{"FromUnorderedPairs", "[", 
   RowBox[{"RandomSubset", "[", 
    RowBox[{"Edges", "[", 
     RowBox[{"CompleteKPartiteGraph", "[", 
      RowBox[{"k", ",", "l"}], "]"}], "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4008459573125*^9, 3.400846034046875*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rb", "=", 
   RowBox[{"RandomBipartiteGraph", "[", 
    RowBox[{"3", ",", "4"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"EdgeColoringWithIPD", "[", "rb", "]"}], "\[IndentingNewLine]", 
 RowBox[{"ValidEdgeColoringQ", "[", 
  RowBox[{"rb", ",", 
   RowBox[{"EdgeColoringWithIPD", "[", "rb", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.400846037171875*^9, 3.40084605415625*^9}, {
  3.40084715946875*^9, 3.400847188859375*^9}, {3.40084723375*^9, 
  3.400847234984375*^9}, {3.400847702859375*^9, 3.400847719765625*^9}, {
  3.400864175953125*^9, 3.400864176203125*^9}, {3.4010406745*^9, 
  3.4010406748125*^9}, {3.401040806828125*^9, 3.401040812140625*^9}, {
  3.401040979734375*^9, 3.40104098128125*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "2", ",", "1", ",", "2", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{
  3.401040813203125*^9, 3.40104098240625*^9, {3.40104104875*^9, 
   3.40104106321875*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.401040813203125*^9, 3.40104098240625*^9, {3.40104104875*^9, 
   3.401041063234375*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"c3", "=", 
   RowBox[{"CompleteGraph", "[", "3", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"SolutionD", "[", "c3", "]"}], "\[IndentingNewLine]", 
 RowBox[{"ValidEdgeColoringQ", "[", 
  RowBox[{"c3", ",", 
   RowBox[{"EdgeColoringWithIPD", "[", "c3", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4008472429375*^9, 3.400847254859375*^9}, {
   3.400847287171875*^9, 3.400847302515625*^9}, 3.4008477238125*^9, {
   3.401040823265625*^9, 3.401040845421875*^9}, {3.401041095125*^9, 
   3.401041095390625*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"1", ",", "1"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"2", ",", "1"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"2", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"3", ",", "1"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"3", ",", "2"}]], "\[Rule]", "0"}]}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{
  3.40104082621875*^9, 3.40104098328125*^9, {3.40104104965625*^9, 
   3.401041064140625*^9}}],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{
  3.40104082621875*^9, 3.40104098328125*^9, {3.40104104965625*^9, 
   3.40104106415625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"c4", "=", 
   RowBox[{"CompleteGraph", "[", "4", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"SolutionD", "[", "c4", "]"}], "\[IndentingNewLine]", 
 RowBox[{"EdgeColoringWithIPD", "[", "c4", "]"}], "\[IndentingNewLine]", 
 RowBox[{"ValidEdgeColoringQ", "[", 
  RowBox[{"c4", ",", 
   RowBox[{"EdgeColoringWithIPD", "[", "c4", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4008472429375*^9, 3.400847254859375*^9}, {
   3.400847287171875*^9, 3.400847302515625*^9}, 3.4008477238125*^9, {
   3.400864161171875*^9, 3.400864182171875*^9}, {3.40104084690625*^9, 
   3.401040850515625*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"1", ",", "1"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", "1"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"1", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"2", ",", "1"}]], "\[Rule]", "1"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"2", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"2", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"3", ",", "1"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"3", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"3", ",", "3"}]], "\[Rule]", "1"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"4", ",", "1"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"4", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"4", ",", "3"}]], "\[Rule]", "1"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"5", ",", "1"}]], "\[Rule]", "1"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"5", ",", "2"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"5", ",", "3"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"6", ",", "1"}]], "\[Rule]", "0"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"6", ",", "2"}]], "\[Rule]", "1"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"6", ",", "3"}]], "\[Rule]", "0"}]}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{{3.40084730140625*^9, 3.400847303203125*^9}, 
   3.400847724125*^9, {3.400864155234375*^9, 3.400864183265625*^9}, 
   3.401040850796875*^9, 3.40104098471875*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "1", ",", "3", ",", "3", ",", "1", ",", "2"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.40084730140625*^9, 3.400847303203125*^9}, 
   3.400847724125*^9, {3.400864155234375*^9, 3.400864183265625*^9}, 
   3.401040850796875*^9, 3.401040984734375*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.40084730140625*^9, 3.400847303203125*^9}, 
   3.400847724125*^9, {3.400864155234375*^9, 3.400864183265625*^9}, 
   3.401040850796875*^9, 3.40104098475*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SolutionD2", "[", "g_Graph", "]"}], ":=", 
   RowBox[{"Minimize", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f", "[", "g", "]"}], ",", 
       RowBox[{"Cons", "[", "g", "]"}]}], "}"}], ",", 
     RowBox[{"VariablesECD", "[", "g", "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.40014752628125*^9, 3.400147551671875*^9}, {
   3.400847668796875*^9, 3.40084768828125*^9}, 3.401040596796875*^9, 
   3.4010406965*^9, {3.40104104371875*^9, 3.401041090953125*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SolutionD2", "[", "c3", "]"}]], "Input",
 CellChangeTimes->{3.40104109928125*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Minimize", "::", "\<\"infeas\"\>"}], ":", 
  " ", "\<\"There are no values of \\!\\({x\\_\\(1, 1\\), x\\_\\(1, 2\\), \
x\\_\\(2, 1\\), x\\_\\(2, 2\\), x\\_\\(3, 1\\), x\\_\\(3, 2\\)}\\) for which \
the constraints \\!\\(\\(\\(x\\_\\(1, 1\\) \[Element] Integers\\)\\) && \
\\(\\(0 \[LessEqual] x\\_\\(1, 1\\) \[LessEqual] 1\\)\\) && \\(\\(x\\_\\(1, 2\
\\) \[Element] Integers\\)\\) && \\(\\(0 \[LessEqual] x\\_\\(1, 2\\) \
\[LessEqual] 1\\)\\) && \\(\\(x\\_\\(2, 1\\) \[Element] Integers\\)\\) && \\(\
\\(0 \[LessEqual] x\\_\\(2, 1\\) \[LessEqual] 1\\)\\) && \\(\\(x\\_\\(2, 2\\) \
\[Element] Integers\\)\\) && \\(\\(0 \[LessEqual] x\\_\\(2, 2\\) \[LessEqual] \
1\\)\\) && \\(\\(x\\_\\(3, 1\\) \[Element] Integers\\)\\) && \\(\\(0 \
\[LessEqual] x\\_\\(3, 1\\) \[LessEqual] 1\\)\\) && \\(\\(\[LeftSkeleton] 11 \
\[RightSkeleton]\\)\\)\\) are satisfied and the objective function \\!\\(1\\) \
is real-valued.  \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/Minimize\\\", \
ButtonNote -> \\\"Minimize::infeas\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.401041099953125*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\[Infinity]", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"1", ",", "1"}]], "\[Rule]", "Indeterminate"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", "Indeterminate"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"2", ",", "1"}]], "\[Rule]", "Indeterminate"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"2", ",", "2"}]], "\[Rule]", "Indeterminate"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"3", ",", "1"}]], "\[Rule]", "Indeterminate"}], ",", 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"3", ",", "2"}]], "\[Rule]", "Indeterminate"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.401041099953125*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Edge colouring as Quadratic Programming Problem", "Section",
 CellTags->"QP"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Conditions1QP", "[", "g_Graph", "]"}], ":=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"0", "\[LessEqual]", "#", "\[LessEqual]", "1"}], "&"}], ",", 
    RowBox[{"VariablesEC", "[", "g", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.40014776553125*^9, 3.400147767203125*^9}, {
  3.400147809078125*^9, 3.4001478105625*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ConditionsQP", "[", "g_Graph", "]"}], ":=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"Conditions1QP", "[", "g", "]"}], ",", 
     RowBox[{"Conditions2", "[", "g", "]"}], ",", 
     RowBox[{"Conditions3", "[", "g", "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.40014783396875*^9, 3.400147834171875*^9}, {
  3.4001479301875*^9, 3.400147930390625*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fQP", "[", "g_Graph", "]"}], ":=", 
  RowBox[{"Total", "[", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", 
       RowBox[{"(", 
        RowBox[{"1", "-", "#"}], ")"}]}], "&"}], ",", 
     RowBox[{"VariablesEC", "[", "g", "]"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.400147890453125*^9, 3.400147890625*^9}, {
   3.400148597015625*^9, 3.40014859925*^9}, {3.4006700225*^9, 
   3.400670032265625*^9}, 3.4006700653125*^9, {3.400670101390625*^9, 
   3.400670111734375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ConsQP", "[", "g_Graph", "]"}], ":=", 
  RowBox[{"Apply", "[", 
   RowBox[{"And", ",", 
    RowBox[{"ConditionsQP", "[", "g", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.40014699096875*^9, 3.40014699125*^9}, {
  3.400147932578125*^9, 3.40014794678125*^9}, {3.400148633890625*^9, 
  3.40014863409375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SolutionQP", "[", "g_Graph", "]"}], ":=", 
  RowBox[{"NMinimize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"fQP", "[", "g", "]"}], ",", 
      RowBox[{"ConsQP", "[", "g", "]"}]}], "}"}], ",", 
    RowBox[{"VariablesEC", "[", "g", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.400148013328125*^9, 3.40014802921875*^9}, {
  3.400148640625*^9, 3.40014864084375*^9}}],

Cell[CellGroupData[{

Cell["Tests", "Subsection",
 CellChangeTimes->{{3.40084936271875*^9, 3.400849364421875*^9}},
 CellTags->"QPtests"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"SolutionQP", "[", 
   RowBox[{"RandomGraph", "[", 
    RowBox[{"5", ",", "0.4"}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.40014803165625*^9, 3.400148043953125*^9}, {
  3.400148373390625*^9, 3.40014839646875*^9}, {3.400148667921875*^9, 
  3.400148668140625*^9}, {3.400670092703125*^9, 3.40067009309375*^9}, {
  3.400670159734375*^9, 3.40067016109375*^9}, {3.400684922125*^9, 
  3.400684923578125*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.15599999999999856`", ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"1", ",", "1"}]], "\[Rule]", "0.`"}], ",", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"1", ",", "2"}]], "\[Rule]", "1.`"}], ",", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"2", ",", "1"}]], "\[Rule]", "0.`"}], ",", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"2", ",", "2"}]], "\[Rule]", "1.`"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.40067003734375*^9, {3.40067007125*^9, 3.4006701165625*^9}, {
   3.40067017075*^9, 3.400670200796875*^9}, 3.400684909171875*^9, 
   3.40084775390625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"SolutionQP", "[", 
   RowBox[{"RandomGraph", "[", 
    RowBox[{"10", ",", "0.4"}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.40014840103125*^9, 3.400148408203125*^9}, {
  3.400670144265625*^9, 3.400670144515625*^9}}],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.4006701566875*^9, 3.400684942203125*^9, 
  3.40084777134375*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Linear programming", "Subsection",
 CellChangeTimes->{{3.400662367234375*^9, 3.400662372078125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fLP", "[", "g_Graph", "]"}], ":=", "1"}]], "Input",
 CellChangeTimes->{{3.400148600203125*^9, 3.40014861459375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ConsLP", "[", "g_Graph", "]"}], ":=", 
  RowBox[{"Apply", "[", 
   RowBox[{"And", ",", 
    RowBox[{"ConditionsQP", "[", "g", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.40014863646875*^9, 3.400148637*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SolutionLP", "[", "g_Graph", "]"}], ":=", 
  RowBox[{"NMinimize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"fLP", "[", "g", "]"}], ",", 
      RowBox[{"ConsLP", "[", "g", "]"}]}], "}"}], ",", 
    RowBox[{"VariablesEC", "[", "g", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.400148643796875*^9, 3.4001486485625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"SolutionLP", "[", 
   RowBox[{"RandomGraph", "[", 
    RowBox[{"5", ",", "0.4"}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.40014867275*^9, 3.400148673203125*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.014999999999999694`", ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"1", ",", "1"}]], "\[Rule]", "0.`"}], ",", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"1", ",", "2"}]], "\[Rule]", "0.`"}], ",", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"1", ",", "3"}]], "\[Rule]", "0.`"}], ",", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"1", ",", "4"}]], "\[Rule]", "1.`"}], ",", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"1", ",", "5"}]], "\[Rule]", "0.`"}], ",", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"2", ",", "1"}]], "\[Rule]", "0.`"}], ",", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"2", ",", "2"}]], "\[Rule]", "0.`"}], ",", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"2", ",", "3"}]], "\[Rule]", "1.`"}], ",", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"2", ",", "4"}]], "\[Rule]", "0.`"}], ",", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"2", ",", "5"}]], "\[Rule]", "0.`"}], ",", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"3", ",", "1"}]], "\[Rule]", "0.`"}], ",", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"3", ",", "2"}]], "\[Rule]", "1.`"}], ",", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"3", ",", "3"}]], "\[Rule]", "0.`"}], ",", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"3", ",", "4"}]], "\[Rule]", "0.`"}], ",", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"3", ",", "5"}]], "\[Rule]", "0.`"}], ",", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"4", ",", "1"}]], "\[Rule]", "1.`"}], ",", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"4", ",", "2"}]], "\[Rule]", "0.`"}], ",", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"4", ",", "3"}]], "\[Rule]", "0.`"}], ",", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"4", ",", "4"}]], "\[Rule]", "0.`"}], ",", 
       RowBox[{
        SubscriptBox["x", 
         RowBox[{"4", ",", "5"}]], "\[Rule]", "0.`"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.40067333803125*^9, {3.400847796984375*^9, 3.400847805671875*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"SolutionLP", "[", 
   RowBox[{"RandomGraph", "[", 
    RowBox[{"20", ",", "0.4"}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.400673354*^9, 3.40067335578125*^9}, {
  3.400847815828125*^9, 3.400847816328125*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Validating", "Section",
 CellChangeTimes->{{3.400147685484375*^9, 3.400147693484375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ValidEdgeColoringQ", "[", 
   RowBox[{"G_Graph", ",", " ", "colourlist_List", ",", 
    RowBox[{"colournumber_:", "Infinity"}]}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"And", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Length", "[", "colourlist", "]"}], "\[Equal]", 
     RowBox[{"M", "[", "G", "]"}]}], ",", 
    RowBox[{"And", "@@", 
     RowBox[{"Append", "[", 
      RowBox[{
       RowBox[{"Map", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"e", "=", 
             RowBox[{"colourlist", "\[LeftDoubleBracket]", 
              RowBox[{"Select", "[", 
               RowBox[{
                RowBox[{"Range", "[", 
                 RowBox[{"M", "[", "G", "]"}], "]"}], ",", 
                RowBox[{"Function", "[", 
                 RowBox[{"x", ",", 
                  RowBox[{"MemberQ", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Edges", "[", "G", "]"}], "\[LeftDoubleBracket]", 
                    "x", "\[RightDoubleBracket]"}], ",", "#"}], "]"}]}], 
                 "]"}]}], "]"}], "\[RightDoubleBracket]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Length", "[", "e", "]"}], "\[Equal]", 
             RowBox[{"Length", "[", 
              RowBox[{"Union", "[", "e", "]"}], "]"}]}]}], ")"}], "&"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Range", "[", 
          RowBox[{"V", "[", "G", "]"}], "]"}]}], "]"}], ",", 
       RowBox[{
        RowBox[{"Length", "[", 
         RowBox[{"Union", "[", "colourlist", "]"}], "]"}], "\[LessEqual]", 
        "colournumber"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.401040729578125*^9, 3.4010407616875*^9}, {
  3.4010409543125*^9, 3.40104097321875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"GoodEdgeAlgorithmQ", "[", 
   RowBox[{"Algorithm_", ",", "n_Integer", ",", "v_Integer", ",", "p_Real"}], 
   "]"}], ":=", 
  RowBox[{"And", "@@", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"ValidEdgeColoringQ", "[", 
      RowBox[{
       RowBox[{"r", "=", 
        RowBox[{"RandomGraph", "[", 
         RowBox[{"v", ",", "p"}], "]"}]}], ",", 
       RowBox[{"Algorithm", "[", "r", "]"}]}], "]"}], ",", 
     RowBox[{"{", "n", "}"}]}], "]"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"GoodEdgeAlgorithmQ", "[", 
   RowBox[{"EdgeColoring", ",", "10", ",", "20", ",", ".6"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4008478511875*^9, 3.400847859375*^9}, {
  3.40084790559375*^9, 3.400847914609375*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3.562`", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{{3.40084786265625*^9, 3.4008478745*^9}, {
  3.4008479105625*^9, 3.400847918515625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"GoodEdgeAlgorithmQ", "[", 
   RowBox[{"Vizing", ",", "10", ",", "30", ",", ".6"}], "]"}], "]"}]], "Input",\

 CellChangeTimes->{{3.4008479205*^9, 3.400847933171875*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"24.141`", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{{3.400847930703125*^9, 3.400847957828125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"GoodEdgeAlgorithmQ", "[", 
   RowBox[{"EdgeColoringWithIP", ",", "10", ",", "10", ",", ".6"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.40068366578125*^9, 3.40068366796875*^9}, {
  3.400684049640625*^9, 3.400684095921875*^9}, {3.400845582453125*^9, 
  3.400845613171875*^9}, {3.400845737125*^9, 3.400845738125*^9}, {
  3.4008478456875*^9, 3.4008478460625*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3.969`", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{3.400845592078125*^9, 3.400845698859375*^9, 
  3.400845747734375*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{3.400845578984375*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowCellTags->True,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (April 20, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "vizing"->{
  Cell[2989, 90, 134, 2, 85, "Section",
   CellTags->"vizing"]},
 "tests"->{
  Cell[21655, 519, 158, 3, 85, "Section",
   CellTags->"tests"]},
 "animation"->{
  Cell[660275, 11985, 117, 2, 85, "Section",
   CellTags->"animation"]},
 "IP"->{
  Cell[4008029, 82445, 146, 2, 85, "Section",
   CellTags->"IP"]},
 "IPtests"->{
  Cell[4012913, 82607, 107, 2, 50, "Subsection",
   CellTags->"IPtests"]},
 "QP"->{
  Cell[4028930, 83084, 83, 1, 85, "Section",
   CellTags->"QP"]},
 "QPtests"->{
  Cell[4031161, 83151, 114, 2, 50, "Subsection",
   CellTags->"QPtests"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"vizing", 4041262, 83467},
 {"tests", 4041339, 83470},
 {"animation", 4041421, 83473},
 {"IP", 4041503, 83476},
 {"IPtests", 4041584, 83479},
 {"QP", 4041668, 83482},
 {"QPtests", 4041748, 83485}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 230, 6, 83, "Title"],
Cell[823, 31, 152, 2, 49, "Subtitle"],
Cell[978, 35, 318, 7, 101, "Text"],
Cell[1299, 44, 87, 1, 52, "Input"],
Cell[1389, 47, 79, 1, 31, "Input"],
Cell[CellGroupData[{
Cell[1493, 52, 148, 2, 71, "Section"],
Cell[1644, 56, 199, 5, 31, "Input"],
Cell[CellGroupData[{
Cell[1868, 65, 124, 2, 31, "Input"],
Cell[1995, 69, 945, 15, 50, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2989, 90, 134, 2, 85, "Section",
 CellTags->"vizing"],
Cell[3126, 94, 185, 5, 31, "Input"],
Cell[3314, 101, 17080, 387, 1432, "Input"],
Cell[CellGroupData[{
Cell[20419, 492, 125, 2, 31, "Input"],
Cell[20547, 496, 1059, 17, 50, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[21655, 519, 158, 3, 85, "Section",
 CellTags->"tests"],
Cell[21816, 524, 273, 7, 31, "Input"],
Cell[CellGroupData[{
Cell[22114, 535, 281, 3, 36, "Subsection"],
Cell[22398, 540, 918, 19, 92, "Input"],
Cell[23319, 561, 455, 14, 31, "Input"],
Cell[CellGroupData[{
Cell[23799, 579, 575, 16, 31, "Input"],
Cell[24377, 597, 765, 25, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25179, 627, 496, 13, 31, "Input"],
Cell[25678, 642, 766, 25, 30, "Output"]
}, Open  ]],
Cell[26459, 670, 945, 22, 92, "Input"],
Cell[27407, 694, 1810, 48, 92, "Input"],
Cell[CellGroupData[{
Cell[29242, 746, 1753, 38, 172, "Input"],
Cell[30998, 786, 2065, 61, 267, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[33112, 853, 281, 3, 36, "Subsection"],
Cell[33396, 858, 1535, 36, 132, "Input"],
Cell[34934, 896, 721, 20, 31, "Input"],
Cell[CellGroupData[{
Cell[35680, 920, 1196, 30, 52, "Input"],
Cell[36879, 952, 15538, 424, 544, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[52454, 1381, 866, 24, 52, "Input"],
Cell[53323, 1407, 15538, 424, 544, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[68898, 1836, 1095, 28, 52, "Input"],
Cell[69996, 1866, 102780, 1660, 389, 65566, 1048, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[172813, 3531, 299, 7, 31, "Input"],
Cell[173115, 3540, 184007, 3061, 438, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[357171, 6607, 234, 3, 36, "Subsection"],
Cell[357408, 6612, 941, 20, 112, "Input"],
Cell[358352, 6634, 521, 15, 31, "Input"],
Cell[CellGroupData[{
Cell[358898, 6653, 723, 18, 31, "Input"],
Cell[359624, 6673, 964, 25, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[360625, 6703, 675, 18, 31, "Input"],
Cell[361303, 6723, 967, 25, 50, "Output"]
}, Open  ]],
Cell[362285, 6751, 945, 22, 92, "Input"],
Cell[363233, 6775, 1810, 48, 92, "Input"],
Cell[CellGroupData[{
Cell[365068, 6827, 1595, 35, 172, "Input"],
Cell[366666, 6864, 2464, 66, 289, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[369179, 6936, 235, 3, 36, "Subsection"],
Cell[369417, 6941, 1439, 35, 132, "Input"],
Cell[370859, 6978, 720, 20, 31, "Input"],
Cell[CellGroupData[{
Cell[371604, 7002, 1333, 32, 52, "Input"],
Cell[372940, 7036, 3739, 93, 126, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[376716, 7134, 1004, 27, 52, "Input"],
Cell[377723, 7163, 3748, 93, 126, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[381508, 7261, 938, 26, 31, "Input"],
Cell[382449, 7289, 98260, 1603, 421, 66057, 1073, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[480746, 8897, 249, 6, 31, "Input"],
Cell[480998, 8905, 179216, 3073, 470, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[660275, 11985, 117, 2, 85, "Section",
 CellTags->"animation"],
Cell[660395, 11989, 2029, 50, 232, "Input"],
Cell[662427, 12041, 160, 4, 31, "Input"],
Cell[662590, 12047, 19050, 447, 1552, "Input"],
Cell[681643, 12496, 3996, 121, 112, "Input"],
Cell[CellGroupData[{
Cell[685664, 12621, 296, 5, 31, "Input"],
Cell[685963, 12628, 3322017, 69811, 450, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4008029, 82445, 146, 2, 85, "Section",
 CellTags->"IP"],
Cell[CellGroupData[{
Cell[4008200, 82451, 105, 1, 36, "Subsection"],
Cell[4008308, 82454, 312, 7, 31, "Input"],
Cell[4008623, 82463, 489, 15, 31, "Input"],
Cell[4009115, 82480, 450, 13, 31, "Input"],
Cell[4009568, 82495, 556, 18, 31, "Input"],
Cell[4010127, 82515, 1123, 34, 52, "Input"],
Cell[4011253, 82551, 331, 10, 31, "Input"],
Cell[4011587, 82563, 334, 8, 52, "Input"],
Cell[4011924, 82573, 446, 12, 31, "Input"],
Cell[4012373, 82587, 503, 15, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4012913, 82607, 107, 2, 50, "Subsection",
 CellTags->"IPtests"],
Cell[CellGroupData[{
Cell[4013045, 82613, 354, 8, 31, "Input"],
Cell[4013402, 82623, 251, 4, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4013690, 82632, 354, 8, 31, "Input"],
Cell[4014047, 82642, 173, 2, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4014257, 82649, 358, 8, 31, "Input"],
Cell[4014618, 82659, 123, 2, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4014790, 82667, 150, 2, 36, "Subsection"],
Cell[4014943, 82671, 312, 7, 31, "Input"],
Cell[4015258, 82680, 529, 15, 31, "Input"],
Cell[4015790, 82697, 497, 14, 31, "Input"],
Cell[4016290, 82713, 596, 19, 31, "Input"],
Cell[4016889, 82734, 1184, 35, 52, "Input"],
Cell[4018076, 82771, 400, 11, 31, "Input"],
Cell[4018479, 82784, 357, 9, 52, "Input"],
Cell[4018839, 82795, 538, 13, 31, "Input"],
Cell[4019380, 82810, 551, 16, 31, "Input"],
Cell[4019934, 82828, 384, 9, 31, "Input"],
Cell[CellGroupData[{
Cell[4020343, 82841, 750, 14, 72, "Input"],
Cell[4021096, 82857, 214, 5, 30, "Output"],
Cell[4021313, 82864, 143, 3, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4021493, 82872, 550, 11, 72, "Input"],
Cell[4022046, 82885, 796, 26, 30, "Output"],
Cell[4022845, 82913, 145, 3, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4023027, 82921, 626, 12, 92, "Input"],
Cell[4023656, 82935, 2015, 62, 50, "Output"],
Cell[4025674, 82999, 298, 6, 30, "Output"],
Cell[4025975, 83007, 209, 3, 30, "Output"]
}, Open  ]],
Cell[4026199, 83013, 539, 13, 31, "Input"],
Cell[CellGroupData[{
Cell[4026763, 83030, 105, 2, 31, "Input"],
Cell[4026871, 83034, 1190, 17, 59, "Message"],
Cell[4028064, 83053, 805, 24, 30, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4028930, 83084, 83, 1, 85, "Section",
 CellTags->"QP"],
Cell[4029016, 83087, 380, 9, 31, "Input"],
Cell[4029399, 83098, 419, 10, 31, "Input"],
Cell[4029821, 83110, 539, 14, 31, "Input"],
Cell[4030363, 83126, 345, 8, 31, "Input"],
Cell[4030711, 83136, 425, 11, 31, "Input"],
Cell[CellGroupData[{
Cell[4031161, 83151, 114, 2, 50, "Subsection",
 CellTags->"QPtests"],
Cell[CellGroupData[{
Cell[4031300, 83157, 463, 9, 31, "Input"],
Cell[4031766, 83168, 772, 23, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4032575, 83196, 277, 6, 31, "Input"],
Cell[4032855, 83204, 121, 2, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4033025, 83212, 106, 1, 36, "Subsection"],
Cell[4033134, 83215, 151, 3, 31, "Input"],
Cell[4033288, 83220, 247, 6, 31, "Input"],
Cell[4033538, 83228, 379, 10, 31, "Input"],
Cell[CellGroupData[{
Cell[4033942, 83242, 224, 5, 31, "Input"],
Cell[4034169, 83249, 2350, 69, 50, "Output"]
}, Open  ]],
Cell[4036534, 83321, 271, 6, 31, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4036854, 83333, 95, 1, 71, "Section"],
Cell[4036952, 83336, 1861, 46, 112, "Input"],
Cell[4038816, 83384, 501, 14, 52, "Input"],
Cell[CellGroupData[{
Cell[4039342, 83402, 274, 6, 31, "Input"],
Cell[4039619, 83410, 188, 4, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4039844, 83419, 219, 5, 31, "Input"],
Cell[4040066, 83426, 148, 3, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4040251, 83434, 418, 8, 31, "Input"],
Cell[4040672, 83444, 170, 4, 30, "Output"]
}, Open  ]],
Cell[4040857, 83451, 68, 1, 31, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
